/*  Prototype JavaScript framework, version 1.7
 *  (c) 2005-2010 Sam Stephenson
 *
 *  Prototype is freely distributable under the terms of an MIT-style license.
 *  For details, see the Prototype web site: http://www.prototypejs.org/
 *
 *--------------------------------------------------------------------------*/

var Prototype = {

  Version: '1.7',

  Browser: (function(){
    var ua = navigator.userAgent;
    var isOpera = Object.prototype.toString.call(window.opera) == '[object Opera]';
    return {
      IE:             !!window.attachEvent && !isOpera,
      Opera:          isOpera,
      WebKit:         ua.indexOf('AppleWebKit/') > -1,
      Gecko:          ua.indexOf('Gecko') > -1 && ua.indexOf('KHTML') === -1,
      MobileSafari:   /Apple.*Mobile/.test(ua)
    }
  })(),

  BrowserFeatures: {
    XPath: !!document.evaluate,

    SelectorsAPI: !!document.querySelector,

    ElementExtensions: (function() {
      var constructor = window.Element || window.HTMLElement;
      return !!(constructor && constructor.prototype);
    })(),
    SpecificElementExtensions: (function() {
      if (typeof window.HTMLDivElement !== 'undefined')
        return true;

      var div = document.createElement('div'),
          form = document.createElement('form'),
          isSupported = false;

      if (div['__proto__'] && (div['__proto__'] !== form['__proto__'])) {
        isSupported = true;
      }

      div = form = null;

      return isSupported;
    })()
  },

  ScriptFragment: '<script[^>]*>([\\S\\s]*?)<\/script>',
  JSONFilter: /^\/\*-secure-([\s\S]*)\*\/\s*$/,

  emptyFunction: function() { },

  K: function(x) { return x }
};

if (Prototype.Browser.MobileSafari)
  Prototype.BrowserFeatures.SpecificElementExtensions = false;
/* Based on Alex Arnell's inheritance implementation. */

var Class = (function() {

  var IS_DONTENUM_BUGGY = (function(){
    for (var p in { toString: 1 }) {
      if (p === 'toString') return false;
    }
    return true;
  })();

  function subclass() {};
  function create() {
    var parent = null, properties = $A(arguments);
    if (Object.isFunction(properties[0]))
      parent = properties.shift();

    function klass() {
      this.initialize.apply(this, arguments);
    }

    Object.extend(klass, Class.Methods);
    klass.superclass = parent;
    klass.subclasses = [];

    if (parent) {
      subclass.prototype = parent.prototype;
      klass.prototype = new subclass;
      parent.subclasses.push(klass);
    }

    for (var i = 0, length = properties.length; i < length; i++)
      klass.addMethods(properties[i]);

    if (!klass.prototype.initialize)
      klass.prototype.initialize = Prototype.emptyFunction;

    klass.prototype.constructor = klass;
    return klass;
  }

  function addMethods(source) {
    var ancestor   = this.superclass && this.superclass.prototype,
        properties = Object.keys(source);

    if (IS_DONTENUM_BUGGY) {
      if (source.toString != Object.prototype.toString)
        properties.push("toString");
      if (source.valueOf != Object.prototype.valueOf)
        properties.push("valueOf");
    }

    for (var i = 0, length = properties.length; i < length; i++) {
      var property = properties[i], value = source[property];
      if (ancestor && Object.isFunction(value) &&
          value.argumentNames()[0] == "$super") {
        var method = value;
        value = (function(m) {
          return function() { return ancestor[m].apply(this, arguments); };
        })(property).wrap(method);

        value.valueOf = method.valueOf.bind(method);
        value.toString = method.toString.bind(method);
      }
      this.prototype[property] = value;
    }

    return this;
  }

  return {
    create: create,
    Methods: {
      addMethods: addMethods
    }
  };
})();
(function() {

  var _toString = Object.prototype.toString,
      NULL_TYPE = 'Null',
      UNDEFINED_TYPE = 'Undefined',
      BOOLEAN_TYPE = 'Boolean',
      NUMBER_TYPE = 'Number',
      STRING_TYPE = 'String',
      OBJECT_TYPE = 'Object',
      FUNCTION_CLASS = '[object Function]',
      BOOLEAN_CLASS = '[object Boolean]',
      NUMBER_CLASS = '[object Number]',
      STRING_CLASS = '[object String]',
      ARRAY_CLASS = '[object Array]',
      DATE_CLASS = '[object Date]',
      NATIVE_JSON_STRINGIFY_SUPPORT = window.JSON &&
        typeof JSON.stringify === 'function' &&
        JSON.stringify(0) === '0' &&
        typeof JSON.stringify(Prototype.K) === 'undefined';

  function Type(o) {
    switch(o) {
      case null: return NULL_TYPE;
      case (void 0): return UNDEFINED_TYPE;
    }
    var type = typeof o;
    switch(type) {
      case 'boolean': return BOOLEAN_TYPE;
      case 'number':  return NUMBER_TYPE;
      case 'string':  return STRING_TYPE;
    }
    return OBJECT_TYPE;
  }

  function extend(destination, source) {
    for (var property in source)
      destination[property] = source[property];
    return destination;
  }

  function inspect(object) {
    try {
      if (isUndefined(object)) return 'undefined';
      if (object === null) return 'null';
      return object.inspect ? object.inspect() : String(object);
    } catch (e) {
      if (e instanceof RangeError) return '...';
      throw e;
    }
  }

  function toJSON(value) {
    return Str('', { '': value }, []);
  }

  function Str(key, holder, stack) {
    var value = holder[key],
        type = typeof value;

    if (Type(value) === OBJECT_TYPE && typeof value.toJSON === 'function') {
      value = value.toJSON(key);
    }

    var _class = _toString.call(value);

    switch (_class) {
      case NUMBER_CLASS:
      case BOOLEAN_CLASS:
      case STRING_CLASS:
        value = value.valueOf();
    }

    switch (value) {
      case null: return 'null';
      case true: return 'true';
      case false: return 'false';
    }

    type = typeof value;
    switch (type) {
      case 'string':
        return value.inspect(true);
      case 'number':
        return isFinite(value) ? String(value) : 'null';
      case 'object':

        for (var i = 0, length = stack.length; i < length; i++) {
          if (stack[i] === value) { throw new TypeError(); }
        }
        stack.push(value);

        var partial = [];
        if (_class === ARRAY_CLASS) {
          for (var i = 0, length = value.length; i < length; i++) {
            var str = Str(i, value, stack);
            partial.push(typeof str === 'undefined' ? 'null' : str);
          }
          partial = '[' + partial.join(',') + ']';
        } else {
          var keys = Object.keys(value);
          for (var i = 0, length = keys.length; i < length; i++) {
            var key = keys[i], str = Str(key, value, stack);
            if (typeof str !== "undefined") {
               partial.push(key.inspect(true)+ ':' + str);
             }
          }
          partial = '{' + partial.join(',') + '}';
        }
        stack.pop();
        return partial;
    }
  }

  function stringify(object) {
    return JSON.stringify(object);
  }

  function toQueryString(object) {
    return $H(object).toQueryString();
  }

  function toHTML(object) {
    return object && object.toHTML ? object.toHTML() : String.interpret(object);
  }

  function keys(object) {
    if (Type(object) !== OBJECT_TYPE) { throw new TypeError(); }
    var results = [];
    for (var property in object) {
      if (object.hasOwnProperty(property)) {
        results.push(property);
      }
    }
    return results;
  }

  function values(object) {
    var results = [];
    for (var property in object)
      results.push(object[property]);
    return results;
  }

  function clone(object) {
    return extend({ }, object);
  }

  function isElement(object) {
    return !!(object && object.nodeType == 1);
  }

  function isArray(object) {
    return _toString.call(object) === ARRAY_CLASS;
  }

  var hasNativeIsArray = (typeof Array.isArray == 'function')
    && Array.isArray([]) && !Array.isArray({});

  if (hasNativeIsArray) {
    isArray = Array.isArray;
  }

  function isHash(object) {
    return object instanceof Hash;
  }

  function isFunction(object) {
    return _toString.call(object) === FUNCTION_CLASS;
  }

  function isString(object) {
    return _toString.call(object) === STRING_CLASS;
  }

  function isNumber(object) {
    return _toString.call(object) === NUMBER_CLASS;
  }

  function isDate(object) {
    return _toString.call(object) === DATE_CLASS;
  }

  function isUndefined(object) {
    return typeof object === "undefined";
  }

  extend(Object, {
    extend:        extend,
    inspect:       inspect,
    toJSON:        NATIVE_JSON_STRINGIFY_SUPPORT ? stringify : toJSON,
    toQueryString: toQueryString,
    toHTML:        toHTML,
    keys:          Object.keys || keys,
    values:        values,
    clone:         clone,
    isElement:     isElement,
    isArray:       isArray,
    isHash:        isHash,
    isFunction:    isFunction,
    isString:      isString,
    isNumber:      isNumber,
    isDate:        isDate,
    isUndefined:   isUndefined
  });
})();
Object.extend(Function.prototype, (function() {
  var slice = Array.prototype.slice;

  function update(array, args) {
    var arrayLength = array.length, length = args.length;
    while (length--) array[arrayLength + length] = args[length];
    return array;
  }

  function merge(array, args) {
    array = slice.call(array, 0);
    return update(array, args);
  }

  function argumentNames() {
    var names = this.toString().match(/^[\s\(]*function[^(]*\(([^)]*)\)/)[1]
      .replace(/\/\/.*?[\r\n]|\/\*(?:.|[\r\n])*?\*\//g, '')
      .replace(/\s+/g, '').split(',');
    return names.length == 1 && !names[0] ? [] : names;
  }

  function bind(context) {
    if (arguments.length < 2 && Object.isUndefined(arguments[0])) return this;
    var __method = this, args = slice.call(arguments, 1);
    return function() {
      var a = merge(args, arguments);
      return __method.apply(context, a);
    }
  }

  function bindAsEventListener(context) {
    var __method = this, args = slice.call(arguments, 1);
    return function(event) {
      var a = update([event || window.event], args);
      return __method.apply(context, a);
    }
  }

  function curry() {
    if (!arguments.length) return this;
    var __method = this, args = slice.call(arguments, 0);
    return function() {
      var a = merge(args, arguments);
      return __method.apply(this, a);
    }
  }

  function delay(timeout) {
    var __method = this, args = slice.call(arguments, 1);
    timeout = timeout * 1000;
    return window.setTimeout(function() {
      return __method.apply(__method, args);
    }, timeout);
  }

  function defer() {
    var args = update([0.01], arguments);
    return this.delay.apply(this, args);
  }

  function wrap(wrapper) {
    var __method = this;
    return function() {
      var a = update([__method.bind(this)], arguments);
      return wrapper.apply(this, a);
    }
  }

  function methodize() {
    if (this._methodized) return this._methodized;
    var __method = this;
    return this._methodized = function() {
      var a = update([this], arguments);
      return __method.apply(null, a);
    };
  }

  return {
    argumentNames:       argumentNames,
    bind:                bind,
    bindAsEventListener: bindAsEventListener,
    curry:               curry,
    delay:               delay,
    defer:               defer,
    wrap:                wrap,
    methodize:           methodize
  }
})());



(function(proto) {


  function toISOString() {
    return this.getUTCFullYear() + '-' +
      (this.getUTCMonth() + 1).toPaddedString(2) + '-' +
      this.getUTCDate().toPaddedString(2) + 'T' +
      this.getUTCHours().toPaddedString(2) + ':' +
      this.getUTCMinutes().toPaddedString(2) + ':' +
      this.getUTCSeconds().toPaddedString(2) + 'Z';
  }


  function toJSON() {
    return this.toISOString();
  }

  if (!proto.toISOString) proto.toISOString = toISOString;
  if (!proto.toJSON) proto.toJSON = toJSON;

})(Date.prototype);


RegExp.prototype.match = RegExp.prototype.test;

RegExp.escape = function(str) {
  return String(str).replace(/([.*+?^=!:${}()|[\]\/\\])/g, '\\$1');
};
var PeriodicalExecuter = Class.create({
  initialize: function(callback, frequency) {
    this.callback = callback;
    this.frequency = frequency;
    this.currentlyExecuting = false;

    this.registerCallback();
  },

  registerCallback: function() {
    this.timer = setInterval(this.onTimerEvent.bind(this), this.frequency * 1000);
  },

  execute: function() {
    this.callback(this);
  },

  stop: function() {
    if (!this.timer) return;
    clearInterval(this.timer);
    this.timer = null;
  },

  onTimerEvent: function() {
    if (!this.currentlyExecuting) {
      try {
        this.currentlyExecuting = true;
        this.execute();
        this.currentlyExecuting = false;
      } catch(e) {
        this.currentlyExecuting = false;
        throw e;
      }
    }
  }
});
Object.extend(String, {
  interpret: function(value) {
    return value == null ? '' : String(value);
  },
  specialChar: {
    '\b': '\\b',
    '\t': '\\t',
    '\n': '\\n',
    '\f': '\\f',
    '\r': '\\r',
    '\\': '\\\\'
  }
});

Object.extend(String.prototype, (function() {
  var NATIVE_JSON_PARSE_SUPPORT = window.JSON &&
    typeof JSON.parse === 'function' &&
    JSON.parse('{"test": true}').test;

  function prepareReplacement(replacement) {
    if (Object.isFunction(replacement)) return replacement;
    var template = new Template(replacement);
    return function(match) { return template.evaluate(match) };
  }

  function gsub(pattern, replacement) {
    var result = '', source = this, match;
    replacement = prepareReplacement(replacement);

    if (Object.isString(pattern))
      pattern = RegExp.escape(pattern);

    if (!(pattern.length || pattern.source)) {
      replacement = replacement('');
      return replacement + source.split('').join(replacement) + replacement;
    }

    while (source.length > 0) {
      if (match = source.match(pattern)) {
        result += source.slice(0, match.index);
        result += String.interpret(replacement(match));
        source  = source.slice(match.index + match[0].length);
      } else {
        result += source, source = '';
      }
    }
    return result;
  }

  function sub(pattern, replacement, count) {
    replacement = prepareReplacement(replacement);
    count = Object.isUndefined(count) ? 1 : count;

    return this.gsub(pattern, function(match) {
      if (--count < 0) return match[0];
      return replacement(match);
    });
  }

  function scan(pattern, iterator) {
    this.gsub(pattern, iterator);
    return String(this);
  }

  function truncate(length, truncation) {
    length = length || 30;
    truncation = Object.isUndefined(truncation) ? '...' : truncation;
    return this.length > length ?
      this.slice(0, length - truncation.length) + truncation : String(this);
  }

  function strip() {
    return this.replace(/^\s+/, '').replace(/\s+$/, '');
  }

  function stripTags() {
    return this.replace(/<\w+(\s+("[^"]*"|'[^']*'|[^>])+)?>|<\/\w+>/gi, '');
  }

  function stripScripts() {
    return this.replace(new RegExp(Prototype.ScriptFragment, 'img'), '');
  }

  function extractScripts() {
    var matchAll = new RegExp(Prototype.ScriptFragment, 'img'),
        matchOne = new RegExp(Prototype.ScriptFragment, 'im');
    return (this.match(matchAll) || []).map(function(scriptTag) {
      return (scriptTag.match(matchOne) || ['', ''])[1];
    });
  }

  function evalScripts() {
    return this.extractScripts().map(function(script) { return eval(script) });
  }

  function escapeHTML() {
    return this.replace(/&/g,'&amp;').replace(/</g,'&lt;').replace(/>/g,'&gt;');
  }

  function unescapeHTML() {
    return this.stripTags().replace(/&lt;/g,'<').replace(/&gt;/g,'>').replace(/&amp;/g,'&');
  }


  function toQueryParams(separator) {
    var match = this.strip().match(/([^?#]*)(#.*)?$/);
    if (!match) return { };

    return match[1].split(separator || '&').inject({ }, function(hash, pair) {
      if ((pair = pair.split('='))[0]) {
        var key = decodeURIComponent(pair.shift()),
            value = pair.length > 1 ? pair.join('=') : pair[0];

        if (value != undefined) value = decodeURIComponent(value);

        if (key in hash) {
          if (!Object.isArray(hash[key])) hash[key] = [hash[key]];
          hash[key].push(value);
        }
        else hash[key] = value;
      }
      return hash;
    });
  }

  function toArray() {
    return this.split('');
  }

  function succ() {
    return this.slice(0, this.length - 1) +
      String.fromCharCode(this.charCodeAt(this.length - 1) + 1);
  }

  function times(count) {
    return count < 1 ? '' : new Array(count + 1).join(this);
  }

  function camelize() {
    return this.replace(/-+(.)?/g, function(match, chr) {
      return chr ? chr.toUpperCase() : '';
    });
  }

  function capitalize() {
    return this.charAt(0).toUpperCase() + this.substring(1).toLowerCase();
  }

  function underscore() {
    return this.replace(/::/g, '/')
               .replace(/([A-Z]+)([A-Z][a-z])/g, '$1_$2')
               .replace(/([a-z\d])([A-Z])/g, '$1_$2')
               .replace(/-/g, '_')
               .toLowerCase();
  }

  function dasherize() {
    return this.replace(/_/g, '-');
  }

  function inspect(useDoubleQuotes) {
    var escapedString = this.replace(/[\x00-\x1f\\]/g, function(character) {
      if (character in String.specialChar) {
        return String.specialChar[character];
      }
      return '\\u00' + character.charCodeAt().toPaddedString(2, 16);
    });
    if (useDoubleQuotes) return '"' + escapedString.replace(/"/g, '\\"') + '"';
    return "'" + escapedString.replace(/'/g, '\\\'') + "'";
  }

  function unfilterJSON(filter) {
    return this.replace(filter || Prototype.JSONFilter, '$1');
  }

  function isJSON() {
    var str = this;
    if (str.blank()) return false;
    str = str.replace(/\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g, '@');
    str = str.replace(/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g, ']');
    str = str.replace(/(?:^|:|,)(?:\s*\[)+/g, '');
    return (/^[\],:{}\s]*$/).test(str);
  }

  function evalJSON(sanitize) {
    var json = this.unfilterJSON(),
        cx = /[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g;
    if (cx.test(json)) {
      json = json.replace(cx, function (a) {
        return '\\u' + ('0000' + a.charCodeAt(0).toString(16)).slice(-4);
      });
    }
    try {
      if (!sanitize || json.isJSON()) return eval('(' + json + ')');
    } catch (e) { }
    throw new SyntaxError('Badly formed JSON string: ' + this.inspect());
  }

  function parseJSON() {
    var json = this.unfilterJSON();
    return JSON.parse(json);
  }

  function include(pattern) {
    return this.indexOf(pattern) > -1;
  }

  function startsWith(pattern) {
    return this.lastIndexOf(pattern, 0) === 0;
  }

  function endsWith(pattern) {
    var d = this.length - pattern.length;
    return d >= 0 && this.indexOf(pattern, d) === d;
  }

  function empty() {
    return this == '';
  }

  function blank() {
    return /^\s*$/.test(this);
  }

  function interpolate(object, pattern) {
    return new Template(this, pattern).evaluate(object);
  }

  return {
    gsub:           gsub,
    sub:            sub,
    scan:           scan,
    truncate:       truncate,
    strip:          String.prototype.trim || strip,
    stripTags:      stripTags,
    stripScripts:   stripScripts,
    extractScripts: extractScripts,
    evalScripts:    evalScripts,
    escapeHTML:     escapeHTML,
    unescapeHTML:   unescapeHTML,
    toQueryParams:  toQueryParams,
    parseQuery:     toQueryParams,
    toArray:        toArray,
    succ:           succ,
    times:          times,
    camelize:       camelize,
    capitalize:     capitalize,
    underscore:     underscore,
    dasherize:      dasherize,
    inspect:        inspect,
    unfilterJSON:   unfilterJSON,
    isJSON:         isJSON,
    evalJSON:       NATIVE_JSON_PARSE_SUPPORT ? parseJSON : evalJSON,
    include:        include,
    startsWith:     startsWith,
    endsWith:       endsWith,
    empty:          empty,
    blank:          blank,
    interpolate:    interpolate
  };
})());

var Template = Class.create({
  initialize: function(template, pattern) {
    this.template = template.toString();
    this.pattern = pattern || Template.Pattern;
  },

  evaluate: function(object) {
    if (object && Object.isFunction(object.toTemplateReplacements))
      object = object.toTemplateReplacements();

    return this.template.gsub(this.pattern, function(match) {
      if (object == null) return (match[1] + '');

      var before = match[1] || '';
      if (before == '\\') return match[2];

      var ctx = object, expr = match[3],
          pattern = /^([^.[]+|\[((?:.*?[^\\])?)\])(\.|\[|$)/;

      match = pattern.exec(expr);
      if (match == null) return before;

      while (match != null) {
        var comp = match[1].startsWith('[') ? match[2].replace(/\\\\]/g, ']') : match[1];
        ctx = ctx[comp];
        if (null == ctx || '' == match[3]) break;
        expr = expr.substring('[' == match[3] ? match[1].length : match[0].length);
        match = pattern.exec(expr);
      }

      return before + String.interpret(ctx);
    });
  }
});
Template.Pattern = /(^|.|\r|\n)(#\{(.*?)\})/;

var $break = { };

var Enumerable = (function() {
  function each(iterator, context) {
    var index = 0;
    try {
      this._each(function(value) {
        iterator.call(context, value, index++);
      });
    } catch (e) {
      if (e != $break) throw e;
    }
    return this;
  }

  function eachSlice(number, iterator, context) {
    var index = -number, slices = [], array = this.toArray();
    if (number < 1) return array;
    while ((index += number) < array.length)
      slices.push(array.slice(index, index+number));
    return slices.collect(iterator, context);
  }

  function all(iterator, context) {
    iterator = iterator || Prototype.K;
    var result = true;
    this.each(function(value, index) {
      result = result && !!iterator.call(context, value, index);
      if (!result) throw $break;
    });
    return result;
  }

  function any(iterator, context) {
    iterator = iterator || Prototype.K;
    var result = false;
    this.each(function(value, index) {
      if (result = !!iterator.call(context, value, index))
        throw $break;
    });
    return result;
  }

  function collect(iterator, context) {
    iterator = iterator || Prototype.K;
    var results = [];
    this.each(function(value, index) {
      results.push(iterator.call(context, value, index));
    });
    return results;
  }

  function detect(iterator, context) {
    var result;
    this.each(function(value, index) {
      if (iterator.call(context, value, index)) {
        result = value;
        throw $break;
      }
    });
    return result;
  }

  function findAll(iterator, context) {
    var results = [];
    this.each(function(value, index) {
      if (iterator.call(context, value, index))
        results.push(value);
    });
    return results;
  }

  function grep(filter, iterator, context) {
    iterator = iterator || Prototype.K;
    var results = [];

    if (Object.isString(filter))
      filter = new RegExp(RegExp.escape(filter));

    this.each(function(value, index) {
      if (filter.match(value))
        results.push(iterator.call(context, value, index));
    });
    return results;
  }

  function include(object) {
    if (Object.isFunction(this.indexOf))
      if (this.indexOf(object) != -1) return true;

    var found = false;
    this.each(function(value) {
      if (value == object) {
        found = true;
        throw $break;
      }
    });
    return found;
  }

  function inGroupsOf(number, fillWith) {
    fillWith = Object.isUndefined(fillWith) ? null : fillWith;
    return this.eachSlice(number, function(slice) {
      while(slice.length < number) slice.push(fillWith);
      return slice;
    });
  }

  function inject(memo, iterator, context) {
    this.each(function(value, index) {
      memo = iterator.call(context, memo, value, index);
    });
    return memo;
  }

  function invoke(method) {
    var args = $A(arguments).slice(1);
    return this.map(function(value) {
      return value[method].apply(value, args);
    });
  }

  function max(iterator, context) {
    iterator = iterator || Prototype.K;
    var result;
    this.each(function(value, index) {
      value = iterator.call(context, value, index);
      if (result == null || value >= result)
        result = value;
    });
    return result;
  }

  function min(iterator, context) {
    iterator = iterator || Prototype.K;
    var result;
    this.each(function(value, index) {
      value = iterator.call(context, value, index);
      if (result == null || value < result)
        result = value;
    });
    return result;
  }

  function partition(iterator, context) {
    iterator = iterator || Prototype.K;
    var trues = [], falses = [];
    this.each(function(value, index) {
      (iterator.call(context, value, index) ?
        trues : falses).push(value);
    });
    return [trues, falses];
  }

  function pluck(property) {
    var results = [];
    this.each(function(value) {
      results.push(value[property]);
    });
    return results;
  }

  function reject(iterator, context) {
    var results = [];
    this.each(function(value, index) {
      if (!iterator.call(context, value, index))
        results.push(value);
    });
    return results;
  }

  function sortBy(iterator, context) {
    return this.map(function(value, index) {
      return {
        value: value,
        criteria: iterator.call(context, value, index)
      };
    }).sort(function(left, right) {
      var a = left.criteria, b = right.criteria;
      return a < b ? -1 : a > b ? 1 : 0;
    }).pluck('value');
  }

  function toArray() {
    return this.map();
  }

  function zip() {
    var iterator = Prototype.K, args = $A(arguments);
    if (Object.isFunction(args.last()))
      iterator = args.pop();

    var collections = [this].concat(args).map($A);
    return this.map(function(value, index) {
      return iterator(collections.pluck(index));
    });
  }

  function size() {
    return this.toArray().length;
  }

  function inspect() {
    return '#<Enumerable:' + this.toArray().inspect() + '>';
  }









  return {
    each:       each,
    eachSlice:  eachSlice,
    all:        all,
    every:      all,
    any:        any,
    some:       any,
    collect:    collect,
    map:        collect,
    detect:     detect,
    findAll:    findAll,
    select:     findAll,
    filter:     findAll,
    grep:       grep,
    include:    include,
    member:     include,
    inGroupsOf: inGroupsOf,
    inject:     inject,
    invoke:     invoke,
    max:        max,
    min:        min,
    partition:  partition,
    pluck:      pluck,
    reject:     reject,
    sortBy:     sortBy,
    toArray:    toArray,
    entries:    toArray,
    zip:        zip,
    size:       size,
    inspect:    inspect,
    find:       detect
  };
})();

function $A(iterable) {
  if (!iterable) return [];
  if ('toArray' in Object(iterable)) return iterable.toArray();
  var length = iterable.length || 0, results = new Array(length);
  while (length--) results[length] = iterable[length];
  return results;
}


function $w(string) {
  if (!Object.isString(string)) return [];
  string = string.strip();
  return string ? string.split(/\s+/) : [];
}

Array.from = $A;


(function() {
  var arrayProto = Array.prototype,
      slice = arrayProto.slice,
      _each = arrayProto.forEach; // use native browser JS 1.6 implementation if available

  function each(iterator, context) {
    for (var i = 0, length = this.length >>> 0; i < length; i++) {
      if (i in this) iterator.call(context, this[i], i, this);
    }
  }
  if (!_each) _each = each;

  function clear() {
    this.length = 0;
    return this;
  }

  function first() {
    return this[0];
  }

  function last() {
    return this[this.length - 1];
  }

  function compact() {
    return this.select(function(value) {
      return value != null;
    });
  }

  function flatten() {
    return this.inject([], function(array, value) {
      if (Object.isArray(value))
        return array.concat(value.flatten());
      array.push(value);
      return array;
    });
  }

  function without() {
    var values = slice.call(arguments, 0);
    return this.select(function(value) {
      return !values.include(value);
    });
  }

  function reverse(inline) {
    return (inline === false ? this.toArray() : this)._reverse();
  }

  function uniq(sorted) {
    return this.inject([], function(array, value, index) {
      if (0 == index || (sorted ? array.last() != value : !array.include(value)))
        array.push(value);
      return array;
    });
  }

  function intersect(array) {
    return this.uniq().findAll(function(item) {
      return array.detect(function(value) { return item === value });
    });
  }


  function clone() {
    return slice.call(this, 0);
  }

  function size() {
    return this.length;
  }

  function inspect() {
    return '[' + this.map(Object.inspect).join(', ') + ']';
  }

  function indexOf(item, i) {
    i || (i = 0);
    var length = this.length;
    if (i < 0) i = length + i;
    for (; i < length; i++)
      if (this[i] === item) return i;
    return -1;
  }

  function lastIndexOf(item, i) {
    i = isNaN(i) ? this.length : (i < 0 ? this.length + i : i) + 1;
    var n = this.slice(0, i).reverse().indexOf(item);
    return (n < 0) ? n : i - n - 1;
  }

  function concat() {
    var array = slice.call(this, 0), item;
    for (var i = 0, length = arguments.length; i < length; i++) {
      item = arguments[i];
      if (Object.isArray(item) && !('callee' in item)) {
        for (var j = 0, arrayLength = item.length; j < arrayLength; j++)
          array.push(item[j]);
      } else {
        array.push(item);
      }
    }
    return array;
  }

  Object.extend(arrayProto, Enumerable);

  if (!arrayProto._reverse)
    arrayProto._reverse = arrayProto.reverse;

  Object.extend(arrayProto, {
    _each:     _each,
    clear:     clear,
    first:     first,
    last:      last,
    compact:   compact,
    flatten:   flatten,
    without:   without,
    reverse:   reverse,
    uniq:      uniq,
    intersect: intersect,
    clone:     clone,
    toArray:   clone,
    size:      size,
    inspect:   inspect
  });

  var CONCAT_ARGUMENTS_BUGGY = (function() {
    return [].concat(arguments)[0][0] !== 1;
  })(1,2)

  if (CONCAT_ARGUMENTS_BUGGY) arrayProto.concat = concat;

  if (!arrayProto.indexOf) arrayProto.indexOf = indexOf;
  if (!arrayProto.lastIndexOf) arrayProto.lastIndexOf = lastIndexOf;
})();
function $H(object) {
  return new Hash(object);
};

var Hash = Class.create(Enumerable, (function() {
  function initialize(object) {
    this._object = Object.isHash(object) ? object.toObject() : Object.clone(object);
  }


  function _each(iterator) {
    for (var key in this._object) {
      var value = this._object[key], pair = [key, value];
      pair.key = key;
      pair.value = value;
      iterator(pair);
    }
  }

  function set(key, value) {
    return this._object[key] = value;
  }

  function get(key) {
    if (this._object[key] !== Object.prototype[key])
      return this._object[key];
  }

  function unset(key) {
    var value = this._object[key];
    delete this._object[key];
    return value;
  }

  function toObject() {
    return Object.clone(this._object);
  }



  function keys() {
    return this.pluck('key');
  }

  function values() {
    return this.pluck('value');
  }

  function index(value) {
    var match = this.detect(function(pair) {
      return pair.value === value;
    });
    return match && match.key;
  }

  function merge(object) {
    return this.clone().update(object);
  }

  function update(object) {
    return new Hash(object).inject(this, function(result, pair) {
      result.set(pair.key, pair.value);
      return result;
    });
  }

  function toQueryPair(key, value) {
    if (Object.isUndefined(value)) return key;
    return key + '=' + encodeURIComponent(String.interpret(value));
  }

  function toQueryString() {
    return this.inject([], function(results, pair) {
      var key = encodeURIComponent(pair.key), values = pair.value;

      if (values && typeof values == 'object') {
        if (Object.isArray(values)) {
          var queryValues = [];
          for (var i = 0, len = values.length, value; i < len; i++) {
            value = values[i];
            queryValues.push(toQueryPair(key, value));
          }
          return results.concat(queryValues);
        }
      } else results.push(toQueryPair(key, values));
      return results;
    }).join('&');
  }

  function inspect() {
    return '#<Hash:{' + this.map(function(pair) {
      return pair.map(Object.inspect).join(': ');
    }).join(', ') + '}>';
  }

  function clone() {
    return new Hash(this);
  }

  return {
    initialize:             initialize,
    _each:                  _each,
    set:                    set,
    get:                    get,
    unset:                  unset,
    toObject:               toObject,
    toTemplateReplacements: toObject,
    keys:                   keys,
    values:                 values,
    index:                  index,
    merge:                  merge,
    update:                 update,
    toQueryString:          toQueryString,
    inspect:                inspect,
    toJSON:                 toObject,
    clone:                  clone
  };
})());

Hash.from = $H;
Object.extend(Number.prototype, (function() {
  function toColorPart() {
    return this.toPaddedString(2, 16);
  }

  function succ() {
    return this + 1;
  }

  function times(iterator, context) {
    $R(0, this, true).each(iterator, context);
    return this;
  }

  function toPaddedString(length, radix) {
    var string = this.toString(radix || 10);
    return '0'.times(length - string.length) + string;
  }

  function abs() {
    return Math.abs(this);
  }

  function round() {
    return Math.round(this);
  }

  function ceil() {
    return Math.ceil(this);
  }

  function floor() {
    return Math.floor(this);
  }

  return {
    toColorPart:    toColorPart,
    succ:           succ,
    times:          times,
    toPaddedString: toPaddedString,
    abs:            abs,
    round:          round,
    ceil:           ceil,
    floor:          floor
  };
})());

function $R(start, end, exclusive) {
  return new ObjectRange(start, end, exclusive);
}

var ObjectRange = Class.create(Enumerable, (function() {
  function initialize(start, end, exclusive) {
    this.start = start;
    this.end = end;
    this.exclusive = exclusive;
  }

  function _each(iterator) {
    var value = this.start;
    while (this.include(value)) {
      iterator(value);
      value = value.succ();
    }
  }

  function include(value) {
    if (value < this.start)
      return false;
    if (this.exclusive)
      return value < this.end;
    return value <= this.end;
  }

  return {
    initialize: initialize,
    _each:      _each,
    include:    include
  };
})());



var Abstract = { };


var Try = {
  these: function() {
    var returnValue;

    for (var i = 0, length = arguments.length; i < length; i++) {
      var lambda = arguments[i];
      try {
        returnValue = lambda();
        break;
      } catch (e) { }
    }

    return returnValue;
  }
};

var Ajax = {
  getTransport: function() {
    return Try.these(
      function() {return new XMLHttpRequest()},
      function() {return new ActiveXObject('Msxml2.XMLHTTP')},
      function() {return new ActiveXObject('Microsoft.XMLHTTP')}
    ) || false;
  },

  activeRequestCount: 0
};

Ajax.Responders = {
  responders: [],

  _each: function(iterator) {
    this.responders._each(iterator);
  },

  register: function(responder) {
    if (!this.include(responder))
      this.responders.push(responder);
  },

  unregister: function(responder) {
    this.responders = this.responders.without(responder);
  },

  dispatch: function(callback, request, transport, json) {
    this.each(function(responder) {
      if (Object.isFunction(responder[callback])) {
        try {
          responder[callback].apply(responder, [request, transport, json]);
        } catch (e) { }
      }
    });
  }
};

Object.extend(Ajax.Responders, Enumerable);

Ajax.Responders.register({
  onCreate:   function() { Ajax.activeRequestCount++ },
  onComplete: function() { Ajax.activeRequestCount-- }
});
Ajax.Base = Class.create({
  initialize: function(options) {
    this.options = {
      method:       'post',
      asynchronous: true,
      contentType:  'application/x-www-form-urlencoded',
      encoding:     'UTF-8',
      parameters:   '',
      evalJSON:     true,
      evalJS:       true
    };
    Object.extend(this.options, options || { });

    this.options.method = this.options.method.toLowerCase();

    if (Object.isHash(this.options.parameters))
      this.options.parameters = this.options.parameters.toObject();
  }
});
Ajax.Request = Class.create(Ajax.Base, {
  _complete: false,

  initialize: function($super, url, options) {
    $super(options);
    this.transport = Ajax.getTransport();
    this.request(url);
  },

  request: function(url) {
    this.url = url;
    this.method = this.options.method;
    var params = Object.isString(this.options.parameters) ?
          this.options.parameters :
          Object.toQueryString(this.options.parameters);

    if (!['get', 'post'].include(this.method)) {
      params += (params ? '&' : '') + "_method=" + this.method;
      this.method = 'post';
    }

    if (params && this.method === 'get') {
      this.url += (this.url.include('?') ? '&' : '?') + params;
    }

    this.parameters = params.toQueryParams();

    try {
      var response = new Ajax.Response(this);
      if (this.options.onCreate) this.options.onCreate(response);
      Ajax.Responders.dispatch('onCreate', this, response);

      this.transport.open(this.method.toUpperCase(), this.url,
        this.options.asynchronous);

      if (this.options.asynchronous) this.respondToReadyState.bind(this).defer(1);

      this.transport.onreadystatechange = this.onStateChange.bind(this);
      this.setRequestHeaders();

      this.body = this.method == 'post' ? (this.options.postBody || params) : null;
      this.transport.send(this.body);

      /* Force Firefox to handle ready state 4 for synchronous requests */
      if (!this.options.asynchronous && this.transport.overrideMimeType)
        this.onStateChange();

    }
    catch (e) {
      this.dispatchException(e);
    }
  },

  onStateChange: function() {
    var readyState = this.transport.readyState;
    if (readyState > 1 && !((readyState == 4) && this._complete))
      this.respondToReadyState(this.transport.readyState);
  },

  setRequestHeaders: function() {
    var headers = {
      'X-Requested-With': 'XMLHttpRequest',
      'X-Prototype-Version': Prototype.Version,
      'Accept': 'text/javascript, text/html, application/xml, text/xml, */*'
    };

    if (this.method == 'post') {
      headers['Content-type'] = this.options.contentType +
        (this.options.encoding ? '; charset=' + this.options.encoding : '');

      /* Force "Connection: close" for older Mozilla browsers to work
       * around a bug where XMLHttpRequest sends an incorrect
       * Content-length header. See Mozilla Bugzilla #246651.
       */
      if (this.transport.overrideMimeType &&
          (navigator.userAgent.match(/Gecko\/(\d{4})/) || [0,2005])[1] < 2005)
            headers['Connection'] = 'close';
    }

    if (typeof this.options.requestHeaders == 'object') {
      var extras = this.options.requestHeaders;

      if (Object.isFunction(extras.push))
        for (var i = 0, length = extras.length; i < length; i += 2)
          headers[extras[i]] = extras[i+1];
      else
        $H(extras).each(function(pair) { headers[pair.key] = pair.value });
    }

    for (var name in headers)
      this.transport.setRequestHeader(name, headers[name]);
  },

  success: function() {
    var status = this.getStatus();
    return !status || (status >= 200 && status < 300) || status == 304;
  },

  getStatus: function() {
    try {
      if (this.transport.status === 1223) return 204;
      return this.transport.status || 0;
    } catch (e) { return 0 }
  },

  respondToReadyState: function(readyState) {
    var state = Ajax.Request.Events[readyState], response = new Ajax.Response(this);

    if (state == 'Complete') {
      try {
        this._complete = true;
        (this.options['on' + response.status]
         || this.options['on' + (this.success() ? 'Success' : 'Failure')]
         || Prototype.emptyFunction)(response, response.headerJSON);
      } catch (e) {
        this.dispatchException(e);
      }

      var contentType = response.getHeader('Content-type');
      if (this.options.evalJS == 'force'
          || (this.options.evalJS && this.isSameOrigin() && contentType
          && contentType.match(/^\s*(text|application)\/(x-)?(java|ecma)script(;.*)?\s*$/i)))
        this.evalResponse();
    }

    try {
      (this.options['on' + state] || Prototype.emptyFunction)(response, response.headerJSON);
      Ajax.Responders.dispatch('on' + state, this, response, response.headerJSON);
    } catch (e) {
      this.dispatchException(e);
    }

    if (state == 'Complete') {
      this.transport.onreadystatechange = Prototype.emptyFunction;
    }
  },

  isSameOrigin: function() {
    var m = this.url.match(/^\s*https?:\/\/[^\/]*/);
    return !m || (m[0] == '#{protocol}//#{domain}#{port}'.interpolate({
      protocol: location.protocol,
      domain: document.domain,
      port: location.port ? ':' + location.port : ''
    }));
  },

  getHeader: function(name) {
    try {
      return this.transport.getResponseHeader(name) || null;
    } catch (e) { return null; }
  },

  evalResponse: function() {
    try {
      return eval((this.transport.responseText || '').unfilterJSON());
    } catch (e) {
      this.dispatchException(e);
    }
  },

  dispatchException: function(exception) {
    (this.options.onException || Prototype.emptyFunction)(this, exception);
    Ajax.Responders.dispatch('onException', this, exception);
  }
});

Ajax.Request.Events =
  ['Uninitialized', 'Loading', 'Loaded', 'Interactive', 'Complete'];








Ajax.Response = Class.create({
  initialize: function(request){
    this.request = request;
    var transport  = this.transport  = request.transport,
        readyState = this.readyState = transport.readyState;

    if ((readyState > 2 && !Prototype.Browser.IE) || readyState == 4) {
      this.status       = this.getStatus();
      this.statusText   = this.getStatusText();
      this.responseText = String.interpret(transport.responseText);
      this.headerJSON   = this._getHeaderJSON();
    }

    if (readyState == 4) {
      var xml = transport.responseXML;
      this.responseXML  = Object.isUndefined(xml) ? null : xml;
      this.responseJSON = this._getResponseJSON();
    }
  },

  status:      0,

  statusText: '',

  getStatus: Ajax.Request.prototype.getStatus,

  getStatusText: function() {
    try {
      return this.transport.statusText || '';
    } catch (e) { return '' }
  },

  getHeader: Ajax.Request.prototype.getHeader,

  getAllHeaders: function() {
    try {
      return this.getAllResponseHeaders();
    } catch (e) { return null }
  },

  getResponseHeader: function(name) {
    return this.transport.getResponseHeader(name);
  },

  getAllResponseHeaders: function() {
    return this.transport.getAllResponseHeaders();
  },

  _getHeaderJSON: function() {
    var json = this.getHeader('X-JSON');
    if (!json) return null;
    json = decodeURIComponent(escape(json));
    try {
      return json.evalJSON(this.request.options.sanitizeJSON ||
        !this.request.isSameOrigin());
    } catch (e) {
      this.request.dispatchException(e);
    }
  },

  _getResponseJSON: function() {
    var options = this.request.options;
    if (!options.evalJSON || (options.evalJSON != 'force' &&
      !(this.getHeader('Content-type') || '').include('application/json')) ||
        this.responseText.blank())
          return null;
    try {
      return this.responseText.evalJSON(options.sanitizeJSON ||
        !this.request.isSameOrigin());
    } catch (e) {
      this.request.dispatchException(e);
    }
  }
});

Ajax.Updater = Class.create(Ajax.Request, {
  initialize: function($super, container, url, options) {
    this.container = {
      success: (container.success || container),
      failure: (container.failure || (container.success ? null : container))
    };

    options = Object.clone(options);
    var onComplete = options.onComplete;
    options.onComplete = (function(response, json) {
      this.updateContent(response.responseText);
      if (Object.isFunction(onComplete)) onComplete(response, json);
    }).bind(this);

    $super(url, options);
  },

  updateContent: function(responseText) {
    var receiver = this.container[this.success() ? 'success' : 'failure'],
        options = this.options;

    if (!options.evalScripts) responseText = responseText.stripScripts();

    if (receiver = $(receiver)) {
      if (options.insertion) {
        if (Object.isString(options.insertion)) {
          var insertion = { }; insertion[options.insertion] = responseText;
          receiver.insert(insertion);
        }
        else options.insertion(receiver, responseText);
      }
      else receiver.update(responseText);
    }
  }
});

Ajax.PeriodicalUpdater = Class.create(Ajax.Base, {
  initialize: function($super, container, url, options) {
    $super(options);
    this.onComplete = this.options.onComplete;

    this.frequency = (this.options.frequency || 2);
    this.decay = (this.options.decay || 1);

    this.updater = { };
    this.container = container;
    this.url = url;

    this.start();
  },

  start: function() {
    this.options.onComplete = this.updateComplete.bind(this);
    this.onTimerEvent();
  },

  stop: function() {
    this.updater.options.onComplete = undefined;
    clearTimeout(this.timer);
    (this.onComplete || Prototype.emptyFunction).apply(this, arguments);
  },

  updateComplete: function(response) {
    if (this.options.decay) {
      this.decay = (response.responseText == this.lastText ?
        this.decay * this.options.decay : 1);

      this.lastText = response.responseText;
    }
    this.timer = this.onTimerEvent.bind(this).delay(this.decay * this.frequency);
  },

  onTimerEvent: function() {
    this.updater = new Ajax.Updater(this.container, this.url, this.options);
  }
});


function $(element) {
  if (arguments.length > 1) {
    for (var i = 0, elements = [], length = arguments.length; i < length; i++)
      elements.push($(arguments[i]));
    return elements;
  }
  if (Object.isString(element))
    element = document.getElementById(element);
  return Element.extend(element);
}

if (Prototype.BrowserFeatures.XPath) {
  document._getElementsByXPath = function(expression, parentElement) {
    var results = [];
    var query = document.evaluate(expression, $(parentElement) || document,
      null, XPathResult.ORDERED_NODE_SNAPSHOT_TYPE, null);
    for (var i = 0, length = query.snapshotLength; i < length; i++)
      results.push(Element.extend(query.snapshotItem(i)));
    return results;
  };
}

/*--------------------------------------------------------------------------*/

if (!Node) var Node = { };

if (!Node.ELEMENT_NODE) {
  Object.extend(Node, {
    ELEMENT_NODE: 1,
    ATTRIBUTE_NODE: 2,
    TEXT_NODE: 3,
    CDATA_SECTION_NODE: 4,
    ENTITY_REFERENCE_NODE: 5,
    ENTITY_NODE: 6,
    PROCESSING_INSTRUCTION_NODE: 7,
    COMMENT_NODE: 8,
    DOCUMENT_NODE: 9,
    DOCUMENT_TYPE_NODE: 10,
    DOCUMENT_FRAGMENT_NODE: 11,
    NOTATION_NODE: 12
  });
}



(function(global) {
  function shouldUseCache(tagName, attributes) {
    if (tagName === 'select') return false;
    if ('type' in attributes) return false;
    return true;
  }

  var HAS_EXTENDED_CREATE_ELEMENT_SYNTAX = (function(){
    try {
      var el = document.createElement('<input name="x">');
      return el.tagName.toLowerCase() === 'input' && el.name === 'x';
    }
    catch(err) {
      return false;
    }
  })();

  var element = global.Element;

  global.Element = function(tagName, attributes) {
    attributes = attributes || { };
    tagName = tagName.toLowerCase();
    var cache = Element.cache;

    if (HAS_EXTENDED_CREATE_ELEMENT_SYNTAX && attributes.name) {
      tagName = '<' + tagName + ' name="' + attributes.name + '">';
      delete attributes.name;
      return Element.writeAttribute(document.createElement(tagName), attributes);
    }

    if (!cache[tagName]) cache[tagName] = Element.extend(document.createElement(tagName));

    var node = shouldUseCache(tagName, attributes) ?
     cache[tagName].cloneNode(false) : document.createElement(tagName);

    return Element.writeAttribute(node, attributes);
  };

  Object.extend(global.Element, element || { });
  if (element) global.Element.prototype = element.prototype;

})(this);

Element.idCounter = 1;
Element.cache = { };

Element._purgeElement = function(element) {
  var uid = element._prototypeUID;
  if (uid) {
    Element.stopObserving(element);
    element._prototypeUID = void 0;
    delete Element.Storage[uid];
  }
}

Element.Methods = {
  visible: function(element) {
    return $(element).style.display != 'none';
  },

  toggle: function(element) {
    element = $(element);
    Element[Element.visible(element) ? 'hide' : 'show'](element);
    return element;
  },

  hide: function(element) {
    element = $(element);
    element.style.display = 'none';
    return element;
  },

  show: function(element) {
    element = $(element);
    element.style.display = '';
    return element;
  },

  remove: function(element) {
    element = $(element);
    element.parentNode.removeChild(element);
    return element;
  },

  update: (function(){

    var SELECT_ELEMENT_INNERHTML_BUGGY = (function(){
      var el = document.createElement("select"),
          isBuggy = true;
      el.innerHTML = "<option value=\"test\">test</option>";
      if (el.options && el.options[0]) {
        isBuggy = el.options[0].nodeName.toUpperCase() !== "OPTION";
      }
      el = null;
      return isBuggy;
    })();

    var TABLE_ELEMENT_INNERHTML_BUGGY = (function(){
      try {
        var el = document.createElement("table");
        if (el && el.tBodies) {
          el.innerHTML = "<tbody><tr><td>test</td></tr></tbody>";
          var isBuggy = typeof el.tBodies[0] == "undefined";
          el = null;
          return isBuggy;
        }
      } catch (e) {
        return true;
      }
    })();

    var LINK_ELEMENT_INNERHTML_BUGGY = (function() {
      try {
        var el = document.createElement('div');
        el.innerHTML = "<link>";
        var isBuggy = (el.childNodes.length === 0);
        el = null;
        return isBuggy;
      } catch(e) {
        return true;
      }
    })();

    var ANY_INNERHTML_BUGGY = SELECT_ELEMENT_INNERHTML_BUGGY ||
     TABLE_ELEMENT_INNERHTML_BUGGY || LINK_ELEMENT_INNERHTML_BUGGY;

    var SCRIPT_ELEMENT_REJECTS_TEXTNODE_APPENDING = (function () {
      var s = document.createElement("script"),
          isBuggy = false;
      try {
        s.appendChild(document.createTextNode(""));
        isBuggy = !s.firstChild ||
          s.firstChild && s.firstChild.nodeType !== 3;
      } catch (e) {
        isBuggy = true;
      }
      s = null;
      return isBuggy;
    })();


    function update(element, content) {
      element = $(element);
      var purgeElement = Element._purgeElement;

      var descendants = element.getElementsByTagName('*'),
       i = descendants.length;
      while (i--) purgeElement(descendants[i]);

      if (content && content.toElement)
        content = content.toElement();

      if (Object.isElement(content))
        return element.update().insert(content);

      content = Object.toHTML(content);

      var tagName = element.tagName.toUpperCase();

      if (tagName === 'SCRIPT' && SCRIPT_ELEMENT_REJECTS_TEXTNODE_APPENDING) {
        element.text = content;
        return element;
      }

      if (ANY_INNERHTML_BUGGY) {
        if (tagName in Element._insertionTranslations.tags) {
          while (element.firstChild) {
            element.removeChild(element.firstChild);
          }
          Element._getContentFromAnonymousElement(tagName, content.stripScripts())
            .each(function(node) {
              element.appendChild(node)
            });
        } else if (LINK_ELEMENT_INNERHTML_BUGGY && Object.isString(content) && content.indexOf('<link') > -1) {
          while (element.firstChild) {
            element.removeChild(element.firstChild);
          }
          var nodes = Element._getContentFromAnonymousElement(tagName, content.stripScripts(), true);
          nodes.each(function(node) { element.appendChild(node) });
        }
        else {
          element.innerHTML = content.stripScripts();
        }
      }
      else {
        element.innerHTML = content.stripScripts();
      }

      content.evalScripts.bind(content).defer();
      return element;
    }

    return update;
  })(),

  replace: function(element, content) {
    element = $(element);
    if (content && content.toElement) content = content.toElement();
    else if (!Object.isElement(content)) {
      content = Object.toHTML(content);
      var range = element.ownerDocument.createRange();
      range.selectNode(element);
      content.evalScripts.bind(content).defer();
      content = range.createContextualFragment(content.stripScripts());
    }
    element.parentNode.replaceChild(content, element);
    return element;
  },

  insert: function(element, insertions) {
    element = $(element);

    if (Object.isString(insertions) || Object.isNumber(insertions) ||
        Object.isElement(insertions) || (insertions && (insertions.toElement || insertions.toHTML)))
          insertions = {bottom:insertions};

    var content, insert, tagName, childNodes;

    for (var position in insertions) {
      content  = insertions[position];
      position = position.toLowerCase();
      insert = Element._insertionTranslations[position];

      if (content && content.toElement) content = content.toElement();
      if (Object.isElement(content)) {
        insert(element, content);
        continue;
      }

      content = Object.toHTML(content);

      tagName = ((position == 'before' || position == 'after')
        ? element.parentNode : element).tagName.toUpperCase();

      childNodes = Element._getContentFromAnonymousElement(tagName, content.stripScripts());

      if (position == 'top' || position == 'after') childNodes.reverse();
      childNodes.each(insert.curry(element));

      content.evalScripts.bind(content).defer();
    }

    return element;
  },

  wrap: function(element, wrapper, attributes) {
    element = $(element);
    if (Object.isElement(wrapper))
      $(wrapper).writeAttribute(attributes || { });
    else if (Object.isString(wrapper)) wrapper = new Element(wrapper, attributes);
    else wrapper = new Element('div', wrapper);
    if (element.parentNode)
      element.parentNode.replaceChild(wrapper, element);
    wrapper.appendChild(element);
    return wrapper;
  },

  inspect: function(element) {
    element = $(element);
    var result = '<' + element.tagName.toLowerCase();
    $H({'id': 'id', 'className': 'class'}).each(function(pair) {
      var property = pair.first(),
          attribute = pair.last(),
          value = (element[property] || '').toString();
      if (value) result += ' ' + attribute + '=' + value.inspect(true);
    });
    return result + '>';
  },

  recursivelyCollect: function(element, property, maximumLength) {
    element = $(element);
    maximumLength = maximumLength || -1;
    var elements = [];

    while (element = element[property]) {
      if (element.nodeType == 1)
        elements.push(Element.extend(element));
      if (elements.length == maximumLength)
        break;
    }

    return elements;
  },

  ancestors: function(element) {
    return Element.recursivelyCollect(element, 'parentNode');
  },

  descendants: function(element) {
    return Element.select(element, "*");
  },

  firstDescendant: function(element) {
    element = $(element).firstChild;
    while (element && element.nodeType != 1) element = element.nextSibling;
    return $(element);
  },

  immediateDescendants: function(element) {
    var results = [], child = $(element).firstChild;
    while (child) {
      if (child.nodeType === 1) {
        results.push(Element.extend(child));
      }
      child = child.nextSibling;
    }
    return results;
  },

  previousSiblings: function(element, maximumLength) {
    return Element.recursivelyCollect(element, 'previousSibling');
  },

  nextSiblings: function(element) {
    return Element.recursivelyCollect(element, 'nextSibling');
  },

  siblings: function(element) {
    element = $(element);
    return Element.previousSiblings(element).reverse()
      .concat(Element.nextSiblings(element));
  },

  match: function(element, selector) {
    element = $(element);
    if (Object.isString(selector))
      return Prototype.Selector.match(element, selector);
    return selector.match(element);
  },

  up: function(element, expression, index) {
    element = $(element);
    if (arguments.length == 1) return $(element.parentNode);
    var ancestors = Element.ancestors(element);
    return Object.isNumber(expression) ? ancestors[expression] :
      Prototype.Selector.find(ancestors, expression, index);
  },

  down: function(element, expression, index) {
    element = $(element);
    if (arguments.length == 1) return Element.firstDescendant(element);
    return Object.isNumber(expression) ? Element.descendants(element)[expression] :
      Element.select(element, expression)[index || 0];
  },

  previous: function(element, expression, index) {
    element = $(element);
    if (Object.isNumber(expression)) index = expression, expression = false;
    if (!Object.isNumber(index)) index = 0;

    if (expression) {
      return Prototype.Selector.find(element.previousSiblings(), expression, index);
    } else {
      return element.recursivelyCollect("previousSibling", index + 1)[index];
    }
  },

  next: function(element, expression, index) {
    element = $(element);
    if (Object.isNumber(expression)) index = expression, expression = false;
    if (!Object.isNumber(index)) index = 0;

    if (expression) {
      return Prototype.Selector.find(element.nextSiblings(), expression, index);
    } else {
      var maximumLength = Object.isNumber(index) ? index + 1 : 1;
      return element.recursivelyCollect("nextSibling", index + 1)[index];
    }
  },


  select: function(element) {
    element = $(element);
    var expressions = Array.prototype.slice.call(arguments, 1).join(', ');
    return Prototype.Selector.select(expressions, element);
  },

  adjacent: function(element) {
    element = $(element);
    var expressions = Array.prototype.slice.call(arguments, 1).join(', ');
    return Prototype.Selector.select(expressions, element.parentNode).without(element);
  },

  identify: function(element) {
    element = $(element);
    var id = Element.readAttribute(element, 'id');
    if (id) return id;
    do { id = 'anonymous_element_' + Element.idCounter++ } while ($(id));
    Element.writeAttribute(element, 'id', id);
    return id;
  },

  readAttribute: function(element, name) {
    element = $(element);
    if (Prototype.Browser.IE) {
      var t = Element._attributeTranslations.read;
      if (t.values[name]) return t.values[name](element, name);
      if (t.names[name]) name = t.names[name];
      if (name.include(':')) {
        return (!element.attributes || !element.attributes[name]) ? null :
         element.attributes[name].value;
      }
    }
    return element.getAttribute(name);
  },

  writeAttribute: function(element, name, value) {
    element = $(element);
    var attributes = { }, t = Element._attributeTranslations.write;

    if (typeof name == 'object') attributes = name;
    else attributes[name] = Object.isUndefined(value) ? true : value;

    for (var attr in attributes) {
      name = t.names[attr] || attr;
      value = attributes[attr];
      if (t.values[attr]) name = t.values[attr](element, value);
      if (value === false || value === null)
        element.removeAttribute(name);
      else if (value === true)
        element.setAttribute(name, name);
      else element.setAttribute(name, value);
    }
    return element;
  },

  getHeight: function(element) {
    return Element.getDimensions(element).height;
  },

  getWidth: function(element) {
    return Element.getDimensions(element).width;
  },

  classNames: function(element) {
    return new Element.ClassNames(element);
  },

  hasClassName: function(element, className) {
    if (!(element = $(element))) return;
    var elementClassName = element.className;
    return (elementClassName.length > 0 && (elementClassName == className ||
      new RegExp("(^|\\s)" + className + "(\\s|$)").test(elementClassName)));
  },

  addClassName: function(element, className) {
    if (!(element = $(element))) return;
    if (!Element.hasClassName(element, className))
      element.className += (element.className ? ' ' : '') + className;
    return element;
  },

  removeClassName: function(element, className) {
    if (!(element = $(element))) return;
    element.className = element.className.replace(
      new RegExp("(^|\\s+)" + className + "(\\s+|$)"), ' ').strip();
    return element;
  },

  toggleClassName: function(element, className) {
    if (!(element = $(element))) return;
    return Element[Element.hasClassName(element, className) ?
      'removeClassName' : 'addClassName'](element, className);
  },

  cleanWhitespace: function(element) {
    element = $(element);
    var node = element.firstChild;
    while (node) {
      var nextNode = node.nextSibling;
      if (node.nodeType == 3 && !/\S/.test(node.nodeValue))
        element.removeChild(node);
      node = nextNode;
    }
    return element;
  },

  empty: function(element) {
    return $(element).innerHTML.blank();
  },

  descendantOf: function(element, ancestor) {
    element = $(element), ancestor = $(ancestor);

    if (element.compareDocumentPosition)
      return (element.compareDocumentPosition(ancestor) & 8) === 8;

    if (ancestor.contains)
      return ancestor.contains(element) && ancestor !== element;

    while (element = element.parentNode)
      if (element == ancestor) return true;

    return false;
  },

  scrollTo: function(element) {
    element = $(element);
    var pos = Element.cumulativeOffset(element);
    window.scrollTo(pos[0], pos[1]);
    return element;
  },

  getStyle: function(element, style) {
    element = $(element);
    style = style == 'float' ? 'cssFloat' : style.camelize();
    var value = element.style[style];
    if (!value || value == 'auto') {
      var css = document.defaultView.getComputedStyle(element, null);
      value = css ? css[style] : null;
    }
    if (style == 'opacity') return value ? parseFloat(value) : 1.0;
    return value == 'auto' ? null : value;
  },

  getOpacity: function(element) {
    return $(element).getStyle('opacity');
  },

  setStyle: function(element, styles) {
    element = $(element);
    var elementStyle = element.style, match;
    if (Object.isString(styles)) {
      element.style.cssText += ';' + styles;
      return styles.include('opacity') ?
        element.setOpacity(styles.match(/opacity:\s*(\d?\.?\d*)/)[1]) : element;
    }
    for (var property in styles)
      if (property == 'opacity') element.setOpacity(styles[property]);
      else
        elementStyle[(property == 'float' || property == 'cssFloat') ?
          (Object.isUndefined(elementStyle.styleFloat) ? 'cssFloat' : 'styleFloat') :
            property] = styles[property];

    return element;
  },

  setOpacity: function(element, value) {
    element = $(element);
    element.style.opacity = (value == 1 || value === '') ? '' :
      (value < 0.00001) ? 0 : value;
    return element;
  },

  makePositioned: function(element) {
    element = $(element);
    var pos = Element.getStyle(element, 'position');
    if (pos == 'static' || !pos) {
      element._madePositioned = true;
      element.style.position = 'relative';
      if (Prototype.Browser.Opera) {
        element.style.top = 0;
        element.style.left = 0;
      }
    }
    return element;
  },

  undoPositioned: function(element) {
    element = $(element);
    if (element._madePositioned) {
      element._madePositioned = undefined;
      element.style.position =
        element.style.top =
        element.style.left =
        element.style.bottom =
        element.style.right = '';
    }
    return element;
  },

  makeClipping: function(element) {
    element = $(element);
    if (element._overflow) return element;
    element._overflow = Element.getStyle(element, 'overflow') || 'auto';
    if (element._overflow !== 'hidden')
      element.style.overflow = 'hidden';
    return element;
  },

  undoClipping: function(element) {
    element = $(element);
    if (!element._overflow) return element;
    element.style.overflow = element._overflow == 'auto' ? '' : element._overflow;
    element._overflow = null;
    return element;
  },

  clonePosition: function(element, source) {
    var options = Object.extend({
      setLeft:    true,
      setTop:     true,
      setWidth:   true,
      setHeight:  true,
      offsetTop:  0,
      offsetLeft: 0
    }, arguments[2] || { });

    source = $(source);
    var p = Element.viewportOffset(source), delta = [0, 0], parent = null;

    element = $(element);

    if (Element.getStyle(element, 'position') == 'absolute') {
      parent = Element.getOffsetParent(element);
      delta = Element.viewportOffset(parent);
    }

    if (parent == document.body) {
      delta[0] -= document.body.offsetLeft;
      delta[1] -= document.body.offsetTop;
    }

    if (options.setLeft)   element.style.left  = (p[0] - delta[0] + options.offsetLeft) + 'px';
    if (options.setTop)    element.style.top   = (p[1] - delta[1] + options.offsetTop) + 'px';
    if (options.setWidth)  element.style.width = source.offsetWidth + 'px';
    if (options.setHeight) element.style.height = source.offsetHeight + 'px';
    return element;
  }
};

Object.extend(Element.Methods, {
  getElementsBySelector: Element.Methods.select,

  childElements: Element.Methods.immediateDescendants
});

Element._attributeTranslations = {
  write: {
    names: {
      className: 'class',
      htmlFor:   'for'
    },
    values: { }
  }
};

if (Prototype.Browser.Opera) {
  Element.Methods.getStyle = Element.Methods.getStyle.wrap(
    function(proceed, element, style) {
      switch (style) {
        case 'height': case 'width':
          if (!Element.visible(element)) return null;

          var dim = parseInt(proceed(element, style), 10);

          if (dim !== element['offset' + style.capitalize()])
            return dim + 'px';

          var properties;
          if (style === 'height') {
            properties = ['border-top-width', 'padding-top',
             'padding-bottom', 'border-bottom-width'];
          }
          else {
            properties = ['border-left-width', 'padding-left',
             'padding-right', 'border-right-width'];
          }
          return properties.inject(dim, function(memo, property) {
            var val = proceed(element, property);
            return val === null ? memo : memo - parseInt(val, 10);
          }) + 'px';
        default: return proceed(element, style);
      }
    }
  );

  Element.Methods.readAttribute = Element.Methods.readAttribute.wrap(
    function(proceed, element, attribute) {
      if (attribute === 'title') return element.title;
      return proceed(element, attribute);
    }
  );
}

else if (Prototype.Browser.IE) {
  Element.Methods.getStyle = function(element, style) {
    element = $(element);
    style = (style == 'float' || style == 'cssFloat') ? 'styleFloat' : style.camelize();
    var value = element.style[style];
    if (!value && element.currentStyle) value = element.currentStyle[style];

    if (style == 'opacity') {
      if (value = (element.getStyle('filter') || '').match(/alpha\(opacity=(.*)\)/))
        if (value[1]) return parseFloat(value[1]) / 100;
      return 1.0;
    }

    if (value == 'auto') {
      if ((style == 'width' || style == 'height') && (element.getStyle('display') != 'none'))
        return element['offset' + style.capitalize()] + 'px';
      return null;
    }
    return value;
  };

  Element.Methods.setOpacity = function(element, value) {
    function stripAlpha(filter){
      return filter.replace(/alpha\([^\)]*\)/gi,'');
    }
    element = $(element);
    var currentStyle = element.currentStyle;
    if ((currentStyle && !currentStyle.hasLayout) ||
      (!currentStyle && element.style.zoom == 'normal'))
        element.style.zoom = 1;

    var filter = element.getStyle('filter'), style = element.style;
    if (value == 1 || value === '') {
      (filter = stripAlpha(filter)) ?
        style.filter = filter : style.removeAttribute('filter');
      return element;
    } else if (value < 0.00001) value = 0;
    style.filter = stripAlpha(filter) +
      'alpha(opacity=' + (value * 100) + ')';
    return element;
  };

  Element._attributeTranslations = (function(){

    var classProp = 'className',
        forProp = 'for',
        el = document.createElement('div');

    el.setAttribute(classProp, 'x');

    if (el.className !== 'x') {
      el.setAttribute('class', 'x');
      if (el.className === 'x') {
        classProp = 'class';
      }
    }
    el = null;

    el = document.createElement('label');
    el.setAttribute(forProp, 'x');
    if (el.htmlFor !== 'x') {
      el.setAttribute('htmlFor', 'x');
      if (el.htmlFor === 'x') {
        forProp = 'htmlFor';
      }
    }
    el = null;

    return {
      read: {
        names: {
          'class':      classProp,
          'className':  classProp,
          'for':        forProp,
          'htmlFor':    forProp
        },
        values: {
          _getAttr: function(element, attribute) {
            return element.getAttribute(attribute);
          },
          _getAttr2: function(element, attribute) {
            return element.getAttribute(attribute, 2);
          },
          _getAttrNode: function(element, attribute) {
            var node = element.getAttributeNode(attribute);
            return node ? node.value : "";
          },
          _getEv: (function(){

            var el = document.createElement('div'), f;
            el.onclick = Prototype.emptyFunction;
            var value = el.getAttribute('onclick');

            if (String(value).indexOf('{') > -1) {
              f = function(element, attribute) {
                attribute = element.getAttribute(attribute);
                if (!attribute) return null;
                attribute = attribute.toString();
                attribute = attribute.split('{')[1];
                attribute = attribute.split('}')[0];
                return attribute.strip();
              };
            }
            else if (value === '') {
              f = function(element, attribute) {
                attribute = element.getAttribute(attribute);
                if (!attribute) return null;
                return attribute.strip();
              };
            }
            el = null;
            return f;
          })(),
          _flag: function(element, attribute) {
            return $(element).hasAttribute(attribute) ? attribute : null;
          },
          style: function(element) {
            return element.style.cssText.toLowerCase();
          },
          title: function(element) {
            return element.title;
          }
        }
      }
    }
  })();

  Element._attributeTranslations.write = {
    names: Object.extend({
      cellpadding: 'cellPadding',
      cellspacing: 'cellSpacing'
    }, Element._attributeTranslations.read.names),
    values: {
      checked: function(element, value) {
        element.checked = !!value;
      },

      style: function(element, value) {
        element.style.cssText = value ? value : '';
      }
    }
  };

  Element._attributeTranslations.has = {};

  $w('colSpan rowSpan vAlign dateTime accessKey tabIndex ' +
      'encType maxLength readOnly longDesc frameBorder').each(function(attr) {
    Element._attributeTranslations.write.names[attr.toLowerCase()] = attr;
    Element._attributeTranslations.has[attr.toLowerCase()] = attr;
  });

  (function(v) {
    Object.extend(v, {
      href:        v._getAttr2,
      src:         v._getAttr2,
      type:        v._getAttr,
      action:      v._getAttrNode,
      disabled:    v._flag,
      checked:     v._flag,
      readonly:    v._flag,
      multiple:    v._flag,
      onload:      v._getEv,
      onunload:    v._getEv,
      onclick:     v._getEv,
      ondblclick:  v._getEv,
      onmousedown: v._getEv,
      onmouseup:   v._getEv,
      onmouseover: v._getEv,
      onmousemove: v._getEv,
      onmouseout:  v._getEv,
      onfocus:     v._getEv,
      onblur:      v._getEv,
      onkeypress:  v._getEv,
      onkeydown:   v._getEv,
      onkeyup:     v._getEv,
      onsubmit:    v._getEv,
      onreset:     v._getEv,
      onselect:    v._getEv,
      onchange:    v._getEv
    });
  })(Element._attributeTranslations.read.values);

  if (Prototype.BrowserFeatures.ElementExtensions) {
    (function() {
      function _descendants(element) {
        var nodes = element.getElementsByTagName('*'), results = [];
        for (var i = 0, node; node = nodes[i]; i++)
          if (node.tagName !== "!") // Filter out comment nodes.
            results.push(node);
        return results;
      }

      Element.Methods.down = function(element, expression, index) {
        element = $(element);
        if (arguments.length == 1) return element.firstDescendant();
        return Object.isNumber(expression) ? _descendants(element)[expression] :
          Element.select(element, expression)[index || 0];
      }
    })();
  }

}

else if (Prototype.Browser.Gecko && /rv:1\.8\.0/.test(navigator.userAgent)) {
  Element.Methods.setOpacity = function(element, value) {
    element = $(element);
    element.style.opacity = (value == 1) ? 0.999999 :
      (value === '') ? '' : (value < 0.00001) ? 0 : value;
    return element;
  };
}

else if (Prototype.Browser.WebKit) {
  Element.Methods.setOpacity = function(element, value) {
    element = $(element);
    element.style.opacity = (value == 1 || value === '') ? '' :
      (value < 0.00001) ? 0 : value;

    if (value == 1)
      if (element.tagName.toUpperCase() == 'IMG' && element.width) {
        element.width++; element.width--;
      } else try {
        var n = document.createTextNode(' ');
        element.appendChild(n);
        element.removeChild(n);
      } catch (e) { }

    return element;
  };
}

if ('outerHTML' in document.documentElement) {
  Element.Methods.replace = function(element, content) {
    element = $(element);

    if (content && content.toElement) content = content.toElement();
    if (Object.isElement(content)) {
      element.parentNode.replaceChild(content, element);
      return element;
    }

    content = Object.toHTML(content);
    var parent = element.parentNode, tagName = parent.tagName.toUpperCase();

    if (Element._insertionTranslations.tags[tagName]) {
      var nextSibling = element.next(),
          fragments = Element._getContentFromAnonymousElement(tagName, content.stripScripts());
      parent.removeChild(element);
      if (nextSibling)
        fragments.each(function(node) { parent.insertBefore(node, nextSibling) });
      else
        fragments.each(function(node) { parent.appendChild(node) });
    }
    else element.outerHTML = content.stripScripts();

    content.evalScripts.bind(content).defer();
    return element;
  };
}

Element._returnOffset = function(l, t) {
  var result = [l, t];
  result.left = l;
  result.top = t;
  return result;
};

Element._getContentFromAnonymousElement = function(tagName, html, force) {
  var div = new Element('div'),
      t = Element._insertionTranslations.tags[tagName];

  var workaround = false;
  if (t) workaround = true;
  else if (force) {
    workaround = true;
    t = ['', '', 0];
  }

  if (workaround) {
    div.innerHTML = '&nbsp;' + t[0] + html + t[1];
    div.removeChild(div.firstChild);
    for (var i = t[2]; i--; ) {
      div = div.firstChild;
    }
  }
  else {
    div.innerHTML = html;
  }
  return $A(div.childNodes);
};

Element._insertionTranslations = {
  before: function(element, node) {
    element.parentNode.insertBefore(node, element);
  },
  top: function(element, node) {
    element.insertBefore(node, element.firstChild);
  },
  bottom: function(element, node) {
    element.appendChild(node);
  },
  after: function(element, node) {
    element.parentNode.insertBefore(node, element.nextSibling);
  },
  tags: {
    TABLE:  ['<table>',                '</table>',                   1],
    TBODY:  ['<table><tbody>',         '</tbody></table>',           2],
    TR:     ['<table><tbody><tr>',     '</tr></tbody></table>',      3],
    TD:     ['<table><tbody><tr><td>', '</td></tr></tbody></table>', 4],
    SELECT: ['<select>',               '</select>',                  1]
  }
};

(function() {
  var tags = Element._insertionTranslations.tags;
  Object.extend(tags, {
    THEAD: tags.TBODY,
    TFOOT: tags.TBODY,
    TH:    tags.TD
  });
})();

Element.Methods.Simulated = {
  hasAttribute: function(element, attribute) {
    attribute = Element._attributeTranslations.has[attribute] || attribute;
    var node = $(element).getAttributeNode(attribute);
    return !!(node && node.specified);
  }
};

Element.Methods.ByTag = { };

Object.extend(Element, Element.Methods);

(function(div) {

  if (!Prototype.BrowserFeatures.ElementExtensions && div['__proto__']) {
    window.HTMLElement = { };
    window.HTMLElement.prototype = div['__proto__'];
    Prototype.BrowserFeatures.ElementExtensions = true;
  }

  div = null;

})(document.createElement('div'));

Element.extend = (function() {

  function checkDeficiency(tagName) {
    if (typeof window.Element != 'undefined') {
      var proto = window.Element.prototype;
      if (proto) {
        var id = '_' + (Math.random()+'').slice(2),
            el = document.createElement(tagName);
        proto[id] = 'x';
        var isBuggy = (el[id] !== 'x');
        delete proto[id];
        el = null;
        return isBuggy;
      }
    }
    return false;
  }

  function extendElementWith(element, methods) {
    for (var property in methods) {
      var value = methods[property];
      if (Object.isFunction(value) && !(property in element))
        element[property] = value.methodize();
    }
  }

  var HTMLOBJECTELEMENT_PROTOTYPE_BUGGY = checkDeficiency('object');

  if (Prototype.BrowserFeatures.SpecificElementExtensions) {
    if (HTMLOBJECTELEMENT_PROTOTYPE_BUGGY) {
      return function(element) {
        if (element && typeof element._extendedByPrototype == 'undefined') {
          var t = element.tagName;
          if (t && (/^(?:object|applet|embed)$/i.test(t))) {
            extendElementWith(element, Element.Methods);
            extendElementWith(element, Element.Methods.Simulated);
            extendElementWith(element, Element.Methods.ByTag[t.toUpperCase()]);
          }
        }
        return element;
      }
    }
    return Prototype.K;
  }

  var Methods = { }, ByTag = Element.Methods.ByTag;

  var extend = Object.extend(function(element) {
    if (!element || typeof element._extendedByPrototype != 'undefined' ||
        element.nodeType != 1 || element == window) return element;

    var methods = Object.clone(Methods),
        tagName = element.tagName.toUpperCase();

    if (ByTag[tagName]) Object.extend(methods, ByTag[tagName]);

    extendElementWith(element, methods);

    element._extendedByPrototype = Prototype.emptyFunction;
    return element;

  }, {
    refresh: function() {
      if (!Prototype.BrowserFeatures.ElementExtensions) {
        Object.extend(Methods, Element.Methods);
        Object.extend(Methods, Element.Methods.Simulated);
      }
    }
  });

  extend.refresh();
  return extend;
})();

if (document.documentElement.hasAttribute) {
  Element.hasAttribute = function(element, attribute) {
    return element.hasAttribute(attribute);
  };
}
else {
  Element.hasAttribute = Element.Methods.Simulated.hasAttribute;
}

Element.addMethods = function(methods) {
  var F = Prototype.BrowserFeatures, T = Element.Methods.ByTag;

  if (!methods) {
    Object.extend(Form, Form.Methods);
    Object.extend(Form.Element, Form.Element.Methods);
    Object.extend(Element.Methods.ByTag, {
      "FORM":     Object.clone(Form.Methods),
      "INPUT":    Object.clone(Form.Element.Methods),
      "SELECT":   Object.clone(Form.Element.Methods),
      "TEXTAREA": Object.clone(Form.Element.Methods),
      "BUTTON":   Object.clone(Form.Element.Methods)
    });
  }

  if (arguments.length == 2) {
    var tagName = methods;
    methods = arguments[1];
  }

  if (!tagName) Object.extend(Element.Methods, methods || { });
  else {
    if (Object.isArray(tagName)) tagName.each(extend);
    else extend(tagName);
  }

  function extend(tagName) {
    tagName = tagName.toUpperCase();
    if (!Element.Methods.ByTag[tagName])
      Element.Methods.ByTag[tagName] = { };
    Object.extend(Element.Methods.ByTag[tagName], methods);
  }

  function copy(methods, destination, onlyIfAbsent) {
    onlyIfAbsent = onlyIfAbsent || false;
    for (var property in methods) {
      var value = methods[property];
      if (!Object.isFunction(value)) continue;
      if (!onlyIfAbsent || !(property in destination))
        destination[property] = value.methodize();
    }
  }

  function findDOMClass(tagName) {
    var klass;
    var trans = {
      "OPTGROUP": "OptGroup", "TEXTAREA": "TextArea", "P": "Paragraph",
      "FIELDSET": "FieldSet", "UL": "UList", "OL": "OList", "DL": "DList",
      "DIR": "Directory", "H1": "Heading", "H2": "Heading", "H3": "Heading",
      "H4": "Heading", "H5": "Heading", "H6": "Heading", "Q": "Quote",
      "INS": "Mod", "DEL": "Mod", "A": "Anchor", "IMG": "Image", "CAPTION":
      "TableCaption", "COL": "TableCol", "COLGROUP": "TableCol", "THEAD":
      "TableSection", "TFOOT": "TableSection", "TBODY": "TableSection", "TR":
      "TableRow", "TH": "TableCell", "TD": "TableCell", "FRAMESET":
      "FrameSet", "IFRAME": "IFrame"
    };
    if (trans[tagName]) klass = 'HTML' + trans[tagName] + 'Element';
    if (window[klass]) return window[klass];
    klass = 'HTML' + tagName + 'Element';
    if (window[klass]) return window[klass];
    klass = 'HTML' + tagName.capitalize() + 'Element';
    if (window[klass]) return window[klass];

    var element = document.createElement(tagName),
        proto = element['__proto__'] || element.constructor.prototype;

    element = null;
    return proto;
  }

  var elementPrototype = window.HTMLElement ? HTMLElement.prototype :
   Element.prototype;

  if (F.ElementExtensions) {
    copy(Element.Methods, elementPrototype);
    copy(Element.Methods.Simulated, elementPrototype, true);
  }

  if (F.SpecificElementExtensions) {
    for (var tag in Element.Methods.ByTag) {
      var klass = findDOMClass(tag);
      if (Object.isUndefined(klass)) continue;
      copy(T[tag], klass.prototype);
    }
  }

  Object.extend(Element, Element.Methods);
  delete Element.ByTag;

  if (Element.extend.refresh) Element.extend.refresh();
  Element.cache = { };
};


document.viewport = {

  getDimensions: function() {
    return { width: this.getWidth(), height: this.getHeight() };
  },

  getScrollOffsets: function() {
    return Element._returnOffset(
      window.pageXOffset || document.documentElement.scrollLeft || document.body.scrollLeft,
      window.pageYOffset || document.documentElement.scrollTop  || document.body.scrollTop);
  }
};

(function(viewport) {
  var B = Prototype.Browser, doc = document, element, property = {};

  function getRootElement() {
    if (B.WebKit && !doc.evaluate)
      return document;

    if (B.Opera && window.parseFloat(window.opera.version()) < 9.5)
      return document.body;

    return document.documentElement;
  }

  function define(D) {
    if (!element) element = getRootElement();

    property[D] = 'client' + D;

    viewport['get' + D] = function() { return element[property[D]] };
    return viewport['get' + D]();
  }

  viewport.getWidth  = define.curry('Width');

  viewport.getHeight = define.curry('Height');
})(document.viewport);


Element.Storage = {
  UID: 1
};

Element.addMethods({
  getStorage: function(element) {
    if (!(element = $(element))) return;

    var uid;
    if (element === window) {
      uid = 0;
    } else {
      if (typeof element._prototypeUID === "undefined")
        element._prototypeUID = Element.Storage.UID++;
      uid = element._prototypeUID;
    }

    if (!Element.Storage[uid])
      Element.Storage[uid] = $H();

    return Element.Storage[uid];
  },

  store: function(element, key, value) {
    if (!(element = $(element))) return;

    if (arguments.length === 2) {
      Element.getStorage(element).update(key);
    } else {
      Element.getStorage(element).set(key, value);
    }

    return element;
  },

  retrieve: function(element, key, defaultValue) {
    if (!(element = $(element))) return;
    var hash = Element.getStorage(element), value = hash.get(key);

    if (Object.isUndefined(value)) {
      hash.set(key, defaultValue);
      value = defaultValue;
    }

    return value;
  },

  clone: function(element, deep) {
    if (!(element = $(element))) return;
    var clone = element.cloneNode(deep);
    clone._prototypeUID = void 0;
    if (deep) {
      var descendants = Element.select(clone, '*'),
          i = descendants.length;
      while (i--) {
        descendants[i]._prototypeUID = void 0;
      }
    }
    return Element.extend(clone);
  },

  purge: function(element) {
    if (!(element = $(element))) return;
    var purgeElement = Element._purgeElement;

    purgeElement(element);

    var descendants = element.getElementsByTagName('*'),
     i = descendants.length;

    while (i--) purgeElement(descendants[i]);

    return null;
  }
});

(function() {

  function toDecimal(pctString) {
    var match = pctString.match(/^(\d+)%?$/i);
    if (!match) return null;
    return (Number(match[1]) / 100);
  }

  function getPixelValue(value, property, context) {
    var element = null;
    if (Object.isElement(value)) {
      element = value;
      value = element.getStyle(property);
    }

    if (value === null) {
      return null;
    }

    if ((/^(?:-)?\d+(\.\d+)?(px)?$/i).test(value)) {
      return window.parseFloat(value);
    }

    var isPercentage = value.include('%'), isViewport = (context === document.viewport);

    if (/\d/.test(value) && element && element.runtimeStyle && !(isPercentage && isViewport)) {
      var style = element.style.left, rStyle = element.runtimeStyle.left;
      element.runtimeStyle.left = element.currentStyle.left;
      element.style.left = value || 0;
      value = element.style.pixelLeft;
      element.style.left = style;
      element.runtimeStyle.left = rStyle;

      return value;
    }

    if (element && isPercentage) {
      context = context || element.parentNode;
      var decimal = toDecimal(value);
      var whole = null;
      var position = element.getStyle('position');

      var isHorizontal = property.include('left') || property.include('right') ||
       property.include('width');

      var isVertical =  property.include('top') || property.include('bottom') ||
        property.include('height');

      if (context === document.viewport) {
        if (isHorizontal) {
          whole = document.viewport.getWidth();
        } else if (isVertical) {
          whole = document.viewport.getHeight();
        }
      } else {
        if (isHorizontal) {
          whole = $(context).measure('width');
        } else if (isVertical) {
          whole = $(context).measure('height');
        }
      }

      return (whole === null) ? 0 : whole * decimal;
    }

    return 0;
  }

  function toCSSPixels(number) {
    if (Object.isString(number) && number.endsWith('px')) {
      return number;
    }
    return number + 'px';
  }

  function isDisplayed(element) {
    var originalElement = element;
    while (element && element.parentNode) {
      var display = element.getStyle('display');
      if (display === 'none') {
        return false;
      }
      element = $(element.parentNode);
    }
    return true;
  }

  var hasLayout = Prototype.K;
  if ('currentStyle' in document.documentElement) {
    hasLayout = function(element) {
      if (!element.currentStyle.hasLayout) {
        element.style.zoom = 1;
      }
      return element;
    };
  }

  function cssNameFor(key) {
    if (key.include('border')) key = key + '-width';
    return key.camelize();
  }

  Element.Layout = Class.create(Hash, {
    initialize: function($super, element, preCompute) {
      $super();
      this.element = $(element);

      Element.Layout.PROPERTIES.each( function(property) {
        this._set(property, null);
      }, this);

      if (preCompute) {
        this._preComputing = true;
        this._begin();
        Element.Layout.PROPERTIES.each( this._compute, this );
        this._end();
        this._preComputing = false;
      }
    },

    _set: function(property, value) {
      return Hash.prototype.set.call(this, property, value);
    },

    set: function(property, value) {
      throw "Properties of Element.Layout are read-only.";
    },

    get: function($super, property) {
      var value = $super(property);
      return value === null ? this._compute(property) : value;
    },

    _begin: function() {
      if (this._prepared) return;

      var element = this.element;
      if (isDisplayed(element)) {
        this._prepared = true;
        return;
      }

      var originalStyles = {
        position:   element.style.position   || '',
        width:      element.style.width      || '',
        visibility: element.style.visibility || '',
        display:    element.style.display    || ''
      };

      element.store('prototype_original_styles', originalStyles);

      var position = element.getStyle('position'),
       width = element.getStyle('width');

      if (width === "0px" || width === null) {
        element.style.display = 'block';
        width = element.getStyle('width');
      }

      var context = (position === 'fixed') ? document.viewport :
       element.parentNode;

      element.setStyle({
        position:   'absolute',
        visibility: 'hidden',
        display:    'block'
      });

      var positionedWidth = element.getStyle('width');

      var newWidth;
      if (width && (positionedWidth === width)) {
        newWidth = getPixelValue(element, 'width', context);
      } else if (position === 'absolute' || position === 'fixed') {
        newWidth = getPixelValue(element, 'width', context);
      } else {
        var parent = element.parentNode, pLayout = $(parent).getLayout();

        newWidth = pLayout.get('width') -
         this.get('margin-left') -
         this.get('border-left') -
         this.get('padding-left') -
         this.get('padding-right') -
         this.get('border-right') -
         this.get('margin-right');
      }

      element.setStyle({ width: newWidth + 'px' });

      this._prepared = true;
    },

    _end: function() {
      var element = this.element;
      var originalStyles = element.retrieve('prototype_original_styles');
      element.store('prototype_original_styles', null);
      element.setStyle(originalStyles);
      this._prepared = false;
    },

    _compute: function(property) {
      var COMPUTATIONS = Element.Layout.COMPUTATIONS;
      if (!(property in COMPUTATIONS)) {
        throw "Property not found.";
      }

      return this._set(property, COMPUTATIONS[property].call(this, this.element));
    },

    toObject: function() {
      var args = $A(arguments);
      var keys = (args.length === 0) ? Element.Layout.PROPERTIES :
       args.join(' ').split(' ');
      var obj = {};
      keys.each( function(key) {
        if (!Element.Layout.PROPERTIES.include(key)) return;
        var value = this.get(key);
        if (value != null) obj[key] = value;
      }, this);
      return obj;
    },

    toHash: function() {
      var obj = this.toObject.apply(this, arguments);
      return new Hash(obj);
    },

    toCSS: function() {
      var args = $A(arguments);
      var keys = (args.length === 0) ? Element.Layout.PROPERTIES :
       args.join(' ').split(' ');
      var css = {};

      keys.each( function(key) {
        if (!Element.Layout.PROPERTIES.include(key)) return;
        if (Element.Layout.COMPOSITE_PROPERTIES.include(key)) return;

        var value = this.get(key);
        if (value != null) css[cssNameFor(key)] = value + 'px';
      }, this);
      return css;
    },

    inspect: function() {
      return "#<Element.Layout>";
    }
  });

  Object.extend(Element.Layout, {
    PROPERTIES: $w('height width top left right bottom border-left border-right border-top border-bottom padding-left padding-right padding-top padding-bottom margin-top margin-bottom margin-left margin-right padding-box-width padding-box-height border-box-width border-box-height margin-box-width margin-box-height'),

    COMPOSITE_PROPERTIES: $w('padding-box-width padding-box-height margin-box-width margin-box-height border-box-width border-box-height'),

    COMPUTATIONS: {
      'height': function(element) {
        if (!this._preComputing) this._begin();

        var bHeight = this.get('border-box-height');
        if (bHeight <= 0) {
          if (!this._preComputing) this._end();
          return 0;
        }

        var bTop = this.get('border-top'),
         bBottom = this.get('border-bottom');

        var pTop = this.get('padding-top'),
         pBottom = this.get('padding-bottom');

        if (!this._preComputing) this._end();

        return bHeight - bTop - bBottom - pTop - pBottom;
      },

      'width': function(element) {
        if (!this._preComputing) this._begin();

        var bWidth = this.get('border-box-width');
        if (bWidth <= 0) {
          if (!this._preComputing) this._end();
          return 0;
        }

        var bLeft = this.get('border-left'),
         bRight = this.get('border-right');

        var pLeft = this.get('padding-left'),
         pRight = this.get('padding-right');

        if (!this._preComputing) this._end();

        return bWidth - bLeft - bRight - pLeft - pRight;
      },

      'padding-box-height': function(element) {
        var height = this.get('height'),
         pTop = this.get('padding-top'),
         pBottom = this.get('padding-bottom');

        return height + pTop + pBottom;
      },

      'padding-box-width': function(element) {
        var width = this.get('width'),
         pLeft = this.get('padding-left'),
         pRight = this.get('padding-right');

        return width + pLeft + pRight;
      },

      'border-box-height': function(element) {
        if (!this._preComputing) this._begin();
        var height = element.offsetHeight;
        if (!this._preComputing) this._end();
        return height;
      },

      'border-box-width': function(element) {
        if (!this._preComputing) this._begin();
        var width = element.offsetWidth;
        if (!this._preComputing) this._end();
        return width;
      },

      'margin-box-height': function(element) {
        var bHeight = this.get('border-box-height'),
         mTop = this.get('margin-top'),
         mBottom = this.get('margin-bottom');

        if (bHeight <= 0) return 0;

        return bHeight + mTop + mBottom;
      },

      'margin-box-width': function(element) {
        var bWidth = this.get('border-box-width'),
         mLeft = this.get('margin-left'),
         mRight = this.get('margin-right');

        if (bWidth <= 0) return 0;

        return bWidth + mLeft + mRight;
      },

      'top': function(element) {
        var offset = element.positionedOffset();
        return offset.top;
      },

      'bottom': function(element) {
        var offset = element.positionedOffset(),
         parent = element.getOffsetParent(),
         pHeight = parent.measure('height');

        var mHeight = this.get('border-box-height');

        return pHeight - mHeight - offset.top;
      },

      'left': function(element) {
        var offset = element.positionedOffset();
        return offset.left;
      },

      'right': function(element) {
        var offset = element.positionedOffset(),
         parent = element.getOffsetParent(),
         pWidth = parent.measure('width');

        var mWidth = this.get('border-box-width');

        return pWidth - mWidth - offset.left;
      },

      'padding-top': function(element) {
        return getPixelValue(element, 'paddingTop');
      },

      'padding-bottom': function(element) {
        return getPixelValue(element, 'paddingBottom');
      },

      'padding-left': function(element) {
        return getPixelValue(element, 'paddingLeft');
      },

      'padding-right': function(element) {
        return getPixelValue(element, 'paddingRight');
      },

      'border-top': function(element) {
        return getPixelValue(element, 'borderTopWidth');
      },

      'border-bottom': function(element) {
        return getPixelValue(element, 'borderBottomWidth');
      },

      'border-left': function(element) {
        return getPixelValue(element, 'borderLeftWidth');
      },

      'border-right': function(element) {
        return getPixelValue(element, 'borderRightWidth');
      },

      'margin-top': function(element) {
        return getPixelValue(element, 'marginTop');
      },

      'margin-bottom': function(element) {
        return getPixelValue(element, 'marginBottom');
      },

      'margin-left': function(element) {
        return getPixelValue(element, 'marginLeft');
      },

      'margin-right': function(element) {
        return getPixelValue(element, 'marginRight');
      }
    }
  });

  if ('getBoundingClientRect' in document.documentElement) {
    Object.extend(Element.Layout.COMPUTATIONS, {
      'right': function(element) {
        var parent = hasLayout(element.getOffsetParent());
        var rect = element.getBoundingClientRect(),
         pRect = parent.getBoundingClientRect();

        return (pRect.right - rect.right).round();
      },

      'bottom': function(element) {
        var parent = hasLayout(element.getOffsetParent());
        var rect = element.getBoundingClientRect(),
         pRect = parent.getBoundingClientRect();

        return (pRect.bottom - rect.bottom).round();
      }
    });
  }

  Element.Offset = Class.create({
    initialize: function(left, top) {
      this.left = left.round();
      this.top  = top.round();

      this[0] = this.left;
      this[1] = this.top;
    },

    relativeTo: function(offset) {
      return new Element.Offset(
        this.left - offset.left,
        this.top  - offset.top
      );
    },

    inspect: function() {
      return "#<Element.Offset left: #{left} top: #{top}>".interpolate(this);
    },

    toString: function() {
      return "[#{left}, #{top}]".interpolate(this);
    },

    toArray: function() {
      return [this.left, this.top];
    }
  });

  function getLayout(element, preCompute) {
    return new Element.Layout(element, preCompute);
  }

  function measure(element, property) {
    return $(element).getLayout().get(property);
  }

  function getDimensions(element) {
    element = $(element);
    var display = Element.getStyle(element, 'display');

    if (display && display !== 'none') {
      return { width: element.offsetWidth, height: element.offsetHeight };
    }

    var style = element.style;
    var originalStyles = {
      visibility: style.visibility,
      position:   style.position,
      display:    style.display
    };

    var newStyles = {
      visibility: 'hidden',
      display:    'block'
    };

    if (originalStyles.position !== 'fixed')
      newStyles.position = 'absolute';

    Element.setStyle(element, newStyles);

    var dimensions = {
      width:  element.offsetWidth,
      height: element.offsetHeight
    };

    Element.setStyle(element, originalStyles);

    return dimensions;
  }

  function getOffsetParent(element) {
    element = $(element);

    if (isDocument(element) || isDetached(element) || isBody(element) || isHtml(element))
      return $(document.body);

    var isInline = (Element.getStyle(element, 'display') === 'inline');
    if (!isInline && element.offsetParent) return $(element.offsetParent);

    while ((element = element.parentNode) && element !== document.body) {
      if (Element.getStyle(element, 'position') !== 'static') {
        return isHtml(element) ? $(document.body) : $(element);
      }
    }

    return $(document.body);
  }


  function cumulativeOffset(element) {
    element = $(element);
    var valueT = 0, valueL = 0;
    if (element.parentNode) {
      do {
        valueT += element.offsetTop  || 0;
        valueL += element.offsetLeft || 0;
        element = element.offsetParent;
      } while (element);
    }
    return new Element.Offset(valueL, valueT);
  }

  function positionedOffset(element) {
    element = $(element);

    var layout = element.getLayout();

    var valueT = 0, valueL = 0;
    do {
      valueT += element.offsetTop  || 0;
      valueL += element.offsetLeft || 0;
      element = element.offsetParent;
      if (element) {
        if (isBody(element)) break;
        var p = Element.getStyle(element, 'position');
        if (p !== 'static') break;
      }
    } while (element);

    valueL -= layout.get('margin-top');
    valueT -= layout.get('margin-left');

    return new Element.Offset(valueL, valueT);
  }

  function cumulativeScrollOffset(element) {
    var valueT = 0, valueL = 0;
    do {
      valueT += element.scrollTop  || 0;
      valueL += element.scrollLeft || 0;
      element = element.parentNode;
    } while (element);
    return new Element.Offset(valueL, valueT);
  }

  function viewportOffset(forElement) {
    element = $(element);
    var valueT = 0, valueL = 0, docBody = document.body;

    var element = forElement;
    do {
      valueT += element.offsetTop  || 0;
      valueL += element.offsetLeft || 0;
      if (element.offsetParent == docBody &&
        Element.getStyle(element, 'position') == 'absolute') break;
    } while (element = element.offsetParent);

    element = forElement;
    do {
      if (element != docBody) {
        valueT -= element.scrollTop  || 0;
        valueL -= element.scrollLeft || 0;
      }
    } while (element = element.parentNode);
    return new Element.Offset(valueL, valueT);
  }

  function absolutize(element) {
    element = $(element);

    if (Element.getStyle(element, 'position') === 'absolute') {
      return element;
    }

    var offsetParent = getOffsetParent(element);
    var eOffset = element.viewportOffset(),
     pOffset = offsetParent.viewportOffset();

    var offset = eOffset.relativeTo(pOffset);
    var layout = element.getLayout();

    element.store('prototype_absolutize_original_styles', {
      left:   element.getStyle('left'),
      top:    element.getStyle('top'),
      width:  element.getStyle('width'),
      height: element.getStyle('height')
    });

    element.setStyle({
      position: 'absolute',
      top:    offset.top + 'px',
      left:   offset.left + 'px',
      width:  layout.get('width') + 'px',
      height: layout.get('height') + 'px'
    });

    return element;
  }

  function relativize(element) {
    element = $(element);
    if (Element.getStyle(element, 'position') === 'relative') {
      return element;
    }

    var originalStyles =
     element.retrieve('prototype_absolutize_original_styles');

    if (originalStyles) element.setStyle(originalStyles);
    return element;
  }

  if (Prototype.Browser.IE) {
    getOffsetParent = getOffsetParent.wrap(
      function(proceed, element) {
        element = $(element);

        if (isDocument(element) || isDetached(element) || isBody(element) || isHtml(element))
          return $(document.body);

        var position = element.getStyle('position');
        if (position !== 'static') return proceed(element);

        element.setStyle({ position: 'relative' });
        var value = proceed(element);
        element.setStyle({ position: position });
        return value;
      }
    );

    positionedOffset = positionedOffset.wrap(function(proceed, element) {
      element = $(element);
      if (!element.parentNode) return new Element.Offset(0, 0);
      var position = element.getStyle('position');
      if (position !== 'static') return proceed(element);

      var offsetParent = element.getOffsetParent();
      if (offsetParent && offsetParent.getStyle('position') === 'fixed')
        hasLayout(offsetParent);

      element.setStyle({ position: 'relative' });
      var value = proceed(element);
      element.setStyle({ position: position });
      return value;
    });
  } else if (Prototype.Browser.Webkit) {
    cumulativeOffset = function(element) {
      element = $(element);
      var valueT = 0, valueL = 0;
      do {
        valueT += element.offsetTop  || 0;
        valueL += element.offsetLeft || 0;
        if (element.offsetParent == document.body)
          if (Element.getStyle(element, 'position') == 'absolute') break;

        element = element.offsetParent;
      } while (element);

      return new Element.Offset(valueL, valueT);
    };
  }


  Element.addMethods({
    getLayout:              getLayout,
    measure:                measure,
    getDimensions:          getDimensions,
    getOffsetParent:        getOffsetParent,
    cumulativeOffset:       cumulativeOffset,
    positionedOffset:       positionedOffset,
    cumulativeScrollOffset: cumulativeScrollOffset,
    viewportOffset:         viewportOffset,
    absolutize:             absolutize,
    relativize:             relativize
  });

  function isBody(element) {
    return element.nodeName.toUpperCase() === 'BODY';
  }

  function isHtml(element) {
    return element.nodeName.toUpperCase() === 'HTML';
  }

  function isDocument(element) {
    return element.nodeType === Node.DOCUMENT_NODE;
  }

  function isDetached(element) {
    return element !== document.body &&
     !Element.descendantOf(element, document.body);
  }

  if ('getBoundingClientRect' in document.documentElement) {
    Element.addMethods({
      viewportOffset: function(element) {
        element = $(element);
        if (isDetached(element)) return new Element.Offset(0, 0);

        var rect = element.getBoundingClientRect(),
         docEl = document.documentElement;
        return new Element.Offset(rect.left - docEl.clientLeft,
         rect.top - docEl.clientTop);
      }
    });
  }
})();
window.$$ = function() {
  var expression = $A(arguments).join(', ');
  return Prototype.Selector.select(expression, document);
};

Prototype.Selector = (function() {

  function select() {
    throw new Error('Method "Prototype.Selector.select" must be defined.');
  }

  function match() {
    throw new Error('Method "Prototype.Selector.match" must be defined.');
  }

  function find(elements, expression, index) {
    index = index || 0;
    var match = Prototype.Selector.match, length = elements.length, matchIndex = 0, i;

    for (i = 0; i < length; i++) {
      if (match(elements[i], expression) && index == matchIndex++) {
        return Element.extend(elements[i]);
      }
    }
  }

  function extendElements(elements) {
    for (var i = 0, length = elements.length; i < length; i++) {
      Element.extend(elements[i]);
    }
    return elements;
  }


  var K = Prototype.K;

  return {
    select: select,
    match: match,
    find: find,
    extendElements: (Element.extend === K) ? K : extendElements,
    extendElement: Element.extend
  };
})();
/*!
 * Sizzle CSS Selector Engine - v1.0
 *  Copyright 2009, The Dojo Foundation
 *  Released under the MIT, BSD, and GPL Licenses.
 *  More information: http://sizzlejs.com/
 */
(function(){

var chunker = /((?:\((?:\([^()]+\)|[^()]+)+\)|\[(?:\[[^[\]]*\]|['"][^'"]*['"]|[^[\]'"]+)+\]|\\.|[^ >+~,(\[\\]+)+|[>+~])(\s*,\s*)?((?:.|\r|\n)*)/g,
	done = 0,
	toString = Object.prototype.toString,
	hasDuplicate = false,
	baseHasDuplicate = true;

[0, 0].sort(function(){
	baseHasDuplicate = false;
	return 0;
});

var Sizzle = function(selector, context, results, seed) {
	results = results || [];
	var origContext = context = context || document;

	if ( context.nodeType !== 1 && context.nodeType !== 9 ) {
		return [];
	}

	if ( !selector || typeof selector !== "string" ) {
		return results;
	}

	var parts = [], m, set, checkSet, check, mode, extra, prune = true, contextXML = isXML(context),
		soFar = selector;

	while ( (chunker.exec(""), m = chunker.exec(soFar)) !== null ) {
		soFar = m[3];

		parts.push( m[1] );

		if ( m[2] ) {
			extra = m[3];
			break;
		}
	}

	if ( parts.length > 1 && origPOS.exec( selector ) ) {
		if ( parts.length === 2 && Expr.relative[ parts[0] ] ) {
			set = posProcess( parts[0] + parts[1], context );
		} else {
			set = Expr.relative[ parts[0] ] ?
				[ context ] :
				Sizzle( parts.shift(), context );

			while ( parts.length ) {
				selector = parts.shift();

				if ( Expr.relative[ selector ] )
					selector += parts.shift();

				set = posProcess( selector, set );
			}
		}
	} else {
		if ( !seed && parts.length > 1 && context.nodeType === 9 && !contextXML &&
				Expr.match.ID.test(parts[0]) && !Expr.match.ID.test(parts[parts.length - 1]) ) {
			var ret = Sizzle.find( parts.shift(), context, contextXML );
			context = ret.expr ? Sizzle.filter( ret.expr, ret.set )[0] : ret.set[0];
		}

		if ( context ) {
			var ret = seed ?
				{ expr: parts.pop(), set: makeArray(seed) } :
				Sizzle.find( parts.pop(), parts.length === 1 && (parts[0] === "~" || parts[0] === "+") && context.parentNode ? context.parentNode : context, contextXML );
			set = ret.expr ? Sizzle.filter( ret.expr, ret.set ) : ret.set;

			if ( parts.length > 0 ) {
				checkSet = makeArray(set);
			} else {
				prune = false;
			}

			while ( parts.length ) {
				var cur = parts.pop(), pop = cur;

				if ( !Expr.relative[ cur ] ) {
					cur = "";
				} else {
					pop = parts.pop();
				}

				if ( pop == null ) {
					pop = context;
				}

				Expr.relative[ cur ]( checkSet, pop, contextXML );
			}
		} else {
			checkSet = parts = [];
		}
	}

	if ( !checkSet ) {
		checkSet = set;
	}

	if ( !checkSet ) {
		throw "Syntax error, unrecognized expression: " + (cur || selector);
	}

	if ( toString.call(checkSet) === "[object Array]" ) {
		if ( !prune ) {
			results.push.apply( results, checkSet );
		} else if ( context && context.nodeType === 1 ) {
			for ( var i = 0; checkSet[i] != null; i++ ) {
				if ( checkSet[i] && (checkSet[i] === true || checkSet[i].nodeType === 1 && contains(context, checkSet[i])) ) {
					results.push( set[i] );
				}
			}
		} else {
			for ( var i = 0; checkSet[i] != null; i++ ) {
				if ( checkSet[i] && checkSet[i].nodeType === 1 ) {
					results.push( set[i] );
				}
			}
		}
	} else {
		makeArray( checkSet, results );
	}

	if ( extra ) {
		Sizzle( extra, origContext, results, seed );
		Sizzle.uniqueSort( results );
	}

	return results;
};

Sizzle.uniqueSort = function(results){
	if ( sortOrder ) {
		hasDuplicate = baseHasDuplicate;
		results.sort(sortOrder);

		if ( hasDuplicate ) {
			for ( var i = 1; i < results.length; i++ ) {
				if ( results[i] === results[i-1] ) {
					results.splice(i--, 1);
				}
			}
		}
	}

	return results;
};

Sizzle.matches = function(expr, set){
	return Sizzle(expr, null, null, set);
};

Sizzle.find = function(expr, context, isXML){
	var set, match;

	if ( !expr ) {
		return [];
	}

	for ( var i = 0, l = Expr.order.length; i < l; i++ ) {
		var type = Expr.order[i], match;

		if ( (match = Expr.leftMatch[ type ].exec( expr )) ) {
			var left = match[1];
			match.splice(1,1);

			if ( left.substr( left.length - 1 ) !== "\\" ) {
				match[1] = (match[1] || "").replace(/\\/g, "");
				set = Expr.find[ type ]( match, context, isXML );
				if ( set != null ) {
					expr = expr.replace( Expr.match[ type ], "" );
					break;
				}
			}
		}
	}

	if ( !set ) {
		set = context.getElementsByTagName("*");
	}

	return {set: set, expr: expr};
};

Sizzle.filter = function(expr, set, inplace, not){
	var old = expr, result = [], curLoop = set, match, anyFound,
		isXMLFilter = set && set[0] && isXML(set[0]);

	while ( expr && set.length ) {
		for ( var type in Expr.filter ) {
			if ( (match = Expr.match[ type ].exec( expr )) != null ) {
				var filter = Expr.filter[ type ], found, item;
				anyFound = false;

				if ( curLoop == result ) {
					result = [];
				}

				if ( Expr.preFilter[ type ] ) {
					match = Expr.preFilter[ type ]( match, curLoop, inplace, result, not, isXMLFilter );

					if ( !match ) {
						anyFound = found = true;
					} else if ( match === true ) {
						continue;
					}
				}

				if ( match ) {
					for ( var i = 0; (item = curLoop[i]) != null; i++ ) {
						if ( item ) {
							found = filter( item, match, i, curLoop );
							var pass = not ^ !!found;

							if ( inplace && found != null ) {
								if ( pass ) {
									anyFound = true;
								} else {
									curLoop[i] = false;
								}
							} else if ( pass ) {
								result.push( item );
								anyFound = true;
							}
						}
					}
				}

				if ( found !== undefined ) {
					if ( !inplace ) {
						curLoop = result;
					}

					expr = expr.replace( Expr.match[ type ], "" );

					if ( !anyFound ) {
						return [];
					}

					break;
				}
			}
		}

		if ( expr == old ) {
			if ( anyFound == null ) {
				throw "Syntax error, unrecognized expression: " + expr;
			} else {
				break;
			}
		}

		old = expr;
	}

	return curLoop;
};

var Expr = Sizzle.selectors = {
	order: [ "ID", "NAME", "TAG" ],
	match: {
		ID: /#((?:[\w\u00c0-\uFFFF-]|\\.)+)/,
		CLASS: /\.((?:[\w\u00c0-\uFFFF-]|\\.)+)/,
		NAME: /\[name=['"]*((?:[\w\u00c0-\uFFFF-]|\\.)+)['"]*\]/,
		ATTR: /\[\s*((?:[\w\u00c0-\uFFFF-]|\\.)+)\s*(?:(\S?=)\s*(['"]*)(.*?)\3|)\s*\]/,
		TAG: /^((?:[\w\u00c0-\uFFFF\*-]|\\.)+)/,
		CHILD: /:(only|nth|last|first)-child(?:\((even|odd|[\dn+-]*)\))?/,
		POS: /:(nth|eq|gt|lt|first|last|even|odd)(?:\((\d*)\))?(?=[^-]|$)/,
		PSEUDO: /:((?:[\w\u00c0-\uFFFF-]|\\.)+)(?:\((['"]*)((?:\([^\)]+\)|[^\2\(\)]*)+)\2\))?/
	},
	leftMatch: {},
	attrMap: {
		"class": "className",
		"for": "htmlFor"
	},
	attrHandle: {
		href: function(elem){
			return elem.getAttribute("href");
		}
	},
	relative: {
		"+": function(checkSet, part, isXML){
			var isPartStr = typeof part === "string",
				isTag = isPartStr && !/\W/.test(part),
				isPartStrNotTag = isPartStr && !isTag;

			if ( isTag && !isXML ) {
				part = part.toUpperCase();
			}

			for ( var i = 0, l = checkSet.length, elem; i < l; i++ ) {
				if ( (elem = checkSet[i]) ) {
					while ( (elem = elem.previousSibling) && elem.nodeType !== 1 ) {}

					checkSet[i] = isPartStrNotTag || elem && elem.nodeName === part ?
						elem || false :
						elem === part;
				}
			}

			if ( isPartStrNotTag ) {
				Sizzle.filter( part, checkSet, true );
			}
		},
		">": function(checkSet, part, isXML){
			var isPartStr = typeof part === "string";

			if ( isPartStr && !/\W/.test(part) ) {
				part = isXML ? part : part.toUpperCase();

				for ( var i = 0, l = checkSet.length; i < l; i++ ) {
					var elem = checkSet[i];
					if ( elem ) {
						var parent = elem.parentNode;
						checkSet[i] = parent.nodeName === part ? parent : false;
					}
				}
			} else {
				for ( var i = 0, l = checkSet.length; i < l; i++ ) {
					var elem = checkSet[i];
					if ( elem ) {
						checkSet[i] = isPartStr ?
							elem.parentNode :
							elem.parentNode === part;
					}
				}

				if ( isPartStr ) {
					Sizzle.filter( part, checkSet, true );
				}
			}
		},
		"": function(checkSet, part, isXML){
			var doneName = done++, checkFn = dirCheck;

			if ( !/\W/.test(part) ) {
				var nodeCheck = part = isXML ? part : part.toUpperCase();
				checkFn = dirNodeCheck;
			}

			checkFn("parentNode", part, doneName, checkSet, nodeCheck, isXML);
		},
		"~": function(checkSet, part, isXML){
			var doneName = done++, checkFn = dirCheck;

			if ( typeof part === "string" && !/\W/.test(part) ) {
				var nodeCheck = part = isXML ? part : part.toUpperCase();
				checkFn = dirNodeCheck;
			}

			checkFn("previousSibling", part, doneName, checkSet, nodeCheck, isXML);
		}
	},
	find: {
		ID: function(match, context, isXML){
			if ( typeof context.getElementById !== "undefined" && !isXML ) {
				var m = context.getElementById(match[1]);
				return m ? [m] : [];
			}
		},
		NAME: function(match, context, isXML){
			if ( typeof context.getElementsByName !== "undefined" ) {
				var ret = [], results = context.getElementsByName(match[1]);

				for ( var i = 0, l = results.length; i < l; i++ ) {
					if ( results[i].getAttribute("name") === match[1] ) {
						ret.push( results[i] );
					}
				}

				return ret.length === 0 ? null : ret;
			}
		},
		TAG: function(match, context){
			return context.getElementsByTagName(match[1]);
		}
	},
	preFilter: {
		CLASS: function(match, curLoop, inplace, result, not, isXML){
			match = " " + match[1].replace(/\\/g, "") + " ";

			if ( isXML ) {
				return match;
			}

			for ( var i = 0, elem; (elem = curLoop[i]) != null; i++ ) {
				if ( elem ) {
					if ( not ^ (elem.className && (" " + elem.className + " ").indexOf(match) >= 0) ) {
						if ( !inplace )
							result.push( elem );
					} else if ( inplace ) {
						curLoop[i] = false;
					}
				}
			}

			return false;
		},
		ID: function(match){
			return match[1].replace(/\\/g, "");
		},
		TAG: function(match, curLoop){
			for ( var i = 0; curLoop[i] === false; i++ ){}
			return curLoop[i] && isXML(curLoop[i]) ? match[1] : match[1].toUpperCase();
		},
		CHILD: function(match){
			if ( match[1] == "nth" ) {
				var test = /(-?)(\d*)n((?:\+|-)?\d*)/.exec(
					match[2] == "even" && "2n" || match[2] == "odd" && "2n+1" ||
					!/\D/.test( match[2] ) && "0n+" + match[2] || match[2]);

				match[2] = (test[1] + (test[2] || 1)) - 0;
				match[3] = test[3] - 0;
			}

			match[0] = done++;

			return match;
		},
		ATTR: function(match, curLoop, inplace, result, not, isXML){
			var name = match[1].replace(/\\/g, "");

			if ( !isXML && Expr.attrMap[name] ) {
				match[1] = Expr.attrMap[name];
			}

			if ( match[2] === "~=" ) {
				match[4] = " " + match[4] + " ";
			}

			return match;
		},
		PSEUDO: function(match, curLoop, inplace, result, not){
			if ( match[1] === "not" ) {
				if ( ( chunker.exec(match[3]) || "" ).length > 1 || /^\w/.test(match[3]) ) {
					match[3] = Sizzle(match[3], null, null, curLoop);
				} else {
					var ret = Sizzle.filter(match[3], curLoop, inplace, true ^ not);
					if ( !inplace ) {
						result.push.apply( result, ret );
					}
					return false;
				}
			} else if ( Expr.match.POS.test( match[0] ) || Expr.match.CHILD.test( match[0] ) ) {
				return true;
			}

			return match;
		},
		POS: function(match){
			match.unshift( true );
			return match;
		}
	},
	filters: {
		enabled: function(elem){
			return elem.disabled === false && elem.type !== "hidden";
		},
		disabled: function(elem){
			return elem.disabled === true;
		},
		checked: function(elem){
			return elem.checked === true;
		},
		selected: function(elem){
			elem.parentNode.selectedIndex;
			return elem.selected === true;
		},
		parent: function(elem){
			return !!elem.firstChild;
		},
		empty: function(elem){
			return !elem.firstChild;
		},
		has: function(elem, i, match){
			return !!Sizzle( match[3], elem ).length;
		},
		header: function(elem){
			return /h\d/i.test( elem.nodeName );
		},
		text: function(elem){
			return "text" === elem.type;
		},
		radio: function(elem){
			return "radio" === elem.type;
		},
		checkbox: function(elem){
			return "checkbox" === elem.type;
		},
		file: function(elem){
			return "file" === elem.type;
		},
		password: function(elem){
			return "password" === elem.type;
		},
		submit: function(elem){
			return "submit" === elem.type;
		},
		image: function(elem){
			return "image" === elem.type;
		},
		reset: function(elem){
			return "reset" === elem.type;
		},
		button: function(elem){
			return "button" === elem.type || elem.nodeName.toUpperCase() === "BUTTON";
		},
		input: function(elem){
			return /input|select|textarea|button/i.test(elem.nodeName);
		}
	},
	setFilters: {
		first: function(elem, i){
			return i === 0;
		},
		last: function(elem, i, match, array){
			return i === array.length - 1;
		},
		even: function(elem, i){
			return i % 2 === 0;
		},
		odd: function(elem, i){
			return i % 2 === 1;
		},
		lt: function(elem, i, match){
			return i < match[3] - 0;
		},
		gt: function(elem, i, match){
			return i > match[3] - 0;
		},
		nth: function(elem, i, match){
			return match[3] - 0 == i;
		},
		eq: function(elem, i, match){
			return match[3] - 0 == i;
		}
	},
	filter: {
		PSEUDO: function(elem, match, i, array){
			var name = match[1], filter = Expr.filters[ name ];

			if ( filter ) {
				return filter( elem, i, match, array );
			} else if ( name === "contains" ) {
				return (elem.textContent || elem.innerText || "").indexOf(match[3]) >= 0;
			} else if ( name === "not" ) {
				var not = match[3];

				for ( var i = 0, l = not.length; i < l; i++ ) {
					if ( not[i] === elem ) {
						return false;
					}
				}

				return true;
			}
		},
		CHILD: function(elem, match){
			var type = match[1], node = elem;
			switch (type) {
				case 'only':
				case 'first':
					while ( (node = node.previousSibling) )  {
						if ( node.nodeType === 1 ) return false;
					}
					if ( type == 'first') return true;
					node = elem;
				case 'last':
					while ( (node = node.nextSibling) )  {
						if ( node.nodeType === 1 ) return false;
					}
					return true;
				case 'nth':
					var first = match[2], last = match[3];

					if ( first == 1 && last == 0 ) {
						return true;
					}

					var doneName = match[0],
						parent = elem.parentNode;

					if ( parent && (parent.sizcache !== doneName || !elem.nodeIndex) ) {
						var count = 0;
						for ( node = parent.firstChild; node; node = node.nextSibling ) {
							if ( node.nodeType === 1 ) {
								node.nodeIndex = ++count;
							}
						}
						parent.sizcache = doneName;
					}

					var diff = elem.nodeIndex - last;
					if ( first == 0 ) {
						return diff == 0;
					} else {
						return ( diff % first == 0 && diff / first >= 0 );
					}
			}
		},
		ID: function(elem, match){
			return elem.nodeType === 1 && elem.getAttribute("id") === match;
		},
		TAG: function(elem, match){
			return (match === "*" && elem.nodeType === 1) || elem.nodeName === match;
		},
		CLASS: function(elem, match){
			return (" " + (elem.className || elem.getAttribute("class")) + " ")
				.indexOf( match ) > -1;
		},
		ATTR: function(elem, match){
			var name = match[1],
				result = Expr.attrHandle[ name ] ?
					Expr.attrHandle[ name ]( elem ) :
					elem[ name ] != null ?
						elem[ name ] :
						elem.getAttribute( name ),
				value = result + "",
				type = match[2],
				check = match[4];

			return result == null ?
				type === "!=" :
				type === "=" ?
				value === check :
				type === "*=" ?
				value.indexOf(check) >= 0 :
				type === "~=" ?
				(" " + value + " ").indexOf(check) >= 0 :
				!check ?
				value && result !== false :
				type === "!=" ?
				value != check :
				type === "^=" ?
				value.indexOf(check) === 0 :
				type === "$=" ?
				value.substr(value.length - check.length) === check :
				type === "|=" ?
				value === check || value.substr(0, check.length + 1) === check + "-" :
				false;
		},
		POS: function(elem, match, i, array){
			var name = match[2], filter = Expr.setFilters[ name ];

			if ( filter ) {
				return filter( elem, i, match, array );
			}
		}
	}
};

var origPOS = Expr.match.POS;

for ( var type in Expr.match ) {
	Expr.match[ type ] = new RegExp( Expr.match[ type ].source + /(?![^\[]*\])(?![^\(]*\))/.source );
	Expr.leftMatch[ type ] = new RegExp( /(^(?:.|\r|\n)*?)/.source + Expr.match[ type ].source );
}

var makeArray = function(array, results) {
	array = Array.prototype.slice.call( array, 0 );

	if ( results ) {
		results.push.apply( results, array );
		return results;
	}

	return array;
};

try {
	Array.prototype.slice.call( document.documentElement.childNodes, 0 );

} catch(e){
	makeArray = function(array, results) {
		var ret = results || [];

		if ( toString.call(array) === "[object Array]" ) {
			Array.prototype.push.apply( ret, array );
		} else {
			if ( typeof array.length === "number" ) {
				for ( var i = 0, l = array.length; i < l; i++ ) {
					ret.push( array[i] );
				}
			} else {
				for ( var i = 0; array[i]; i++ ) {
					ret.push( array[i] );
				}
			}
		}

		return ret;
	};
}

var sortOrder;

if ( document.documentElement.compareDocumentPosition ) {
	sortOrder = function( a, b ) {
		if ( !a.compareDocumentPosition || !b.compareDocumentPosition ) {
			if ( a == b ) {
				hasDuplicate = true;
			}
			return 0;
		}

		var ret = a.compareDocumentPosition(b) & 4 ? -1 : a === b ? 0 : 1;
		if ( ret === 0 ) {
			hasDuplicate = true;
		}
		return ret;
	};
} else if ( "sourceIndex" in document.documentElement ) {
	sortOrder = function( a, b ) {
		if ( !a.sourceIndex || !b.sourceIndex ) {
			if ( a == b ) {
				hasDuplicate = true;
			}
			return 0;
		}

		var ret = a.sourceIndex - b.sourceIndex;
		if ( ret === 0 ) {
			hasDuplicate = true;
		}
		return ret;
	};
} else if ( document.createRange ) {
	sortOrder = function( a, b ) {
		if ( !a.ownerDocument || !b.ownerDocument ) {
			if ( a == b ) {
				hasDuplicate = true;
			}
			return 0;
		}

		var aRange = a.ownerDocument.createRange(), bRange = b.ownerDocument.createRange();
		aRange.setStart(a, 0);
		aRange.setEnd(a, 0);
		bRange.setStart(b, 0);
		bRange.setEnd(b, 0);
		var ret = aRange.compareBoundaryPoints(Range.START_TO_END, bRange);
		if ( ret === 0 ) {
			hasDuplicate = true;
		}
		return ret;
	};
}

(function(){
	var form = document.createElement("div"),
		id = "script" + (new Date).getTime();
	form.innerHTML = "<a name='" + id + "'/>";

	var root = document.documentElement;
	root.insertBefore( form, root.firstChild );

	if ( !!document.getElementById( id ) ) {
		Expr.find.ID = function(match, context, isXML){
			if ( typeof context.getElementById !== "undefined" && !isXML ) {
				var m = context.getElementById(match[1]);
				return m ? m.id === match[1] || typeof m.getAttributeNode !== "undefined" && m.getAttributeNode("id").nodeValue === match[1] ? [m] : undefined : [];
			}
		};

		Expr.filter.ID = function(elem, match){
			var node = typeof elem.getAttributeNode !== "undefined" && elem.getAttributeNode("id");
			return elem.nodeType === 1 && node && node.nodeValue === match;
		};
	}

	root.removeChild( form );
	root = form = null; // release memory in IE
})();

(function(){

	var div = document.createElement("div");
	div.appendChild( document.createComment("") );

	if ( div.getElementsByTagName("*").length > 0 ) {
		Expr.find.TAG = function(match, context){
			var results = context.getElementsByTagName(match[1]);

			if ( match[1] === "*" ) {
				var tmp = [];

				for ( var i = 0; results[i]; i++ ) {
					if ( results[i].nodeType === 1 ) {
						tmp.push( results[i] );
					}
				}

				results = tmp;
			}

			return results;
		};
	}

	div.innerHTML = "<a href='#'></a>";
	if ( div.firstChild && typeof div.firstChild.getAttribute !== "undefined" &&
			div.firstChild.getAttribute("href") !== "#" ) {
		Expr.attrHandle.href = function(elem){
			return elem.getAttribute("href", 2);
		};
	}

	div = null; // release memory in IE
})();

if ( document.querySelectorAll ) (function(){
	var oldSizzle = Sizzle, div = document.createElement("div");
	div.innerHTML = "<p class='TEST'></p>";

	if ( div.querySelectorAll && div.querySelectorAll(".TEST").length === 0 ) {
		return;
	}

	Sizzle = function(query, context, extra, seed){
		context = context || document;

		if ( !seed && context.nodeType === 9 && !isXML(context) ) {
			try {
				return makeArray( context.querySelectorAll(query), extra );
			} catch(e){}
		}

		return oldSizzle(query, context, extra, seed);
	};

	for ( var prop in oldSizzle ) {
		Sizzle[ prop ] = oldSizzle[ prop ];
	}

	div = null; // release memory in IE
})();

if ( document.getElementsByClassName && document.documentElement.getElementsByClassName ) (function(){
	var div = document.createElement("div");
	div.innerHTML = "<div class='test e'></div><div class='test'></div>";

	if ( div.getElementsByClassName("e").length === 0 )
		return;

	div.lastChild.className = "e";

	if ( div.getElementsByClassName("e").length === 1 )
		return;

	Expr.order.splice(1, 0, "CLASS");
	Expr.find.CLASS = function(match, context, isXML) {
		if ( typeof context.getElementsByClassName !== "undefined" && !isXML ) {
			return context.getElementsByClassName(match[1]);
		}
	};

	div = null; // release memory in IE
})();

function dirNodeCheck( dir, cur, doneName, checkSet, nodeCheck, isXML ) {
	var sibDir = dir == "previousSibling" && !isXML;
	for ( var i = 0, l = checkSet.length; i < l; i++ ) {
		var elem = checkSet[i];
		if ( elem ) {
			if ( sibDir && elem.nodeType === 1 ){
				elem.sizcache = doneName;
				elem.sizset = i;
			}
			elem = elem[dir];
			var match = false;

			while ( elem ) {
				if ( elem.sizcache === doneName ) {
					match = checkSet[elem.sizset];
					break;
				}

				if ( elem.nodeType === 1 && !isXML ){
					elem.sizcache = doneName;
					elem.sizset = i;
				}

				if ( elem.nodeName === cur ) {
					match = elem;
					break;
				}

				elem = elem[dir];
			}

			checkSet[i] = match;
		}
	}
}

function dirCheck( dir, cur, doneName, checkSet, nodeCheck, isXML ) {
	var sibDir = dir == "previousSibling" && !isXML;
	for ( var i = 0, l = checkSet.length; i < l; i++ ) {
		var elem = checkSet[i];
		if ( elem ) {
			if ( sibDir && elem.nodeType === 1 ) {
				elem.sizcache = doneName;
				elem.sizset = i;
			}
			elem = elem[dir];
			var match = false;

			while ( elem ) {
				if ( elem.sizcache === doneName ) {
					match = checkSet[elem.sizset];
					break;
				}

				if ( elem.nodeType === 1 ) {
					if ( !isXML ) {
						elem.sizcache = doneName;
						elem.sizset = i;
					}
					if ( typeof cur !== "string" ) {
						if ( elem === cur ) {
							match = true;
							break;
						}

					} else if ( Sizzle.filter( cur, [elem] ).length > 0 ) {
						match = elem;
						break;
					}
				}

				elem = elem[dir];
			}

			checkSet[i] = match;
		}
	}
}

var contains = document.compareDocumentPosition ?  function(a, b){
	return a.compareDocumentPosition(b) & 16;
} : function(a, b){
	return a !== b && (a.contains ? a.contains(b) : true);
};

var isXML = function(elem){
	return elem.nodeType === 9 && elem.documentElement.nodeName !== "HTML" ||
		!!elem.ownerDocument && elem.ownerDocument.documentElement.nodeName !== "HTML";
};

var posProcess = function(selector, context){
	var tmpSet = [], later = "", match,
		root = context.nodeType ? [context] : context;

	while ( (match = Expr.match.PSEUDO.exec( selector )) ) {
		later += match[0];
		selector = selector.replace( Expr.match.PSEUDO, "" );
	}

	selector = Expr.relative[selector] ? selector + "*" : selector;

	for ( var i = 0, l = root.length; i < l; i++ ) {
		Sizzle( selector, root[i], tmpSet );
	}

	return Sizzle.filter( later, tmpSet );
};


window.Sizzle = Sizzle;

})();

Prototype._original_property = window.Sizzle;

;(function(engine) {
  var extendElements = Prototype.Selector.extendElements;

  function select(selector, scope) {
    return extendElements(engine(selector, scope || document));
  }

  function match(element, selector) {
    return engine.matches(selector, [element]).length == 1;
  }

  Prototype.Selector.engine = engine;
  Prototype.Selector.select = select;
  Prototype.Selector.match = match;
})(Sizzle);

window.Sizzle = Prototype._original_property;
delete Prototype._original_property;

var Form = {
  reset: function(form) {
    form = $(form);
    form.reset();
    return form;
  },

  serializeElements: function(elements, options) {
    if (typeof options != 'object') options = { hash: !!options };
    else if (Object.isUndefined(options.hash)) options.hash = true;
    var key, value, submitted = false, submit = options.submit, accumulator, initial;

    if (options.hash) {
      initial = {};
      accumulator = function(result, key, value) {
        if (key in result) {
          if (!Object.isArray(result[key])) result[key] = [result[key]];
          result[key].push(value);
        } else result[key] = value;
        return result;
      };
    } else {
      initial = '';
      accumulator = function(result, key, value) {
        return result + (result ? '&' : '') + encodeURIComponent(key) + '=' + encodeURIComponent(value);
      }
    }

    return elements.inject(initial, function(result, element) {
      if (!element.disabled && element.name) {
        key = element.name; value = $(element).getValue();
        if (value != null && element.type != 'file' && (element.type != 'submit' || (!submitted &&
            submit !== false && (!submit || key == submit) && (submitted = true)))) {
          result = accumulator(result, key, value);
        }
      }
      return result;
    });
  }
};

Form.Methods = {
  serialize: function(form, options) {
    return Form.serializeElements(Form.getElements(form), options);
  },

  getElements: function(form) {
    var elements = $(form).getElementsByTagName('*'),
        element,
        arr = [ ],
        serializers = Form.Element.Serializers;
    for (var i = 0; element = elements[i]; i++) {
      arr.push(element);
    }
    return arr.inject([], function(elements, child) {
      if (serializers[child.tagName.toLowerCase()])
        elements.push(Element.extend(child));
      return elements;
    })
  },

  getInputs: function(form, typeName, name) {
    form = $(form);
    var inputs = form.getElementsByTagName('input');

    if (!typeName && !name) return $A(inputs).map(Element.extend);

    for (var i = 0, matchingInputs = [], length = inputs.length; i < length; i++) {
      var input = inputs[i];
      if ((typeName && input.type != typeName) || (name && input.name != name))
        continue;
      matchingInputs.push(Element.extend(input));
    }

    return matchingInputs;
  },

  disable: function(form) {
    form = $(form);
    Form.getElements(form).invoke('disable');
    return form;
  },

  enable: function(form) {
    form = $(form);
    Form.getElements(form).invoke('enable');
    return form;
  },

  findFirstElement: function(form) {
    var elements = $(form).getElements().findAll(function(element) {
      return 'hidden' != element.type && !element.disabled;
    });
    var firstByIndex = elements.findAll(function(element) {
      return element.hasAttribute('tabIndex') && element.tabIndex >= 0;
    }).sortBy(function(element) { return element.tabIndex }).first();

    return firstByIndex ? firstByIndex : elements.find(function(element) {
      return /^(?:input|select|textarea)$/i.test(element.tagName);
    });
  },

  focusFirstElement: function(form) {
    form = $(form);
    var element = form.findFirstElement();
    if (element) element.activate();
    return form;
  },

  request: function(form, options) {
    form = $(form), options = Object.clone(options || { });

    var params = options.parameters, action = form.readAttribute('action') || '';
    if (action.blank()) action = window.location.href;
    options.parameters = form.serialize(true);

    if (params) {
      if (Object.isString(params)) params = params.toQueryParams();
      Object.extend(options.parameters, params);
    }

    if (form.hasAttribute('method') && !options.method)
      options.method = form.method;

    return new Ajax.Request(action, options);
  }
};

/*--------------------------------------------------------------------------*/


Form.Element = {
  focus: function(element) {
    $(element).focus();
    return element;
  },

  select: function(element) {
    $(element).select();
    return element;
  }
};

Form.Element.Methods = {

  serialize: function(element) {
    element = $(element);
    if (!element.disabled && element.name) {
      var value = element.getValue();
      if (value != undefined) {
        var pair = { };
        pair[element.name] = value;
        return Object.toQueryString(pair);
      }
    }
    return '';
  },

  getValue: function(element) {
    element = $(element);
    var method = element.tagName.toLowerCase();
    return Form.Element.Serializers[method](element);
  },

  setValue: function(element, value) {
    element = $(element);
    var method = element.tagName.toLowerCase();
    Form.Element.Serializers[method](element, value);
    return element;
  },

  clear: function(element) {
    $(element).value = '';
    return element;
  },

  present: function(element) {
    return $(element).value != '';
  },

  activate: function(element) {
    element = $(element);
    try {
      element.focus();
      if (element.select && (element.tagName.toLowerCase() != 'input' ||
          !(/^(?:button|reset|submit)$/i.test(element.type))))
        element.select();
    } catch (e) { }
    return element;
  },

  disable: function(element) {
    element = $(element);
    element.disabled = true;
    return element;
  },

  enable: function(element) {
    element = $(element);
    element.disabled = false;
    return element;
  }
};

/*--------------------------------------------------------------------------*/

var Field = Form.Element;

var $F = Form.Element.Methods.getValue;

/*--------------------------------------------------------------------------*/

Form.Element.Serializers = (function() {
  function input(element, value) {
    switch (element.type.toLowerCase()) {
      case 'checkbox':
      case 'radio':
        return inputSelector(element, value);
      default:
        return valueSelector(element, value);
    }
  }

  function inputSelector(element, value) {
    if (Object.isUndefined(value))
      return element.checked ? element.value : null;
    else element.checked = !!value;
  }

  function valueSelector(element, value) {
    if (Object.isUndefined(value)) return element.value;
    else element.value = value;
  }

  function select(element, value) {
    if (Object.isUndefined(value))
      return (element.type === 'select-one' ? selectOne : selectMany)(element);

    var opt, currentValue, single = !Object.isArray(value);
    for (var i = 0, length = element.length; i < length; i++) {
      opt = element.options[i];
      currentValue = this.optionValue(opt);
      if (single) {
        if (currentValue == value) {
          opt.selected = true;
          return;
        }
      }
      else opt.selected = value.include(currentValue);
    }
  }

  function selectOne(element) {
    var index = element.selectedIndex;
    return index >= 0 ? optionValue(element.options[index]) : null;
  }

  function selectMany(element) {
    var values, length = element.length;
    if (!length) return null;

    for (var i = 0, values = []; i < length; i++) {
      var opt = element.options[i];
      if (opt.selected) values.push(optionValue(opt));
    }
    return values;
  }

  function optionValue(opt) {
    return Element.hasAttribute(opt, 'value') ? opt.value : opt.text;
  }

  return {
    input:         input,
    inputSelector: inputSelector,
    textarea:      valueSelector,
    select:        select,
    selectOne:     selectOne,
    selectMany:    selectMany,
    optionValue:   optionValue,
    button:        valueSelector
  };
})();

/*--------------------------------------------------------------------------*/


Abstract.TimedObserver = Class.create(PeriodicalExecuter, {
  initialize: function($super, element, frequency, callback) {
    $super(callback, frequency);
    this.element   = $(element);
    this.lastValue = this.getValue();
  },

  execute: function() {
    var value = this.getValue();
    if (Object.isString(this.lastValue) && Object.isString(value) ?
        this.lastValue != value : String(this.lastValue) != String(value)) {
      this.callback(this.element, value);
      this.lastValue = value;
    }
  }
});

Form.Element.Observer = Class.create(Abstract.TimedObserver, {
  getValue: function() {
    return Form.Element.getValue(this.element);
  }
});

Form.Observer = Class.create(Abstract.TimedObserver, {
  getValue: function() {
    return Form.serialize(this.element);
  }
});

/*--------------------------------------------------------------------------*/

Abstract.EventObserver = Class.create({
  initialize: function(element, callback) {
    this.element  = $(element);
    this.callback = callback;

    this.lastValue = this.getValue();
    if (this.element.tagName.toLowerCase() == 'form')
      this.registerFormCallbacks();
    else
      this.registerCallback(this.element);
  },

  onElementEvent: function() {
    var value = this.getValue();
    if (this.lastValue != value) {
      this.callback(this.element, value);
      this.lastValue = value;
    }
  },

  registerFormCallbacks: function() {
    Form.getElements(this.element).each(this.registerCallback, this);
  },

  registerCallback: function(element) {
    if (element.type) {
      switch (element.type.toLowerCase()) {
        case 'checkbox':
        case 'radio':
          Event.observe(element, 'click', this.onElementEvent.bind(this));
          break;
        default:
          Event.observe(element, 'change', this.onElementEvent.bind(this));
          break;
      }
    }
  }
});

Form.Element.EventObserver = Class.create(Abstract.EventObserver, {
  getValue: function() {
    return Form.Element.getValue(this.element);
  }
});

Form.EventObserver = Class.create(Abstract.EventObserver, {
  getValue: function() {
    return Form.serialize(this.element);
  }
});
(function() {

  var Event = {
    KEY_BACKSPACE: 8,
    KEY_TAB:       9,
    KEY_RETURN:   13,
    KEY_ESC:      27,
    KEY_LEFT:     37,
    KEY_UP:       38,
    KEY_RIGHT:    39,
    KEY_DOWN:     40,
    KEY_DELETE:   46,
    KEY_HOME:     36,
    KEY_END:      35,
    KEY_PAGEUP:   33,
    KEY_PAGEDOWN: 34,
    KEY_INSERT:   45,

    cache: {}
  };

  var docEl = document.documentElement;
  var MOUSEENTER_MOUSELEAVE_EVENTS_SUPPORTED = 'onmouseenter' in docEl
    && 'onmouseleave' in docEl;



  var isIELegacyEvent = function(event) { return false; };

  if (window.attachEvent) {
    if (window.addEventListener) {
      isIELegacyEvent = function(event) {
        return !(event instanceof window.Event);
      };
    } else {
      isIELegacyEvent = function(event) { return true; };
    }
  }

  var _isButton;

  function _isButtonForDOMEvents(event, code) {
    return event.which ? (event.which === code + 1) : (event.button === code);
  }

  var legacyButtonMap = { 0: 1, 1: 4, 2: 2 };
  function _isButtonForLegacyEvents(event, code) {
    return event.button === legacyButtonMap[code];
  }

  function _isButtonForWebKit(event, code) {
    switch (code) {
      case 0: return event.which == 1 && !event.metaKey;
      case 1: return event.which == 2 || (event.which == 1 && event.metaKey);
      case 2: return event.which == 3;
      default: return false;
    }
  }

  if (window.attachEvent) {
    if (!window.addEventListener) {
      _isButton = _isButtonForLegacyEvents;
    } else {
      _isButton = function(event, code) {
        return isIELegacyEvent(event) ? _isButtonForLegacyEvents(event, code) :
         _isButtonForDOMEvents(event, code);
      }
    }
  } else if (Prototype.Browser.WebKit) {
    _isButton = _isButtonForWebKit;
  } else {
    _isButton = _isButtonForDOMEvents;
  }

  function isLeftClick(event)   { return _isButton(event, 0) }

  function isMiddleClick(event) { return _isButton(event, 1) }

  function isRightClick(event)  { return _isButton(event, 2) }

  function element(event) {
    event = Event.extend(event);

    var node = event.target, type = event.type,
     currentTarget = event.currentTarget;

    if (currentTarget && currentTarget.tagName) {
      if (type === 'load' || type === 'error' ||
        (type === 'click' && currentTarget.tagName.toLowerCase() === 'input'
          && currentTarget.type === 'radio'))
            node = currentTarget;
    }

    if (node.nodeType == Node.TEXT_NODE)
      node = node.parentNode;

    return Element.extend(node);
  }

  function findElement(event, expression) {
    var element = Event.element(event);

    if (!expression) return element;
    while (element) {
      if (Object.isElement(element) && Prototype.Selector.match(element, expression)) {
        return Element.extend(element);
      }
      element = element.parentNode;
    }
  }

  function pointer(event) {
    return { x: pointerX(event), y: pointerY(event) };
  }

  function pointerX(event) {
    var docElement = document.documentElement,
     body = document.body || { scrollLeft: 0 };

    return event.pageX || (event.clientX +
      (docElement.scrollLeft || body.scrollLeft) -
      (docElement.clientLeft || 0));
  }

  function pointerY(event) {
    var docElement = document.documentElement,
     body = document.body || { scrollTop: 0 };

    return  event.pageY || (event.clientY +
       (docElement.scrollTop || body.scrollTop) -
       (docElement.clientTop || 0));
  }


  function stop(event) {
    Event.extend(event);
    event.preventDefault();
    event.stopPropagation();

    event.stopped = true;
  }


  Event.Methods = {
    isLeftClick:   isLeftClick,
    isMiddleClick: isMiddleClick,
    isRightClick:  isRightClick,

    element:     element,
    findElement: findElement,

    pointer:  pointer,
    pointerX: pointerX,
    pointerY: pointerY,

    stop: stop
  };

  var methods = Object.keys(Event.Methods).inject({ }, function(m, name) {
    m[name] = Event.Methods[name].methodize();
    return m;
  });

  if (window.attachEvent) {
    function _relatedTarget(event) {
      var element;
      switch (event.type) {
        case 'mouseover':
        case 'mouseenter':
          element = event.fromElement;
          break;
        case 'mouseout':
        case 'mouseleave':
          element = event.toElement;
          break;
        default:
          return null;
      }
      return Element.extend(element);
    }

    var additionalMethods = {
      stopPropagation: function() { this.cancelBubble = true },
      preventDefault:  function() { this.returnValue = false },
      inspect: function() { return '[object Event]' }
    };

    Event.extend = function(event, element) {
      if (!event) return false;

      if (!isIELegacyEvent(event)) return event;

      if (event._extendedByPrototype) return event;
      event._extendedByPrototype = Prototype.emptyFunction;

      var pointer = Event.pointer(event);

      Object.extend(event, {
        target: event.srcElement || element,
        relatedTarget: _relatedTarget(event),
        pageX:  pointer.x,
        pageY:  pointer.y
      });

      Object.extend(event, methods);
      Object.extend(event, additionalMethods);

      return event;
    };
  } else {
    Event.extend = Prototype.K;
  }

  if (window.addEventListener) {
    Event.prototype = window.Event.prototype || document.createEvent('HTMLEvents').__proto__;
    Object.extend(Event.prototype, methods);
  }

  function _createResponder(element, eventName, handler) {
    var registry = Element.retrieve(element, 'prototype_event_registry');

    if (Object.isUndefined(registry)) {
      CACHE.push(element);
      registry = Element.retrieve(element, 'prototype_event_registry', $H());
    }

    var respondersForEvent = registry.get(eventName);
    if (Object.isUndefined(respondersForEvent)) {
      respondersForEvent = [];
      registry.set(eventName, respondersForEvent);
    }

    if (respondersForEvent.pluck('handler').include(handler)) return false;

    var responder;
    if (eventName.include(":")) {
      responder = function(event) {
        if (Object.isUndefined(event.eventName))
          return false;

        if (event.eventName !== eventName)
          return false;

        Event.extend(event, element);
        handler.call(element, event);
      };
    } else {
      if (!MOUSEENTER_MOUSELEAVE_EVENTS_SUPPORTED &&
       (eventName === "mouseenter" || eventName === "mouseleave")) {
        if (eventName === "mouseenter" || eventName === "mouseleave") {
          responder = function(event) {
            Event.extend(event, element);

            var parent = event.relatedTarget;
            while (parent && parent !== element) {
              try { parent = parent.parentNode; }
              catch(e) { parent = element; }
            }

            if (parent === element) return;

            handler.call(element, event);
          };
        }
      } else {
        responder = function(event) {
          Event.extend(event, element);
          handler.call(element, event);
        };
      }
    }

    responder.handler = handler;
    respondersForEvent.push(responder);
    return responder;
  }

  function _destroyCache() {
    for (var i = 0, length = CACHE.length; i < length; i++) {
      Event.stopObserving(CACHE[i]);
      CACHE[i] = null;
    }
  }

  var CACHE = [];

  if (Prototype.Browser.IE)
    window.attachEvent('onunload', _destroyCache);

  if (Prototype.Browser.WebKit)
    window.addEventListener('unload', Prototype.emptyFunction, false);


  var _getDOMEventName = Prototype.K,
      translations = { mouseenter: "mouseover", mouseleave: "mouseout" };

  if (!MOUSEENTER_MOUSELEAVE_EVENTS_SUPPORTED) {
    _getDOMEventName = function(eventName) {
      return (translations[eventName] || eventName);
    };
  }

  function observe(element, eventName, handler) {
    element = $(element);

    var responder = _createResponder(element, eventName, handler);

    if (!responder) return element;

    if (eventName.include(':')) {
      if (element.addEventListener)
        element.addEventListener("dataavailable", responder, false);
      else {
        element.attachEvent("ondataavailable", responder);
        element.attachEvent("onlosecapture", responder);
      }
    } else {
      var actualEventName = _getDOMEventName(eventName);

      if (element.addEventListener)
        element.addEventListener(actualEventName, responder, false);
      else
        element.attachEvent("on" + actualEventName, responder);
    }

    return element;
  }

  function stopObserving(element, eventName, handler) {
    element = $(element);

    var registry = Element.retrieve(element, 'prototype_event_registry');
    if (!registry) return element;

    if (!eventName) {
      registry.each( function(pair) {
        var eventName = pair.key;
        stopObserving(element, eventName);
      });
      return element;
    }

    var responders = registry.get(eventName);
    if (!responders) return element;

    if (!handler) {
      responders.each(function(r) {
        stopObserving(element, eventName, r.handler);
      });
      return element;
    }

    var i = responders.length, responder;
    while (i--) {
      if (responders[i].handler === handler) {
        responder = responders[i];
        break;
      }
    }
    if (!responder) return element;

    if (eventName.include(':')) {
      if (element.removeEventListener)
        element.removeEventListener("dataavailable", responder, false);
      else {
        element.detachEvent("ondataavailable", responder);
        element.detachEvent("onlosecapture", responder);
      }
    } else {
      var actualEventName = _getDOMEventName(eventName);
      if (element.removeEventListener)
        element.removeEventListener(actualEventName, responder, false);
      else
        element.detachEvent('on' + actualEventName, responder);
    }

    registry.set(eventName, responders.without(responder));

    return element;
  }

  function fire(element, eventName, memo, bubble) {
    element = $(element);

    if (Object.isUndefined(bubble))
      bubble = true;

    if (element == document && document.createEvent && !element.dispatchEvent)
      element = document.documentElement;

    var event;
    if (document.createEvent) {
      event = document.createEvent('HTMLEvents');
      event.initEvent('dataavailable', bubble, true);
    } else {
      event = document.createEventObject();
      event.eventType = bubble ? 'ondataavailable' : 'onlosecapture';
    }

    event.eventName = eventName;
    event.memo = memo || { };

    if (document.createEvent)
      element.dispatchEvent(event);
    else
      element.fireEvent(event.eventType, event);

    return Event.extend(event);
  }

  Event.Handler = Class.create({
    initialize: function(element, eventName, selector, callback) {
      this.element   = $(element);
      this.eventName = eventName;
      this.selector  = selector;
      this.callback  = callback;
      this.handler   = this.handleEvent.bind(this);
    },

    start: function() {
      Event.observe(this.element, this.eventName, this.handler);
      return this;
    },

    stop: function() {
      Event.stopObserving(this.element, this.eventName, this.handler);
      return this;
    },

    handleEvent: function(event) {
      var element = Event.findElement(event, this.selector);
      if (element) this.callback.call(this.element, event, element);
    }
  });

  function on(element, eventName, selector, callback) {
    element = $(element);
    if (Object.isFunction(selector) && Object.isUndefined(callback)) {
      callback = selector, selector = null;
    }

    return new Event.Handler(element, eventName, selector, callback).start();
  }

  Object.extend(Event, Event.Methods);

  Object.extend(Event, {
    fire:          fire,
    observe:       observe,
    stopObserving: stopObserving,
    on:            on
  });

  Element.addMethods({
    fire:          fire,

    observe:       observe,

    stopObserving: stopObserving,

    on:            on
  });

  Object.extend(document, {
    fire:          fire.methodize(),

    observe:       observe.methodize(),

    stopObserving: stopObserving.methodize(),

    on:            on.methodize(),

    loaded:        false
  });

  if (window.Event) Object.extend(window.Event, Event);
  else window.Event = Event;
})();

(function() {
  /* Support for the DOMContentLoaded event is based on work by Dan Webb,
     Matthias Miller, Dean Edwards, John Resig, and Diego Perini. */

  var timer;

  function fireContentLoadedEvent() {
    if (document.loaded) return;
    if (timer) window.clearTimeout(timer);
    document.loaded = true;
    document.fire('dom:loaded');
  }

  function checkReadyState() {
    if (document.readyState === 'complete') {
      document.stopObserving('readystatechange', checkReadyState);
      fireContentLoadedEvent();
    }
  }

  function pollDoScroll() {
    try { document.documentElement.doScroll('left'); }
    catch(e) {
      timer = pollDoScroll.defer();
      return;
    }
    fireContentLoadedEvent();
  }

  if (document.addEventListener) {
    document.addEventListener('DOMContentLoaded', fireContentLoadedEvent, false);
  } else {
    document.observe('readystatechange', checkReadyState);
    if (window == top)
      timer = pollDoScroll.defer();
  }

  Event.observe(window, 'load', fireContentLoadedEvent);
})();


Element.addMethods();
/*------------------------------- DEPRECATED -------------------------------*/

Hash.toQueryString = Object.toQueryString;

var Toggle = { display: Element.toggle };

Element.Methods.childOf = Element.Methods.descendantOf;

var Insertion = {
  Before: function(element, content) {
    return Element.insert(element, {before:content});
  },

  Top: function(element, content) {
    return Element.insert(element, {top:content});
  },

  Bottom: function(element, content) {
    return Element.insert(element, {bottom:content});
  },

  After: function(element, content) {
    return Element.insert(element, {after:content});
  }
};

var $continue = new Error('"throw $continue" is deprecated, use "return" instead');

var Position = {
  includeScrollOffsets: false,

  prepare: function() {
    this.deltaX =  window.pageXOffset
                || document.documentElement.scrollLeft
                || document.body.scrollLeft
                || 0;
    this.deltaY =  window.pageYOffset
                || document.documentElement.scrollTop
                || document.body.scrollTop
                || 0;
  },

  within: function(element, x, y) {
    if (this.includeScrollOffsets)
      return this.withinIncludingScrolloffsets(element, x, y);
    this.xcomp = x;
    this.ycomp = y;
    this.offset = Element.cumulativeOffset(element);

    return (y >= this.offset[1] &&
            y <  this.offset[1] + element.offsetHeight &&
            x >= this.offset[0] &&
            x <  this.offset[0] + element.offsetWidth);
  },

  withinIncludingScrolloffsets: function(element, x, y) {
    var offsetcache = Element.cumulativeScrollOffset(element);

    this.xcomp = x + offsetcache[0] - this.deltaX;
    this.ycomp = y + offsetcache[1] - this.deltaY;
    this.offset = Element.cumulativeOffset(element);

    return (this.ycomp >= this.offset[1] &&
            this.ycomp <  this.offset[1] + element.offsetHeight &&
            this.xcomp >= this.offset[0] &&
            this.xcomp <  this.offset[0] + element.offsetWidth);
  },

  overlap: function(mode, element) {
    if (!mode) return 0;
    if (mode == 'vertical')
      return ((this.offset[1] + element.offsetHeight) - this.ycomp) /
        element.offsetHeight;
    if (mode == 'horizontal')
      return ((this.offset[0] + element.offsetWidth) - this.xcomp) /
        element.offsetWidth;
  },


  cumulativeOffset: Element.Methods.cumulativeOffset,

  positionedOffset: Element.Methods.positionedOffset,

  absolutize: function(element) {
    Position.prepare();
    return Element.absolutize(element);
  },

  relativize: function(element) {
    Position.prepare();
    return Element.relativize(element);
  },

  realOffset: Element.Methods.cumulativeScrollOffset,

  offsetParent: Element.Methods.getOffsetParent,

  page: Element.Methods.viewportOffset,

  clone: function(source, target, options) {
    options = options || { };
    return Element.clonePosition(target, source, options);
  }
};

/*--------------------------------------------------------------------------*/

if (!document.getElementsByClassName) document.getElementsByClassName = function(instanceMethods){
  function iter(name) {
    return name.blank() ? null : "[contains(concat(' ', @class, ' '), ' " + name + " ')]";
  }

  instanceMethods.getElementsByClassName = Prototype.BrowserFeatures.XPath ?
  function(element, className) {
    className = className.toString().strip();
    var cond = /\s/.test(className) ? $w(className).map(iter).join('') : iter(className);
    return cond ? document._getElementsByXPath('.//*' + cond, element) : [];
  } : function(element, className) {
    className = className.toString().strip();
    var elements = [], classNames = (/\s/.test(className) ? $w(className) : null);
    if (!classNames && !className) return elements;

    var nodes = $(element).getElementsByTagName('*');
    className = ' ' + className + ' ';

    for (var i = 0, child, cn; child = nodes[i]; i++) {
      if (child.className && (cn = ' ' + child.className + ' ') && (cn.include(className) ||
          (classNames && classNames.all(function(name) {
            return !name.toString().blank() && cn.include(' ' + name + ' ');
          }))))
        elements.push(Element.extend(child));
    }
    return elements;
  };

  return function(className, parentElement) {
    return $(parentElement || document.body).getElementsByClassName(className);
  };
}(Element.Methods);

/*--------------------------------------------------------------------------*/

Element.ClassNames = Class.create();
Element.ClassNames.prototype = {
  initialize: function(element) {
    this.element = $(element);
  },

  _each: function(iterator) {
    this.element.className.split(/\s+/).select(function(name) {
      return name.length > 0;
    })._each(iterator);
  },

  set: function(className) {
    this.element.className = className;
  },

  add: function(classNameToAdd) {
    if (this.include(classNameToAdd)) return;
    this.set($A(this).concat(classNameToAdd).join(' '));
  },

  remove: function(classNameToRemove) {
    if (!this.include(classNameToRemove)) return;
    this.set($A(this).without(classNameToRemove).join(' '));
  },

  toString: function() {
    return $A(this).join(' ');
  }
};

Object.extend(Element.ClassNames.prototype, Enumerable);

/*--------------------------------------------------------------------------*/

(function() {
  window.Selector = Class.create({
    initialize: function(expression) {
      this.expression = expression.strip();
    },

    findElements: function(rootElement) {
      return Prototype.Selector.select(this.expression, rootElement);
    },

    match: function(element) {
      return Prototype.Selector.match(element, this.expression);
    },

    toString: function() {
      return this.expression;
    },

    inspect: function() {
      return "#<Selector: " + this.expression + ">";
    }
  });

  Object.extend(Selector, {
    matchElements: function(elements, expression) {
      var match = Prototype.Selector.match,
          results = [];

      for (var i = 0, length = elements.length; i < length; i++) {
        var element = elements[i];
        if (match(element, expression)) {
          results.push(Element.extend(element));
        }
      }
      return results;
    },

    findElement: function(elements, expression, index) {
      index = index || 0;
      var matchIndex = 0, element;
      for (var i = 0, length = elements.length; i < length; i++) {
        element = elements[i];
        if (Prototype.Selector.match(element, expression) && index === matchIndex++) {
          return Element.extend(element);
        }
      }
    },

    findChildElements: function(element, expressions) {
      var selector = expressions.toArray().join(', ');
      return Prototype.Selector.select(selector, element || document);
    }
  });
})();

/*!
 * jQuery JavaScript Library v1.7.2
 * http://jquery.com/
 *
 * Copyright 2011, John Resig
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 * Copyright 2011, The Dojo Foundation
 * Released under the MIT, BSD, and GPL Licenses.
 *
 * Date: Wed Mar 21 12:46:34 2012 -0700
 */
(function( window, undefined ) {

// Use the correct document accordingly with window argument (sandbox)
var document = window.document,
	navigator = window.navigator,
	location = window.location;
var jQuery = (function() {

// Define a local copy of jQuery
var jQuery = function( selector, context ) {
		// The jQuery object is actually just the init constructor 'enhanced'
		return new jQuery.fn.init( selector, context, rootjQuery );
	},

	// Map over jQuery in case of overwrite
	_jQuery = window.jQuery,

	// Map over the $ in case of overwrite
	_$ = window.$,

	// A central reference to the root jQuery(document)
	rootjQuery,

	// A simple way to check for HTML strings or ID strings
	// Prioritize #id over <tag> to avoid XSS via location.hash (#9521)
	quickExpr = /^(?:[^#<]*(<[\w\W]+>)[^>]*$|#([\w\-]*)$)/,

	// Check if a string has a non-whitespace character in it
	rnotwhite = /\S/,

	// Used for trimming whitespace
	trimLeft = /^\s+/,
	trimRight = /\s+$/,

	// Match a standalone tag
	rsingleTag = /^<(\w+)\s*\/?>(?:<\/\1>)?$/,

	// JSON RegExp
	rvalidchars = /^[\],:{}\s]*$/,
	rvalidescape = /\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g,
	rvalidtokens = /"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g,
	rvalidbraces = /(?:^|:|,)(?:\s*\[)+/g,

	// Useragent RegExp
	rwebkit = /(webkit)[ \/]([\w.]+)/,
	ropera = /(opera)(?:.*version)?[ \/]([\w.]+)/,
	rmsie = /(msie) ([\w.]+)/,
	rmozilla = /(mozilla)(?:.*? rv:([\w.]+))?/,

	// Matches dashed string for camelizing
	rdashAlpha = /-([a-z]|[0-9])/ig,
	rmsPrefix = /^-ms-/,

	// Used by jQuery.camelCase as callback to replace()
	fcamelCase = function( all, letter ) {
		return ( letter + "" ).toUpperCase();
	},

	// Keep a UserAgent string for use with jQuery.browser
	userAgent = navigator.userAgent,

	// For matching the engine and version of the browser
	browserMatch,

	// The deferred used on DOM ready
	readyList,

	// The ready event handler
	DOMContentLoaded,

	// Save a reference to some core methods
	toString = Object.prototype.toString,
	hasOwn = Object.prototype.hasOwnProperty,
	push = Array.prototype.push,
	slice = Array.prototype.slice,
	trim = String.prototype.trim,
	indexOf = Array.prototype.indexOf,

	// [[Class]] -> type pairs
	class2type = {};

jQuery.fn = jQuery.prototype = {
	constructor: jQuery,
	init: function( selector, context, rootjQuery ) {
		var match, elem, ret, doc;

		// Handle $(""), $(null), or $(undefined)
		if ( !selector ) {
			return this;
		}

		// Handle $(DOMElement)
		if ( selector.nodeType ) {
			this.context = this[0] = selector;
			this.length = 1;
			return this;
		}

		// The body element only exists once, optimize finding it
		if ( selector === "body" && !context && document.body ) {
			this.context = document;
			this[0] = document.body;
			this.selector = selector;
			this.length = 1;
			return this;
		}

		// Handle HTML strings
		if ( typeof selector === "string" ) {
			// Are we dealing with HTML string or an ID?
			if ( selector.charAt(0) === "<" && selector.charAt( selector.length - 1 ) === ">" && selector.length >= 3 ) {
				// Assume that strings that start and end with <> are HTML and skip the regex check
				match = [ null, selector, null ];

			} else {
				match = quickExpr.exec( selector );
			}

			// Verify a match, and that no context was specified for #id
			if ( match && (match[1] || !context) ) {

				// HANDLE: $(html) -> $(array)
				if ( match[1] ) {
					context = context instanceof jQuery ? context[0] : context;
					doc = ( context ? context.ownerDocument || context : document );

					// If a single string is passed in and it's a single tag
					// just do a createElement and skip the rest
					ret = rsingleTag.exec( selector );

					if ( ret ) {
						if ( jQuery.isPlainObject( context ) ) {
							selector = [ document.createElement( ret[1] ) ];
							jQuery.fn.attr.call( selector, context, true );

						} else {
							selector = [ doc.createElement( ret[1] ) ];
						}

					} else {
						ret = jQuery.buildFragment( [ match[1] ], [ doc ] );
						selector = ( ret.cacheable ? jQuery.clone(ret.fragment) : ret.fragment ).childNodes;
					}

					return jQuery.merge( this, selector );

				// HANDLE: $("#id")
				} else {
					elem = document.getElementById( match[2] );

					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document #6963
					if ( elem && elem.parentNode ) {
						// Handle the case where IE and Opera return items
						// by name instead of ID
						if ( elem.id !== match[2] ) {
							return rootjQuery.find( selector );
						}

						// Otherwise, we inject the element directly into the jQuery object
						this.length = 1;
						this[0] = elem;
					}

					this.context = document;
					this.selector = selector;
					return this;
				}

			// HANDLE: $(expr, $(...))
			} else if ( !context || context.jquery ) {
				return ( context || rootjQuery ).find( selector );

			// HANDLE: $(expr, context)
			// (which is just equivalent to: $(context).find(expr)
			} else {
				return this.constructor( context ).find( selector );
			}

		// HANDLE: $(function)
		// Shortcut for document ready
		} else if ( jQuery.isFunction( selector ) ) {
			return rootjQuery.ready( selector );
		}

		if ( selector.selector !== undefined ) {
			this.selector = selector.selector;
			this.context = selector.context;
		}

		return jQuery.makeArray( selector, this );
	},

	// Start with an empty selector
	selector: "",

	// The current version of jQuery being used
	jquery: "1.7.2",

	// The default length of a jQuery object is 0
	length: 0,

	// The number of elements contained in the matched element set
	size: function() {
		return this.length;
	},

	toArray: function() {
		return slice.call( this, 0 );
	},

	// Get the Nth element in the matched element set OR
	// Get the whole matched element set as a clean array
	get: function( num ) {
		return num == null ?

			// Return a 'clean' array
			this.toArray() :

			// Return just the object
			( num < 0 ? this[ this.length + num ] : this[ num ] );
	},

	// Take an array of elements and push it onto the stack
	// (returning the new matched element set)
	pushStack: function( elems, name, selector ) {
		// Build a new jQuery matched element set
		var ret = this.constructor();

		if ( jQuery.isArray( elems ) ) {
			push.apply( ret, elems );

		} else {
			jQuery.merge( ret, elems );
		}

		// Add the old object onto the stack (as a reference)
		ret.prevObject = this;

		ret.context = this.context;

		if ( name === "find" ) {
			ret.selector = this.selector + ( this.selector ? " " : "" ) + selector;
		} else if ( name ) {
			ret.selector = this.selector + "." + name + "(" + selector + ")";
		}

		// Return the newly-formed element set
		return ret;
	},

	// Execute a callback for every element in the matched set.
	// (You can seed the arguments with an array of args, but this is
	// only used internally.)
	each: function( callback, args ) {
		return jQuery.each( this, callback, args );
	},

	ready: function( fn ) {
		// Attach the listeners
		jQuery.bindReady();

		// Add the callback
		readyList.add( fn );

		return this;
	},

	eq: function( i ) {
		i = +i;
		return i === -1 ?
			this.slice( i ) :
			this.slice( i, i + 1 );
	},

	first: function() {
		return this.eq( 0 );
	},

	last: function() {
		return this.eq( -1 );
	},

	slice: function() {
		return this.pushStack( slice.apply( this, arguments ),
			"slice", slice.call(arguments).join(",") );
	},

	map: function( callback ) {
		return this.pushStack( jQuery.map(this, function( elem, i ) {
			return callback.call( elem, i, elem );
		}));
	},

	end: function() {
		return this.prevObject || this.constructor(null);
	},

	// For internal use only.
	// Behaves like an Array's method, not like a jQuery method.
	push: push,
	sort: [].sort,
	splice: [].splice
};

// Give the init function the jQuery prototype for later instantiation
jQuery.fn.init.prototype = jQuery.fn;

jQuery.extend = jQuery.fn.extend = function() {
	var options, name, src, copy, copyIsArray, clone,
		target = arguments[0] || {},
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if ( typeof target === "boolean" ) {
		deep = target;
		target = arguments[1] || {};
		// skip the boolean and the target
		i = 2;
	}

	// Handle case when target is a string or something (possible in deep copy)
	if ( typeof target !== "object" && !jQuery.isFunction(target) ) {
		target = {};
	}

	// extend jQuery itself if only one argument is passed
	if ( length === i ) {
		target = this;
		--i;
	}

	for ( ; i < length; i++ ) {
		// Only deal with non-null/undefined values
		if ( (options = arguments[ i ]) != null ) {
			// Extend the base object
			for ( name in options ) {
				src = target[ name ];
				copy = options[ name ];

				// Prevent never-ending loop
				if ( target === copy ) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if ( deep && copy && ( jQuery.isPlainObject(copy) || (copyIsArray = jQuery.isArray(copy)) ) ) {
					if ( copyIsArray ) {
						copyIsArray = false;
						clone = src && jQuery.isArray(src) ? src : [];

					} else {
						clone = src && jQuery.isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[ name ] = jQuery.extend( deep, clone, copy );

				// Don't bring in undefined values
				} else if ( copy !== undefined ) {
					target[ name ] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};

jQuery.extend({
	noConflict: function( deep ) {
		if ( window.$ === jQuery ) {
			window.$ = _$;
		}

		if ( deep && window.jQuery === jQuery ) {
			window.jQuery = _jQuery;
		}

		return jQuery;
	},

	// Is the DOM ready to be used? Set to true once it occurs.
	isReady: false,

	// A counter to track how many items to wait for before
	// the ready event fires. See #6781
	readyWait: 1,

	// Hold (or release) the ready event
	holdReady: function( hold ) {
		if ( hold ) {
			jQuery.readyWait++;
		} else {
			jQuery.ready( true );
		}
	},

	// Handle when the DOM is ready
	ready: function( wait ) {
		// Either a released hold or an DOMready/load event and not yet ready
		if ( (wait === true && !--jQuery.readyWait) || (wait !== true && !jQuery.isReady) ) {
			// Make sure body exists, at least, in case IE gets a little overzealous (ticket #5443).
			if ( !document.body ) {
				return setTimeout( jQuery.ready, 1 );
			}

			// Remember that the DOM is ready
			jQuery.isReady = true;

			// If a normal DOM Ready event fired, decrement, and wait if need be
			if ( wait !== true && --jQuery.readyWait > 0 ) {
				return;
			}

			// If there are functions bound, to execute
			readyList.fireWith( document, [ jQuery ] );

			// Trigger any bound ready events
			if ( jQuery.fn.trigger ) {
				jQuery( document ).trigger( "ready" ).off( "ready" );
			}
		}
	},

	bindReady: function() {
		if ( readyList ) {
			return;
		}

		readyList = jQuery.Callbacks( "once memory" );

		// Catch cases where $(document).ready() is called after the
		// browser event has already occurred.
		if ( document.readyState === "complete" ) {
			// Handle it asynchronously to allow scripts the opportunity to delay ready
			return setTimeout( jQuery.ready, 1 );
		}

		// Mozilla, Opera and webkit nightlies currently support this event
		if ( document.addEventListener ) {
			// Use the handy event callback
			document.addEventListener( "DOMContentLoaded", DOMContentLoaded, false );

			// A fallback to window.onload, that will always work
			window.addEventListener( "load", jQuery.ready, false );

		// If IE event model is used
		} else if ( document.attachEvent ) {
			// ensure firing before onload,
			// maybe late but safe also for iframes
			document.attachEvent( "onreadystatechange", DOMContentLoaded );

			// A fallback to window.onload, that will always work
			window.attachEvent( "onload", jQuery.ready );

			// If IE and not a frame
			// continually check to see if the document is ready
			var toplevel = false;

			try {
				toplevel = window.frameElement == null;
			} catch(e) {}

			if ( document.documentElement.doScroll && toplevel ) {
				doScrollCheck();
			}
		}
	},

	// See test/unit/core.js for details concerning isFunction.
	// Since version 1.3, DOM methods and functions like alert
	// aren't supported. They return false on IE (#2968).
	isFunction: function( obj ) {
		return jQuery.type(obj) === "function";
	},

	isArray: Array.isArray || function( obj ) {
		return jQuery.type(obj) === "array";
	},

	isWindow: function( obj ) {
		return obj != null && obj == obj.window;
	},

	isNumeric: function( obj ) {
		return !isNaN( parseFloat(obj) ) && isFinite( obj );
	},

	type: function( obj ) {
		return obj == null ?
			String( obj ) :
			class2type[ toString.call(obj) ] || "object";
	},

	isPlainObject: function( obj ) {
		// Must be an Object.
		// Because of IE, we also have to check the presence of the constructor property.
		// Make sure that DOM nodes and window objects don't pass through, as well
		if ( !obj || jQuery.type(obj) !== "object" || obj.nodeType || jQuery.isWindow( obj ) ) {
			return false;
		}

		try {
			// Not own constructor property must be Object
			if ( obj.constructor &&
				!hasOwn.call(obj, "constructor") &&
				!hasOwn.call(obj.constructor.prototype, "isPrototypeOf") ) {
				return false;
			}
		} catch ( e ) {
			// IE8,9 Will throw exceptions on certain host objects #9897
			return false;
		}

		// Own properties are enumerated firstly, so to speed up,
		// if last one is own, then all properties are own.

		var key;
		for ( key in obj ) {}

		return key === undefined || hasOwn.call( obj, key );
	},

	isEmptyObject: function( obj ) {
		for ( var name in obj ) {
			return false;
		}
		return true;
	},

	error: function( msg ) {
		throw new Error( msg );
	},

	parseJSON: function( data ) {
		if ( typeof data !== "string" || !data ) {
			return null;
		}

		// Make sure leading/trailing whitespace is removed (IE can't handle it)
		data = jQuery.trim( data );

		// Attempt to parse using the native JSON parser first
		if ( window.JSON && window.JSON.parse ) {
			return window.JSON.parse( data );
		}

		// Make sure the incoming data is actual JSON
		// Logic borrowed from http://json.org/json2.js
		if ( rvalidchars.test( data.replace( rvalidescape, "@" )
			.replace( rvalidtokens, "]" )
			.replace( rvalidbraces, "")) ) {

			return ( new Function( "return " + data ) )();

		}
		jQuery.error( "Invalid JSON: " + data );
	},

	// Cross-browser xml parsing
	parseXML: function( data ) {
		if ( typeof data !== "string" || !data ) {
			return null;
		}
		var xml, tmp;
		try {
			if ( window.DOMParser ) { // Standard
				tmp = new DOMParser();
				xml = tmp.parseFromString( data , "text/xml" );
			} else { // IE
				xml = new ActiveXObject( "Microsoft.XMLDOM" );
				xml.async = "false";
				xml.loadXML( data );
			}
		} catch( e ) {
			xml = undefined;
		}
		if ( !xml || !xml.documentElement || xml.getElementsByTagName( "parsererror" ).length ) {
			jQuery.error( "Invalid XML: " + data );
		}
		return xml;
	},

	noop: function() {},

	// Evaluates a script in a global context
	// Workarounds based on findings by Jim Driscoll
	// http://weblogs.java.net/blog/driscoll/archive/2009/09/08/eval-javascript-global-context
	globalEval: function( data ) {
		if ( data && rnotwhite.test( data ) ) {
			// We use execScript on Internet Explorer
			// We use an anonymous function so that context is window
			// rather than jQuery in Firefox
			( window.execScript || function( data ) {
				window[ "eval" ].call( window, data );
			} )( data );
		}
	},

	// Convert dashed to camelCase; used by the css and data modules
	// Microsoft forgot to hump their vendor prefix (#9572)
	camelCase: function( string ) {
		return string.replace( rmsPrefix, "ms-" ).replace( rdashAlpha, fcamelCase );
	},

	nodeName: function( elem, name ) {
		return elem.nodeName && elem.nodeName.toUpperCase() === name.toUpperCase();
	},

	// args is for internal usage only
	each: function( object, callback, args ) {
		var name, i = 0,
			length = object.length,
			isObj = length === undefined || jQuery.isFunction( object );

		if ( args ) {
			if ( isObj ) {
				for ( name in object ) {
					if ( callback.apply( object[ name ], args ) === false ) {
						break;
					}
				}
			} else {
				for ( ; i < length; ) {
					if ( callback.apply( object[ i++ ], args ) === false ) {
						break;
					}
				}
			}

		// A special, fast, case for the most common use of each
		} else {
			if ( isObj ) {
				for ( name in object ) {
					if ( callback.call( object[ name ], name, object[ name ] ) === false ) {
						break;
					}
				}
			} else {
				for ( ; i < length; ) {
					if ( callback.call( object[ i ], i, object[ i++ ] ) === false ) {
						break;
					}
				}
			}
		}

		return object;
	},

	// Use native String.trim function wherever possible
	trim: trim ?
		function( text ) {
			return text == null ?
				"" :
				trim.call( text );
		} :

		// Otherwise use our own trimming functionality
		function( text ) {
			return text == null ?
				"" :
				text.toString().replace( trimLeft, "" ).replace( trimRight, "" );
		},

	// results is for internal usage only
	makeArray: function( array, results ) {
		var ret = results || [];

		if ( array != null ) {
			// The window, strings (and functions) also have 'length'
			// Tweaked logic slightly to handle Blackberry 4.7 RegExp issues #6930
			var type = jQuery.type( array );

			if ( array.length == null || type === "string" || type === "function" || type === "regexp" || jQuery.isWindow( array ) ) {
				push.call( ret, array );
			} else {
				jQuery.merge( ret, array );
			}
		}

		return ret;
	},

	inArray: function( elem, array, i ) {
		var len;

		if ( array ) {
			if ( indexOf ) {
				return indexOf.call( array, elem, i );
			}

			len = array.length;
			i = i ? i < 0 ? Math.max( 0, len + i ) : i : 0;

			for ( ; i < len; i++ ) {
				// Skip accessing in sparse arrays
				if ( i in array && array[ i ] === elem ) {
					return i;
				}
			}
		}

		return -1;
	},

	merge: function( first, second ) {
		var i = first.length,
			j = 0;

		if ( typeof second.length === "number" ) {
			for ( var l = second.length; j < l; j++ ) {
				first[ i++ ] = second[ j ];
			}

		} else {
			while ( second[j] !== undefined ) {
				first[ i++ ] = second[ j++ ];
			}
		}

		first.length = i;

		return first;
	},

	grep: function( elems, callback, inv ) {
		var ret = [], retVal;
		inv = !!inv;

		// Go through the array, only saving the items
		// that pass the validator function
		for ( var i = 0, length = elems.length; i < length; i++ ) {
			retVal = !!callback( elems[ i ], i );
			if ( inv !== retVal ) {
				ret.push( elems[ i ] );
			}
		}

		return ret;
	},

	// arg is for internal usage only
	map: function( elems, callback, arg ) {
		var value, key, ret = [],
			i = 0,
			length = elems.length,
			// jquery objects are treated as arrays
			isArray = elems instanceof jQuery || length !== undefined && typeof length === "number" && ( ( length > 0 && elems[ 0 ] && elems[ length -1 ] ) || length === 0 || jQuery.isArray( elems ) ) ;

		// Go through the array, translating each of the items to their
		if ( isArray ) {
			for ( ; i < length; i++ ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret[ ret.length ] = value;
				}
			}

		// Go through every key on the object,
		} else {
			for ( key in elems ) {
				value = callback( elems[ key ], key, arg );

				if ( value != null ) {
					ret[ ret.length ] = value;
				}
			}
		}

		// Flatten any nested arrays
		return ret.concat.apply( [], ret );
	},

	// A global GUID counter for objects
	guid: 1,

	// Bind a function to a context, optionally partially applying any
	// arguments.
	proxy: function( fn, context ) {
		if ( typeof context === "string" ) {
			var tmp = fn[ context ];
			context = fn;
			fn = tmp;
		}

		// Quick check to determine if target is callable, in the spec
		// this throws a TypeError, but we will just return undefined.
		if ( !jQuery.isFunction( fn ) ) {
			return undefined;
		}

		// Simulated bind
		var args = slice.call( arguments, 2 ),
			proxy = function() {
				return fn.apply( context, args.concat( slice.call( arguments ) ) );
			};

		// Set the guid of unique handler to the same of original handler, so it can be removed
		proxy.guid = fn.guid = fn.guid || proxy.guid || jQuery.guid++;

		return proxy;
	},

	// Mutifunctional method to get and set values to a collection
	// The value/s can optionally be executed if it's a function
	access: function( elems, fn, key, value, chainable, emptyGet, pass ) {
		var exec,
			bulk = key == null,
			i = 0,
			length = elems.length;

		// Sets many values
		if ( key && typeof key === "object" ) {
			for ( i in key ) {
				jQuery.access( elems, fn, i, key[i], 1, emptyGet, value );
			}
			chainable = 1;

		// Sets one value
		} else if ( value !== undefined ) {
			// Optionally, function values get executed if exec is true
			exec = pass === undefined && jQuery.isFunction( value );

			if ( bulk ) {
				// Bulk operations only iterate when executing function values
				if ( exec ) {
					exec = fn;
					fn = function( elem, key, value ) {
						return exec.call( jQuery( elem ), value );
					};

				// Otherwise they run against the entire set
				} else {
					fn.call( elems, value );
					fn = null;
				}
			}

			if ( fn ) {
				for (; i < length; i++ ) {
					fn( elems[i], key, exec ? value.call( elems[i], i, fn( elems[i], key ) ) : value, pass );
				}
			}

			chainable = 1;
		}

		return chainable ?
			elems :

			// Gets
			bulk ?
				fn.call( elems ) :
				length ? fn( elems[0], key ) : emptyGet;
	},

	now: function() {
		return ( new Date() ).getTime();
	},

	// Use of jQuery.browser is frowned upon.
	// More details: http://docs.jquery.com/Utilities/jQuery.browser
	uaMatch: function( ua ) {
		ua = ua.toLowerCase();

		var match = rwebkit.exec( ua ) ||
			ropera.exec( ua ) ||
			rmsie.exec( ua ) ||
			ua.indexOf("compatible") < 0 && rmozilla.exec( ua ) ||
			[];

		return { browser: match[1] || "", version: match[2] || "0" };
	},

	sub: function() {
		function jQuerySub( selector, context ) {
			return new jQuerySub.fn.init( selector, context );
		}
		jQuery.extend( true, jQuerySub, this );
		jQuerySub.superclass = this;
		jQuerySub.fn = jQuerySub.prototype = this();
		jQuerySub.fn.constructor = jQuerySub;
		jQuerySub.sub = this.sub;
		jQuerySub.fn.init = function init( selector, context ) {
			if ( context && context instanceof jQuery && !(context instanceof jQuerySub) ) {
				context = jQuerySub( context );
			}

			return jQuery.fn.init.call( this, selector, context, rootjQuerySub );
		};
		jQuerySub.fn.init.prototype = jQuerySub.fn;
		var rootjQuerySub = jQuerySub(document);
		return jQuerySub;
	},

	browser: {}
});

// Populate the class2type map
jQuery.each("Boolean Number String Function Array Date RegExp Object".split(" "), function(i, name) {
	class2type[ "[object " + name + "]" ] = name.toLowerCase();
});

browserMatch = jQuery.uaMatch( userAgent );
if ( browserMatch.browser ) {
	jQuery.browser[ browserMatch.browser ] = true;
	jQuery.browser.version = browserMatch.version;
}

// Deprecated, use jQuery.browser.webkit instead
if ( jQuery.browser.webkit ) {
	jQuery.browser.safari = true;
}

// IE doesn't match non-breaking spaces with \s
if ( rnotwhite.test( "\xA0" ) ) {
	trimLeft = /^[\s\xA0]+/;
	trimRight = /[\s\xA0]+$/;
}

// All jQuery objects should point back to these
rootjQuery = jQuery(document);

// Cleanup functions for the document ready method
if ( document.addEventListener ) {
	DOMContentLoaded = function() {
		document.removeEventListener( "DOMContentLoaded", DOMContentLoaded, false );
		jQuery.ready();
	};

} else if ( document.attachEvent ) {
	DOMContentLoaded = function() {
		// Make sure body exists, at least, in case IE gets a little overzealous (ticket #5443).
		if ( document.readyState === "complete" ) {
			document.detachEvent( "onreadystatechange", DOMContentLoaded );
			jQuery.ready();
		}
	};
}

// The DOM ready check for Internet Explorer
function doScrollCheck() {
	if ( jQuery.isReady ) {
		return;
	}

	try {
		// If IE is used, use the trick by Diego Perini
		// http://javascript.nwbox.com/IEContentLoaded/
		document.documentElement.doScroll("left");
	} catch(e) {
		setTimeout( doScrollCheck, 1 );
		return;
	}

	// and execute any waiting functions
	jQuery.ready();
}

return jQuery;

})();


// String to Object flags format cache
var flagsCache = {};

// Convert String-formatted flags into Object-formatted ones and store in cache
function createFlags( flags ) {
	var object = flagsCache[ flags ] = {},
		i, length;
	flags = flags.split( /\s+/ );
	for ( i = 0, length = flags.length; i < length; i++ ) {
		object[ flags[i] ] = true;
	}
	return object;
}

/*
 * Create a callback list using the following parameters:
 *
 *	flags:	an optional list of space-separated flags that will change how
 *			the callback list behaves
 *
 * By default a callback list will act like an event callback list and can be
 * "fired" multiple times.
 *
 * Possible flags:
 *
 *	once:			will ensure the callback list can only be fired once (like a Deferred)
 *
 *	memory:			will keep track of previous values and will call any callback added
 *					after the list has been fired right away with the latest "memorized"
 *					values (like a Deferred)
 *
 *	unique:			will ensure a callback can only be added once (no duplicate in the list)
 *
 *	stopOnFalse:	interrupt callings when a callback returns false
 *
 */
jQuery.Callbacks = function( flags ) {

	// Convert flags from String-formatted to Object-formatted
	// (we check in cache first)
	flags = flags ? ( flagsCache[ flags ] || createFlags( flags ) ) : {};

	var // Actual callback list
		list = [],
		// Stack of fire calls for repeatable lists
		stack = [],
		// Last fire value (for non-forgettable lists)
		memory,
		// Flag to know if list was already fired
		fired,
		// Flag to know if list is currently firing
		firing,
		// First callback to fire (used internally by add and fireWith)
		firingStart,
		// End of the loop when firing
		firingLength,
		// Index of currently firing callback (modified by remove if needed)
		firingIndex,
		// Add one or several callbacks to the list
		add = function( args ) {
			var i,
				length,
				elem,
				type,
				actual;
			for ( i = 0, length = args.length; i < length; i++ ) {
				elem = args[ i ];
				type = jQuery.type( elem );
				if ( type === "array" ) {
					// Inspect recursively
					add( elem );
				} else if ( type === "function" ) {
					// Add if not in unique mode and callback is not in
					if ( !flags.unique || !self.has( elem ) ) {
						list.push( elem );
					}
				}
			}
		},
		// Fire callbacks
		fire = function( context, args ) {
			args = args || [];
			memory = !flags.memory || [ context, args ];
			fired = true;
			firing = true;
			firingIndex = firingStart || 0;
			firingStart = 0;
			firingLength = list.length;
			for ( ; list && firingIndex < firingLength; firingIndex++ ) {
				if ( list[ firingIndex ].apply( context, args ) === false && flags.stopOnFalse ) {
					memory = true; // Mark as halted
					break;
				}
			}
			firing = false;
			if ( list ) {
				if ( !flags.once ) {
					if ( stack && stack.length ) {
						memory = stack.shift();
						self.fireWith( memory[ 0 ], memory[ 1 ] );
					}
				} else if ( memory === true ) {
					self.disable();
				} else {
					list = [];
				}
			}
		},
		// Actual Callbacks object
		self = {
			// Add a callback or a collection of callbacks to the list
			add: function() {
				if ( list ) {
					var length = list.length;
					add( arguments );
					// Do we need to add the callbacks to the
					// current firing batch?
					if ( firing ) {
						firingLength = list.length;
					// With memory, if we're not firing then
					// we should call right away, unless previous
					// firing was halted (stopOnFalse)
					} else if ( memory && memory !== true ) {
						firingStart = length;
						fire( memory[ 0 ], memory[ 1 ] );
					}
				}
				return this;
			},
			// Remove a callback from the list
			remove: function() {
				if ( list ) {
					var args = arguments,
						argIndex = 0,
						argLength = args.length;
					for ( ; argIndex < argLength ; argIndex++ ) {
						for ( var i = 0; i < list.length; i++ ) {
							if ( args[ argIndex ] === list[ i ] ) {
								// Handle firingIndex and firingLength
								if ( firing ) {
									if ( i <= firingLength ) {
										firingLength--;
										if ( i <= firingIndex ) {
											firingIndex--;
										}
									}
								}
								// Remove the element
								list.splice( i--, 1 );
								// If we have some unicity property then
								// we only need to do this once
								if ( flags.unique ) {
									break;
								}
							}
						}
					}
				}
				return this;
			},
			// Control if a given callback is in the list
			has: function( fn ) {
				if ( list ) {
					var i = 0,
						length = list.length;
					for ( ; i < length; i++ ) {
						if ( fn === list[ i ] ) {
							return true;
						}
					}
				}
				return false;
			},
			// Remove all callbacks from the list
			empty: function() {
				list = [];
				return this;
			},
			// Have the list do nothing anymore
			disable: function() {
				list = stack = memory = undefined;
				return this;
			},
			// Is it disabled?
			disabled: function() {
				return !list;
			},
			// Lock the list in its current state
			lock: function() {
				stack = undefined;
				if ( !memory || memory === true ) {
					self.disable();
				}
				return this;
			},
			// Is it locked?
			locked: function() {
				return !stack;
			},
			// Call all callbacks with the given context and arguments
			fireWith: function( context, args ) {
				if ( stack ) {
					if ( firing ) {
						if ( !flags.once ) {
							stack.push( [ context, args ] );
						}
					} else if ( !( flags.once && memory ) ) {
						fire( context, args );
					}
				}
				return this;
			},
			// Call all the callbacks with the given arguments
			fire: function() {
				self.fireWith( this, arguments );
				return this;
			},
			// To know if the callbacks have already been called at least once
			fired: function() {
				return !!fired;
			}
		};

	return self;
};




var // Static reference to slice
	sliceDeferred = [].slice;

jQuery.extend({

	Deferred: function( func ) {
		var doneList = jQuery.Callbacks( "once memory" ),
			failList = jQuery.Callbacks( "once memory" ),
			progressList = jQuery.Callbacks( "memory" ),
			state = "pending",
			lists = {
				resolve: doneList,
				reject: failList,
				notify: progressList
			},
			promise = {
				done: doneList.add,
				fail: failList.add,
				progress: progressList.add,

				state: function() {
					return state;
				},

				// Deprecated
				isResolved: doneList.fired,
				isRejected: failList.fired,

				then: function( doneCallbacks, failCallbacks, progressCallbacks ) {
					deferred.done( doneCallbacks ).fail( failCallbacks ).progress( progressCallbacks );
					return this;
				},
				always: function() {
					deferred.done.apply( deferred, arguments ).fail.apply( deferred, arguments );
					return this;
				},
				pipe: function( fnDone, fnFail, fnProgress ) {
					return jQuery.Deferred(function( newDefer ) {
						jQuery.each( {
							done: [ fnDone, "resolve" ],
							fail: [ fnFail, "reject" ],
							progress: [ fnProgress, "notify" ]
						}, function( handler, data ) {
							var fn = data[ 0 ],
								action = data[ 1 ],
								returned;
							if ( jQuery.isFunction( fn ) ) {
								deferred[ handler ](function() {
									returned = fn.apply( this, arguments );
									if ( returned && jQuery.isFunction( returned.promise ) ) {
										returned.promise().then( newDefer.resolve, newDefer.reject, newDefer.notify );
									} else {
										newDefer[ action + "With" ]( this === deferred ? newDefer : this, [ returned ] );
									}
								});
							} else {
								deferred[ handler ]( newDefer[ action ] );
							}
						});
					}).promise();
				},
				// Get a promise for this deferred
				// If obj is provided, the promise aspect is added to the object
				promise: function( obj ) {
					if ( obj == null ) {
						obj = promise;
					} else {
						for ( var key in promise ) {
							obj[ key ] = promise[ key ];
						}
					}
					return obj;
				}
			},
			deferred = promise.promise({}),
			key;

		for ( key in lists ) {
			deferred[ key ] = lists[ key ].fire;
			deferred[ key + "With" ] = lists[ key ].fireWith;
		}

		// Handle state
		deferred.done( function() {
			state = "resolved";
		}, failList.disable, progressList.lock ).fail( function() {
			state = "rejected";
		}, doneList.disable, progressList.lock );

		// Call given func if any
		if ( func ) {
			func.call( deferred, deferred );
		}

		// All done!
		return deferred;
	},

	// Deferred helper
	when: function( firstParam ) {
		var args = sliceDeferred.call( arguments, 0 ),
			i = 0,
			length = args.length,
			pValues = new Array( length ),
			count = length,
			pCount = length,
			deferred = length <= 1 && firstParam && jQuery.isFunction( firstParam.promise ) ?
				firstParam :
				jQuery.Deferred(),
			promise = deferred.promise();
		function resolveFunc( i ) {
			return function( value ) {
				args[ i ] = arguments.length > 1 ? sliceDeferred.call( arguments, 0 ) : value;
				if ( !( --count ) ) {
					deferred.resolveWith( deferred, args );
				}
			};
		}
		function progressFunc( i ) {
			return function( value ) {
				pValues[ i ] = arguments.length > 1 ? sliceDeferred.call( arguments, 0 ) : value;
				deferred.notifyWith( promise, pValues );
			};
		}
		if ( length > 1 ) {
			for ( ; i < length; i++ ) {
				if ( args[ i ] && args[ i ].promise && jQuery.isFunction( args[ i ].promise ) ) {
					args[ i ].promise().then( resolveFunc(i), deferred.reject, progressFunc(i) );
				} else {
					--count;
				}
			}
			if ( !count ) {
				deferred.resolveWith( deferred, args );
			}
		} else if ( deferred !== firstParam ) {
			deferred.resolveWith( deferred, length ? [ firstParam ] : [] );
		}
		return promise;
	}
});




jQuery.support = (function() {

	var support,
		all,
		a,
		select,
		opt,
		input,
		fragment,
		tds,
		events,
		eventName,
		i,
		isSupported,
		div = document.createElement( "div" ),
		documentElement = document.documentElement;

	// Preliminary tests
	div.setAttribute("className", "t");
	div.innerHTML = "   <link/><table></table><a href='/a' style='top:1px;float:left;opacity:.55;'>a</a><input type='checkbox'/>";

	all = div.getElementsByTagName( "*" );
	a = div.getElementsByTagName( "a" )[ 0 ];

	// Can't get basic test support
	if ( !all || !all.length || !a ) {
		return {};
	}

	// First batch of supports tests
	select = document.createElement( "select" );
	opt = select.appendChild( document.createElement("option") );
	input = div.getElementsByTagName( "input" )[ 0 ];

	support = {
		// IE strips leading whitespace when .innerHTML is used
		leadingWhitespace: ( div.firstChild.nodeType === 3 ),

		// Make sure that tbody elements aren't automatically inserted
		// IE will insert them into empty tables
		tbody: !div.getElementsByTagName("tbody").length,

		// Make sure that link elements get serialized correctly by innerHTML
		// This requires a wrapper element in IE
		htmlSerialize: !!div.getElementsByTagName("link").length,

		// Get the style information from getAttribute
		// (IE uses .cssText instead)
		style: /top/.test( a.getAttribute("style") ),

		// Make sure that URLs aren't manipulated
		// (IE normalizes it by default)
		hrefNormalized: ( a.getAttribute("href") === "/a" ),

		// Make sure that element opacity exists
		// (IE uses filter instead)
		// Use a regex to work around a WebKit issue. See #5145
		opacity: /^0.55/.test( a.style.opacity ),

		// Verify style float existence
		// (IE uses styleFloat instead of cssFloat)
		cssFloat: !!a.style.cssFloat,

		// Make sure that if no value is specified for a checkbox
		// that it defaults to "on".
		// (WebKit defaults to "" instead)
		checkOn: ( input.value === "on" ),

		// Make sure that a selected-by-default option has a working selected property.
		// (WebKit defaults to false instead of true, IE too, if it's in an optgroup)
		optSelected: opt.selected,

		// Test setAttribute on camelCase class. If it works, we need attrFixes when doing get/setAttribute (ie6/7)
		getSetAttribute: div.className !== "t",

		// Tests for enctype support on a form(#6743)
		enctype: !!document.createElement("form").enctype,

		// Makes sure cloning an html5 element does not cause problems
		// Where outerHTML is undefined, this still works
		html5Clone: document.createElement("nav").cloneNode( true ).outerHTML !== "<:nav></:nav>",

		// Will be defined later
		submitBubbles: true,
		changeBubbles: true,
		focusinBubbles: false,
		deleteExpando: true,
		noCloneEvent: true,
		inlineBlockNeedsLayout: false,
		shrinkWrapBlocks: false,
		reliableMarginRight: true,
		pixelMargin: true
	};

	// jQuery.boxModel DEPRECATED in 1.3, use jQuery.support.boxModel instead
	jQuery.boxModel = support.boxModel = (document.compatMode === "CSS1Compat");

	// Make sure checked status is properly cloned
	input.checked = true;
	support.noCloneChecked = input.cloneNode( true ).checked;

	// Make sure that the options inside disabled selects aren't marked as disabled
	// (WebKit marks them as disabled)
	select.disabled = true;
	support.optDisabled = !opt.disabled;

	// Test to see if it's possible to delete an expando from an element
	// Fails in Internet Explorer
	try {
		delete div.test;
	} catch( e ) {
		support.deleteExpando = false;
	}

	if ( !div.addEventListener && div.attachEvent && div.fireEvent ) {
		div.attachEvent( "onclick", function() {
			// Cloning a node shouldn't copy over any
			// bound event handlers (IE does this)
			support.noCloneEvent = false;
		});
		div.cloneNode( true ).fireEvent( "onclick" );
	}

	// Check if a radio maintains its value
	// after being appended to the DOM
	input = document.createElement("input");
	input.value = "t";
	input.setAttribute("type", "radio");
	support.radioValue = input.value === "t";

	input.setAttribute("checked", "checked");

	// #11217 - WebKit loses check when the name is after the checked attribute
	input.setAttribute( "name", "t" );

	div.appendChild( input );
	fragment = document.createDocumentFragment();
	fragment.appendChild( div.lastChild );

	// WebKit doesn't clone checked state correctly in fragments
	support.checkClone = fragment.cloneNode( true ).cloneNode( true ).lastChild.checked;

	// Check if a disconnected checkbox will retain its checked
	// value of true after appended to the DOM (IE6/7)
	support.appendChecked = input.checked;

	fragment.removeChild( input );
	fragment.appendChild( div );

	// Technique from Juriy Zaytsev
	// http://perfectionkills.com/detecting-event-support-without-browser-sniffing/
	// We only care about the case where non-standard event systems
	// are used, namely in IE. Short-circuiting here helps us to
	// avoid an eval call (in setAttribute) which can cause CSP
	// to go haywire. See: https://developer.mozilla.org/en/Security/CSP
	if ( div.attachEvent ) {
		for ( i in {
			submit: 1,
			change: 1,
			focusin: 1
		}) {
			eventName = "on" + i;
			isSupported = ( eventName in div );
			if ( !isSupported ) {
				div.setAttribute( eventName, "return;" );
				isSupported = ( typeof div[ eventName ] === "function" );
			}
			support[ i + "Bubbles" ] = isSupported;
		}
	}

	fragment.removeChild( div );

	// Null elements to avoid leaks in IE
	fragment = select = opt = div = input = null;

	// Run tests that need a body at doc ready
	jQuery(function() {
		var container, outer, inner, table, td, offsetSupport,
			marginDiv, conMarginTop, style, html, positionTopLeftWidthHeight,
			paddingMarginBorderVisibility, paddingMarginBorder,
			body = document.getElementsByTagName("body")[0];

		if ( !body ) {
			// Return for frameset docs that don't have a body
			return;
		}

		conMarginTop = 1;
		paddingMarginBorder = "padding:0;margin:0;border:";
		positionTopLeftWidthHeight = "position:absolute;top:0;left:0;width:1px;height:1px;";
		paddingMarginBorderVisibility = paddingMarginBorder + "0;visibility:hidden;";
		style = "style='" + positionTopLeftWidthHeight + paddingMarginBorder + "5px solid #000;";
		html = "<div " + style + "display:block;'><div style='" + paddingMarginBorder + "0;display:block;overflow:hidden;'></div></div>" +
			"<table " + style + "' cellpadding='0' cellspacing='0'>" +
			"<tr><td></td></tr></table>";

		container = document.createElement("div");
		container.style.cssText = paddingMarginBorderVisibility + "width:0;height:0;position:static;top:0;margin-top:" + conMarginTop + "px";
		body.insertBefore( container, body.firstChild );

		// Construct the test element
		div = document.createElement("div");
		container.appendChild( div );

		// Check if table cells still have offsetWidth/Height when they are set
		// to display:none and there are still other visible table cells in a
		// table row; if so, offsetWidth/Height are not reliable for use when
		// determining if an element has been hidden directly using
		// display:none (it is still safe to use offsets if a parent element is
		// hidden; don safety goggles and see bug #4512 for more information).
		// (only IE 8 fails this test)
		div.innerHTML = "<table><tr><td style='" + paddingMarginBorder + "0;display:none'></td><td>t</td></tr></table>";
		tds = div.getElementsByTagName( "td" );
		isSupported = ( tds[ 0 ].offsetHeight === 0 );

		tds[ 0 ].style.display = "";
		tds[ 1 ].style.display = "none";

		// Check if empty table cells still have offsetWidth/Height
		// (IE <= 8 fail this test)
		support.reliableHiddenOffsets = isSupported && ( tds[ 0 ].offsetHeight === 0 );

		// Check if div with explicit width and no margin-right incorrectly
		// gets computed margin-right based on width of container. For more
		// info see bug #3333
		// Fails in WebKit before Feb 2011 nightlies
		// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
		if ( window.getComputedStyle ) {
			div.innerHTML = "";
			marginDiv = document.createElement( "div" );
			marginDiv.style.width = "0";
			marginDiv.style.marginRight = "0";
			div.style.width = "2px";
			div.appendChild( marginDiv );
			support.reliableMarginRight =
				( parseInt( ( window.getComputedStyle( marginDiv, null ) || { marginRight: 0 } ).marginRight, 10 ) || 0 ) === 0;
		}

		if ( typeof div.style.zoom !== "undefined" ) {
			// Check if natively block-level elements act like inline-block
			// elements when setting their display to 'inline' and giving
			// them layout
			// (IE < 8 does this)
			div.innerHTML = "";
			div.style.width = div.style.padding = "1px";
			div.style.border = 0;
			div.style.overflow = "hidden";
			div.style.display = "inline";
			div.style.zoom = 1;
			support.inlineBlockNeedsLayout = ( div.offsetWidth === 3 );

			// Check if elements with layout shrink-wrap their children
			// (IE 6 does this)
			div.style.display = "block";
			div.style.overflow = "visible";
			div.innerHTML = "<div style='width:5px;'></div>";
			support.shrinkWrapBlocks = ( div.offsetWidth !== 3 );
		}

		div.style.cssText = positionTopLeftWidthHeight + paddingMarginBorderVisibility;
		div.innerHTML = html;

		outer = div.firstChild;
		inner = outer.firstChild;
		td = outer.nextSibling.firstChild.firstChild;

		offsetSupport = {
			doesNotAddBorder: ( inner.offsetTop !== 5 ),
			doesAddBorderForTableAndCells: ( td.offsetTop === 5 )
		};

		inner.style.position = "fixed";
		inner.style.top = "20px";

		// safari subtracts parent border width here which is 5px
		offsetSupport.fixedPosition = ( inner.offsetTop === 20 || inner.offsetTop === 15 );
		inner.style.position = inner.style.top = "";

		outer.style.overflow = "hidden";
		outer.style.position = "relative";

		offsetSupport.subtractsBorderForOverflowNotVisible = ( inner.offsetTop === -5 );
		offsetSupport.doesNotIncludeMarginInBodyOffset = ( body.offsetTop !== conMarginTop );

		if ( window.getComputedStyle ) {
			div.style.marginTop = "1%";
			support.pixelMargin = ( window.getComputedStyle( div, null ) || { marginTop: 0 } ).marginTop !== "1%";
		}

		if ( typeof container.style.zoom !== "undefined" ) {
			container.style.zoom = 1;
		}

		body.removeChild( container );
		marginDiv = div = container = null;

		jQuery.extend( support, offsetSupport );
	});

	return support;
})();




var rbrace = /^(?:\{.*\}|\[.*\])$/,
	rmultiDash = /([A-Z])/g;

jQuery.extend({
	cache: {},

	// Please use with caution
	uuid: 0,

	// Unique for each copy of jQuery on the page
	// Non-digits removed to match rinlinejQuery
	expando: "jQuery" + ( jQuery.fn.jquery + Math.random() ).replace( /\D/g, "" ),

	// The following elements throw uncatchable exceptions if you
	// attempt to add expando properties to them.
	noData: {
		"embed": true,
		// Ban all objects except for Flash (which handle expandos)
		"object": "clsid:D27CDB6E-AE6D-11cf-96B8-444553540000",
		"applet": true
	},

	hasData: function( elem ) {
		elem = elem.nodeType ? jQuery.cache[ elem[jQuery.expando] ] : elem[ jQuery.expando ];
		return !!elem && !isEmptyDataObject( elem );
	},

	data: function( elem, name, data, pvt /* Internal Use Only */ ) {
		if ( !jQuery.acceptData( elem ) ) {
			return;
		}

		var privateCache, thisCache, ret,
			internalKey = jQuery.expando,
			getByName = typeof name === "string",

			// We have to handle DOM nodes and JS objects differently because IE6-7
			// can't GC object references properly across the DOM-JS boundary
			isNode = elem.nodeType,

			// Only DOM nodes need the global jQuery cache; JS object data is
			// attached directly to the object so GC can occur automatically
			cache = isNode ? jQuery.cache : elem,

			// Only defining an ID for JS objects if its cache already exists allows
			// the code to shortcut on the same path as a DOM node with no cache
			id = isNode ? elem[ internalKey ] : elem[ internalKey ] && internalKey,
			isEvents = name === "events";

		// Avoid doing any more work than we need to when trying to get data on an
		// object that has no data at all
		if ( (!id || !cache[id] || (!isEvents && !pvt && !cache[id].data)) && getByName && data === undefined ) {
			return;
		}

		if ( !id ) {
			// Only DOM nodes need a new unique ID for each element since their data
			// ends up in the global cache
			if ( isNode ) {
				elem[ internalKey ] = id = ++jQuery.uuid;
			} else {
				id = internalKey;
			}
		}

		if ( !cache[ id ] ) {
			cache[ id ] = {};

			// Avoids exposing jQuery metadata on plain JS objects when the object
			// is serialized using JSON.stringify
			if ( !isNode ) {
				cache[ id ].toJSON = jQuery.noop;
			}
		}

		// An object can be passed to jQuery.data instead of a key/value pair; this gets
		// shallow copied over onto the existing cache
		if ( typeof name === "object" || typeof name === "function" ) {
			if ( pvt ) {
				cache[ id ] = jQuery.extend( cache[ id ], name );
			} else {
				cache[ id ].data = jQuery.extend( cache[ id ].data, name );
			}
		}

		privateCache = thisCache = cache[ id ];

		// jQuery data() is stored in a separate object inside the object's internal data
		// cache in order to avoid key collisions between internal data and user-defined
		// data.
		if ( !pvt ) {
			if ( !thisCache.data ) {
				thisCache.data = {};
			}

			thisCache = thisCache.data;
		}

		if ( data !== undefined ) {
			thisCache[ jQuery.camelCase( name ) ] = data;
		}

		// Users should not attempt to inspect the internal events object using jQuery.data,
		// it is undocumented and subject to change. But does anyone listen? No.
		if ( isEvents && !thisCache[ name ] ) {
			return privateCache.events;
		}

		// Check for both converted-to-camel and non-converted data property names
		// If a data property was specified
		if ( getByName ) {

			// First Try to find as-is property data
			ret = thisCache[ name ];

			// Test for null|undefined property data
			if ( ret == null ) {

				// Try to find the camelCased property
				ret = thisCache[ jQuery.camelCase( name ) ];
			}
		} else {
			ret = thisCache;
		}

		return ret;
	},

	removeData: function( elem, name, pvt /* Internal Use Only */ ) {
		if ( !jQuery.acceptData( elem ) ) {
			return;
		}

		var thisCache, i, l,

			// Reference to internal data cache key
			internalKey = jQuery.expando,

			isNode = elem.nodeType,

			// See jQuery.data for more information
			cache = isNode ? jQuery.cache : elem,

			// See jQuery.data for more information
			id = isNode ? elem[ internalKey ] : internalKey;

		// If there is already no cache entry for this object, there is no
		// purpose in continuing
		if ( !cache[ id ] ) {
			return;
		}

		if ( name ) {

			thisCache = pvt ? cache[ id ] : cache[ id ].data;

			if ( thisCache ) {

				// Support array or space separated string names for data keys
				if ( !jQuery.isArray( name ) ) {

					// try the string as a key before any manipulation
					if ( name in thisCache ) {
						name = [ name ];
					} else {

						// split the camel cased version by spaces unless a key with the spaces exists
						name = jQuery.camelCase( name );
						if ( name in thisCache ) {
							name = [ name ];
						} else {
							name = name.split( " " );
						}
					}
				}

				for ( i = 0, l = name.length; i < l; i++ ) {
					delete thisCache[ name[i] ];
				}

				// If there is no data left in the cache, we want to continue
				// and let the cache object itself get destroyed
				if ( !( pvt ? isEmptyDataObject : jQuery.isEmptyObject )( thisCache ) ) {
					return;
				}
			}
		}

		// See jQuery.data for more information
		if ( !pvt ) {
			delete cache[ id ].data;

			// Don't destroy the parent cache unless the internal data object
			// had been the only thing left in it
			if ( !isEmptyDataObject(cache[ id ]) ) {
				return;
			}
		}

		// Browsers that fail expando deletion also refuse to delete expandos on
		// the window, but it will allow it on all other JS objects; other browsers
		// don't care
		// Ensure that `cache` is not a window object #10080
		if ( jQuery.support.deleteExpando || !cache.setInterval ) {
			delete cache[ id ];
		} else {
			cache[ id ] = null;
		}

		// We destroyed the cache and need to eliminate the expando on the node to avoid
		// false lookups in the cache for entries that no longer exist
		if ( isNode ) {
			// IE does not allow us to delete expando properties from nodes,
			// nor does it have a removeAttribute function on Document nodes;
			// we must handle all of these cases
			if ( jQuery.support.deleteExpando ) {
				delete elem[ internalKey ];
			} else if ( elem.removeAttribute ) {
				elem.removeAttribute( internalKey );
			} else {
				elem[ internalKey ] = null;
			}
		}
	},

	// For internal use only.
	_data: function( elem, name, data ) {
		return jQuery.data( elem, name, data, true );
	},

	// A method for determining if a DOM node can handle the data expando
	acceptData: function( elem ) {
		if ( elem.nodeName ) {
			var match = jQuery.noData[ elem.nodeName.toLowerCase() ];

			if ( match ) {
				return !(match === true || elem.getAttribute("classid") !== match);
			}
		}

		return true;
	}
});

jQuery.fn.extend({
	data: function( key, value ) {
		var parts, part, attr, name, l,
			elem = this[0],
			i = 0,
			data = null;

		// Gets all values
		if ( key === undefined ) {
			if ( this.length ) {
				data = jQuery.data( elem );

				if ( elem.nodeType === 1 && !jQuery._data( elem, "parsedAttrs" ) ) {
					attr = elem.attributes;
					for ( l = attr.length; i < l; i++ ) {
						name = attr[i].name;

						if ( name.indexOf( "data-" ) === 0 ) {
							name = jQuery.camelCase( name.substring(5) );

							dataAttr( elem, name, data[ name ] );
						}
					}
					jQuery._data( elem, "parsedAttrs", true );
				}
			}

			return data;
		}

		// Sets multiple values
		if ( typeof key === "object" ) {
			return this.each(function() {
				jQuery.data( this, key );
			});
		}

		parts = key.split( ".", 2 );
		parts[1] = parts[1] ? "." + parts[1] : "";
		part = parts[1] + "!";

		return jQuery.access( this, function( value ) {

			if ( value === undefined ) {
				data = this.triggerHandler( "getData" + part, [ parts[0] ] );

				// Try to fetch any internally stored data first
				if ( data === undefined && elem ) {
					data = jQuery.data( elem, key );
					data = dataAttr( elem, key, data );
				}

				return data === undefined && parts[1] ?
					this.data( parts[0] ) :
					data;
			}

			parts[1] = value;
			this.each(function() {
				var self = jQuery( this );

				self.triggerHandler( "setData" + part, parts );
				jQuery.data( this, key, value );
				self.triggerHandler( "changeData" + part, parts );
			});
		}, null, value, arguments.length > 1, null, false );
	},

	removeData: function( key ) {
		return this.each(function() {
			jQuery.removeData( this, key );
		});
	}
});

function dataAttr( elem, key, data ) {
	// If nothing was found internally, try to fetch any
	// data from the HTML5 data-* attribute
	if ( data === undefined && elem.nodeType === 1 ) {

		var name = "data-" + key.replace( rmultiDash, "-$1" ).toLowerCase();

		data = elem.getAttribute( name );

		if ( typeof data === "string" ) {
			try {
				data = data === "true" ? true :
				data === "false" ? false :
				data === "null" ? null :
				jQuery.isNumeric( data ) ? +data :
					rbrace.test( data ) ? jQuery.parseJSON( data ) :
					data;
			} catch( e ) {}

			// Make sure we set the data so it isn't changed later
			jQuery.data( elem, key, data );

		} else {
			data = undefined;
		}
	}

	return data;
}

// checks a cache object for emptiness
function isEmptyDataObject( obj ) {
	for ( var name in obj ) {

		// if the public data object is empty, the private is still empty
		if ( name === "data" && jQuery.isEmptyObject( obj[name] ) ) {
			continue;
		}
		if ( name !== "toJSON" ) {
			return false;
		}
	}

	return true;
}




function handleQueueMarkDefer( elem, type, src ) {
	var deferDataKey = type + "defer",
		queueDataKey = type + "queue",
		markDataKey = type + "mark",
		defer = jQuery._data( elem, deferDataKey );
	if ( defer &&
		( src === "queue" || !jQuery._data(elem, queueDataKey) ) &&
		( src === "mark" || !jQuery._data(elem, markDataKey) ) ) {
		// Give room for hard-coded callbacks to fire first
		// and eventually mark/queue something else on the element
		setTimeout( function() {
			if ( !jQuery._data( elem, queueDataKey ) &&
				!jQuery._data( elem, markDataKey ) ) {
				jQuery.removeData( elem, deferDataKey, true );
				defer.fire();
			}
		}, 0 );
	}
}

jQuery.extend({

	_mark: function( elem, type ) {
		if ( elem ) {
			type = ( type || "fx" ) + "mark";
			jQuery._data( elem, type, (jQuery._data( elem, type ) || 0) + 1 );
		}
	},

	_unmark: function( force, elem, type ) {
		if ( force !== true ) {
			type = elem;
			elem = force;
			force = false;
		}
		if ( elem ) {
			type = type || "fx";
			var key = type + "mark",
				count = force ? 0 : ( (jQuery._data( elem, key ) || 1) - 1 );
			if ( count ) {
				jQuery._data( elem, key, count );
			} else {
				jQuery.removeData( elem, key, true );
				handleQueueMarkDefer( elem, type, "mark" );
			}
		}
	},

	queue: function( elem, type, data ) {
		var q;
		if ( elem ) {
			type = ( type || "fx" ) + "queue";
			q = jQuery._data( elem, type );

			// Speed up dequeue by getting out quickly if this is just a lookup
			if ( data ) {
				if ( !q || jQuery.isArray(data) ) {
					q = jQuery._data( elem, type, jQuery.makeArray(data) );
				} else {
					q.push( data );
				}
			}
			return q || [];
		}
	},

	dequeue: function( elem, type ) {
		type = type || "fx";

		var queue = jQuery.queue( elem, type ),
			fn = queue.shift(),
			hooks = {};

		// If the fx queue is dequeued, always remove the progress sentinel
		if ( fn === "inprogress" ) {
			fn = queue.shift();
		}

		if ( fn ) {
			// Add a progress sentinel to prevent the fx queue from being
			// automatically dequeued
			if ( type === "fx" ) {
				queue.unshift( "inprogress" );
			}

			jQuery._data( elem, type + ".run", hooks );
			fn.call( elem, function() {
				jQuery.dequeue( elem, type );
			}, hooks );
		}

		if ( !queue.length ) {
			jQuery.removeData( elem, type + "queue " + type + ".run", true );
			handleQueueMarkDefer( elem, type, "queue" );
		}
	}
});

jQuery.fn.extend({
	queue: function( type, data ) {
		var setter = 2;

		if ( typeof type !== "string" ) {
			data = type;
			type = "fx";
			setter--;
		}

		if ( arguments.length < setter ) {
			return jQuery.queue( this[0], type );
		}

		return data === undefined ?
			this :
			this.each(function() {
				var queue = jQuery.queue( this, type, data );

				if ( type === "fx" && queue[0] !== "inprogress" ) {
					jQuery.dequeue( this, type );
				}
			});
	},
	dequeue: function( type ) {
		return this.each(function() {
			jQuery.dequeue( this, type );
		});
	},
	// Based off of the plugin by Clint Helfers, with permission.
	// http://blindsignals.com/index.php/2009/07/jquery-delay/
	delay: function( time, type ) {
		time = jQuery.fx ? jQuery.fx.speeds[ time ] || time : time;
		type = type || "fx";

		return this.queue( type, function( next, hooks ) {
			var timeout = setTimeout( next, time );
			hooks.stop = function() {
				clearTimeout( timeout );
			};
		});
	},
	clearQueue: function( type ) {
		return this.queue( type || "fx", [] );
	},
	// Get a promise resolved when queues of a certain type
	// are emptied (fx is the type by default)
	promise: function( type, object ) {
		if ( typeof type !== "string" ) {
			object = type;
			type = undefined;
		}
		type = type || "fx";
		var defer = jQuery.Deferred(),
			elements = this,
			i = elements.length,
			count = 1,
			deferDataKey = type + "defer",
			queueDataKey = type + "queue",
			markDataKey = type + "mark",
			tmp;
		function resolve() {
			if ( !( --count ) ) {
				defer.resolveWith( elements, [ elements ] );
			}
		}
		while( i-- ) {
			if (( tmp = jQuery.data( elements[ i ], deferDataKey, undefined, true ) ||
					( jQuery.data( elements[ i ], queueDataKey, undefined, true ) ||
						jQuery.data( elements[ i ], markDataKey, undefined, true ) ) &&
					jQuery.data( elements[ i ], deferDataKey, jQuery.Callbacks( "once memory" ), true ) )) {
				count++;
				tmp.add( resolve );
			}
		}
		resolve();
		return defer.promise( object );
	}
});




var rclass = /[\n\t\r]/g,
	rspace = /\s+/,
	rreturn = /\r/g,
	rtype = /^(?:button|input)$/i,
	rfocusable = /^(?:button|input|object|select|textarea)$/i,
	rclickable = /^a(?:rea)?$/i,
	rboolean = /^(?:autofocus|autoplay|async|checked|controls|defer|disabled|hidden|loop|multiple|open|readonly|required|scoped|selected)$/i,
	getSetAttribute = jQuery.support.getSetAttribute,
	nodeHook, boolHook, fixSpecified;

jQuery.fn.extend({
	attr: function( name, value ) {
		return jQuery.access( this, jQuery.attr, name, value, arguments.length > 1 );
	},

	removeAttr: function( name ) {
		return this.each(function() {
			jQuery.removeAttr( this, name );
		});
	},

	prop: function( name, value ) {
		return jQuery.access( this, jQuery.prop, name, value, arguments.length > 1 );
	},

	removeProp: function( name ) {
		name = jQuery.propFix[ name ] || name;
		return this.each(function() {
			// try/catch handles cases where IE balks (such as removing a property on window)
			try {
				this[ name ] = undefined;
				delete this[ name ];
			} catch( e ) {}
		});
	},

	addClass: function( value ) {
		var classNames, i, l, elem,
			setClass, c, cl;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).addClass( value.call(this, j, this.className) );
			});
		}

		if ( value && typeof value === "string" ) {
			classNames = value.split( rspace );

			for ( i = 0, l = this.length; i < l; i++ ) {
				elem = this[ i ];

				if ( elem.nodeType === 1 ) {
					if ( !elem.className && classNames.length === 1 ) {
						elem.className = value;

					} else {
						setClass = " " + elem.className + " ";

						for ( c = 0, cl = classNames.length; c < cl; c++ ) {
							if ( !~setClass.indexOf( " " + classNames[ c ] + " " ) ) {
								setClass += classNames[ c ] + " ";
							}
						}
						elem.className = jQuery.trim( setClass );
					}
				}
			}
		}

		return this;
	},

	removeClass: function( value ) {
		var classNames, i, l, elem, className, c, cl;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).removeClass( value.call(this, j, this.className) );
			});
		}

		if ( (value && typeof value === "string") || value === undefined ) {
			classNames = ( value || "" ).split( rspace );

			for ( i = 0, l = this.length; i < l; i++ ) {
				elem = this[ i ];

				if ( elem.nodeType === 1 && elem.className ) {
					if ( value ) {
						className = (" " + elem.className + " ").replace( rclass, " " );
						for ( c = 0, cl = classNames.length; c < cl; c++ ) {
							className = className.replace(" " + classNames[ c ] + " ", " ");
						}
						elem.className = jQuery.trim( className );

					} else {
						elem.className = "";
					}
				}
			}
		}

		return this;
	},

	toggleClass: function( value, stateVal ) {
		var type = typeof value,
			isBool = typeof stateVal === "boolean";

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( i ) {
				jQuery( this ).toggleClass( value.call(this, i, this.className, stateVal), stateVal );
			});
		}

		return this.each(function() {
			if ( type === "string" ) {
				// toggle individual class names
				var className,
					i = 0,
					self = jQuery( this ),
					state = stateVal,
					classNames = value.split( rspace );

				while ( (className = classNames[ i++ ]) ) {
					// check each className given, space seperated list
					state = isBool ? state : !self.hasClass( className );
					self[ state ? "addClass" : "removeClass" ]( className );
				}

			} else if ( type === "undefined" || type === "boolean" ) {
				if ( this.className ) {
					// store className if set
					jQuery._data( this, "__className__", this.className );
				}

				// toggle whole className
				this.className = this.className || value === false ? "" : jQuery._data( this, "__className__" ) || "";
			}
		});
	},

	hasClass: function( selector ) {
		var className = " " + selector + " ",
			i = 0,
			l = this.length;
		for ( ; i < l; i++ ) {
			if ( this[i].nodeType === 1 && (" " + this[i].className + " ").replace(rclass, " ").indexOf( className ) > -1 ) {
				return true;
			}
		}

		return false;
	},

	val: function( value ) {
		var hooks, ret, isFunction,
			elem = this[0];

		if ( !arguments.length ) {
			if ( elem ) {
				hooks = jQuery.valHooks[ elem.type ] || jQuery.valHooks[ elem.nodeName.toLowerCase() ];

				if ( hooks && "get" in hooks && (ret = hooks.get( elem, "value" )) !== undefined ) {
					return ret;
				}

				ret = elem.value;

				return typeof ret === "string" ?
					// handle most common string cases
					ret.replace(rreturn, "") :
					// handle cases where value is null/undef or number
					ret == null ? "" : ret;
			}

			return;
		}

		isFunction = jQuery.isFunction( value );

		return this.each(function( i ) {
			var self = jQuery(this), val;

			if ( this.nodeType !== 1 ) {
				return;
			}

			if ( isFunction ) {
				val = value.call( this, i, self.val() );
			} else {
				val = value;
			}

			// Treat null/undefined as ""; convert numbers to string
			if ( val == null ) {
				val = "";
			} else if ( typeof val === "number" ) {
				val += "";
			} else if ( jQuery.isArray( val ) ) {
				val = jQuery.map(val, function ( value ) {
					return value == null ? "" : value + "";
				});
			}

			hooks = jQuery.valHooks[ this.type ] || jQuery.valHooks[ this.nodeName.toLowerCase() ];

			// If set returns undefined, fall back to normal setting
			if ( !hooks || !("set" in hooks) || hooks.set( this, val, "value" ) === undefined ) {
				this.value = val;
			}
		});
	}
});

jQuery.extend({
	valHooks: {
		option: {
			get: function( elem ) {
				// attributes.value is undefined in Blackberry 4.7 but
				// uses .value. See #6932
				var val = elem.attributes.value;
				return !val || val.specified ? elem.value : elem.text;
			}
		},
		select: {
			get: function( elem ) {
				var value, i, max, option,
					index = elem.selectedIndex,
					values = [],
					options = elem.options,
					one = elem.type === "select-one";

				// Nothing was selected
				if ( index < 0 ) {
					return null;
				}

				// Loop through all the selected options
				i = one ? index : 0;
				max = one ? index + 1 : options.length;
				for ( ; i < max; i++ ) {
					option = options[ i ];

					// Don't return options that are disabled or in a disabled optgroup
					if ( option.selected && (jQuery.support.optDisabled ? !option.disabled : option.getAttribute("disabled") === null) &&
							(!option.parentNode.disabled || !jQuery.nodeName( option.parentNode, "optgroup" )) ) {

						// Get the specific value for the option
						value = jQuery( option ).val();

						// We don't need an array for one selects
						if ( one ) {
							return value;
						}

						// Multi-Selects return an array
						values.push( value );
					}
				}

				// Fixes Bug #2551 -- select.val() broken in IE after form.reset()
				if ( one && !values.length && options.length ) {
					return jQuery( options[ index ] ).val();
				}

				return values;
			},

			set: function( elem, value ) {
				var values = jQuery.makeArray( value );

				jQuery(elem).find("option").each(function() {
					this.selected = jQuery.inArray( jQuery(this).val(), values ) >= 0;
				});

				if ( !values.length ) {
					elem.selectedIndex = -1;
				}
				return values;
			}
		}
	},

	attrFn: {
		val: true,
		css: true,
		html: true,
		text: true,
		data: true,
		width: true,
		height: true,
		offset: true
	},

	attr: function( elem, name, value, pass ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// don't get/set attributes on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		if ( pass && name in jQuery.attrFn ) {
			return jQuery( elem )[ name ]( value );
		}

		// Fallback to prop when attributes are not supported
		if ( typeof elem.getAttribute === "undefined" ) {
			return jQuery.prop( elem, name, value );
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		// All attributes are lowercase
		// Grab necessary hook if one is defined
		if ( notxml ) {
			name = name.toLowerCase();
			hooks = jQuery.attrHooks[ name ] || ( rboolean.test( name ) ? boolHook : nodeHook );
		}

		if ( value !== undefined ) {

			if ( value === null ) {
				jQuery.removeAttr( elem, name );
				return;

			} else if ( hooks && "set" in hooks && notxml && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				elem.setAttribute( name, "" + value );
				return value;
			}

		} else if ( hooks && "get" in hooks && notxml && (ret = hooks.get( elem, name )) !== null ) {
			return ret;

		} else {

			ret = elem.getAttribute( name );

			// Non-existent attributes return null, we normalize to undefined
			return ret === null ?
				undefined :
				ret;
		}
	},

	removeAttr: function( elem, value ) {
		var propName, attrNames, name, l, isBool,
			i = 0;

		if ( value && elem.nodeType === 1 ) {
			attrNames = value.toLowerCase().split( rspace );
			l = attrNames.length;

			for ( ; i < l; i++ ) {
				name = attrNames[ i ];

				if ( name ) {
					propName = jQuery.propFix[ name ] || name;
					isBool = rboolean.test( name );

					// See #9699 for explanation of this approach (setting first, then removal)
					// Do not do this for boolean attributes (see #10870)
					if ( !isBool ) {
						jQuery.attr( elem, name, "" );
					}
					elem.removeAttribute( getSetAttribute ? name : propName );

					// Set corresponding property to false for boolean attributes
					if ( isBool && propName in elem ) {
						elem[ propName ] = false;
					}
				}
			}
		}
	},

	attrHooks: {
		type: {
			set: function( elem, value ) {
				// We can't allow the type property to be changed (since it causes problems in IE)
				if ( rtype.test( elem.nodeName ) && elem.parentNode ) {
					jQuery.error( "type property can't be changed" );
				} else if ( !jQuery.support.radioValue && value === "radio" && jQuery.nodeName(elem, "input") ) {
					// Setting the type on a radio button after the value resets the value in IE6-9
					// Reset value to it's default in case type is set after value
					// This is for element creation
					var val = elem.value;
					elem.setAttribute( "type", value );
					if ( val ) {
						elem.value = val;
					}
					return value;
				}
			}
		},
		// Use the value property for back compat
		// Use the nodeHook for button elements in IE6/7 (#1954)
		value: {
			get: function( elem, name ) {
				if ( nodeHook && jQuery.nodeName( elem, "button" ) ) {
					return nodeHook.get( elem, name );
				}
				return name in elem ?
					elem.value :
					null;
			},
			set: function( elem, value, name ) {
				if ( nodeHook && jQuery.nodeName( elem, "button" ) ) {
					return nodeHook.set( elem, value, name );
				}
				// Does not return so that setAttribute is also used
				elem.value = value;
			}
		}
	},

	propFix: {
		tabindex: "tabIndex",
		readonly: "readOnly",
		"for": "htmlFor",
		"class": "className",
		maxlength: "maxLength",
		cellspacing: "cellSpacing",
		cellpadding: "cellPadding",
		rowspan: "rowSpan",
		colspan: "colSpan",
		usemap: "useMap",
		frameborder: "frameBorder",
		contenteditable: "contentEditable"
	},

	prop: function( elem, name, value ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// don't get/set properties on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		if ( notxml ) {
			// Fix name and attach hooks
			name = jQuery.propFix[ name ] || name;
			hooks = jQuery.propHooks[ name ];
		}

		if ( value !== undefined ) {
			if ( hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				return ( elem[ name ] = value );
			}

		} else {
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ) {
				return ret;

			} else {
				return elem[ name ];
			}
		}
	},

	propHooks: {
		tabIndex: {
			get: function( elem ) {
				// elem.tabIndex doesn't always return the correct value when it hasn't been explicitly set
				// http://fluidproject.org/blog/2008/01/09/getting-setting-and-removing-tabindex-values-with-javascript/
				var attributeNode = elem.getAttributeNode("tabindex");

				return attributeNode && attributeNode.specified ?
					parseInt( attributeNode.value, 10 ) :
					rfocusable.test( elem.nodeName ) || rclickable.test( elem.nodeName ) && elem.href ?
						0 :
						undefined;
			}
		}
	}
});

// Add the tabIndex propHook to attrHooks for back-compat (different case is intentional)
jQuery.attrHooks.tabindex = jQuery.propHooks.tabIndex;

// Hook for boolean attributes
boolHook = {
	get: function( elem, name ) {
		// Align boolean attributes with corresponding properties
		// Fall back to attribute presence where some booleans are not supported
		var attrNode,
			property = jQuery.prop( elem, name );
		return property === true || typeof property !== "boolean" && ( attrNode = elem.getAttributeNode(name) ) && attrNode.nodeValue !== false ?
			name.toLowerCase() :
			undefined;
	},
	set: function( elem, value, name ) {
		var propName;
		if ( value === false ) {
			// Remove boolean attributes when set to false
			jQuery.removeAttr( elem, name );
		} else {
			// value is true since we know at this point it's type boolean and not false
			// Set boolean attributes to the same name and set the DOM property
			propName = jQuery.propFix[ name ] || name;
			if ( propName in elem ) {
				// Only set the IDL specifically if it already exists on the element
				elem[ propName ] = true;
			}

			elem.setAttribute( name, name.toLowerCase() );
		}
		return name;
	}
};

// IE6/7 do not support getting/setting some attributes with get/setAttribute
if ( !getSetAttribute ) {

	fixSpecified = {
		name: true,
		id: true,
		coords: true
	};

	// Use this for any attribute in IE6/7
	// This fixes almost every IE6/7 issue
	nodeHook = jQuery.valHooks.button = {
		get: function( elem, name ) {
			var ret;
			ret = elem.getAttributeNode( name );
			return ret && ( fixSpecified[ name ] ? ret.nodeValue !== "" : ret.specified ) ?
				ret.nodeValue :
				undefined;
		},
		set: function( elem, value, name ) {
			// Set the existing or create a new attribute node
			var ret = elem.getAttributeNode( name );
			if ( !ret ) {
				ret = document.createAttribute( name );
				elem.setAttributeNode( ret );
			}
			return ( ret.nodeValue = value + "" );
		}
	};

	// Apply the nodeHook to tabindex
	jQuery.attrHooks.tabindex.set = nodeHook.set;

	// Set width and height to auto instead of 0 on empty string( Bug #8150 )
	// This is for removals
	jQuery.each([ "width", "height" ], function( i, name ) {
		jQuery.attrHooks[ name ] = jQuery.extend( jQuery.attrHooks[ name ], {
			set: function( elem, value ) {
				if ( value === "" ) {
					elem.setAttribute( name, "auto" );
					return value;
				}
			}
		});
	});

	// Set contenteditable to false on removals(#10429)
	// Setting to empty string throws an error as an invalid value
	jQuery.attrHooks.contenteditable = {
		get: nodeHook.get,
		set: function( elem, value, name ) {
			if ( value === "" ) {
				value = "false";
			}
			nodeHook.set( elem, value, name );
		}
	};
}


// Some attributes require a special call on IE
if ( !jQuery.support.hrefNormalized ) {
	jQuery.each([ "href", "src", "width", "height" ], function( i, name ) {
		jQuery.attrHooks[ name ] = jQuery.extend( jQuery.attrHooks[ name ], {
			get: function( elem ) {
				var ret = elem.getAttribute( name, 2 );
				return ret === null ? undefined : ret;
			}
		});
	});
}

if ( !jQuery.support.style ) {
	jQuery.attrHooks.style = {
		get: function( elem ) {
			// Return undefined in the case of empty string
			// Normalize to lowercase since IE uppercases css property names
			return elem.style.cssText.toLowerCase() || undefined;
		},
		set: function( elem, value ) {
			return ( elem.style.cssText = "" + value );
		}
	};
}

// Safari mis-reports the default selected property of an option
// Accessing the parent's selectedIndex property fixes it
if ( !jQuery.support.optSelected ) {
	jQuery.propHooks.selected = jQuery.extend( jQuery.propHooks.selected, {
		get: function( elem ) {
			var parent = elem.parentNode;

			if ( parent ) {
				parent.selectedIndex;

				// Make sure that it also works with optgroups, see #5701
				if ( parent.parentNode ) {
					parent.parentNode.selectedIndex;
				}
			}
			return null;
		}
	});
}

// IE6/7 call enctype encoding
if ( !jQuery.support.enctype ) {
	jQuery.propFix.enctype = "encoding";
}

// Radios and checkboxes getter/setter
if ( !jQuery.support.checkOn ) {
	jQuery.each([ "radio", "checkbox" ], function() {
		jQuery.valHooks[ this ] = {
			get: function( elem ) {
				// Handle the case where in Webkit "" is returned instead of "on" if a value isn't specified
				return elem.getAttribute("value") === null ? "on" : elem.value;
			}
		};
	});
}
jQuery.each([ "radio", "checkbox" ], function() {
	jQuery.valHooks[ this ] = jQuery.extend( jQuery.valHooks[ this ], {
		set: function( elem, value ) {
			if ( jQuery.isArray( value ) ) {
				return ( elem.checked = jQuery.inArray( jQuery(elem).val(), value ) >= 0 );
			}
		}
	});
});




var rformElems = /^(?:textarea|input|select)$/i,
	rtypenamespace = /^([^\.]*)?(?:\.(.+))?$/,
	rhoverHack = /(?:^|\s)hover(\.\S+)?\b/,
	rkeyEvent = /^key/,
	rmouseEvent = /^(?:mouse|contextmenu)|click/,
	rfocusMorph = /^(?:focusinfocus|focusoutblur)$/,
	rquickIs = /^(\w*)(?:#([\w\-]+))?(?:\.([\w\-]+))?$/,
	quickParse = function( selector ) {
		var quick = rquickIs.exec( selector );
		if ( quick ) {
			//   0  1    2   3
			// [ _, tag, id, class ]
			quick[1] = ( quick[1] || "" ).toLowerCase();
			quick[3] = quick[3] && new RegExp( "(?:^|\\s)" + quick[3] + "(?:\\s|$)" );
		}
		return quick;
	},
	quickIs = function( elem, m ) {
		var attrs = elem.attributes || {};
		return (
			(!m[1] || elem.nodeName.toLowerCase() === m[1]) &&
			(!m[2] || (attrs.id || {}).value === m[2]) &&
			(!m[3] || m[3].test( (attrs[ "class" ] || {}).value ))
		);
	},
	hoverHack = function( events ) {
		return jQuery.event.special.hover ? events : events.replace( rhoverHack, "mouseenter$1 mouseleave$1" );
	};

/*
 * Helper functions for managing events -- not part of the public interface.
 * Props to Dean Edwards' addEvent library for many of the ideas.
 */
jQuery.event = {

	add: function( elem, types, handler, data, selector ) {

		var elemData, eventHandle, events,
			t, tns, type, namespaces, handleObj,
			handleObjIn, quick, handlers, special;

		// Don't attach events to noData or text/comment nodes (allow plain objects tho)
		if ( elem.nodeType === 3 || elem.nodeType === 8 || !types || !handler || !(elemData = jQuery._data( elem )) ) {
			return;
		}

		// Caller can pass in an object of custom data in lieu of the handler
		if ( handler.handler ) {
			handleObjIn = handler;
			handler = handleObjIn.handler;
			selector = handleObjIn.selector;
		}

		// Make sure that the handler has a unique ID, used to find/remove it later
		if ( !handler.guid ) {
			handler.guid = jQuery.guid++;
		}

		// Init the element's event structure and main handler, if this is the first
		events = elemData.events;
		if ( !events ) {
			elemData.events = events = {};
		}
		eventHandle = elemData.handle;
		if ( !eventHandle ) {
			elemData.handle = eventHandle = function( e ) {
				// Discard the second event of a jQuery.event.trigger() and
				// when an event is called after a page has unloaded
				return typeof jQuery !== "undefined" && (!e || jQuery.event.triggered !== e.type) ?
					jQuery.event.dispatch.apply( eventHandle.elem, arguments ) :
					undefined;
			};
			// Add elem as a property of the handle fn to prevent a memory leak with IE non-native events
			eventHandle.elem = elem;
		}

		// Handle multiple events separated by a space
		// jQuery(...).bind("mouseover mouseout", fn);
		types = jQuery.trim( hoverHack(types) ).split( " " );
		for ( t = 0; t < types.length; t++ ) {

			tns = rtypenamespace.exec( types[t] ) || [];
			type = tns[1];
			namespaces = ( tns[2] || "" ).split( "." ).sort();

			// If event changes its type, use the special event handlers for the changed type
			special = jQuery.event.special[ type ] || {};

			// If selector defined, determine special event api type, otherwise given type
			type = ( selector ? special.delegateType : special.bindType ) || type;

			// Update special based on newly reset type
			special = jQuery.event.special[ type ] || {};

			// handleObj is passed to all event handlers
			handleObj = jQuery.extend({
				type: type,
				origType: tns[1],
				data: data,
				handler: handler,
				guid: handler.guid,
				selector: selector,
				quick: selector && quickParse( selector ),
				namespace: namespaces.join(".")
			}, handleObjIn );

			// Init the event handler queue if we're the first
			handlers = events[ type ];
			if ( !handlers ) {
				handlers = events[ type ] = [];
				handlers.delegateCount = 0;

				// Only use addEventListener/attachEvent if the special events handler returns false
				if ( !special.setup || special.setup.call( elem, data, namespaces, eventHandle ) === false ) {
					// Bind the global event handler to the element
					if ( elem.addEventListener ) {
						elem.addEventListener( type, eventHandle, false );

					} else if ( elem.attachEvent ) {
						elem.attachEvent( "on" + type, eventHandle );
					}
				}
			}

			if ( special.add ) {
				special.add.call( elem, handleObj );

				if ( !handleObj.handler.guid ) {
					handleObj.handler.guid = handler.guid;
				}
			}

			// Add to the element's handler list, delegates in front
			if ( selector ) {
				handlers.splice( handlers.delegateCount++, 0, handleObj );
			} else {
				handlers.push( handleObj );
			}

			// Keep track of which events have ever been used, for event optimization
			jQuery.event.global[ type ] = true;
		}

		// Nullify elem to prevent memory leaks in IE
		elem = null;
	},

	global: {},

	// Detach an event or set of events from an element
	remove: function( elem, types, handler, selector, mappedTypes ) {

		var elemData = jQuery.hasData( elem ) && jQuery._data( elem ),
			t, tns, type, origType, namespaces, origCount,
			j, events, special, handle, eventType, handleObj;

		if ( !elemData || !(events = elemData.events) ) {
			return;
		}

		// Once for each type.namespace in types; type may be omitted
		types = jQuery.trim( hoverHack( types || "" ) ).split(" ");
		for ( t = 0; t < types.length; t++ ) {
			tns = rtypenamespace.exec( types[t] ) || [];
			type = origType = tns[1];
			namespaces = tns[2];

			// Unbind all events (on this namespace, if provided) for the element
			if ( !type ) {
				for ( type in events ) {
					jQuery.event.remove( elem, type + types[ t ], handler, selector, true );
				}
				continue;
			}

			special = jQuery.event.special[ type ] || {};
			type = ( selector? special.delegateType : special.bindType ) || type;
			eventType = events[ type ] || [];
			origCount = eventType.length;
			namespaces = namespaces ? new RegExp("(^|\\.)" + namespaces.split(".").sort().join("\\.(?:.*\\.)?") + "(\\.|$)") : null;

			// Remove matching events
			for ( j = 0; j < eventType.length; j++ ) {
				handleObj = eventType[ j ];

				if ( ( mappedTypes || origType === handleObj.origType ) &&
					 ( !handler || handler.guid === handleObj.guid ) &&
					 ( !namespaces || namespaces.test( handleObj.namespace ) ) &&
					 ( !selector || selector === handleObj.selector || selector === "**" && handleObj.selector ) ) {
					eventType.splice( j--, 1 );

					if ( handleObj.selector ) {
						eventType.delegateCount--;
					}
					if ( special.remove ) {
						special.remove.call( elem, handleObj );
					}
				}
			}

			// Remove generic event handler if we removed something and no more handlers exist
			// (avoids potential for endless recursion during removal of special event handlers)
			if ( eventType.length === 0 && origCount !== eventType.length ) {
				if ( !special.teardown || special.teardown.call( elem, namespaces ) === false ) {
					jQuery.removeEvent( elem, type, elemData.handle );
				}

				delete events[ type ];
			}
		}

		// Remove the expando if it's no longer used
		if ( jQuery.isEmptyObject( events ) ) {
			handle = elemData.handle;
			if ( handle ) {
				handle.elem = null;
			}

			// removeData also checks for emptiness and clears the expando if empty
			// so use it instead of delete
			jQuery.removeData( elem, [ "events", "handle" ], true );
		}
	},

	// Events that are safe to short-circuit if no handlers are attached.
	// Native DOM events should not be added, they may have inline handlers.
	customEvent: {
		"getData": true,
		"setData": true,
		"changeData": true
	},

	trigger: function( event, data, elem, onlyHandlers ) {
		// Don't do events on text and comment nodes
		if ( elem && (elem.nodeType === 3 || elem.nodeType === 8) ) {
			return;
		}

		// Event object or event type
		var type = event.type || event,
			namespaces = [],
			cache, exclusive, i, cur, old, ontype, special, handle, eventPath, bubbleType;

		// focus/blur morphs to focusin/out; ensure we're not firing them right now
		if ( rfocusMorph.test( type + jQuery.event.triggered ) ) {
			return;
		}

		if ( type.indexOf( "!" ) >= 0 ) {
			// Exclusive events trigger only for the exact event (no namespaces)
			type = type.slice(0, -1);
			exclusive = true;
		}

		if ( type.indexOf( "." ) >= 0 ) {
			// Namespaced trigger; create a regexp to match event type in handle()
			namespaces = type.split(".");
			type = namespaces.shift();
			namespaces.sort();
		}

		if ( (!elem || jQuery.event.customEvent[ type ]) && !jQuery.event.global[ type ] ) {
			// No jQuery handlers for this event type, and it can't have inline handlers
			return;
		}

		// Caller can pass in an Event, Object, or just an event type string
		event = typeof event === "object" ?
			// jQuery.Event object
			event[ jQuery.expando ] ? event :
			// Object literal
			new jQuery.Event( type, event ) :
			// Just the event type (string)
			new jQuery.Event( type );

		event.type = type;
		event.isTrigger = true;
		event.exclusive = exclusive;
		event.namespace = namespaces.join( "." );
		event.namespace_re = event.namespace? new RegExp("(^|\\.)" + namespaces.join("\\.(?:.*\\.)?") + "(\\.|$)") : null;
		ontype = type.indexOf( ":" ) < 0 ? "on" + type : "";

		// Handle a global trigger
		if ( !elem ) {

			// TODO: Stop taunting the data cache; remove global events and always attach to document
			cache = jQuery.cache;
			for ( i in cache ) {
				if ( cache[ i ].events && cache[ i ].events[ type ] ) {
					jQuery.event.trigger( event, data, cache[ i ].handle.elem, true );
				}
			}
			return;
		}

		// Clean up the event in case it is being reused
		event.result = undefined;
		if ( !event.target ) {
			event.target = elem;
		}

		// Clone any incoming data and prepend the event, creating the handler arg list
		data = data != null ? jQuery.makeArray( data ) : [];
		data.unshift( event );

		// Allow special events to draw outside the lines
		special = jQuery.event.special[ type ] || {};
		if ( special.trigger && special.trigger.apply( elem, data ) === false ) {
			return;
		}

		// Determine event propagation path in advance, per W3C events spec (#9951)
		// Bubble up to document, then to window; watch for a global ownerDocument var (#9724)
		eventPath = [[ elem, special.bindType || type ]];
		if ( !onlyHandlers && !special.noBubble && !jQuery.isWindow( elem ) ) {

			bubbleType = special.delegateType || type;
			cur = rfocusMorph.test( bubbleType + type ) ? elem : elem.parentNode;
			old = null;
			for ( ; cur; cur = cur.parentNode ) {
				eventPath.push([ cur, bubbleType ]);
				old = cur;
			}

			// Only add window if we got to document (e.g., not plain obj or detached DOM)
			if ( old && old === elem.ownerDocument ) {
				eventPath.push([ old.defaultView || old.parentWindow || window, bubbleType ]);
			}
		}

		// Fire handlers on the event path
		for ( i = 0; i < eventPath.length && !event.isPropagationStopped(); i++ ) {

			cur = eventPath[i][0];
			event.type = eventPath[i][1];

			handle = ( jQuery._data( cur, "events" ) || {} )[ event.type ] && jQuery._data( cur, "handle" );
			if ( handle ) {
				handle.apply( cur, data );
			}
			// Note that this is a bare JS function and not a jQuery handler
			handle = ontype && cur[ ontype ];
			if ( handle && jQuery.acceptData( cur ) && handle.apply( cur, data ) === false ) {
				event.preventDefault();
			}
		}
		event.type = type;

		// If nobody prevented the default action, do it now
		if ( !onlyHandlers && !event.isDefaultPrevented() ) {

			if ( (!special._default || special._default.apply( elem.ownerDocument, data ) === false) &&
				!(type === "click" && jQuery.nodeName( elem, "a" )) && jQuery.acceptData( elem ) ) {

				// Call a native DOM method on the target with the same name name as the event.
				// Can't use an .isFunction() check here because IE6/7 fails that test.
				// Don't do default actions on window, that's where global variables be (#6170)
				// IE<9 dies on focus/blur to hidden element (#1486)
				if ( ontype && elem[ type ] && ((type !== "focus" && type !== "blur") || event.target.offsetWidth !== 0) && !jQuery.isWindow( elem ) ) {

					// Don't re-trigger an onFOO event when we call its FOO() method
					old = elem[ ontype ];

					if ( old ) {
						elem[ ontype ] = null;
					}

					// Prevent re-triggering of the same event, since we already bubbled it above
					jQuery.event.triggered = type;
					elem[ type ]();
					jQuery.event.triggered = undefined;

					if ( old ) {
						elem[ ontype ] = old;
					}
				}
			}
		}

		return event.result;
	},

	dispatch: function( event ) {

		// Make a writable jQuery.Event from the native event object
		event = jQuery.event.fix( event || window.event );

		var handlers = ( (jQuery._data( this, "events" ) || {} )[ event.type ] || []),
			delegateCount = handlers.delegateCount,
			args = [].slice.call( arguments, 0 ),
			run_all = !event.exclusive && !event.namespace,
			special = jQuery.event.special[ event.type ] || {},
			handlerQueue = [],
			i, j, cur, jqcur, ret, selMatch, matched, matches, handleObj, sel, related;

		// Use the fix-ed jQuery.Event rather than the (read-only) native event
		args[0] = event;
		event.delegateTarget = this;

		// Call the preDispatch hook for the mapped type, and let it bail if desired
		if ( special.preDispatch && special.preDispatch.call( this, event ) === false ) {
			return;
		}

		// Determine handlers that should run if there are delegated events
		// Avoid non-left-click bubbling in Firefox (#3861)
		if ( delegateCount && !(event.button && event.type === "click") ) {

			// Pregenerate a single jQuery object for reuse with .is()
			jqcur = jQuery(this);
			jqcur.context = this.ownerDocument || this;

			for ( cur = event.target; cur != this; cur = cur.parentNode || this ) {

				// Don't process events on disabled elements (#6911, #8165)
				if ( cur.disabled !== true ) {
					selMatch = {};
					matches = [];
					jqcur[0] = cur;
					for ( i = 0; i < delegateCount; i++ ) {
						handleObj = handlers[ i ];
						sel = handleObj.selector;

						if ( selMatch[ sel ] === undefined ) {
							selMatch[ sel ] = (
								handleObj.quick ? quickIs( cur, handleObj.quick ) : jqcur.is( sel )
							);
						}
						if ( selMatch[ sel ] ) {
							matches.push( handleObj );
						}
					}
					if ( matches.length ) {
						handlerQueue.push({ elem: cur, matches: matches });
					}
				}
			}
		}

		// Add the remaining (directly-bound) handlers
		if ( handlers.length > delegateCount ) {
			handlerQueue.push({ elem: this, matches: handlers.slice( delegateCount ) });
		}

		// Run delegates first; they may want to stop propagation beneath us
		for ( i = 0; i < handlerQueue.length && !event.isPropagationStopped(); i++ ) {
			matched = handlerQueue[ i ];
			event.currentTarget = matched.elem;

			for ( j = 0; j < matched.matches.length && !event.isImmediatePropagationStopped(); j++ ) {
				handleObj = matched.matches[ j ];

				// Triggered event must either 1) be non-exclusive and have no namespace, or
				// 2) have namespace(s) a subset or equal to those in the bound event (both can have no namespace).
				if ( run_all || (!event.namespace && !handleObj.namespace) || event.namespace_re && event.namespace_re.test( handleObj.namespace ) ) {

					event.data = handleObj.data;
					event.handleObj = handleObj;

					ret = ( (jQuery.event.special[ handleObj.origType ] || {}).handle || handleObj.handler )
							.apply( matched.elem, args );

					if ( ret !== undefined ) {
						event.result = ret;
						if ( ret === false ) {
							event.preventDefault();
							event.stopPropagation();
						}
					}
				}
			}
		}

		// Call the postDispatch hook for the mapped type
		if ( special.postDispatch ) {
			special.postDispatch.call( this, event );
		}

		return event.result;
	},

	// Includes some event props shared by KeyEvent and MouseEvent
	// *** attrChange attrName relatedNode srcElement  are not normalized, non-W3C, deprecated, will be removed in 1.8 ***
	props: "attrChange attrName relatedNode srcElement altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),

	fixHooks: {},

	keyHooks: {
		props: "char charCode key keyCode".split(" "),
		filter: function( event, original ) {

			// Add which for key events
			if ( event.which == null ) {
				event.which = original.charCode != null ? original.charCode : original.keyCode;
			}

			return event;
		}
	},

	mouseHooks: {
		props: "button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement".split(" "),
		filter: function( event, original ) {
			var eventDoc, doc, body,
				button = original.button,
				fromElement = original.fromElement;

			// Calculate pageX/Y if missing and clientX/Y available
			if ( event.pageX == null && original.clientX != null ) {
				eventDoc = event.target.ownerDocument || document;
				doc = eventDoc.documentElement;
				body = eventDoc.body;

				event.pageX = original.clientX + ( doc && doc.scrollLeft || body && body.scrollLeft || 0 ) - ( doc && doc.clientLeft || body && body.clientLeft || 0 );
				event.pageY = original.clientY + ( doc && doc.scrollTop  || body && body.scrollTop  || 0 ) - ( doc && doc.clientTop  || body && body.clientTop  || 0 );
			}

			// Add relatedTarget, if necessary
			if ( !event.relatedTarget && fromElement ) {
				event.relatedTarget = fromElement === event.target ? original.toElement : fromElement;
			}

			// Add which for click: 1 === left; 2 === middle; 3 === right
			// Note: button is not normalized, so don't use it
			if ( !event.which && button !== undefined ) {
				event.which = ( button & 1 ? 1 : ( button & 2 ? 3 : ( button & 4 ? 2 : 0 ) ) );
			}

			return event;
		}
	},

	fix: function( event ) {
		if ( event[ jQuery.expando ] ) {
			return event;
		}

		// Create a writable copy of the event object and normalize some properties
		var i, prop,
			originalEvent = event,
			fixHook = jQuery.event.fixHooks[ event.type ] || {},
			copy = fixHook.props ? this.props.concat( fixHook.props ) : this.props;

		event = jQuery.Event( originalEvent );

		for ( i = copy.length; i; ) {
			prop = copy[ --i ];
			event[ prop ] = originalEvent[ prop ];
		}

		// Fix target property, if necessary (#1925, IE 6/7/8 & Safari2)
		if ( !event.target ) {
			event.target = originalEvent.srcElement || document;
		}

		// Target should not be a text node (#504, Safari)
		if ( event.target.nodeType === 3 ) {
			event.target = event.target.parentNode;
		}

		// For mouse/key events; add metaKey if it's not there (#3368, IE6/7/8)
		if ( event.metaKey === undefined ) {
			event.metaKey = event.ctrlKey;
		}

		return fixHook.filter? fixHook.filter( event, originalEvent ) : event;
	},

	special: {
		ready: {
			// Make sure the ready event is setup
			setup: jQuery.bindReady
		},

		load: {
			// Prevent triggered image.load events from bubbling to window.load
			noBubble: true
		},

		focus: {
			delegateType: "focusin"
		},
		blur: {
			delegateType: "focusout"
		},

		beforeunload: {
			setup: function( data, namespaces, eventHandle ) {
				// We only want to do this special case on windows
				if ( jQuery.isWindow( this ) ) {
					this.onbeforeunload = eventHandle;
				}
			},

			teardown: function( namespaces, eventHandle ) {
				if ( this.onbeforeunload === eventHandle ) {
					this.onbeforeunload = null;
				}
			}
		}
	},

	simulate: function( type, elem, event, bubble ) {
		// Piggyback on a donor event to simulate a different one.
		// Fake originalEvent to avoid donor's stopPropagation, but if the
		// simulated event prevents default then we do the same on the donor.
		var e = jQuery.extend(
			new jQuery.Event(),
			event,
			{ type: type,
				isSimulated: true,
				originalEvent: {}
			}
		);
		if ( bubble ) {
			jQuery.event.trigger( e, null, elem );
		} else {
			jQuery.event.dispatch.call( elem, e );
		}
		if ( e.isDefaultPrevented() ) {
			event.preventDefault();
		}
	}
};

// Some plugins are using, but it's undocumented/deprecated and will be removed.
// The 1.7 special event interface should provide all the hooks needed now.
jQuery.event.handle = jQuery.event.dispatch;

jQuery.removeEvent = document.removeEventListener ?
	function( elem, type, handle ) {
		if ( elem.removeEventListener ) {
			elem.removeEventListener( type, handle, false );
		}
	} :
	function( elem, type, handle ) {
		if ( elem.detachEvent ) {
			elem.detachEvent( "on" + type, handle );
		}
	};

jQuery.Event = function( src, props ) {
	// Allow instantiation without the 'new' keyword
	if ( !(this instanceof jQuery.Event) ) {
		return new jQuery.Event( src, props );
	}

	// Event object
	if ( src && src.type ) {
		this.originalEvent = src;
		this.type = src.type;

		// Events bubbling up the document may have been marked as prevented
		// by a handler lower down the tree; reflect the correct value.
		this.isDefaultPrevented = ( src.defaultPrevented || src.returnValue === false ||
			src.getPreventDefault && src.getPreventDefault() ) ? returnTrue : returnFalse;

	// Event type
	} else {
		this.type = src;
	}

	// Put explicitly provided properties onto the event object
	if ( props ) {
		jQuery.extend( this, props );
	}

	// Create a timestamp if incoming event doesn't have one
	this.timeStamp = src && src.timeStamp || jQuery.now();

	// Mark it as fixed
	this[ jQuery.expando ] = true;
};

function returnFalse() {
	return false;
}
function returnTrue() {
	return true;
}

// jQuery.Event is based on DOM3 Events as specified by the ECMAScript Language Binding
// http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331/ecma-script-binding.html
jQuery.Event.prototype = {
	preventDefault: function() {
		this.isDefaultPrevented = returnTrue;

		var e = this.originalEvent;
		if ( !e ) {
			return;
		}

		// if preventDefault exists run it on the original event
		if ( e.preventDefault ) {
			e.preventDefault();

		// otherwise set the returnValue property of the original event to false (IE)
		} else {
			e.returnValue = false;
		}
	},
	stopPropagation: function() {
		this.isPropagationStopped = returnTrue;

		var e = this.originalEvent;
		if ( !e ) {
			return;
		}
		// if stopPropagation exists run it on the original event
		if ( e.stopPropagation ) {
			e.stopPropagation();
		}
		// otherwise set the cancelBubble property of the original event to true (IE)
		e.cancelBubble = true;
	},
	stopImmediatePropagation: function() {
		this.isImmediatePropagationStopped = returnTrue;
		this.stopPropagation();
	},
	isDefaultPrevented: returnFalse,
	isPropagationStopped: returnFalse,
	isImmediatePropagationStopped: returnFalse
};

// Create mouseenter/leave events using mouseover/out and event-time checks
jQuery.each({
	mouseenter: "mouseover",
	mouseleave: "mouseout"
}, function( orig, fix ) {
	jQuery.event.special[ orig ] = {
		delegateType: fix,
		bindType: fix,

		handle: function( event ) {
			var target = this,
				related = event.relatedTarget,
				handleObj = event.handleObj,
				selector = handleObj.selector,
				ret;

			// For mousenter/leave call the handler if related is outside the target.
			// NB: No relatedTarget if the mouse left/entered the browser window
			if ( !related || (related !== target && !jQuery.contains( target, related )) ) {
				event.type = handleObj.origType;
				ret = handleObj.handler.apply( this, arguments );
				event.type = fix;
			}
			return ret;
		}
	};
});

// IE submit delegation
if ( !jQuery.support.submitBubbles ) {

	jQuery.event.special.submit = {
		setup: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Lazy-add a submit handler when a descendant form may potentially be submitted
			jQuery.event.add( this, "click._submit keypress._submit", function( e ) {
				// Node name check avoids a VML-related crash in IE (#9807)
				var elem = e.target,
					form = jQuery.nodeName( elem, "input" ) || jQuery.nodeName( elem, "button" ) ? elem.form : undefined;
				if ( form && !form._submit_attached ) {
					jQuery.event.add( form, "submit._submit", function( event ) {
						event._submit_bubble = true;
					});
					form._submit_attached = true;
				}
			});
			// return undefined since we don't need an event listener
		},
		
		postDispatch: function( event ) {
			// If form was submitted by the user, bubble the event up the tree
			if ( event._submit_bubble ) {
				delete event._submit_bubble;
				if ( this.parentNode && !event.isTrigger ) {
					jQuery.event.simulate( "submit", this.parentNode, event, true );
				}
			}
		},

		teardown: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Remove delegated handlers; cleanData eventually reaps submit handlers attached above
			jQuery.event.remove( this, "._submit" );
		}
	};
}

// IE change delegation and checkbox/radio fix
if ( !jQuery.support.changeBubbles ) {

	jQuery.event.special.change = {

		setup: function() {

			if ( rformElems.test( this.nodeName ) ) {
				// IE doesn't fire change on a check/radio until blur; trigger it on click
				// after a propertychange. Eat the blur-change in special.change.handle.
				// This still fires onchange a second time for check/radio after blur.
				if ( this.type === "checkbox" || this.type === "radio" ) {
					jQuery.event.add( this, "propertychange._change", function( event ) {
						if ( event.originalEvent.propertyName === "checked" ) {
							this._just_changed = true;
						}
					});
					jQuery.event.add( this, "click._change", function( event ) {
						if ( this._just_changed && !event.isTrigger ) {
							this._just_changed = false;
							jQuery.event.simulate( "change", this, event, true );
						}
					});
				}
				return false;
			}
			// Delegated event; lazy-add a change handler on descendant inputs
			jQuery.event.add( this, "beforeactivate._change", function( e ) {
				var elem = e.target;

				if ( rformElems.test( elem.nodeName ) && !elem._change_attached ) {
					jQuery.event.add( elem, "change._change", function( event ) {
						if ( this.parentNode && !event.isSimulated && !event.isTrigger ) {
							jQuery.event.simulate( "change", this.parentNode, event, true );
						}
					});
					elem._change_attached = true;
				}
			});
		},

		handle: function( event ) {
			var elem = event.target;

			// Swallow native change events from checkbox/radio, we already triggered them above
			if ( this !== elem || event.isSimulated || event.isTrigger || (elem.type !== "radio" && elem.type !== "checkbox") ) {
				return event.handleObj.handler.apply( this, arguments );
			}
		},

		teardown: function() {
			jQuery.event.remove( this, "._change" );

			return rformElems.test( this.nodeName );
		}
	};
}

// Create "bubbling" focus and blur events
if ( !jQuery.support.focusinBubbles ) {
	jQuery.each({ focus: "focusin", blur: "focusout" }, function( orig, fix ) {

		// Attach a single capturing handler while someone wants focusin/focusout
		var attaches = 0,
			handler = function( event ) {
				jQuery.event.simulate( fix, event.target, jQuery.event.fix( event ), true );
			};

		jQuery.event.special[ fix ] = {
			setup: function() {
				if ( attaches++ === 0 ) {
					document.addEventListener( orig, handler, true );
				}
			},
			teardown: function() {
				if ( --attaches === 0 ) {
					document.removeEventListener( orig, handler, true );
				}
			}
		};
	});
}

jQuery.fn.extend({

	on: function( types, selector, data, fn, /*INTERNAL*/ one ) {
		var origFn, type;

		// Types can be a map of types/handlers
		if ( typeof types === "object" ) {
			// ( types-Object, selector, data )
			if ( typeof selector !== "string" ) { // && selector != null
				// ( types-Object, data )
				data = data || selector;
				selector = undefined;
			}
			for ( type in types ) {
				this.on( type, selector, data, types[ type ], one );
			}
			return this;
		}

		if ( data == null && fn == null ) {
			// ( types, fn )
			fn = selector;
			data = selector = undefined;
		} else if ( fn == null ) {
			if ( typeof selector === "string" ) {
				// ( types, selector, fn )
				fn = data;
				data = undefined;
			} else {
				// ( types, data, fn )
				fn = data;
				data = selector;
				selector = undefined;
			}
		}
		if ( fn === false ) {
			fn = returnFalse;
		} else if ( !fn ) {
			return this;
		}

		if ( one === 1 ) {
			origFn = fn;
			fn = function( event ) {
				// Can use an empty set, since event contains the info
				jQuery().off( event );
				return origFn.apply( this, arguments );
			};
			// Use same guid so caller can remove using origFn
			fn.guid = origFn.guid || ( origFn.guid = jQuery.guid++ );
		}
		return this.each( function() {
			jQuery.event.add( this, types, fn, data, selector );
		});
	},
	one: function( types, selector, data, fn ) {
		return this.on( types, selector, data, fn, 1 );
	},
	off: function( types, selector, fn ) {
		if ( types && types.preventDefault && types.handleObj ) {
			// ( event )  dispatched jQuery.Event
			var handleObj = types.handleObj;
			jQuery( types.delegateTarget ).off(
				handleObj.namespace ? handleObj.origType + "." + handleObj.namespace : handleObj.origType,
				handleObj.selector,
				handleObj.handler
			);
			return this;
		}
		if ( typeof types === "object" ) {
			// ( types-object [, selector] )
			for ( var type in types ) {
				this.off( type, selector, types[ type ] );
			}
			return this;
		}
		if ( selector === false || typeof selector === "function" ) {
			// ( types [, fn] )
			fn = selector;
			selector = undefined;
		}
		if ( fn === false ) {
			fn = returnFalse;
		}
		return this.each(function() {
			jQuery.event.remove( this, types, fn, selector );
		});
	},

	bind: function( types, data, fn ) {
		return this.on( types, null, data, fn );
	},
	unbind: function( types, fn ) {
		return this.off( types, null, fn );
	},

	live: function( types, data, fn ) {
		jQuery( this.context ).on( types, this.selector, data, fn );
		return this;
	},
	die: function( types, fn ) {
		jQuery( this.context ).off( types, this.selector || "**", fn );
		return this;
	},

	delegate: function( selector, types, data, fn ) {
		return this.on( types, selector, data, fn );
	},
	undelegate: function( selector, types, fn ) {
		// ( namespace ) or ( selector, types [, fn] )
		return arguments.length == 1? this.off( selector, "**" ) : this.off( types, selector, fn );
	},

	trigger: function( type, data ) {
		return this.each(function() {
			jQuery.event.trigger( type, data, this );
		});
	},
	triggerHandler: function( type, data ) {
		if ( this[0] ) {
			return jQuery.event.trigger( type, data, this[0], true );
		}
	},

	toggle: function( fn ) {
		// Save reference to arguments for access in closure
		var args = arguments,
			guid = fn.guid || jQuery.guid++,
			i = 0,
			toggler = function( event ) {
				// Figure out which function to execute
				var lastToggle = ( jQuery._data( this, "lastToggle" + fn.guid ) || 0 ) % i;
				jQuery._data( this, "lastToggle" + fn.guid, lastToggle + 1 );

				// Make sure that clicks stop
				event.preventDefault();

				// and execute the function
				return args[ lastToggle ].apply( this, arguments ) || false;
			};

		// link all the functions, so any of them can unbind this click handler
		toggler.guid = guid;
		while ( i < args.length ) {
			args[ i++ ].guid = guid;
		}

		return this.click( toggler );
	},

	hover: function( fnOver, fnOut ) {
		return this.mouseenter( fnOver ).mouseleave( fnOut || fnOver );
	}
});

jQuery.each( ("blur focus focusin focusout load resize scroll unload click dblclick " +
	"mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave " +
	"change select submit keydown keypress keyup error contextmenu").split(" "), function( i, name ) {

	// Handle event binding
	jQuery.fn[ name ] = function( data, fn ) {
		if ( fn == null ) {
			fn = data;
			data = null;
		}

		return arguments.length > 0 ?
			this.on( name, null, data, fn ) :
			this.trigger( name );
	};

	if ( jQuery.attrFn ) {
		jQuery.attrFn[ name ] = true;
	}

	if ( rkeyEvent.test( name ) ) {
		jQuery.event.fixHooks[ name ] = jQuery.event.keyHooks;
	}

	if ( rmouseEvent.test( name ) ) {
		jQuery.event.fixHooks[ name ] = jQuery.event.mouseHooks;
	}
});



/*!
 * Sizzle CSS Selector Engine
 *  Copyright 2011, The Dojo Foundation
 *  Released under the MIT, BSD, and GPL Licenses.
 *  More information: http://sizzlejs.com/
 */
(function(){

var chunker = /((?:\((?:\([^()]+\)|[^()]+)+\)|\[(?:\[[^\[\]]*\]|['"][^'"]*['"]|[^\[\]'"]+)+\]|\\.|[^ >+~,(\[\\]+)+|[>+~])(\s*,\s*)?((?:.|\r|\n)*)/g,
	expando = "sizcache" + (Math.random() + '').replace('.', ''),
	done = 0,
	toString = Object.prototype.toString,
	hasDuplicate = false,
	baseHasDuplicate = true,
	rBackslash = /\\/g,
	rReturn = /\r\n/g,
	rNonWord = /\W/;

// Here we check if the JavaScript engine is using some sort of
// optimization where it does not always call our comparision
// function. If that is the case, discard the hasDuplicate value.
//   Thus far that includes Google Chrome.
[0, 0].sort(function() {
	baseHasDuplicate = false;
	return 0;
});

var Sizzle = function( selector, context, results, seed ) {
	results = results || [];
	context = context || document;

	var origContext = context;

	if ( context.nodeType !== 1 && context.nodeType !== 9 ) {
		return [];
	}

	if ( !selector || typeof selector !== "string" ) {
		return results;
	}

	var m, set, checkSet, extra, ret, cur, pop, i,
		prune = true,
		contextXML = Sizzle.isXML( context ),
		parts = [],
		soFar = selector;

	// Reset the position of the chunker regexp (start from head)
	do {
		chunker.exec( "" );
		m = chunker.exec( soFar );

		if ( m ) {
			soFar = m[3];

			parts.push( m[1] );

			if ( m[2] ) {
				extra = m[3];
				break;
			}
		}
	} while ( m );

	if ( parts.length > 1 && origPOS.exec( selector ) ) {

		if ( parts.length === 2 && Expr.relative[ parts[0] ] ) {
			set = posProcess( parts[0] + parts[1], context, seed );

		} else {
			set = Expr.relative[ parts[0] ] ?
				[ context ] :
				Sizzle( parts.shift(), context );

			while ( parts.length ) {
				selector = parts.shift();

				if ( Expr.relative[ selector ] ) {
					selector += parts.shift();
				}

				set = posProcess( selector, set, seed );
			}
		}

	} else {
		// Take a shortcut and set the context if the root selector is an ID
		// (but not if it'll be faster if the inner selector is an ID)
		if ( !seed && parts.length > 1 && context.nodeType === 9 && !contextXML &&
				Expr.match.ID.test(parts[0]) && !Expr.match.ID.test(parts[parts.length - 1]) ) {

			ret = Sizzle.find( parts.shift(), context, contextXML );
			context = ret.expr ?
				Sizzle.filter( ret.expr, ret.set )[0] :
				ret.set[0];
		}

		if ( context ) {
			ret = seed ?
				{ expr: parts.pop(), set: makeArray(seed) } :
				Sizzle.find( parts.pop(), parts.length === 1 && (parts[0] === "~" || parts[0] === "+") && context.parentNode ? context.parentNode : context, contextXML );

			set = ret.expr ?
				Sizzle.filter( ret.expr, ret.set ) :
				ret.set;

			if ( parts.length > 0 ) {
				checkSet = makeArray( set );

			} else {
				prune = false;
			}

			while ( parts.length ) {
				cur = parts.pop();
				pop = cur;

				if ( !Expr.relative[ cur ] ) {
					cur = "";
				} else {
					pop = parts.pop();
				}

				if ( pop == null ) {
					pop = context;
				}

				Expr.relative[ cur ]( checkSet, pop, contextXML );
			}

		} else {
			checkSet = parts = [];
		}
	}

	if ( !checkSet ) {
		checkSet = set;
	}

	if ( !checkSet ) {
		Sizzle.error( cur || selector );
	}

	if ( toString.call(checkSet) === "[object Array]" ) {
		if ( !prune ) {
			results.push.apply( results, checkSet );

		} else if ( context && context.nodeType === 1 ) {
			for ( i = 0; checkSet[i] != null; i++ ) {
				if ( checkSet[i] && (checkSet[i] === true || checkSet[i].nodeType === 1 && Sizzle.contains(context, checkSet[i])) ) {
					results.push( set[i] );
				}
			}

		} else {
			for ( i = 0; checkSet[i] != null; i++ ) {
				if ( checkSet[i] && checkSet[i].nodeType === 1 ) {
					results.push( set[i] );
				}
			}
		}

	} else {
		makeArray( checkSet, results );
	}

	if ( extra ) {
		Sizzle( extra, origContext, results, seed );
		Sizzle.uniqueSort( results );
	}

	return results;
};

Sizzle.uniqueSort = function( results ) {
	if ( sortOrder ) {
		hasDuplicate = baseHasDuplicate;
		results.sort( sortOrder );

		if ( hasDuplicate ) {
			for ( var i = 1; i < results.length; i++ ) {
				if ( results[i] === results[ i - 1 ] ) {
					results.splice( i--, 1 );
				}
			}
		}
	}

	return results;
};

Sizzle.matches = function( expr, set ) {
	return Sizzle( expr, null, null, set );
};

Sizzle.matchesSelector = function( node, expr ) {
	return Sizzle( expr, null, null, [node] ).length > 0;
};

Sizzle.find = function( expr, context, isXML ) {
	var set, i, len, match, type, left;

	if ( !expr ) {
		return [];
	}

	for ( i = 0, len = Expr.order.length; i < len; i++ ) {
		type = Expr.order[i];

		if ( (match = Expr.leftMatch[ type ].exec( expr )) ) {
			left = match[1];
			match.splice( 1, 1 );

			if ( left.substr( left.length - 1 ) !== "\\" ) {
				match[1] = (match[1] || "").replace( rBackslash, "" );
				set = Expr.find[ type ]( match, context, isXML );

				if ( set != null ) {
					expr = expr.replace( Expr.match[ type ], "" );
					break;
				}
			}
		}
	}

	if ( !set ) {
		set = typeof context.getElementsByTagName !== "undefined" ?
			context.getElementsByTagName( "*" ) :
			[];
	}

	return { set: set, expr: expr };
};

Sizzle.filter = function( expr, set, inplace, not ) {
	var match, anyFound,
		type, found, item, filter, left,
		i, pass,
		old = expr,
		result = [],
		curLoop = set,
		isXMLFilter = set && set[0] && Sizzle.isXML( set[0] );

	while ( expr && set.length ) {
		for ( type in Expr.filter ) {
			if ( (match = Expr.leftMatch[ type ].exec( expr )) != null && match[2] ) {
				filter = Expr.filter[ type ];
				left = match[1];

				anyFound = false;

				match.splice(1,1);

				if ( left.substr( left.length - 1 ) === "\\" ) {
					continue;
				}

				if ( curLoop === result ) {
					result = [];
				}

				if ( Expr.preFilter[ type ] ) {
					match = Expr.preFilter[ type ]( match, curLoop, inplace, result, not, isXMLFilter );

					if ( !match ) {
						anyFound = found = true;

					} else if ( match === true ) {
						continue;
					}
				}

				if ( match ) {
					for ( i = 0; (item = curLoop[i]) != null; i++ ) {
						if ( item ) {
							found = filter( item, match, i, curLoop );
							pass = not ^ found;

							if ( inplace && found != null ) {
								if ( pass ) {
									anyFound = true;

								} else {
									curLoop[i] = false;
								}

							} else if ( pass ) {
								result.push( item );
								anyFound = true;
							}
						}
					}
				}

				if ( found !== undefined ) {
					if ( !inplace ) {
						curLoop = result;
					}

					expr = expr.replace( Expr.match[ type ], "" );

					if ( !anyFound ) {
						return [];
					}

					break;
				}
			}
		}

		// Improper expression
		if ( expr === old ) {
			if ( anyFound == null ) {
				Sizzle.error( expr );

			} else {
				break;
			}
		}

		old = expr;
	}

	return curLoop;
};

Sizzle.error = function( msg ) {
	throw new Error( "Syntax error, unrecognized expression: " + msg );
};

/**
 * Utility function for retreiving the text value of an array of DOM nodes
 * @param {Array|Element} elem
 */
var getText = Sizzle.getText = function( elem ) {
    var i, node,
		nodeType = elem.nodeType,
		ret = "";

	if ( nodeType ) {
		if ( nodeType === 1 || nodeType === 9 || nodeType === 11 ) {
			// Use textContent || innerText for elements
			if ( typeof elem.textContent === 'string' ) {
				return elem.textContent;
			} else if ( typeof elem.innerText === 'string' ) {
				// Replace IE's carriage returns
				return elem.innerText.replace( rReturn, '' );
			} else {
				// Traverse it's children
				for ( elem = elem.firstChild; elem; elem = elem.nextSibling) {
					ret += getText( elem );
				}
			}
		} else if ( nodeType === 3 || nodeType === 4 ) {
			return elem.nodeValue;
		}
	} else {

		// If no nodeType, this is expected to be an array
		for ( i = 0; (node = elem[i]); i++ ) {
			// Do not traverse comment nodes
			if ( node.nodeType !== 8 ) {
				ret += getText( node );
			}
		}
	}
	return ret;
};

var Expr = Sizzle.selectors = {
	order: [ "ID", "NAME", "TAG" ],

	match: {
		ID: /#((?:[\w\u00c0-\uFFFF\-]|\\.)+)/,
		CLASS: /\.((?:[\w\u00c0-\uFFFF\-]|\\.)+)/,
		NAME: /\[name=['"]*((?:[\w\u00c0-\uFFFF\-]|\\.)+)['"]*\]/,
		ATTR: /\[\s*((?:[\w\u00c0-\uFFFF\-]|\\.)+)\s*(?:(\S?=)\s*(?:(['"])(.*?)\3|(#?(?:[\w\u00c0-\uFFFF\-]|\\.)*)|)|)\s*\]/,
		TAG: /^((?:[\w\u00c0-\uFFFF\*\-]|\\.)+)/,
		CHILD: /:(only|nth|last|first)-child(?:\(\s*(even|odd|(?:[+\-]?\d+|(?:[+\-]?\d*)?n\s*(?:[+\-]\s*\d+)?))\s*\))?/,
		POS: /:(nth|eq|gt|lt|first|last|even|odd)(?:\((\d*)\))?(?=[^\-]|$)/,
		PSEUDO: /:((?:[\w\u00c0-\uFFFF\-]|\\.)+)(?:\((['"]?)((?:\([^\)]+\)|[^\(\)]*)+)\2\))?/
	},

	leftMatch: {},

	attrMap: {
		"class": "className",
		"for": "htmlFor"
	},

	attrHandle: {
		href: function( elem ) {
			return elem.getAttribute( "href" );
		},
		type: function( elem ) {
			return elem.getAttribute( "type" );
		}
	},

	relative: {
		"+": function(checkSet, part){
			var isPartStr = typeof part === "string",
				isTag = isPartStr && !rNonWord.test( part ),
				isPartStrNotTag = isPartStr && !isTag;

			if ( isTag ) {
				part = part.toLowerCase();
			}

			for ( var i = 0, l = checkSet.length, elem; i < l; i++ ) {
				if ( (elem = checkSet[i]) ) {
					while ( (elem = elem.previousSibling) && elem.nodeType !== 1 ) {}

					checkSet[i] = isPartStrNotTag || elem && elem.nodeName.toLowerCase() === part ?
						elem || false :
						elem === part;
				}
			}

			if ( isPartStrNotTag ) {
				Sizzle.filter( part, checkSet, true );
			}
		},

		">": function( checkSet, part ) {
			var elem,
				isPartStr = typeof part === "string",
				i = 0,
				l = checkSet.length;

			if ( isPartStr && !rNonWord.test( part ) ) {
				part = part.toLowerCase();

				for ( ; i < l; i++ ) {
					elem = checkSet[i];

					if ( elem ) {
						var parent = elem.parentNode;
						checkSet[i] = parent.nodeName.toLowerCase() === part ? parent : false;
					}
				}

			} else {
				for ( ; i < l; i++ ) {
					elem = checkSet[i];

					if ( elem ) {
						checkSet[i] = isPartStr ?
							elem.parentNode :
							elem.parentNode === part;
					}
				}

				if ( isPartStr ) {
					Sizzle.filter( part, checkSet, true );
				}
			}
		},

		"": function(checkSet, part, isXML){
			var nodeCheck,
				doneName = done++,
				checkFn = dirCheck;

			if ( typeof part === "string" && !rNonWord.test( part ) ) {
				part = part.toLowerCase();
				nodeCheck = part;
				checkFn = dirNodeCheck;
			}

			checkFn( "parentNode", part, doneName, checkSet, nodeCheck, isXML );
		},

		"~": function( checkSet, part, isXML ) {
			var nodeCheck,
				doneName = done++,
				checkFn = dirCheck;

			if ( typeof part === "string" && !rNonWord.test( part ) ) {
				part = part.toLowerCase();
				nodeCheck = part;
				checkFn = dirNodeCheck;
			}

			checkFn( "previousSibling", part, doneName, checkSet, nodeCheck, isXML );
		}
	},

	find: {
		ID: function( match, context, isXML ) {
			if ( typeof context.getElementById !== "undefined" && !isXML ) {
				var m = context.getElementById(match[1]);
				// Check parentNode to catch when Blackberry 4.6 returns
				// nodes that are no longer in the document #6963
				return m && m.parentNode ? [m] : [];
			}
		},

		NAME: function( match, context ) {
			if ( typeof context.getElementsByName !== "undefined" ) {
				var ret = [],
					results = context.getElementsByName( match[1] );

				for ( var i = 0, l = results.length; i < l; i++ ) {
					if ( results[i].getAttribute("name") === match[1] ) {
						ret.push( results[i] );
					}
				}

				return ret.length === 0 ? null : ret;
			}
		},

		TAG: function( match, context ) {
			if ( typeof context.getElementsByTagName !== "undefined" ) {
				return context.getElementsByTagName( match[1] );
			}
		}
	},
	preFilter: {
		CLASS: function( match, curLoop, inplace, result, not, isXML ) {
			match = " " + match[1].replace( rBackslash, "" ) + " ";

			if ( isXML ) {
				return match;
			}

			for ( var i = 0, elem; (elem = curLoop[i]) != null; i++ ) {
				if ( elem ) {
					if ( not ^ (elem.className && (" " + elem.className + " ").replace(/[\t\n\r]/g, " ").indexOf(match) >= 0) ) {
						if ( !inplace ) {
							result.push( elem );
						}

					} else if ( inplace ) {
						curLoop[i] = false;
					}
				}
			}

			return false;
		},

		ID: function( match ) {
			return match[1].replace( rBackslash, "" );
		},

		TAG: function( match, curLoop ) {
			return match[1].replace( rBackslash, "" ).toLowerCase();
		},

		CHILD: function( match ) {
			if ( match[1] === "nth" ) {
				if ( !match[2] ) {
					Sizzle.error( match[0] );
				}

				match[2] = match[2].replace(/^\+|\s*/g, '');

				// parse equations like 'even', 'odd', '5', '2n', '3n+2', '4n-1', '-n+6'
				var test = /(-?)(\d*)(?:n([+\-]?\d*))?/.exec(
					match[2] === "even" && "2n" || match[2] === "odd" && "2n+1" ||
					!/\D/.test( match[2] ) && "0n+" + match[2] || match[2]);

				// calculate the numbers (first)n+(last) including if they are negative
				match[2] = (test[1] + (test[2] || 1)) - 0;
				match[3] = test[3] - 0;
			}
			else if ( match[2] ) {
				Sizzle.error( match[0] );
			}

			// TODO: Move to normal caching system
			match[0] = done++;

			return match;
		},

		ATTR: function( match, curLoop, inplace, result, not, isXML ) {
			var name = match[1] = match[1].replace( rBackslash, "" );

			if ( !isXML && Expr.attrMap[name] ) {
				match[1] = Expr.attrMap[name];
			}

			// Handle if an un-quoted value was used
			match[4] = ( match[4] || match[5] || "" ).replace( rBackslash, "" );

			if ( match[2] === "~=" ) {
				match[4] = " " + match[4] + " ";
			}

			return match;
		},

		PSEUDO: function( match, curLoop, inplace, result, not ) {
			if ( match[1] === "not" ) {
				// If we're dealing with a complex expression, or a simple one
				if ( ( chunker.exec(match[3]) || "" ).length > 1 || /^\w/.test(match[3]) ) {
					match[3] = Sizzle(match[3], null, null, curLoop);

				} else {
					var ret = Sizzle.filter(match[3], curLoop, inplace, true ^ not);

					if ( !inplace ) {
						result.push.apply( result, ret );
					}

					return false;
				}

			} else if ( Expr.match.POS.test( match[0] ) || Expr.match.CHILD.test( match[0] ) ) {
				return true;
			}

			return match;
		},

		POS: function( match ) {
			match.unshift( true );

			return match;
		}
	},

	filters: {
		enabled: function( elem ) {
			return elem.disabled === false && elem.type !== "hidden";
		},

		disabled: function( elem ) {
			return elem.disabled === true;
		},

		checked: function( elem ) {
			return elem.checked === true;
		},

		selected: function( elem ) {
			// Accessing this property makes selected-by-default
			// options in Safari work properly
			if ( elem.parentNode ) {
				elem.parentNode.selectedIndex;
			}

			return elem.selected === true;
		},

		parent: function( elem ) {
			return !!elem.firstChild;
		},

		empty: function( elem ) {
			return !elem.firstChild;
		},

		has: function( elem, i, match ) {
			return !!Sizzle( match[3], elem ).length;
		},

		header: function( elem ) {
			return (/h\d/i).test( elem.nodeName );
		},

		text: function( elem ) {
			var attr = elem.getAttribute( "type" ), type = elem.type;
			// IE6 and 7 will map elem.type to 'text' for new HTML5 types (search, etc)
			// use getAttribute instead to test this case
			return elem.nodeName.toLowerCase() === "input" && "text" === type && ( attr === type || attr === null );
		},

		radio: function( elem ) {
			return elem.nodeName.toLowerCase() === "input" && "radio" === elem.type;
		},

		checkbox: function( elem ) {
			return elem.nodeName.toLowerCase() === "input" && "checkbox" === elem.type;
		},

		file: function( elem ) {
			return elem.nodeName.toLowerCase() === "input" && "file" === elem.type;
		},

		password: function( elem ) {
			return elem.nodeName.toLowerCase() === "input" && "password" === elem.type;
		},

		submit: function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return (name === "input" || name === "button") && "submit" === elem.type;
		},

		image: function( elem ) {
			return elem.nodeName.toLowerCase() === "input" && "image" === elem.type;
		},

		reset: function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return (name === "input" || name === "button") && "reset" === elem.type;
		},

		button: function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return name === "input" && "button" === elem.type || name === "button";
		},

		input: function( elem ) {
			return (/input|select|textarea|button/i).test( elem.nodeName );
		},

		focus: function( elem ) {
			return elem === elem.ownerDocument.activeElement;
		}
	},
	setFilters: {
		first: function( elem, i ) {
			return i === 0;
		},

		last: function( elem, i, match, array ) {
			return i === array.length - 1;
		},

		even: function( elem, i ) {
			return i % 2 === 0;
		},

		odd: function( elem, i ) {
			return i % 2 === 1;
		},

		lt: function( elem, i, match ) {
			return i < match[3] - 0;
		},

		gt: function( elem, i, match ) {
			return i > match[3] - 0;
		},

		nth: function( elem, i, match ) {
			return match[3] - 0 === i;
		},

		eq: function( elem, i, match ) {
			return match[3] - 0 === i;
		}
	},
	filter: {
		PSEUDO: function( elem, match, i, array ) {
			var name = match[1],
				filter = Expr.filters[ name ];

			if ( filter ) {
				return filter( elem, i, match, array );

			} else if ( name === "contains" ) {
				return (elem.textContent || elem.innerText || getText([ elem ]) || "").indexOf(match[3]) >= 0;

			} else if ( name === "not" ) {
				var not = match[3];

				for ( var j = 0, l = not.length; j < l; j++ ) {
					if ( not[j] === elem ) {
						return false;
					}
				}

				return true;

			} else {
				Sizzle.error( name );
			}
		},

		CHILD: function( elem, match ) {
			var first, last,
				doneName, parent, cache,
				count, diff,
				type = match[1],
				node = elem;

			switch ( type ) {
				case "only":
				case "first":
					while ( (node = node.previousSibling) ) {
						if ( node.nodeType === 1 ) {
							return false;
						}
					}

					if ( type === "first" ) {
						return true;
					}

					node = elem;

					/* falls through */
				case "last":
					while ( (node = node.nextSibling) ) {
						if ( node.nodeType === 1 ) {
							return false;
						}
					}

					return true;

				case "nth":
					first = match[2];
					last = match[3];

					if ( first === 1 && last === 0 ) {
						return true;
					}

					doneName = match[0];
					parent = elem.parentNode;

					if ( parent && (parent[ expando ] !== doneName || !elem.nodeIndex) ) {
						count = 0;

						for ( node = parent.firstChild; node; node = node.nextSibling ) {
							if ( node.nodeType === 1 ) {
								node.nodeIndex = ++count;
							}
						}

						parent[ expando ] = doneName;
					}

					diff = elem.nodeIndex - last;

					if ( first === 0 ) {
						return diff === 0;

					} else {
						return ( diff % first === 0 && diff / first >= 0 );
					}
			}
		},

		ID: function( elem, match ) {
			return elem.nodeType === 1 && elem.getAttribute("id") === match;
		},

		TAG: function( elem, match ) {
			return (match === "*" && elem.nodeType === 1) || !!elem.nodeName && elem.nodeName.toLowerCase() === match;
		},

		CLASS: function( elem, match ) {
			return (" " + (elem.className || elem.getAttribute("class")) + " ")
				.indexOf( match ) > -1;
		},

		ATTR: function( elem, match ) {
			var name = match[1],
				result = Sizzle.attr ?
					Sizzle.attr( elem, name ) :
					Expr.attrHandle[ name ] ?
					Expr.attrHandle[ name ]( elem ) :
					elem[ name ] != null ?
						elem[ name ] :
						elem.getAttribute( name ),
				value = result + "",
				type = match[2],
				check = match[4];

			return result == null ?
				type === "!=" :
				!type && Sizzle.attr ?
				result != null :
				type === "=" ?
				value === check :
				type === "*=" ?
				value.indexOf(check) >= 0 :
				type === "~=" ?
				(" " + value + " ").indexOf(check) >= 0 :
				!check ?
				value && result !== false :
				type === "!=" ?
				value !== check :
				type === "^=" ?
				value.indexOf(check) === 0 :
				type === "$=" ?
				value.substr(value.length - check.length) === check :
				type === "|=" ?
				value === check || value.substr(0, check.length + 1) === check + "-" :
				false;
		},

		POS: function( elem, match, i, array ) {
			var name = match[2],
				filter = Expr.setFilters[ name ];

			if ( filter ) {
				return filter( elem, i, match, array );
			}
		}
	}
};

var origPOS = Expr.match.POS,
	fescape = function(all, num){
		return "\\" + (num - 0 + 1);
	};

for ( var type in Expr.match ) {
	Expr.match[ type ] = new RegExp( Expr.match[ type ].source + (/(?![^\[]*\])(?![^\(]*\))/.source) );
	Expr.leftMatch[ type ] = new RegExp( /(^(?:.|\r|\n)*?)/.source + Expr.match[ type ].source.replace(/\\(\d+)/g, fescape) );
}
// Expose origPOS
// "global" as in regardless of relation to brackets/parens
Expr.match.globalPOS = origPOS;

var makeArray = function( array, results ) {
	array = Array.prototype.slice.call( array, 0 );

	if ( results ) {
		results.push.apply( results, array );
		return results;
	}

	return array;
};

// Perform a simple check to determine if the browser is capable of
// converting a NodeList to an array using builtin methods.
// Also verifies that the returned array holds DOM nodes
// (which is not the case in the Blackberry browser)
try {
	Array.prototype.slice.call( document.documentElement.childNodes, 0 )[0].nodeType;

// Provide a fallback method if it does not work
} catch( e ) {
	makeArray = function( array, results ) {
		var i = 0,
			ret = results || [];

		if ( toString.call(array) === "[object Array]" ) {
			Array.prototype.push.apply( ret, array );

		} else {
			if ( typeof array.length === "number" ) {
				for ( var l = array.length; i < l; i++ ) {
					ret.push( array[i] );
				}

			} else {
				for ( ; array[i]; i++ ) {
					ret.push( array[i] );
				}
			}
		}

		return ret;
	};
}

var sortOrder, siblingCheck;

if ( document.documentElement.compareDocumentPosition ) {
	sortOrder = function( a, b ) {
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		if ( !a.compareDocumentPosition || !b.compareDocumentPosition ) {
			return a.compareDocumentPosition ? -1 : 1;
		}

		return a.compareDocumentPosition(b) & 4 ? -1 : 1;
	};

} else {
	sortOrder = function( a, b ) {
		// The nodes are identical, we can exit early
		if ( a === b ) {
			hasDuplicate = true;
			return 0;

		// Fallback to using sourceIndex (in IE) if it's available on both nodes
		} else if ( a.sourceIndex && b.sourceIndex ) {
			return a.sourceIndex - b.sourceIndex;
		}

		var al, bl,
			ap = [],
			bp = [],
			aup = a.parentNode,
			bup = b.parentNode,
			cur = aup;

		// If the nodes are siblings (or identical) we can do a quick check
		if ( aup === bup ) {
			return siblingCheck( a, b );

		// If no parents were found then the nodes are disconnected
		} else if ( !aup ) {
			return -1;

		} else if ( !bup ) {
			return 1;
		}

		// Otherwise they're somewhere else in the tree so we need
		// to build up a full list of the parentNodes for comparison
		while ( cur ) {
			ap.unshift( cur );
			cur = cur.parentNode;
		}

		cur = bup;

		while ( cur ) {
			bp.unshift( cur );
			cur = cur.parentNode;
		}

		al = ap.length;
		bl = bp.length;

		// Start walking down the tree looking for a discrepancy
		for ( var i = 0; i < al && i < bl; i++ ) {
			if ( ap[i] !== bp[i] ) {
				return siblingCheck( ap[i], bp[i] );
			}
		}

		// We ended someplace up the tree so do a sibling check
		return i === al ?
			siblingCheck( a, bp[i], -1 ) :
			siblingCheck( ap[i], b, 1 );
	};

	siblingCheck = function( a, b, ret ) {
		if ( a === b ) {
			return ret;
		}

		var cur = a.nextSibling;

		while ( cur ) {
			if ( cur === b ) {
				return -1;
			}

			cur = cur.nextSibling;
		}

		return 1;
	};
}

// Check to see if the browser returns elements by name when
// querying by getElementById (and provide a workaround)
(function(){
	// We're going to inject a fake input element with a specified name
	var form = document.createElement("div"),
		id = "script" + (new Date()).getTime(),
		root = document.documentElement;

	form.innerHTML = "<a name='" + id + "'/>";

	// Inject it into the root element, check its status, and remove it quickly
	root.insertBefore( form, root.firstChild );

	// The workaround has to do additional checks after a getElementById
	// Which slows things down for other browsers (hence the branching)
	if ( document.getElementById( id ) ) {
		Expr.find.ID = function( match, context, isXML ) {
			if ( typeof context.getElementById !== "undefined" && !isXML ) {
				var m = context.getElementById(match[1]);

				return m ?
					m.id === match[1] || typeof m.getAttributeNode !== "undefined" && m.getAttributeNode("id").nodeValue === match[1] ?
						[m] :
						undefined :
					[];
			}
		};

		Expr.filter.ID = function( elem, match ) {
			var node = typeof elem.getAttributeNode !== "undefined" && elem.getAttributeNode("id");

			return elem.nodeType === 1 && node && node.nodeValue === match;
		};
	}

	root.removeChild( form );

	// release memory in IE
	root = form = null;
})();

(function(){
	// Check to see if the browser returns only elements
	// when doing getElementsByTagName("*")

	// Create a fake element
	var div = document.createElement("div");
	div.appendChild( document.createComment("") );

	// Make sure no comments are found
	if ( div.getElementsByTagName("*").length > 0 ) {
		Expr.find.TAG = function( match, context ) {
			var results = context.getElementsByTagName( match[1] );

			// Filter out possible comments
			if ( match[1] === "*" ) {
				var tmp = [];

				for ( var i = 0; results[i]; i++ ) {
					if ( results[i].nodeType === 1 ) {
						tmp.push( results[i] );
					}
				}

				results = tmp;
			}

			return results;
		};
	}

	// Check to see if an attribute returns normalized href attributes
	div.innerHTML = "<a href='#'></a>";

	if ( div.firstChild && typeof div.firstChild.getAttribute !== "undefined" &&
			div.firstChild.getAttribute("href") !== "#" ) {

		Expr.attrHandle.href = function( elem ) {
			return elem.getAttribute( "href", 2 );
		};
	}

	// release memory in IE
	div = null;
})();

if ( document.querySelectorAll ) {
	(function(){
		var oldSizzle = Sizzle,
			div = document.createElement("div"),
			id = "__sizzle__";

		div.innerHTML = "<p class='TEST'></p>";

		// Safari can't handle uppercase or unicode characters when
		// in quirks mode.
		if ( div.querySelectorAll && div.querySelectorAll(".TEST").length === 0 ) {
			return;
		}

		Sizzle = function( query, context, extra, seed ) {
			context = context || document;

			// Only use querySelectorAll on non-XML documents
			// (ID selectors don't work in non-HTML documents)
			if ( !seed && !Sizzle.isXML(context) ) {
				// See if we find a selector to speed up
				var match = /^(\w+$)|^\.([\w\-]+$)|^#([\w\-]+$)/.exec( query );

				if ( match && (context.nodeType === 1 || context.nodeType === 9) ) {
					// Speed-up: Sizzle("TAG")
					if ( match[1] ) {
						return makeArray( context.getElementsByTagName( query ), extra );

					// Speed-up: Sizzle(".CLASS")
					} else if ( match[2] && Expr.find.CLASS && context.getElementsByClassName ) {
						return makeArray( context.getElementsByClassName( match[2] ), extra );
					}
				}

				if ( context.nodeType === 9 ) {
					// Speed-up: Sizzle("body")
					// The body element only exists once, optimize finding it
					if ( query === "body" && context.body ) {
						return makeArray( [ context.body ], extra );

					// Speed-up: Sizzle("#ID")
					} else if ( match && match[3] ) {
						var elem = context.getElementById( match[3] );

						// Check parentNode to catch when Blackberry 4.6 returns
						// nodes that are no longer in the document #6963
						if ( elem && elem.parentNode ) {
							// Handle the case where IE and Opera return items
							// by name instead of ID
							if ( elem.id === match[3] ) {
								return makeArray( [ elem ], extra );
							}

						} else {
							return makeArray( [], extra );
						}
					}

					try {
						return makeArray( context.querySelectorAll(query), extra );
					} catch(qsaError) {}

				// qSA works strangely on Element-rooted queries
				// We can work around this by specifying an extra ID on the root
				// and working up from there (Thanks to Andrew Dupont for the technique)
				// IE 8 doesn't work on object elements
				} else if ( context.nodeType === 1 && context.nodeName.toLowerCase() !== "object" ) {
					var oldContext = context,
						old = context.getAttribute( "id" ),
						nid = old || id,
						hasParent = context.parentNode,
						relativeHierarchySelector = /^\s*[+~]/.test( query );

					if ( !old ) {
						context.setAttribute( "id", nid );
					} else {
						nid = nid.replace( /'/g, "\\$&" );
					}
					if ( relativeHierarchySelector && hasParent ) {
						context = context.parentNode;
					}

					try {
						if ( !relativeHierarchySelector || hasParent ) {
							return makeArray( context.querySelectorAll( "[id='" + nid + "'] " + query ), extra );
						}

					} catch(pseudoError) {
					} finally {
						if ( !old ) {
							oldContext.removeAttribute( "id" );
						}
					}
				}
			}

			return oldSizzle(query, context, extra, seed);
		};

		for ( var prop in oldSizzle ) {
			Sizzle[ prop ] = oldSizzle[ prop ];
		}

		// release memory in IE
		div = null;
	})();
}

(function(){
	var html = document.documentElement,
		matches = html.matchesSelector || html.mozMatchesSelector || html.webkitMatchesSelector || html.msMatchesSelector;

	if ( matches ) {
		// Check to see if it's possible to do matchesSelector
		// on a disconnected node (IE 9 fails this)
		var disconnectedMatch = !matches.call( document.createElement( "div" ), "div" ),
			pseudoWorks = false;

		try {
			// This should fail with an exception
			// Gecko does not error, returns false instead
			matches.call( document.documentElement, "[test!='']:sizzle" );

		} catch( pseudoError ) {
			pseudoWorks = true;
		}

		Sizzle.matchesSelector = function( node, expr ) {
			// Make sure that attribute selectors are quoted
			expr = expr.replace(/\=\s*([^'"\]]*)\s*\]/g, "='$1']");

			if ( !Sizzle.isXML( node ) ) {
				try {
					if ( pseudoWorks || !Expr.match.PSEUDO.test( expr ) && !/!=/.test( expr ) ) {
						var ret = matches.call( node, expr );

						// IE 9's matchesSelector returns false on disconnected nodes
						if ( ret || !disconnectedMatch ||
								// As well, disconnected nodes are said to be in a document
								// fragment in IE 9, so check for that
								node.document && node.document.nodeType !== 11 ) {
							return ret;
						}
					}
				} catch(e) {}
			}

			return Sizzle(expr, null, null, [node]).length > 0;
		};
	}
})();

(function(){
	var div = document.createElement("div");

	div.innerHTML = "<div class='test e'></div><div class='test'></div>";

	// Opera can't find a second classname (in 9.6)
	// Also, make sure that getElementsByClassName actually exists
	if ( !div.getElementsByClassName || div.getElementsByClassName("e").length === 0 ) {
		return;
	}

	// Safari caches class attributes, doesn't catch changes (in 3.2)
	div.lastChild.className = "e";

	if ( div.getElementsByClassName("e").length === 1 ) {
		return;
	}

	Expr.order.splice(1, 0, "CLASS");
	Expr.find.CLASS = function( match, context, isXML ) {
		if ( typeof context.getElementsByClassName !== "undefined" && !isXML ) {
			return context.getElementsByClassName(match[1]);
		}
	};

	// release memory in IE
	div = null;
})();

function dirNodeCheck( dir, cur, doneName, checkSet, nodeCheck, isXML ) {
	for ( var i = 0, l = checkSet.length; i < l; i++ ) {
		var elem = checkSet[i];

		if ( elem ) {
			var match = false;

			elem = elem[dir];

			while ( elem ) {
				if ( elem[ expando ] === doneName ) {
					match = checkSet[elem.sizset];
					break;
				}

				if ( elem.nodeType === 1 && !isXML ){
					elem[ expando ] = doneName;
					elem.sizset = i;
				}

				if ( elem.nodeName.toLowerCase() === cur ) {
					match = elem;
					break;
				}

				elem = elem[dir];
			}

			checkSet[i] = match;
		}
	}
}

function dirCheck( dir, cur, doneName, checkSet, nodeCheck, isXML ) {
	for ( var i = 0, l = checkSet.length; i < l; i++ ) {
		var elem = checkSet[i];

		if ( elem ) {
			var match = false;

			elem = elem[dir];

			while ( elem ) {
				if ( elem[ expando ] === doneName ) {
					match = checkSet[elem.sizset];
					break;
				}

				if ( elem.nodeType === 1 ) {
					if ( !isXML ) {
						elem[ expando ] = doneName;
						elem.sizset = i;
					}

					if ( typeof cur !== "string" ) {
						if ( elem === cur ) {
							match = true;
							break;
						}

					} else if ( Sizzle.filter( cur, [elem] ).length > 0 ) {
						match = elem;
						break;
					}
				}

				elem = elem[dir];
			}

			checkSet[i] = match;
		}
	}
}

if ( document.documentElement.contains ) {
	Sizzle.contains = function( a, b ) {
		return a !== b && (a.contains ? a.contains(b) : true);
	};

} else if ( document.documentElement.compareDocumentPosition ) {
	Sizzle.contains = function( a, b ) {
		return !!(a.compareDocumentPosition(b) & 16);
	};

} else {
	Sizzle.contains = function() {
		return false;
	};
}

Sizzle.isXML = function( elem ) {
	// documentElement is verified for cases where it doesn't yet exist
	// (such as loading iframes in IE - #4833)
	var documentElement = (elem ? elem.ownerDocument || elem : 0).documentElement;

	return documentElement ? documentElement.nodeName !== "HTML" : false;
};

var posProcess = function( selector, context, seed ) {
	var match,
		tmpSet = [],
		later = "",
		root = context.nodeType ? [context] : context;

	// Position selectors must be done after the filter
	// And so must :not(positional) so we move all PSEUDOs to the end
	while ( (match = Expr.match.PSEUDO.exec( selector )) ) {
		later += match[0];
		selector = selector.replace( Expr.match.PSEUDO, "" );
	}

	selector = Expr.relative[selector] ? selector + "*" : selector;

	for ( var i = 0, l = root.length; i < l; i++ ) {
		Sizzle( selector, root[i], tmpSet, seed );
	}

	return Sizzle.filter( later, tmpSet );
};

// EXPOSE
// Override sizzle attribute retrieval
Sizzle.attr = jQuery.attr;
Sizzle.selectors.attrMap = {};
jQuery.find = Sizzle;
jQuery.expr = Sizzle.selectors;
jQuery.expr[":"] = jQuery.expr.filters;
jQuery.unique = Sizzle.uniqueSort;
jQuery.text = Sizzle.getText;
jQuery.isXMLDoc = Sizzle.isXML;
jQuery.contains = Sizzle.contains;


})();


var runtil = /Until$/,
	rparentsprev = /^(?:parents|prevUntil|prevAll)/,
	// Note: This RegExp should be improved, or likely pulled from Sizzle
	rmultiselector = /,/,
	isSimple = /^.[^:#\[\.,]*$/,
	slice = Array.prototype.slice,
	POS = jQuery.expr.match.globalPOS,
	// methods guaranteed to produce a unique set when starting from a unique set
	guaranteedUnique = {
		children: true,
		contents: true,
		next: true,
		prev: true
	};

jQuery.fn.extend({
	find: function( selector ) {
		var self = this,
			i, l;

		if ( typeof selector !== "string" ) {
			return jQuery( selector ).filter(function() {
				for ( i = 0, l = self.length; i < l; i++ ) {
					if ( jQuery.contains( self[ i ], this ) ) {
						return true;
					}
				}
			});
		}

		var ret = this.pushStack( "", "find", selector ),
			length, n, r;

		for ( i = 0, l = this.length; i < l; i++ ) {
			length = ret.length;
			jQuery.find( selector, this[i], ret );

			if ( i > 0 ) {
				// Make sure that the results are unique
				for ( n = length; n < ret.length; n++ ) {
					for ( r = 0; r < length; r++ ) {
						if ( ret[r] === ret[n] ) {
							ret.splice(n--, 1);
							break;
						}
					}
				}
			}
		}

		return ret;
	},

	has: function( target ) {
		var targets = jQuery( target );
		return this.filter(function() {
			for ( var i = 0, l = targets.length; i < l; i++ ) {
				if ( jQuery.contains( this, targets[i] ) ) {
					return true;
				}
			}
		});
	},

	not: function( selector ) {
		return this.pushStack( winnow(this, selector, false), "not", selector);
	},

	filter: function( selector ) {
		return this.pushStack( winnow(this, selector, true), "filter", selector );
	},

	is: function( selector ) {
		return !!selector && (
			typeof selector === "string" ?
				// If this is a positional selector, check membership in the returned set
				// so $("p:first").is("p:last") won't return true for a doc with two "p".
				POS.test( selector ) ?
					jQuery( selector, this.context ).index( this[0] ) >= 0 :
					jQuery.filter( selector, this ).length > 0 :
				this.filter( selector ).length > 0 );
	},

	closest: function( selectors, context ) {
		var ret = [], i, l, cur = this[0];

		// Array (deprecated as of jQuery 1.7)
		if ( jQuery.isArray( selectors ) ) {
			var level = 1;

			while ( cur && cur.ownerDocument && cur !== context ) {
				for ( i = 0; i < selectors.length; i++ ) {

					if ( jQuery( cur ).is( selectors[ i ] ) ) {
						ret.push({ selector: selectors[ i ], elem: cur, level: level });
					}
				}

				cur = cur.parentNode;
				level++;
			}

			return ret;
		}

		// String
		var pos = POS.test( selectors ) || typeof selectors !== "string" ?
				jQuery( selectors, context || this.context ) :
				0;

		for ( i = 0, l = this.length; i < l; i++ ) {
			cur = this[i];

			while ( cur ) {
				if ( pos ? pos.index(cur) > -1 : jQuery.find.matchesSelector(cur, selectors) ) {
					ret.push( cur );
					break;

				} else {
					cur = cur.parentNode;
					if ( !cur || !cur.ownerDocument || cur === context || cur.nodeType === 11 ) {
						break;
					}
				}
			}
		}

		ret = ret.length > 1 ? jQuery.unique( ret ) : ret;

		return this.pushStack( ret, "closest", selectors );
	},

	// Determine the position of an element within
	// the matched set of elements
	index: function( elem ) {

		// No argument, return index in parent
		if ( !elem ) {
			return ( this[0] && this[0].parentNode ) ? this.prevAll().length : -1;
		}

		// index in selector
		if ( typeof elem === "string" ) {
			return jQuery.inArray( this[0], jQuery( elem ) );
		}

		// Locate the position of the desired element
		return jQuery.inArray(
			// If it receives a jQuery object, the first element is used
			elem.jquery ? elem[0] : elem, this );
	},

	add: function( selector, context ) {
		var set = typeof selector === "string" ?
				jQuery( selector, context ) :
				jQuery.makeArray( selector && selector.nodeType ? [ selector ] : selector ),
			all = jQuery.merge( this.get(), set );

		return this.pushStack( isDisconnected( set[0] ) || isDisconnected( all[0] ) ?
			all :
			jQuery.unique( all ) );
	},

	andSelf: function() {
		return this.add( this.prevObject );
	}
});

// A painfully simple check to see if an element is disconnected
// from a document (should be improved, where feasible).
function isDisconnected( node ) {
	return !node || !node.parentNode || node.parentNode.nodeType === 11;
}

jQuery.each({
	parent: function( elem ) {
		var parent = elem.parentNode;
		return parent && parent.nodeType !== 11 ? parent : null;
	},
	parents: function( elem ) {
		return jQuery.dir( elem, "parentNode" );
	},
	parentsUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "parentNode", until );
	},
	next: function( elem ) {
		return jQuery.nth( elem, 2, "nextSibling" );
	},
	prev: function( elem ) {
		return jQuery.nth( elem, 2, "previousSibling" );
	},
	nextAll: function( elem ) {
		return jQuery.dir( elem, "nextSibling" );
	},
	prevAll: function( elem ) {
		return jQuery.dir( elem, "previousSibling" );
	},
	nextUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "nextSibling", until );
	},
	prevUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "previousSibling", until );
	},
	siblings: function( elem ) {
		return jQuery.sibling( ( elem.parentNode || {} ).firstChild, elem );
	},
	children: function( elem ) {
		return jQuery.sibling( elem.firstChild );
	},
	contents: function( elem ) {
		return jQuery.nodeName( elem, "iframe" ) ?
			elem.contentDocument || elem.contentWindow.document :
			jQuery.makeArray( elem.childNodes );
	}
}, function( name, fn ) {
	jQuery.fn[ name ] = function( until, selector ) {
		var ret = jQuery.map( this, fn, until );

		if ( !runtil.test( name ) ) {
			selector = until;
		}

		if ( selector && typeof selector === "string" ) {
			ret = jQuery.filter( selector, ret );
		}

		ret = this.length > 1 && !guaranteedUnique[ name ] ? jQuery.unique( ret ) : ret;

		if ( (this.length > 1 || rmultiselector.test( selector )) && rparentsprev.test( name ) ) {
			ret = ret.reverse();
		}

		return this.pushStack( ret, name, slice.call( arguments ).join(",") );
	};
});

jQuery.extend({
	filter: function( expr, elems, not ) {
		if ( not ) {
			expr = ":not(" + expr + ")";
		}

		return elems.length === 1 ?
			jQuery.find.matchesSelector(elems[0], expr) ? [ elems[0] ] : [] :
			jQuery.find.matches(expr, elems);
	},

	dir: function( elem, dir, until ) {
		var matched = [],
			cur = elem[ dir ];

		while ( cur && cur.nodeType !== 9 && (until === undefined || cur.nodeType !== 1 || !jQuery( cur ).is( until )) ) {
			if ( cur.nodeType === 1 ) {
				matched.push( cur );
			}
			cur = cur[dir];
		}
		return matched;
	},

	nth: function( cur, result, dir, elem ) {
		result = result || 1;
		var num = 0;

		for ( ; cur; cur = cur[dir] ) {
			if ( cur.nodeType === 1 && ++num === result ) {
				break;
			}
		}

		return cur;
	},

	sibling: function( n, elem ) {
		var r = [];

		for ( ; n; n = n.nextSibling ) {
			if ( n.nodeType === 1 && n !== elem ) {
				r.push( n );
			}
		}

		return r;
	}
});

// Implement the identical functionality for filter and not
function winnow( elements, qualifier, keep ) {

	// Can't pass null or undefined to indexOf in Firefox 4
	// Set to 0 to skip string check
	qualifier = qualifier || 0;

	if ( jQuery.isFunction( qualifier ) ) {
		return jQuery.grep(elements, function( elem, i ) {
			var retVal = !!qualifier.call( elem, i, elem );
			return retVal === keep;
		});

	} else if ( qualifier.nodeType ) {
		return jQuery.grep(elements, function( elem, i ) {
			return ( elem === qualifier ) === keep;
		});

	} else if ( typeof qualifier === "string" ) {
		var filtered = jQuery.grep(elements, function( elem ) {
			return elem.nodeType === 1;
		});

		if ( isSimple.test( qualifier ) ) {
			return jQuery.filter(qualifier, filtered, !keep);
		} else {
			qualifier = jQuery.filter( qualifier, filtered );
		}
	}

	return jQuery.grep(elements, function( elem, i ) {
		return ( jQuery.inArray( elem, qualifier ) >= 0 ) === keep;
	});
}




function createSafeFragment( document ) {
	var list = nodeNames.split( "|" ),
	safeFrag = document.createDocumentFragment();

	if ( safeFrag.createElement ) {
		while ( list.length ) {
			safeFrag.createElement(
				list.pop()
			);
		}
	}
	return safeFrag;
}

var nodeNames = "abbr|article|aside|audio|bdi|canvas|data|datalist|details|figcaption|figure|footer|" +
		"header|hgroup|mark|meter|nav|output|progress|section|summary|time|video",
	rinlinejQuery = / jQuery\d+="(?:\d+|null)"/g,
	rleadingWhitespace = /^\s+/,
	rxhtmlTag = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/ig,
	rtagName = /<([\w:]+)/,
	rtbody = /<tbody/i,
	rhtml = /<|&#?\w+;/,
	rnoInnerhtml = /<(?:script|style)/i,
	rnocache = /<(?:script|object|embed|option|style)/i,
	rnoshimcache = new RegExp("<(?:" + nodeNames + ")[\\s/>]", "i"),
	// checked="checked" or checked
	rchecked = /checked\s*(?:[^=]|=\s*.checked.)/i,
	rscriptType = /\/(java|ecma)script/i,
	rcleanScript = /^\s*<!(?:\[CDATA\[|\-\-)/,
	wrapMap = {
		option: [ 1, "<select multiple='multiple'>", "</select>" ],
		legend: [ 1, "<fieldset>", "</fieldset>" ],
		thead: [ 1, "<table>", "</table>" ],
		tr: [ 2, "<table><tbody>", "</tbody></table>" ],
		td: [ 3, "<table><tbody><tr>", "</tr></tbody></table>" ],
		col: [ 2, "<table><tbody></tbody><colgroup>", "</colgroup></table>" ],
		area: [ 1, "<map>", "</map>" ],
		_default: [ 0, "", "" ]
	},
	safeFragment = createSafeFragment( document );

wrapMap.optgroup = wrapMap.option;
wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
wrapMap.th = wrapMap.td;

// IE can't serialize <link> and <script> tags normally
if ( !jQuery.support.htmlSerialize ) {
	wrapMap._default = [ 1, "div<div>", "</div>" ];
}

jQuery.fn.extend({
	text: function( value ) {
		return jQuery.access( this, function( value ) {
			return value === undefined ?
				jQuery.text( this ) :
				this.empty().append( ( this[0] && this[0].ownerDocument || document ).createTextNode( value ) );
		}, null, value, arguments.length );
	},

	wrapAll: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapAll( html.call(this, i) );
			});
		}

		if ( this[0] ) {
			// The elements to wrap the target around
			var wrap = jQuery( html, this[0].ownerDocument ).eq(0).clone(true);

			if ( this[0].parentNode ) {
				wrap.insertBefore( this[0] );
			}

			wrap.map(function() {
				var elem = this;

				while ( elem.firstChild && elem.firstChild.nodeType === 1 ) {
					elem = elem.firstChild;
				}

				return elem;
			}).append( this );
		}

		return this;
	},

	wrapInner: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapInner( html.call(this, i) );
			});
		}

		return this.each(function() {
			var self = jQuery( this ),
				contents = self.contents();

			if ( contents.length ) {
				contents.wrapAll( html );

			} else {
				self.append( html );
			}
		});
	},

	wrap: function( html ) {
		var isFunction = jQuery.isFunction( html );

		return this.each(function(i) {
			jQuery( this ).wrapAll( isFunction ? html.call(this, i) : html );
		});
	},

	unwrap: function() {
		return this.parent().each(function() {
			if ( !jQuery.nodeName( this, "body" ) ) {
				jQuery( this ).replaceWith( this.childNodes );
			}
		}).end();
	},

	append: function() {
		return this.domManip(arguments, true, function( elem ) {
			if ( this.nodeType === 1 ) {
				this.appendChild( elem );
			}
		});
	},

	prepend: function() {
		return this.domManip(arguments, true, function( elem ) {
			if ( this.nodeType === 1 ) {
				this.insertBefore( elem, this.firstChild );
			}
		});
	},

	before: function() {
		if ( this[0] && this[0].parentNode ) {
			return this.domManip(arguments, false, function( elem ) {
				this.parentNode.insertBefore( elem, this );
			});
		} else if ( arguments.length ) {
			var set = jQuery.clean( arguments );
			set.push.apply( set, this.toArray() );
			return this.pushStack( set, "before", arguments );
		}
	},

	after: function() {
		if ( this[0] && this[0].parentNode ) {
			return this.domManip(arguments, false, function( elem ) {
				this.parentNode.insertBefore( elem, this.nextSibling );
			});
		} else if ( arguments.length ) {
			var set = this.pushStack( this, "after", arguments );
			set.push.apply( set, jQuery.clean(arguments) );
			return set;
		}
	},

	// keepData is for internal use only--do not document
	remove: function( selector, keepData ) {
		for ( var i = 0, elem; (elem = this[i]) != null; i++ ) {
			if ( !selector || jQuery.filter( selector, [ elem ] ).length ) {
				if ( !keepData && elem.nodeType === 1 ) {
					jQuery.cleanData( elem.getElementsByTagName("*") );
					jQuery.cleanData( [ elem ] );
				}

				if ( elem.parentNode ) {
					elem.parentNode.removeChild( elem );
				}
			}
		}

		return this;
	},

	empty: function() {
		for ( var i = 0, elem; (elem = this[i]) != null; i++ ) {
			// Remove element nodes and prevent memory leaks
			if ( elem.nodeType === 1 ) {
				jQuery.cleanData( elem.getElementsByTagName("*") );
			}

			// Remove any remaining nodes
			while ( elem.firstChild ) {
				elem.removeChild( elem.firstChild );
			}
		}

		return this;
	},

	clone: function( dataAndEvents, deepDataAndEvents ) {
		dataAndEvents = dataAndEvents == null ? false : dataAndEvents;
		deepDataAndEvents = deepDataAndEvents == null ? dataAndEvents : deepDataAndEvents;

		return this.map( function () {
			return jQuery.clone( this, dataAndEvents, deepDataAndEvents );
		});
	},

	html: function( value ) {
		return jQuery.access( this, function( value ) {
			var elem = this[0] || {},
				i = 0,
				l = this.length;

			if ( value === undefined ) {
				return elem.nodeType === 1 ?
					elem.innerHTML.replace( rinlinejQuery, "" ) :
					null;
			}


			if ( typeof value === "string" && !rnoInnerhtml.test( value ) &&
				( jQuery.support.leadingWhitespace || !rleadingWhitespace.test( value ) ) &&
				!wrapMap[ ( rtagName.exec( value ) || ["", ""] )[1].toLowerCase() ] ) {

				value = value.replace( rxhtmlTag, "<$1></$2>" );

				try {
					for (; i < l; i++ ) {
						// Remove element nodes and prevent memory leaks
						elem = this[i] || {};
						if ( elem.nodeType === 1 ) {
							jQuery.cleanData( elem.getElementsByTagName( "*" ) );
							elem.innerHTML = value;
						}
					}

					elem = 0;

				// If using innerHTML throws an exception, use the fallback method
				} catch(e) {}
			}

			if ( elem ) {
				this.empty().append( value );
			}
		}, null, value, arguments.length );
	},

	replaceWith: function( value ) {
		if ( this[0] && this[0].parentNode ) {
			// Make sure that the elements are removed from the DOM before they are inserted
			// this can help fix replacing a parent with child elements
			if ( jQuery.isFunction( value ) ) {
				return this.each(function(i) {
					var self = jQuery(this), old = self.html();
					self.replaceWith( value.call( this, i, old ) );
				});
			}

			if ( typeof value !== "string" ) {
				value = jQuery( value ).detach();
			}

			return this.each(function() {
				var next = this.nextSibling,
					parent = this.parentNode;

				jQuery( this ).remove();

				if ( next ) {
					jQuery(next).before( value );
				} else {
					jQuery(parent).append( value );
				}
			});
		} else {
			return this.length ?
				this.pushStack( jQuery(jQuery.isFunction(value) ? value() : value), "replaceWith", value ) :
				this;
		}
	},

	detach: function( selector ) {
		return this.remove( selector, true );
	},

	domManip: function( args, table, callback ) {
		var results, first, fragment, parent,
			value = args[0],
			scripts = [];

		// We can't cloneNode fragments that contain checked, in WebKit
		if ( !jQuery.support.checkClone && arguments.length === 3 && typeof value === "string" && rchecked.test( value ) ) {
			return this.each(function() {
				jQuery(this).domManip( args, table, callback, true );
			});
		}

		if ( jQuery.isFunction(value) ) {
			return this.each(function(i) {
				var self = jQuery(this);
				args[0] = value.call(this, i, table ? self.html() : undefined);
				self.domManip( args, table, callback );
			});
		}

		if ( this[0] ) {
			parent = value && value.parentNode;

			// If we're in a fragment, just use that instead of building a new one
			if ( jQuery.support.parentNode && parent && parent.nodeType === 11 && parent.childNodes.length === this.length ) {
				results = { fragment: parent };

			} else {
				results = jQuery.buildFragment( args, this, scripts );
			}

			fragment = results.fragment;

			if ( fragment.childNodes.length === 1 ) {
				first = fragment = fragment.firstChild;
			} else {
				first = fragment.firstChild;
			}

			if ( first ) {
				table = table && jQuery.nodeName( first, "tr" );

				for ( var i = 0, l = this.length, lastIndex = l - 1; i < l; i++ ) {
					callback.call(
						table ?
							root(this[i], first) :
							this[i],
						// Make sure that we do not leak memory by inadvertently discarding
						// the original fragment (which might have attached data) instead of
						// using it; in addition, use the original fragment object for the last
						// item instead of first because it can end up being emptied incorrectly
						// in certain situations (Bug #8070).
						// Fragments from the fragment cache must always be cloned and never used
						// in place.
						results.cacheable || ( l > 1 && i < lastIndex ) ?
							jQuery.clone( fragment, true, true ) :
							fragment
					);
				}
			}

			if ( scripts.length ) {
				jQuery.each( scripts, function( i, elem ) {
					if ( elem.src ) {
						jQuery.ajax({
							type: "GET",
							global: false,
							url: elem.src,
							async: false,
							dataType: "script"
						});
					} else {
						jQuery.globalEval( ( elem.text || elem.textContent || elem.innerHTML || "" ).replace( rcleanScript, "/*$0*/" ) );
					}

					if ( elem.parentNode ) {
						elem.parentNode.removeChild( elem );
					}
				});
			}
		}

		return this;
	}
});

function root( elem, cur ) {
	return jQuery.nodeName(elem, "table") ?
		(elem.getElementsByTagName("tbody")[0] ||
		elem.appendChild(elem.ownerDocument.createElement("tbody"))) :
		elem;
}

function cloneCopyEvent( src, dest ) {

	if ( dest.nodeType !== 1 || !jQuery.hasData( src ) ) {
		return;
	}

	var type, i, l,
		oldData = jQuery._data( src ),
		curData = jQuery._data( dest, oldData ),
		events = oldData.events;

	if ( events ) {
		delete curData.handle;
		curData.events = {};

		for ( type in events ) {
			for ( i = 0, l = events[ type ].length; i < l; i++ ) {
				jQuery.event.add( dest, type, events[ type ][ i ] );
			}
		}
	}

	// make the cloned public data object a copy from the original
	if ( curData.data ) {
		curData.data = jQuery.extend( {}, curData.data );
	}
}

function cloneFixAttributes( src, dest ) {
	var nodeName;

	// We do not need to do anything for non-Elements
	if ( dest.nodeType !== 1 ) {
		return;
	}

	// clearAttributes removes the attributes, which we don't want,
	// but also removes the attachEvent events, which we *do* want
	if ( dest.clearAttributes ) {
		dest.clearAttributes();
	}

	// mergeAttributes, in contrast, only merges back on the
	// original attributes, not the events
	if ( dest.mergeAttributes ) {
		dest.mergeAttributes( src );
	}

	nodeName = dest.nodeName.toLowerCase();

	// IE6-8 fail to clone children inside object elements that use
	// the proprietary classid attribute value (rather than the type
	// attribute) to identify the type of content to display
	if ( nodeName === "object" ) {
		dest.outerHTML = src.outerHTML;

	} else if ( nodeName === "input" && (src.type === "checkbox" || src.type === "radio") ) {
		// IE6-8 fails to persist the checked state of a cloned checkbox
		// or radio button. Worse, IE6-7 fail to give the cloned element
		// a checked appearance if the defaultChecked value isn't also set
		if ( src.checked ) {
			dest.defaultChecked = dest.checked = src.checked;
		}

		// IE6-7 get confused and end up setting the value of a cloned
		// checkbox/radio button to an empty string instead of "on"
		if ( dest.value !== src.value ) {
			dest.value = src.value;
		}

	// IE6-8 fails to return the selected option to the default selected
	// state when cloning options
	} else if ( nodeName === "option" ) {
		dest.selected = src.defaultSelected;

	// IE6-8 fails to set the defaultValue to the correct value when
	// cloning other types of input fields
	} else if ( nodeName === "input" || nodeName === "textarea" ) {
		dest.defaultValue = src.defaultValue;

	// IE blanks contents when cloning scripts
	} else if ( nodeName === "script" && dest.text !== src.text ) {
		dest.text = src.text;
	}

	// Event data gets referenced instead of copied if the expando
	// gets copied too
	dest.removeAttribute( jQuery.expando );

	// Clear flags for bubbling special change/submit events, they must
	// be reattached when the newly cloned events are first activated
	dest.removeAttribute( "_submit_attached" );
	dest.removeAttribute( "_change_attached" );
}

jQuery.buildFragment = function( args, nodes, scripts ) {
	var fragment, cacheable, cacheresults, doc,
	first = args[ 0 ];

	// nodes may contain either an explicit document object,
	// a jQuery collection or context object.
	// If nodes[0] contains a valid object to assign to doc
	if ( nodes && nodes[0] ) {
		doc = nodes[0].ownerDocument || nodes[0];
	}

	// Ensure that an attr object doesn't incorrectly stand in as a document object
	// Chrome and Firefox seem to allow this to occur and will throw exception
	// Fixes #8950
	if ( !doc.createDocumentFragment ) {
		doc = document;
	}

	// Only cache "small" (1/2 KB) HTML strings that are associated with the main document
	// Cloning options loses the selected state, so don't cache them
	// IE 6 doesn't like it when you put <object> or <embed> elements in a fragment
	// Also, WebKit does not clone 'checked' attributes on cloneNode, so don't cache
	// Lastly, IE6,7,8 will not correctly reuse cached fragments that were created from unknown elems #10501
	if ( args.length === 1 && typeof first === "string" && first.length < 512 && doc === document &&
		first.charAt(0) === "<" && !rnocache.test( first ) &&
		(jQuery.support.checkClone || !rchecked.test( first )) &&
		(jQuery.support.html5Clone || !rnoshimcache.test( first )) ) {

		cacheable = true;

		cacheresults = jQuery.fragments[ first ];
		if ( cacheresults && cacheresults !== 1 ) {
			fragment = cacheresults;
		}
	}

	if ( !fragment ) {
		fragment = doc.createDocumentFragment();
		jQuery.clean( args, doc, fragment, scripts );
	}

	if ( cacheable ) {
		jQuery.fragments[ first ] = cacheresults ? fragment : 1;
	}

	return { fragment: fragment, cacheable: cacheable };
};

jQuery.fragments = {};

jQuery.each({
	appendTo: "append",
	prependTo: "prepend",
	insertBefore: "before",
	insertAfter: "after",
	replaceAll: "replaceWith"
}, function( name, original ) {
	jQuery.fn[ name ] = function( selector ) {
		var ret = [],
			insert = jQuery( selector ),
			parent = this.length === 1 && this[0].parentNode;

		if ( parent && parent.nodeType === 11 && parent.childNodes.length === 1 && insert.length === 1 ) {
			insert[ original ]( this[0] );
			return this;

		} else {
			for ( var i = 0, l = insert.length; i < l; i++ ) {
				var elems = ( i > 0 ? this.clone(true) : this ).get();
				jQuery( insert[i] )[ original ]( elems );
				ret = ret.concat( elems );
			}

			return this.pushStack( ret, name, insert.selector );
		}
	};
});

function getAll( elem ) {
	if ( typeof elem.getElementsByTagName !== "undefined" ) {
		return elem.getElementsByTagName( "*" );

	} else if ( typeof elem.querySelectorAll !== "undefined" ) {
		return elem.querySelectorAll( "*" );

	} else {
		return [];
	}
}

// Used in clean, fixes the defaultChecked property
function fixDefaultChecked( elem ) {
	if ( elem.type === "checkbox" || elem.type === "radio" ) {
		elem.defaultChecked = elem.checked;
	}
}
// Finds all inputs and passes them to fixDefaultChecked
function findInputs( elem ) {
	var nodeName = ( elem.nodeName || "" ).toLowerCase();
	if ( nodeName === "input" ) {
		fixDefaultChecked( elem );
	// Skip scripts, get other children
	} else if ( nodeName !== "script" && typeof elem.getElementsByTagName !== "undefined" ) {
		jQuery.grep( elem.getElementsByTagName("input"), fixDefaultChecked );
	}
}

// Derived From: http://www.iecss.com/shimprove/javascript/shimprove.1-0-1.js
function shimCloneNode( elem ) {
	var div = document.createElement( "div" );
	safeFragment.appendChild( div );

	div.innerHTML = elem.outerHTML;
	return div.firstChild;
}

jQuery.extend({
	clone: function( elem, dataAndEvents, deepDataAndEvents ) {
		var srcElements,
			destElements,
			i,
			// IE<=8 does not properly clone detached, unknown element nodes
			clone = jQuery.support.html5Clone || jQuery.isXMLDoc(elem) || !rnoshimcache.test( "<" + elem.nodeName + ">" ) ?
				elem.cloneNode( true ) :
				shimCloneNode( elem );

		if ( (!jQuery.support.noCloneEvent || !jQuery.support.noCloneChecked) &&
				(elem.nodeType === 1 || elem.nodeType === 11) && !jQuery.isXMLDoc(elem) ) {
			// IE copies events bound via attachEvent when using cloneNode.
			// Calling detachEvent on the clone will also remove the events
			// from the original. In order to get around this, we use some
			// proprietary methods to clear the events. Thanks to MooTools
			// guys for this hotness.

			cloneFixAttributes( elem, clone );

			// Using Sizzle here is crazy slow, so we use getElementsByTagName instead
			srcElements = getAll( elem );
			destElements = getAll( clone );

			// Weird iteration because IE will replace the length property
			// with an element if you are cloning the body and one of the
			// elements on the page has a name or id of "length"
			for ( i = 0; srcElements[i]; ++i ) {
				// Ensure that the destination node is not null; Fixes #9587
				if ( destElements[i] ) {
					cloneFixAttributes( srcElements[i], destElements[i] );
				}
			}
		}

		// Copy the events from the original to the clone
		if ( dataAndEvents ) {
			cloneCopyEvent( elem, clone );

			if ( deepDataAndEvents ) {
				srcElements = getAll( elem );
				destElements = getAll( clone );

				for ( i = 0; srcElements[i]; ++i ) {
					cloneCopyEvent( srcElements[i], destElements[i] );
				}
			}
		}

		srcElements = destElements = null;

		// Return the cloned set
		return clone;
	},

	clean: function( elems, context, fragment, scripts ) {
		var checkScriptType, script, j,
				ret = [];

		context = context || document;

		// !context.createElement fails in IE with an error but returns typeof 'object'
		if ( typeof context.createElement === "undefined" ) {
			context = context.ownerDocument || context[0] && context[0].ownerDocument || document;
		}

		for ( var i = 0, elem; (elem = elems[i]) != null; i++ ) {
			if ( typeof elem === "number" ) {
				elem += "";
			}

			if ( !elem ) {
				continue;
			}

			// Convert html string into DOM nodes
			if ( typeof elem === "string" ) {
				if ( !rhtml.test( elem ) ) {
					elem = context.createTextNode( elem );
				} else {
					// Fix "XHTML"-style tags in all browsers
					elem = elem.replace(rxhtmlTag, "<$1></$2>");

					// Trim whitespace, otherwise indexOf won't work as expected
					var tag = ( rtagName.exec( elem ) || ["", ""] )[1].toLowerCase(),
						wrap = wrapMap[ tag ] || wrapMap._default,
						depth = wrap[0],
						div = context.createElement("div"),
						safeChildNodes = safeFragment.childNodes,
						remove;

					// Append wrapper element to unknown element safe doc fragment
					if ( context === document ) {
						// Use the fragment we've already created for this document
						safeFragment.appendChild( div );
					} else {
						// Use a fragment created with the owner document
						createSafeFragment( context ).appendChild( div );
					}

					// Go to html and back, then peel off extra wrappers
					div.innerHTML = wrap[1] + elem + wrap[2];

					// Move to the right depth
					while ( depth-- ) {
						div = div.lastChild;
					}

					// Remove IE's autoinserted <tbody> from table fragments
					if ( !jQuery.support.tbody ) {

						// String was a <table>, *may* have spurious <tbody>
						var hasBody = rtbody.test(elem),
							tbody = tag === "table" && !hasBody ?
								div.firstChild && div.firstChild.childNodes :

								// String was a bare <thead> or <tfoot>
								wrap[1] === "<table>" && !hasBody ?
									div.childNodes :
									[];

						for ( j = tbody.length - 1; j >= 0 ; --j ) {
							if ( jQuery.nodeName( tbody[ j ], "tbody" ) && !tbody[ j ].childNodes.length ) {
								tbody[ j ].parentNode.removeChild( tbody[ j ] );
							}
						}
					}

					// IE completely kills leading whitespace when innerHTML is used
					if ( !jQuery.support.leadingWhitespace && rleadingWhitespace.test( elem ) ) {
						div.insertBefore( context.createTextNode( rleadingWhitespace.exec(elem)[0] ), div.firstChild );
					}

					elem = div.childNodes;

					// Clear elements from DocumentFragment (safeFragment or otherwise)
					// to avoid hoarding elements. Fixes #11356
					if ( div ) {
						div.parentNode.removeChild( div );

						// Guard against -1 index exceptions in FF3.6
						if ( safeChildNodes.length > 0 ) {
							remove = safeChildNodes[ safeChildNodes.length - 1 ];

							if ( remove && remove.parentNode ) {
								remove.parentNode.removeChild( remove );
							}
						}
					}
				}
			}

			// Resets defaultChecked for any radios and checkboxes
			// about to be appended to the DOM in IE 6/7 (#8060)
			var len;
			if ( !jQuery.support.appendChecked ) {
				if ( elem[0] && typeof (len = elem.length) === "number" ) {
					for ( j = 0; j < len; j++ ) {
						findInputs( elem[j] );
					}
				} else {
					findInputs( elem );
				}
			}

			if ( elem.nodeType ) {
				ret.push( elem );
			} else {
				ret = jQuery.merge( ret, elem );
			}
		}

		if ( fragment ) {
			checkScriptType = function( elem ) {
				return !elem.type || rscriptType.test( elem.type );
			};
			for ( i = 0; ret[i]; i++ ) {
				script = ret[i];
				if ( scripts && jQuery.nodeName( script, "script" ) && (!script.type || rscriptType.test( script.type )) ) {
					scripts.push( script.parentNode ? script.parentNode.removeChild( script ) : script );

				} else {
					if ( script.nodeType === 1 ) {
						var jsTags = jQuery.grep( script.getElementsByTagName( "script" ), checkScriptType );

						ret.splice.apply( ret, [i + 1, 0].concat( jsTags ) );
					}
					fragment.appendChild( script );
				}
			}
		}

		return ret;
	},

	cleanData: function( elems ) {
		var data, id,
			cache = jQuery.cache,
			special = jQuery.event.special,
			deleteExpando = jQuery.support.deleteExpando;

		for ( var i = 0, elem; (elem = elems[i]) != null; i++ ) {
			if ( elem.nodeName && jQuery.noData[elem.nodeName.toLowerCase()] ) {
				continue;
			}

			id = elem[ jQuery.expando ];

			if ( id ) {
				data = cache[ id ];

				if ( data && data.events ) {
					for ( var type in data.events ) {
						if ( special[ type ] ) {
							jQuery.event.remove( elem, type );

						// This is a shortcut to avoid jQuery.event.remove's overhead
						} else {
							jQuery.removeEvent( elem, type, data.handle );
						}
					}

					// Null the DOM reference to avoid IE6/7/8 leak (#7054)
					if ( data.handle ) {
						data.handle.elem = null;
					}
				}

				if ( deleteExpando ) {
					delete elem[ jQuery.expando ];

				} else if ( elem.removeAttribute ) {
					elem.removeAttribute( jQuery.expando );
				}

				delete cache[ id ];
			}
		}
	}
});




var ralpha = /alpha\([^)]*\)/i,
	ropacity = /opacity=([^)]*)/,
	// fixed for IE9, see #8346
	rupper = /([A-Z]|^ms)/g,
	rnum = /^[\-+]?(?:\d*\.)?\d+$/i,
	rnumnonpx = /^-?(?:\d*\.)?\d+(?!px)[^\d\s]+$/i,
	rrelNum = /^([\-+])=([\-+.\de]+)/,
	rmargin = /^margin/,

	cssShow = { position: "absolute", visibility: "hidden", display: "block" },

	// order is important!
	cssExpand = [ "Top", "Right", "Bottom", "Left" ],

	curCSS,

	getComputedStyle,
	currentStyle;

jQuery.fn.css = function( name, value ) {
	return jQuery.access( this, function( elem, name, value ) {
		return value !== undefined ?
			jQuery.style( elem, name, value ) :
			jQuery.css( elem, name );
	}, name, value, arguments.length > 1 );
};

jQuery.extend({
	// Add in style property hooks for overriding the default
	// behavior of getting and setting a style property
	cssHooks: {
		opacity: {
			get: function( elem, computed ) {
				if ( computed ) {
					// We should always get a number back from opacity
					var ret = curCSS( elem, "opacity" );
					return ret === "" ? "1" : ret;

				} else {
					return elem.style.opacity;
				}
			}
		}
	},

	// Exclude the following css properties to add px
	cssNumber: {
		"fillOpacity": true,
		"fontWeight": true,
		"lineHeight": true,
		"opacity": true,
		"orphans": true,
		"widows": true,
		"zIndex": true,
		"zoom": true
	},

	// Add in properties whose names you wish to fix before
	// setting or getting the value
	cssProps: {
		// normalize float css property
		"float": jQuery.support.cssFloat ? "cssFloat" : "styleFloat"
	},

	// Get and set the style property on a DOM Node
	style: function( elem, name, value, extra ) {
		// Don't set styles on text and comment nodes
		if ( !elem || elem.nodeType === 3 || elem.nodeType === 8 || !elem.style ) {
			return;
		}

		// Make sure that we're working with the right name
		var ret, type, origName = jQuery.camelCase( name ),
			style = elem.style, hooks = jQuery.cssHooks[ origName ];

		name = jQuery.cssProps[ origName ] || origName;

		// Check if we're setting a value
		if ( value !== undefined ) {
			type = typeof value;

			// convert relative number strings (+= or -=) to relative numbers. #7345
			if ( type === "string" && (ret = rrelNum.exec( value )) ) {
				value = ( +( ret[1] + 1) * +ret[2] ) + parseFloat( jQuery.css( elem, name ) );
				// Fixes bug #9237
				type = "number";
			}

			// Make sure that NaN and null values aren't set. See: #7116
			if ( value == null || type === "number" && isNaN( value ) ) {
				return;
			}

			// If a number was passed in, add 'px' to the (except for certain CSS properties)
			if ( type === "number" && !jQuery.cssNumber[ origName ] ) {
				value += "px";
			}

			// If a hook was provided, use that value, otherwise just set the specified value
			if ( !hooks || !("set" in hooks) || (value = hooks.set( elem, value )) !== undefined ) {
				// Wrapped to prevent IE from throwing errors when 'invalid' values are provided
				// Fixes bug #5509
				try {
					style[ name ] = value;
				} catch(e) {}
			}

		} else {
			// If a hook was provided get the non-computed value from there
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, false, extra )) !== undefined ) {
				return ret;
			}

			// Otherwise just get the value from the style object
			return style[ name ];
		}
	},

	css: function( elem, name, extra ) {
		var ret, hooks;

		// Make sure that we're working with the right name
		name = jQuery.camelCase( name );
		hooks = jQuery.cssHooks[ name ];
		name = jQuery.cssProps[ name ] || name;

		// cssFloat needs a special treatment
		if ( name === "cssFloat" ) {
			name = "float";
		}

		// If a hook was provided get the computed value from there
		if ( hooks && "get" in hooks && (ret = hooks.get( elem, true, extra )) !== undefined ) {
			return ret;

		// Otherwise, if a way to get the computed value exists, use that
		} else if ( curCSS ) {
			return curCSS( elem, name );
		}
	},

	// A method for quickly swapping in/out CSS properties to get correct calculations
	swap: function( elem, options, callback ) {
		var old = {},
			ret, name;

		// Remember the old values, and insert the new ones
		for ( name in options ) {
			old[ name ] = elem.style[ name ];
			elem.style[ name ] = options[ name ];
		}

		ret = callback.call( elem );

		// Revert the old values
		for ( name in options ) {
			elem.style[ name ] = old[ name ];
		}

		return ret;
	}
});

// DEPRECATED in 1.3, Use jQuery.css() instead
jQuery.curCSS = jQuery.css;

if ( document.defaultView && document.defaultView.getComputedStyle ) {
	getComputedStyle = function( elem, name ) {
		var ret, defaultView, computedStyle, width,
			style = elem.style;

		name = name.replace( rupper, "-$1" ).toLowerCase();

		if ( (defaultView = elem.ownerDocument.defaultView) &&
				(computedStyle = defaultView.getComputedStyle( elem, null )) ) {

			ret = computedStyle.getPropertyValue( name );
			if ( ret === "" && !jQuery.contains( elem.ownerDocument.documentElement, elem ) ) {
				ret = jQuery.style( elem, name );
			}
		}

		// A tribute to the "awesome hack by Dean Edwards"
		// WebKit uses "computed value (percentage if specified)" instead of "used value" for margins
		// which is against the CSSOM draft spec: http://dev.w3.org/csswg/cssom/#resolved-values
		if ( !jQuery.support.pixelMargin && computedStyle && rmargin.test( name ) && rnumnonpx.test( ret ) ) {
			width = style.width;
			style.width = ret;
			ret = computedStyle.width;
			style.width = width;
		}

		return ret;
	};
}

if ( document.documentElement.currentStyle ) {
	currentStyle = function( elem, name ) {
		var left, rsLeft, uncomputed,
			ret = elem.currentStyle && elem.currentStyle[ name ],
			style = elem.style;

		// Avoid setting ret to empty string here
		// so we don't default to auto
		if ( ret == null && style && (uncomputed = style[ name ]) ) {
			ret = uncomputed;
		}

		// From the awesome hack by Dean Edwards
		// http://erik.eae.net/archives/2007/07/27/18.54.15/#comment-102291

		// If we're not dealing with a regular pixel number
		// but a number that has a weird ending, we need to convert it to pixels
		if ( rnumnonpx.test( ret ) ) {

			// Remember the original values
			left = style.left;
			rsLeft = elem.runtimeStyle && elem.runtimeStyle.left;

			// Put in the new values to get a computed value out
			if ( rsLeft ) {
				elem.runtimeStyle.left = elem.currentStyle.left;
			}
			style.left = name === "fontSize" ? "1em" : ret;
			ret = style.pixelLeft + "px";

			// Revert the changed values
			style.left = left;
			if ( rsLeft ) {
				elem.runtimeStyle.left = rsLeft;
			}
		}

		return ret === "" ? "auto" : ret;
	};
}

curCSS = getComputedStyle || currentStyle;

function getWidthOrHeight( elem, name, extra ) {

	// Start with offset property
	var val = name === "width" ? elem.offsetWidth : elem.offsetHeight,
		i = name === "width" ? 1 : 0,
		len = 4;

	if ( val > 0 ) {
		if ( extra !== "border" ) {
			for ( ; i < len; i += 2 ) {
				if ( !extra ) {
					val -= parseFloat( jQuery.css( elem, "padding" + cssExpand[ i ] ) ) || 0;
				}
				if ( extra === "margin" ) {
					val += parseFloat( jQuery.css( elem, extra + cssExpand[ i ] ) ) || 0;
				} else {
					val -= parseFloat( jQuery.css( elem, "border" + cssExpand[ i ] + "Width" ) ) || 0;
				}
			}
		}

		return val + "px";
	}

	// Fall back to computed then uncomputed css if necessary
	val = curCSS( elem, name );
	if ( val < 0 || val == null ) {
		val = elem.style[ name ];
	}

	// Computed unit is not pixels. Stop here and return.
	if ( rnumnonpx.test(val) ) {
		return val;
	}

	// Normalize "", auto, and prepare for extra
	val = parseFloat( val ) || 0;

	// Add padding, border, margin
	if ( extra ) {
		for ( ; i < len; i += 2 ) {
			val += parseFloat( jQuery.css( elem, "padding" + cssExpand[ i ] ) ) || 0;
			if ( extra !== "padding" ) {
				val += parseFloat( jQuery.css( elem, "border" + cssExpand[ i ] + "Width" ) ) || 0;
			}
			if ( extra === "margin" ) {
				val += parseFloat( jQuery.css( elem, extra + cssExpand[ i ]) ) || 0;
			}
		}
	}

	return val + "px";
}

jQuery.each([ "height", "width" ], function( i, name ) {
	jQuery.cssHooks[ name ] = {
		get: function( elem, computed, extra ) {
			if ( computed ) {
				if ( elem.offsetWidth !== 0 ) {
					return getWidthOrHeight( elem, name, extra );
				} else {
					return jQuery.swap( elem, cssShow, function() {
						return getWidthOrHeight( elem, name, extra );
					});
				}
			}
		},

		set: function( elem, value ) {
			return rnum.test( value ) ?
				value + "px" :
				value;
		}
	};
});

if ( !jQuery.support.opacity ) {
	jQuery.cssHooks.opacity = {
		get: function( elem, computed ) {
			// IE uses filters for opacity
			return ropacity.test( (computed && elem.currentStyle ? elem.currentStyle.filter : elem.style.filter) || "" ) ?
				( parseFloat( RegExp.$1 ) / 100 ) + "" :
				computed ? "1" : "";
		},

		set: function( elem, value ) {
			var style = elem.style,
				currentStyle = elem.currentStyle,
				opacity = jQuery.isNumeric( value ) ? "alpha(opacity=" + value * 100 + ")" : "",
				filter = currentStyle && currentStyle.filter || style.filter || "";

			// IE has trouble with opacity if it does not have layout
			// Force it by setting the zoom level
			style.zoom = 1;

			// if setting opacity to 1, and no other filters exist - attempt to remove filter attribute #6652
			if ( value >= 1 && jQuery.trim( filter.replace( ralpha, "" ) ) === "" ) {

				// Setting style.filter to null, "" & " " still leave "filter:" in the cssText
				// if "filter:" is present at all, clearType is disabled, we want to avoid this
				// style.removeAttribute is IE Only, but so apparently is this code path...
				style.removeAttribute( "filter" );

				// if there there is no filter style applied in a css rule, we are done
				if ( currentStyle && !currentStyle.filter ) {
					return;
				}
			}

			// otherwise, set new filter values
			style.filter = ralpha.test( filter ) ?
				filter.replace( ralpha, opacity ) :
				filter + " " + opacity;
		}
	};
}

jQuery(function() {
	// This hook cannot be added until DOM ready because the support test
	// for it is not run until after DOM ready
	if ( !jQuery.support.reliableMarginRight ) {
		jQuery.cssHooks.marginRight = {
			get: function( elem, computed ) {
				// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
				// Work around by temporarily setting element display to inline-block
				return jQuery.swap( elem, { "display": "inline-block" }, function() {
					if ( computed ) {
						return curCSS( elem, "margin-right" );
					} else {
						return elem.style.marginRight;
					}
				});
			}
		};
	}
});

if ( jQuery.expr && jQuery.expr.filters ) {
	jQuery.expr.filters.hidden = function( elem ) {
		var width = elem.offsetWidth,
			height = elem.offsetHeight;

		return ( width === 0 && height === 0 ) || (!jQuery.support.reliableHiddenOffsets && ((elem.style && elem.style.display) || jQuery.css( elem, "display" )) === "none");
	};

	jQuery.expr.filters.visible = function( elem ) {
		return !jQuery.expr.filters.hidden( elem );
	};
}

// These hooks are used by animate to expand properties
jQuery.each({
	margin: "",
	padding: "",
	border: "Width"
}, function( prefix, suffix ) {

	jQuery.cssHooks[ prefix + suffix ] = {
		expand: function( value ) {
			var i,

				// assumes a single number if not a string
				parts = typeof value === "string" ? value.split(" ") : [ value ],
				expanded = {};

			for ( i = 0; i < 4; i++ ) {
				expanded[ prefix + cssExpand[ i ] + suffix ] =
					parts[ i ] || parts[ i - 2 ] || parts[ 0 ];
			}

			return expanded;
		}
	};
});




var r20 = /%20/g,
	rbracket = /\[\]$/,
	rCRLF = /\r?\n/g,
	rhash = /#.*$/,
	rheaders = /^(.*?):[ \t]*([^\r\n]*)\r?$/mg, // IE leaves an \r character at EOL
	rinput = /^(?:color|date|datetime|datetime-local|email|hidden|month|number|password|range|search|tel|text|time|url|week)$/i,
	// #7653, #8125, #8152: local protocol detection
	rlocalProtocol = /^(?:about|app|app\-storage|.+\-extension|file|res|widget):$/,
	rnoContent = /^(?:GET|HEAD)$/,
	rprotocol = /^\/\//,
	rquery = /\?/,
	rscript = /<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>/gi,
	rselectTextarea = /^(?:select|textarea)/i,
	rspacesAjax = /\s+/,
	rts = /([?&])_=[^&]*/,
	rurl = /^([\w\+\.\-]+:)(?:\/\/([^\/?#:]*)(?::(\d+))?)?/,

	// Keep a copy of the old load method
	_load = jQuery.fn.load,

	/* Prefilters
	 * 1) They are useful to introduce custom dataTypes (see ajax/jsonp.js for an example)
	 * 2) These are called:
	 *    - BEFORE asking for a transport
	 *    - AFTER param serialization (s.data is a string if s.processData is true)
	 * 3) key is the dataType
	 * 4) the catchall symbol "*" can be used
	 * 5) execution will start with transport dataType and THEN continue down to "*" if needed
	 */
	prefilters = {},

	/* Transports bindings
	 * 1) key is the dataType
	 * 2) the catchall symbol "*" can be used
	 * 3) selection will start with transport dataType and THEN go to "*" if needed
	 */
	transports = {},

	// Document location
	ajaxLocation,

	// Document location segments
	ajaxLocParts,

	// Avoid comment-prolog char sequence (#10098); must appease lint and evade compression
	allTypes = ["*/"] + ["*"];

// #8138, IE may throw an exception when accessing
// a field from window.location if document.domain has been set
try {
	ajaxLocation = location.href;
} catch( e ) {
	// Use the href attribute of an A element
	// since IE will modify it given document.location
	ajaxLocation = document.createElement( "a" );
	ajaxLocation.href = "";
	ajaxLocation = ajaxLocation.href;
}

// Segment location into parts
ajaxLocParts = rurl.exec( ajaxLocation.toLowerCase() ) || [];

// Base "constructor" for jQuery.ajaxPrefilter and jQuery.ajaxTransport
function addToPrefiltersOrTransports( structure ) {

	// dataTypeExpression is optional and defaults to "*"
	return function( dataTypeExpression, func ) {

		if ( typeof dataTypeExpression !== "string" ) {
			func = dataTypeExpression;
			dataTypeExpression = "*";
		}

		if ( jQuery.isFunction( func ) ) {
			var dataTypes = dataTypeExpression.toLowerCase().split( rspacesAjax ),
				i = 0,
				length = dataTypes.length,
				dataType,
				list,
				placeBefore;

			// For each dataType in the dataTypeExpression
			for ( ; i < length; i++ ) {
				dataType = dataTypes[ i ];
				// We control if we're asked to add before
				// any existing element
				placeBefore = /^\+/.test( dataType );
				if ( placeBefore ) {
					dataType = dataType.substr( 1 ) || "*";
				}
				list = structure[ dataType ] = structure[ dataType ] || [];
				// then we add to the structure accordingly
				list[ placeBefore ? "unshift" : "push" ]( func );
			}
		}
	};
}

// Base inspection function for prefilters and transports
function inspectPrefiltersOrTransports( structure, options, originalOptions, jqXHR,
		dataType /* internal */, inspected /* internal */ ) {

	dataType = dataType || options.dataTypes[ 0 ];
	inspected = inspected || {};

	inspected[ dataType ] = true;

	var list = structure[ dataType ],
		i = 0,
		length = list ? list.length : 0,
		executeOnly = ( structure === prefilters ),
		selection;

	for ( ; i < length && ( executeOnly || !selection ); i++ ) {
		selection = list[ i ]( options, originalOptions, jqXHR );
		// If we got redirected to another dataType
		// we try there if executing only and not done already
		if ( typeof selection === "string" ) {
			if ( !executeOnly || inspected[ selection ] ) {
				selection = undefined;
			} else {
				options.dataTypes.unshift( selection );
				selection = inspectPrefiltersOrTransports(
						structure, options, originalOptions, jqXHR, selection, inspected );
			}
		}
	}
	// If we're only executing or nothing was selected
	// we try the catchall dataType if not done already
	if ( ( executeOnly || !selection ) && !inspected[ "*" ] ) {
		selection = inspectPrefiltersOrTransports(
				structure, options, originalOptions, jqXHR, "*", inspected );
	}
	// unnecessary when only executing (prefilters)
	// but it'll be ignored by the caller in that case
	return selection;
}

// A special extend for ajax options
// that takes "flat" options (not to be deep extended)
// Fixes #9887
function ajaxExtend( target, src ) {
	var key, deep,
		flatOptions = jQuery.ajaxSettings.flatOptions || {};
	for ( key in src ) {
		if ( src[ key ] !== undefined ) {
			( flatOptions[ key ] ? target : ( deep || ( deep = {} ) ) )[ key ] = src[ key ];
		}
	}
	if ( deep ) {
		jQuery.extend( true, target, deep );
	}
}

jQuery.fn.extend({
	load: function( url, params, callback ) {
		if ( typeof url !== "string" && _load ) {
			return _load.apply( this, arguments );

		// Don't do a request if no elements are being requested
		} else if ( !this.length ) {
			return this;
		}

		var off = url.indexOf( " " );
		if ( off >= 0 ) {
			var selector = url.slice( off, url.length );
			url = url.slice( 0, off );
		}

		// Default to a GET request
		var type = "GET";

		// If the second parameter was provided
		if ( params ) {
			// If it's a function
			if ( jQuery.isFunction( params ) ) {
				// We assume that it's the callback
				callback = params;
				params = undefined;

			// Otherwise, build a param string
			} else if ( typeof params === "object" ) {
				params = jQuery.param( params, jQuery.ajaxSettings.traditional );
				type = "POST";
			}
		}

		var self = this;

		// Request the remote document
		jQuery.ajax({
			url: url,
			type: type,
			dataType: "html",
			data: params,
			// Complete callback (responseText is used internally)
			complete: function( jqXHR, status, responseText ) {
				// Store the response as specified by the jqXHR object
				responseText = jqXHR.responseText;
				// If successful, inject the HTML into all the matched elements
				if ( jqXHR.isResolved() ) {
					// #4825: Get the actual response in case
					// a dataFilter is present in ajaxSettings
					jqXHR.done(function( r ) {
						responseText = r;
					});
					// See if a selector was specified
					self.html( selector ?
						// Create a dummy div to hold the results
						jQuery("<div>")
							// inject the contents of the document in, removing the scripts
							// to avoid any 'Permission Denied' errors in IE
							.append(responseText.replace(rscript, ""))

							// Locate the specified elements
							.find(selector) :

						// If not, just inject the full result
						responseText );
				}

				if ( callback ) {
					self.each( callback, [ responseText, status, jqXHR ] );
				}
			}
		});

		return this;
	},

	serialize: function() {
		return jQuery.param( this.serializeArray() );
	},

	serializeArray: function() {
		return this.map(function(){
			return this.elements ? jQuery.makeArray( this.elements ) : this;
		})
		.filter(function(){
			return this.name && !this.disabled &&
				( this.checked || rselectTextarea.test( this.nodeName ) ||
					rinput.test( this.type ) );
		})
		.map(function( i, elem ){
			var val = jQuery( this ).val();

			return val == null ?
				null :
				jQuery.isArray( val ) ?
					jQuery.map( val, function( val, i ){
						return { name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
					}) :
					{ name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
		}).get();
	}
});

// Attach a bunch of functions for handling common AJAX events
jQuery.each( "ajaxStart ajaxStop ajaxComplete ajaxError ajaxSuccess ajaxSend".split( " " ), function( i, o ){
	jQuery.fn[ o ] = function( f ){
		return this.on( o, f );
	};
});

jQuery.each( [ "get", "post" ], function( i, method ) {
	jQuery[ method ] = function( url, data, callback, type ) {
		// shift arguments if data argument was omitted
		if ( jQuery.isFunction( data ) ) {
			type = type || callback;
			callback = data;
			data = undefined;
		}

		return jQuery.ajax({
			type: method,
			url: url,
			data: data,
			success: callback,
			dataType: type
		});
	};
});

jQuery.extend({

	getScript: function( url, callback ) {
		return jQuery.get( url, undefined, callback, "script" );
	},

	getJSON: function( url, data, callback ) {
		return jQuery.get( url, data, callback, "json" );
	},

	// Creates a full fledged settings object into target
	// with both ajaxSettings and settings fields.
	// If target is omitted, writes into ajaxSettings.
	ajaxSetup: function( target, settings ) {
		if ( settings ) {
			// Building a settings object
			ajaxExtend( target, jQuery.ajaxSettings );
		} else {
			// Extending ajaxSettings
			settings = target;
			target = jQuery.ajaxSettings;
		}
		ajaxExtend( target, settings );
		return target;
	},

	ajaxSettings: {
		url: ajaxLocation,
		isLocal: rlocalProtocol.test( ajaxLocParts[ 1 ] ),
		global: true,
		type: "GET",
		contentType: "application/x-www-form-urlencoded; charset=UTF-8",
		processData: true,
		async: true,
		/*
		timeout: 0,
		data: null,
		dataType: null,
		username: null,
		password: null,
		cache: null,
		traditional: false,
		headers: {},
		*/

		accepts: {
			xml: "application/xml, text/xml",
			html: "text/html",
			text: "text/plain",
			json: "application/json, text/javascript",
			"*": allTypes
		},

		contents: {
			xml: /xml/,
			html: /html/,
			json: /json/
		},

		responseFields: {
			xml: "responseXML",
			text: "responseText"
		},

		// List of data converters
		// 1) key format is "source_type destination_type" (a single space in-between)
		// 2) the catchall symbol "*" can be used for source_type
		converters: {

			// Convert anything to text
			"* text": window.String,

			// Text to html (true = no transformation)
			"text html": true,

			// Evaluate text as a json expression
			"text json": jQuery.parseJSON,

			// Parse text as xml
			"text xml": jQuery.parseXML
		},

		// For options that shouldn't be deep extended:
		// you can add your own custom options here if
		// and when you create one that shouldn't be
		// deep extended (see ajaxExtend)
		flatOptions: {
			context: true,
			url: true
		}
	},

	ajaxPrefilter: addToPrefiltersOrTransports( prefilters ),
	ajaxTransport: addToPrefiltersOrTransports( transports ),

	// Main method
	ajax: function( url, options ) {

		// If url is an object, simulate pre-1.5 signature
		if ( typeof url === "object" ) {
			options = url;
			url = undefined;
		}

		// Force options to be an object
		options = options || {};

		var // Create the final options object
			s = jQuery.ajaxSetup( {}, options ),
			// Callbacks context
			callbackContext = s.context || s,
			// Context for global events
			// It's the callbackContext if one was provided in the options
			// and if it's a DOM node or a jQuery collection
			globalEventContext = callbackContext !== s &&
				( callbackContext.nodeType || callbackContext instanceof jQuery ) ?
						jQuery( callbackContext ) : jQuery.event,
			// Deferreds
			deferred = jQuery.Deferred(),
			completeDeferred = jQuery.Callbacks( "once memory" ),
			// Status-dependent callbacks
			statusCode = s.statusCode || {},
			// ifModified key
			ifModifiedKey,
			// Headers (they are sent all at once)
			requestHeaders = {},
			requestHeadersNames = {},
			// Response headers
			responseHeadersString,
			responseHeaders,
			// transport
			transport,
			// timeout handle
			timeoutTimer,
			// Cross-domain detection vars
			parts,
			// The jqXHR state
			state = 0,
			// To know if global events are to be dispatched
			fireGlobals,
			// Loop variable
			i,
			// Fake xhr
			jqXHR = {

				readyState: 0,

				// Caches the header
				setRequestHeader: function( name, value ) {
					if ( !state ) {
						var lname = name.toLowerCase();
						name = requestHeadersNames[ lname ] = requestHeadersNames[ lname ] || name;
						requestHeaders[ name ] = value;
					}
					return this;
				},

				// Raw string
				getAllResponseHeaders: function() {
					return state === 2 ? responseHeadersString : null;
				},

				// Builds headers hashtable if needed
				getResponseHeader: function( key ) {
					var match;
					if ( state === 2 ) {
						if ( !responseHeaders ) {
							responseHeaders = {};
							while( ( match = rheaders.exec( responseHeadersString ) ) ) {
								responseHeaders[ match[1].toLowerCase() ] = match[ 2 ];
							}
						}
						match = responseHeaders[ key.toLowerCase() ];
					}
					return match === undefined ? null : match;
				},

				// Overrides response content-type header
				overrideMimeType: function( type ) {
					if ( !state ) {
						s.mimeType = type;
					}
					return this;
				},

				// Cancel the request
				abort: function( statusText ) {
					statusText = statusText || "abort";
					if ( transport ) {
						transport.abort( statusText );
					}
					done( 0, statusText );
					return this;
				}
			};

		// Callback for when everything is done
		// It is defined here because jslint complains if it is declared
		// at the end of the function (which would be more logical and readable)
		function done( status, nativeStatusText, responses, headers ) {

			// Called once
			if ( state === 2 ) {
				return;
			}

			// State is "done" now
			state = 2;

			// Clear timeout if it exists
			if ( timeoutTimer ) {
				clearTimeout( timeoutTimer );
			}

			// Dereference transport for early garbage collection
			// (no matter how long the jqXHR object will be used)
			transport = undefined;

			// Cache response headers
			responseHeadersString = headers || "";

			// Set readyState
			jqXHR.readyState = status > 0 ? 4 : 0;

			var isSuccess,
				success,
				error,
				statusText = nativeStatusText,
				response = responses ? ajaxHandleResponses( s, jqXHR, responses ) : undefined,
				lastModified,
				etag;

			// If successful, handle type chaining
			if ( status >= 200 && status < 300 || status === 304 ) {

				// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
				if ( s.ifModified ) {

					if ( ( lastModified = jqXHR.getResponseHeader( "Last-Modified" ) ) ) {
						jQuery.lastModified[ ifModifiedKey ] = lastModified;
					}
					if ( ( etag = jqXHR.getResponseHeader( "Etag" ) ) ) {
						jQuery.etag[ ifModifiedKey ] = etag;
					}
				}

				// If not modified
				if ( status === 304 ) {

					statusText = "notmodified";
					isSuccess = true;

				// If we have data
				} else {

					try {
						success = ajaxConvert( s, response );
						statusText = "success";
						isSuccess = true;
					} catch(e) {
						// We have a parsererror
						statusText = "parsererror";
						error = e;
					}
				}
			} else {
				// We extract error from statusText
				// then normalize statusText and status for non-aborts
				error = statusText;
				if ( !statusText || status ) {
					statusText = "error";
					if ( status < 0 ) {
						status = 0;
					}
				}
			}

			// Set data for the fake xhr object
			jqXHR.status = status;
			jqXHR.statusText = "" + ( nativeStatusText || statusText );

			// Success/Error
			if ( isSuccess ) {
				deferred.resolveWith( callbackContext, [ success, statusText, jqXHR ] );
			} else {
				deferred.rejectWith( callbackContext, [ jqXHR, statusText, error ] );
			}

			// Status-dependent callbacks
			jqXHR.statusCode( statusCode );
			statusCode = undefined;

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajax" + ( isSuccess ? "Success" : "Error" ),
						[ jqXHR, s, isSuccess ? success : error ] );
			}

			// Complete
			completeDeferred.fireWith( callbackContext, [ jqXHR, statusText ] );

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxComplete", [ jqXHR, s ] );
				// Handle the global AJAX counter
				if ( !( --jQuery.active ) ) {
					jQuery.event.trigger( "ajaxStop" );
				}
			}
		}

		// Attach deferreds
		deferred.promise( jqXHR );
		jqXHR.success = jqXHR.done;
		jqXHR.error = jqXHR.fail;
		jqXHR.complete = completeDeferred.add;

		// Status-dependent callbacks
		jqXHR.statusCode = function( map ) {
			if ( map ) {
				var tmp;
				if ( state < 2 ) {
					for ( tmp in map ) {
						statusCode[ tmp ] = [ statusCode[tmp], map[tmp] ];
					}
				} else {
					tmp = map[ jqXHR.status ];
					jqXHR.then( tmp, tmp );
				}
			}
			return this;
		};

		// Remove hash character (#7531: and string promotion)
		// Add protocol if not provided (#5866: IE7 issue with protocol-less urls)
		// We also use the url parameter if available
		s.url = ( ( url || s.url ) + "" ).replace( rhash, "" ).replace( rprotocol, ajaxLocParts[ 1 ] + "//" );

		// Extract dataTypes list
		s.dataTypes = jQuery.trim( s.dataType || "*" ).toLowerCase().split( rspacesAjax );

		// Determine if a cross-domain request is in order
		if ( s.crossDomain == null ) {
			parts = rurl.exec( s.url.toLowerCase() );
			s.crossDomain = !!( parts &&
				( parts[ 1 ] != ajaxLocParts[ 1 ] || parts[ 2 ] != ajaxLocParts[ 2 ] ||
					( parts[ 3 ] || ( parts[ 1 ] === "http:" ? 80 : 443 ) ) !=
						( ajaxLocParts[ 3 ] || ( ajaxLocParts[ 1 ] === "http:" ? 80 : 443 ) ) )
			);
		}

		// Convert data if not already a string
		if ( s.data && s.processData && typeof s.data !== "string" ) {
			s.data = jQuery.param( s.data, s.traditional );
		}

		// Apply prefilters
		inspectPrefiltersOrTransports( prefilters, s, options, jqXHR );

		// If request was aborted inside a prefilter, stop there
		if ( state === 2 ) {
			return false;
		}

		// We can fire global events as of now if asked to
		fireGlobals = s.global;

		// Uppercase the type
		s.type = s.type.toUpperCase();

		// Determine if request has content
		s.hasContent = !rnoContent.test( s.type );

		// Watch for a new set of requests
		if ( fireGlobals && jQuery.active++ === 0 ) {
			jQuery.event.trigger( "ajaxStart" );
		}

		// More options handling for requests with no content
		if ( !s.hasContent ) {

			// If data is available, append data to url
			if ( s.data ) {
				s.url += ( rquery.test( s.url ) ? "&" : "?" ) + s.data;
				// #9682: remove data so that it's not used in an eventual retry
				delete s.data;
			}

			// Get ifModifiedKey before adding the anti-cache parameter
			ifModifiedKey = s.url;

			// Add anti-cache in url if needed
			if ( s.cache === false ) {

				var ts = jQuery.now(),
					// try replacing _= if it is there
					ret = s.url.replace( rts, "$1_=" + ts );

				// if nothing was replaced, add timestamp to the end
				s.url = ret + ( ( ret === s.url ) ? ( rquery.test( s.url ) ? "&" : "?" ) + "_=" + ts : "" );
			}
		}

		// Set the correct header, if data is being sent
		if ( s.data && s.hasContent && s.contentType !== false || options.contentType ) {
			jqXHR.setRequestHeader( "Content-Type", s.contentType );
		}

		// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
		if ( s.ifModified ) {
			ifModifiedKey = ifModifiedKey || s.url;
			if ( jQuery.lastModified[ ifModifiedKey ] ) {
				jqXHR.setRequestHeader( "If-Modified-Since", jQuery.lastModified[ ifModifiedKey ] );
			}
			if ( jQuery.etag[ ifModifiedKey ] ) {
				jqXHR.setRequestHeader( "If-None-Match", jQuery.etag[ ifModifiedKey ] );
			}
		}

		// Set the Accepts header for the server, depending on the dataType
		jqXHR.setRequestHeader(
			"Accept",
			s.dataTypes[ 0 ] && s.accepts[ s.dataTypes[0] ] ?
				s.accepts[ s.dataTypes[0] ] + ( s.dataTypes[ 0 ] !== "*" ? ", " + allTypes + "; q=0.01" : "" ) :
				s.accepts[ "*" ]
		);

		// Check for headers option
		for ( i in s.headers ) {
			jqXHR.setRequestHeader( i, s.headers[ i ] );
		}

		// Allow custom headers/mimetypes and early abort
		if ( s.beforeSend && ( s.beforeSend.call( callbackContext, jqXHR, s ) === false || state === 2 ) ) {
				// Abort if not done already
				jqXHR.abort();
				return false;

		}

		// Install callbacks on deferreds
		for ( i in { success: 1, error: 1, complete: 1 } ) {
			jqXHR[ i ]( s[ i ] );
		}

		// Get transport
		transport = inspectPrefiltersOrTransports( transports, s, options, jqXHR );

		// If no transport, we auto-abort
		if ( !transport ) {
			done( -1, "No Transport" );
		} else {
			jqXHR.readyState = 1;
			// Send global event
			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxSend", [ jqXHR, s ] );
			}
			// Timeout
			if ( s.async && s.timeout > 0 ) {
				timeoutTimer = setTimeout( function(){
					jqXHR.abort( "timeout" );
				}, s.timeout );
			}

			try {
				state = 1;
				transport.send( requestHeaders, done );
			} catch (e) {
				// Propagate exception as error if not done
				if ( state < 2 ) {
					done( -1, e );
				// Simply rethrow otherwise
				} else {
					throw e;
				}
			}
		}

		return jqXHR;
	},

	// Serialize an array of form elements or a set of
	// key/values into a query string
	param: function( a, traditional ) {
		var s = [],
			add = function( key, value ) {
				// If value is a function, invoke it and return its value
				value = jQuery.isFunction( value ) ? value() : value;
				s[ s.length ] = encodeURIComponent( key ) + "=" + encodeURIComponent( value );
			};

		// Set traditional to true for jQuery <= 1.3.2 behavior.
		if ( traditional === undefined ) {
			traditional = jQuery.ajaxSettings.traditional;
		}

		// If an array was passed in, assume that it is an array of form elements.
		if ( jQuery.isArray( a ) || ( a.jquery && !jQuery.isPlainObject( a ) ) ) {
			// Serialize the form elements
			jQuery.each( a, function() {
				add( this.name, this.value );
			});

		} else {
			// If traditional, encode the "old" way (the way 1.3.2 or older
			// did it), otherwise encode params recursively.
			for ( var prefix in a ) {
				buildParams( prefix, a[ prefix ], traditional, add );
			}
		}

		// Return the resulting serialization
		return s.join( "&" ).replace( r20, "+" );
	}
});

function buildParams( prefix, obj, traditional, add ) {
	if ( jQuery.isArray( obj ) ) {
		// Serialize array item.
		jQuery.each( obj, function( i, v ) {
			if ( traditional || rbracket.test( prefix ) ) {
				// Treat each array item as a scalar.
				add( prefix, v );

			} else {
				// If array item is non-scalar (array or object), encode its
				// numeric index to resolve deserialization ambiguity issues.
				// Note that rack (as of 1.0.0) can't currently deserialize
				// nested arrays properly, and attempting to do so may cause
				// a server error. Possible fixes are to modify rack's
				// deserialization algorithm or to provide an option or flag
				// to force array serialization to be shallow.
				buildParams( prefix + "[" + ( typeof v === "object" ? i : "" ) + "]", v, traditional, add );
			}
		});

	} else if ( !traditional && jQuery.type( obj ) === "object" ) {
		// Serialize object item.
		for ( var name in obj ) {
			buildParams( prefix + "[" + name + "]", obj[ name ], traditional, add );
		}

	} else {
		// Serialize scalar item.
		add( prefix, obj );
	}
}

// This is still on the jQuery object... for now
// Want to move this to jQuery.ajax some day
jQuery.extend({

	// Counter for holding the number of active queries
	active: 0,

	// Last-Modified header cache for next request
	lastModified: {},
	etag: {}

});

/* Handles responses to an ajax request:
 * - sets all responseXXX fields accordingly
 * - finds the right dataType (mediates between content-type and expected dataType)
 * - returns the corresponding response
 */
function ajaxHandleResponses( s, jqXHR, responses ) {

	var contents = s.contents,
		dataTypes = s.dataTypes,
		responseFields = s.responseFields,
		ct,
		type,
		finalDataType,
		firstDataType;

	// Fill responseXXX fields
	for ( type in responseFields ) {
		if ( type in responses ) {
			jqXHR[ responseFields[type] ] = responses[ type ];
		}
	}

	// Remove auto dataType and get content-type in the process
	while( dataTypes[ 0 ] === "*" ) {
		dataTypes.shift();
		if ( ct === undefined ) {
			ct = s.mimeType || jqXHR.getResponseHeader( "content-type" );
		}
	}

	// Check if we're dealing with a known content-type
	if ( ct ) {
		for ( type in contents ) {
			if ( contents[ type ] && contents[ type ].test( ct ) ) {
				dataTypes.unshift( type );
				break;
			}
		}
	}

	// Check to see if we have a response for the expected dataType
	if ( dataTypes[ 0 ] in responses ) {
		finalDataType = dataTypes[ 0 ];
	} else {
		// Try convertible dataTypes
		for ( type in responses ) {
			if ( !dataTypes[ 0 ] || s.converters[ type + " " + dataTypes[0] ] ) {
				finalDataType = type;
				break;
			}
			if ( !firstDataType ) {
				firstDataType = type;
			}
		}
		// Or just use first one
		finalDataType = finalDataType || firstDataType;
	}

	// If we found a dataType
	// We add the dataType to the list if needed
	// and return the corresponding response
	if ( finalDataType ) {
		if ( finalDataType !== dataTypes[ 0 ] ) {
			dataTypes.unshift( finalDataType );
		}
		return responses[ finalDataType ];
	}
}

// Chain conversions given the request and the original response
function ajaxConvert( s, response ) {

	// Apply the dataFilter if provided
	if ( s.dataFilter ) {
		response = s.dataFilter( response, s.dataType );
	}

	var dataTypes = s.dataTypes,
		converters = {},
		i,
		key,
		length = dataTypes.length,
		tmp,
		// Current and previous dataTypes
		current = dataTypes[ 0 ],
		prev,
		// Conversion expression
		conversion,
		// Conversion function
		conv,
		// Conversion functions (transitive conversion)
		conv1,
		conv2;

	// For each dataType in the chain
	for ( i = 1; i < length; i++ ) {

		// Create converters map
		// with lowercased keys
		if ( i === 1 ) {
			for ( key in s.converters ) {
				if ( typeof key === "string" ) {
					converters[ key.toLowerCase() ] = s.converters[ key ];
				}
			}
		}

		// Get the dataTypes
		prev = current;
		current = dataTypes[ i ];

		// If current is auto dataType, update it to prev
		if ( current === "*" ) {
			current = prev;
		// If no auto and dataTypes are actually different
		} else if ( prev !== "*" && prev !== current ) {

			// Get the converter
			conversion = prev + " " + current;
			conv = converters[ conversion ] || converters[ "* " + current ];

			// If there is no direct converter, search transitively
			if ( !conv ) {
				conv2 = undefined;
				for ( conv1 in converters ) {
					tmp = conv1.split( " " );
					if ( tmp[ 0 ] === prev || tmp[ 0 ] === "*" ) {
						conv2 = converters[ tmp[1] + " " + current ];
						if ( conv2 ) {
							conv1 = converters[ conv1 ];
							if ( conv1 === true ) {
								conv = conv2;
							} else if ( conv2 === true ) {
								conv = conv1;
							}
							break;
						}
					}
				}
			}
			// If we found no converter, dispatch an error
			if ( !( conv || conv2 ) ) {
				jQuery.error( "No conversion from " + conversion.replace(" "," to ") );
			}
			// If found converter is not an equivalence
			if ( conv !== true ) {
				// Convert with 1 or 2 converters accordingly
				response = conv ? conv( response ) : conv2( conv1(response) );
			}
		}
	}
	return response;
}




var jsc = jQuery.now(),
	jsre = /(\=)\?(&|$)|\?\?/i;

// Default jsonp settings
jQuery.ajaxSetup({
	jsonp: "callback",
	jsonpCallback: function() {
		return jQuery.expando + "_" + ( jsc++ );
	}
});

// Detect, normalize options and install callbacks for jsonp requests
jQuery.ajaxPrefilter( "json jsonp", function( s, originalSettings, jqXHR ) {

	var inspectData = ( typeof s.data === "string" ) && /^application\/x\-www\-form\-urlencoded/.test( s.contentType );

	if ( s.dataTypes[ 0 ] === "jsonp" ||
		s.jsonp !== false && ( jsre.test( s.url ) ||
				inspectData && jsre.test( s.data ) ) ) {

		var responseContainer,
			jsonpCallback = s.jsonpCallback =
				jQuery.isFunction( s.jsonpCallback ) ? s.jsonpCallback() : s.jsonpCallback,
			previous = window[ jsonpCallback ],
			url = s.url,
			data = s.data,
			replace = "$1" + jsonpCallback + "$2";

		if ( s.jsonp !== false ) {
			url = url.replace( jsre, replace );
			if ( s.url === url ) {
				if ( inspectData ) {
					data = data.replace( jsre, replace );
				}
				if ( s.data === data ) {
					// Add callback manually
					url += (/\?/.test( url ) ? "&" : "?") + s.jsonp + "=" + jsonpCallback;
				}
			}
		}

		s.url = url;
		s.data = data;

		// Install callback
		window[ jsonpCallback ] = function( response ) {
			responseContainer = [ response ];
		};

		// Clean-up function
		jqXHR.always(function() {
			// Set callback back to previous value
			window[ jsonpCallback ] = previous;
			// Call if it was a function and we have a response
			if ( responseContainer && jQuery.isFunction( previous ) ) {
				window[ jsonpCallback ]( responseContainer[ 0 ] );
			}
		});

		// Use data converter to retrieve json after script execution
		s.converters["script json"] = function() {
			if ( !responseContainer ) {
				jQuery.error( jsonpCallback + " was not called" );
			}
			return responseContainer[ 0 ];
		};

		// force json dataType
		s.dataTypes[ 0 ] = "json";

		// Delegate to script
		return "script";
	}
});




// Install script dataType
jQuery.ajaxSetup({
	accepts: {
		script: "text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"
	},
	contents: {
		script: /javascript|ecmascript/
	},
	converters: {
		"text script": function( text ) {
			jQuery.globalEval( text );
			return text;
		}
	}
});

// Handle cache's special case and global
jQuery.ajaxPrefilter( "script", function( s ) {
	if ( s.cache === undefined ) {
		s.cache = false;
	}
	if ( s.crossDomain ) {
		s.type = "GET";
		s.global = false;
	}
});

// Bind script tag hack transport
jQuery.ajaxTransport( "script", function(s) {

	// This transport only deals with cross domain requests
	if ( s.crossDomain ) {

		var script,
			head = document.head || document.getElementsByTagName( "head" )[0] || document.documentElement;

		return {

			send: function( _, callback ) {

				script = document.createElement( "script" );

				script.async = "async";

				if ( s.scriptCharset ) {
					script.charset = s.scriptCharset;
				}

				script.src = s.url;

				// Attach handlers for all browsers
				script.onload = script.onreadystatechange = function( _, isAbort ) {

					if ( isAbort || !script.readyState || /loaded|complete/.test( script.readyState ) ) {

						// Handle memory leak in IE
						script.onload = script.onreadystatechange = null;

						// Remove the script
						if ( head && script.parentNode ) {
							head.removeChild( script );
						}

						// Dereference the script
						script = undefined;

						// Callback if not abort
						if ( !isAbort ) {
							callback( 200, "success" );
						}
					}
				};
				// Use insertBefore instead of appendChild  to circumvent an IE6 bug.
				// This arises when a base node is used (#2709 and #4378).
				head.insertBefore( script, head.firstChild );
			},

			abort: function() {
				if ( script ) {
					script.onload( 0, 1 );
				}
			}
		};
	}
});




var // #5280: Internet Explorer will keep connections alive if we don't abort on unload
	xhrOnUnloadAbort = window.ActiveXObject ? function() {
		// Abort all pending requests
		for ( var key in xhrCallbacks ) {
			xhrCallbacks[ key ]( 0, 1 );
		}
	} : false,
	xhrId = 0,
	xhrCallbacks;

// Functions to create xhrs
function createStandardXHR() {
	try {
		return new window.XMLHttpRequest();
	} catch( e ) {}
}

function createActiveXHR() {
	try {
		return new window.ActiveXObject( "Microsoft.XMLHTTP" );
	} catch( e ) {}
}

// Create the request object
// (This is still attached to ajaxSettings for backward compatibility)
jQuery.ajaxSettings.xhr = window.ActiveXObject ?
	/* Microsoft failed to properly
	 * implement the XMLHttpRequest in IE7 (can't request local files),
	 * so we use the ActiveXObject when it is available
	 * Additionally XMLHttpRequest can be disabled in IE7/IE8 so
	 * we need a fallback.
	 */
	function() {
		return !this.isLocal && createStandardXHR() || createActiveXHR();
	} :
	// For all other browsers, use the standard XMLHttpRequest object
	createStandardXHR;

// Determine support properties
(function( xhr ) {
	jQuery.extend( jQuery.support, {
		ajax: !!xhr,
		cors: !!xhr && ( "withCredentials" in xhr )
	});
})( jQuery.ajaxSettings.xhr() );

// Create transport if the browser can provide an xhr
if ( jQuery.support.ajax ) {

	jQuery.ajaxTransport(function( s ) {
		// Cross domain only allowed if supported through XMLHttpRequest
		if ( !s.crossDomain || jQuery.support.cors ) {

			var callback;

			return {
				send: function( headers, complete ) {

					// Get a new xhr
					var xhr = s.xhr(),
						handle,
						i;

					// Open the socket
					// Passing null username, generates a login popup on Opera (#2865)
					if ( s.username ) {
						xhr.open( s.type, s.url, s.async, s.username, s.password );
					} else {
						xhr.open( s.type, s.url, s.async );
					}

					// Apply custom fields if provided
					if ( s.xhrFields ) {
						for ( i in s.xhrFields ) {
							xhr[ i ] = s.xhrFields[ i ];
						}
					}

					// Override mime type if needed
					if ( s.mimeType && xhr.overrideMimeType ) {
						xhr.overrideMimeType( s.mimeType );
					}

					// X-Requested-With header
					// For cross-domain requests, seeing as conditions for a preflight are
					// akin to a jigsaw puzzle, we simply never set it to be sure.
					// (it can always be set on a per-request basis or even using ajaxSetup)
					// For same-domain requests, won't change header if already provided.
					if ( !s.crossDomain && !headers["X-Requested-With"] ) {
						headers[ "X-Requested-With" ] = "XMLHttpRequest";
					}

					// Need an extra try/catch for cross domain requests in Firefox 3
					try {
						for ( i in headers ) {
							xhr.setRequestHeader( i, headers[ i ] );
						}
					} catch( _ ) {}

					// Do send the request
					// This may raise an exception which is actually
					// handled in jQuery.ajax (so no try/catch here)
					xhr.send( ( s.hasContent && s.data ) || null );

					// Listener
					callback = function( _, isAbort ) {

						var status,
							statusText,
							responseHeaders,
							responses,
							xml;

						// Firefox throws exceptions when accessing properties
						// of an xhr when a network error occured
						// http://helpful.knobs-dials.com/index.php/Component_returned_failure_code:_0x80040111_(NS_ERROR_NOT_AVAILABLE)
						try {

							// Was never called and is aborted or complete
							if ( callback && ( isAbort || xhr.readyState === 4 ) ) {

								// Only called once
								callback = undefined;

								// Do not keep as active anymore
								if ( handle ) {
									xhr.onreadystatechange = jQuery.noop;
									if ( xhrOnUnloadAbort ) {
										delete xhrCallbacks[ handle ];
									}
								}

								// If it's an abort
								if ( isAbort ) {
									// Abort it manually if needed
									if ( xhr.readyState !== 4 ) {
										xhr.abort();
									}
								} else {
									status = xhr.status;
									responseHeaders = xhr.getAllResponseHeaders();
									responses = {};
									xml = xhr.responseXML;

									// Construct response list
									if ( xml && xml.documentElement /* #4958 */ ) {
										responses.xml = xml;
									}

									// When requesting binary data, IE6-9 will throw an exception
									// on any attempt to access responseText (#11426)
									try {
										responses.text = xhr.responseText;
									} catch( _ ) {
									}

									// Firefox throws an exception when accessing
									// statusText for faulty cross-domain requests
									try {
										statusText = xhr.statusText;
									} catch( e ) {
										// We normalize with Webkit giving an empty statusText
										statusText = "";
									}

									// Filter status for non standard behaviors

									// If the request is local and we have data: assume a success
									// (success with no data won't get notified, that's the best we
									// can do given current implementations)
									if ( !status && s.isLocal && !s.crossDomain ) {
										status = responses.text ? 200 : 404;
									// IE - #1450: sometimes returns 1223 when it should be 204
									} else if ( status === 1223 ) {
										status = 204;
									}
								}
							}
						} catch( firefoxAccessException ) {
							if ( !isAbort ) {
								complete( -1, firefoxAccessException );
							}
						}

						// Call complete if needed
						if ( responses ) {
							complete( status, statusText, responses, responseHeaders );
						}
					};

					// if we're in sync mode or it's in cache
					// and has been retrieved directly (IE6 & IE7)
					// we need to manually fire the callback
					if ( !s.async || xhr.readyState === 4 ) {
						callback();
					} else {
						handle = ++xhrId;
						if ( xhrOnUnloadAbort ) {
							// Create the active xhrs callbacks list if needed
							// and attach the unload handler
							if ( !xhrCallbacks ) {
								xhrCallbacks = {};
								jQuery( window ).unload( xhrOnUnloadAbort );
							}
							// Add to list of active xhrs callbacks
							xhrCallbacks[ handle ] = callback;
						}
						xhr.onreadystatechange = callback;
					}
				},

				abort: function() {
					if ( callback ) {
						callback(0,1);
					}
				}
			};
		}
	});
}




var elemdisplay = {},
	iframe, iframeDoc,
	rfxtypes = /^(?:toggle|show|hide)$/,
	rfxnum = /^([+\-]=)?([\d+.\-]+)([a-z%]*)$/i,
	timerId,
	fxAttrs = [
		// height animations
		[ "height", "marginTop", "marginBottom", "paddingTop", "paddingBottom" ],
		// width animations
		[ "width", "marginLeft", "marginRight", "paddingLeft", "paddingRight" ],
		// opacity animations
		[ "opacity" ]
	],
	fxNow;

jQuery.fn.extend({
	show: function( speed, easing, callback ) {
		var elem, display;

		if ( speed || speed === 0 ) {
			return this.animate( genFx("show", 3), speed, easing, callback );

		} else {
			for ( var i = 0, j = this.length; i < j; i++ ) {
				elem = this[ i ];

				if ( elem.style ) {
					display = elem.style.display;

					// Reset the inline display of this element to learn if it is
					// being hidden by cascaded rules or not
					if ( !jQuery._data(elem, "olddisplay") && display === "none" ) {
						display = elem.style.display = "";
					}

					// Set elements which have been overridden with display: none
					// in a stylesheet to whatever the default browser style is
					// for such an element
					if ( (display === "" && jQuery.css(elem, "display") === "none") ||
						!jQuery.contains( elem.ownerDocument.documentElement, elem ) ) {
						jQuery._data( elem, "olddisplay", defaultDisplay(elem.nodeName) );
					}
				}
			}

			// Set the display of most of the elements in a second loop
			// to avoid the constant reflow
			for ( i = 0; i < j; i++ ) {
				elem = this[ i ];

				if ( elem.style ) {
					display = elem.style.display;

					if ( display === "" || display === "none" ) {
						elem.style.display = jQuery._data( elem, "olddisplay" ) || "";
					}
				}
			}

			return this;
		}
	},

	hide: function( speed, easing, callback ) {
		if ( speed || speed === 0 ) {
			return this.animate( genFx("hide", 3), speed, easing, callback);

		} else {
			var elem, display,
				i = 0,
				j = this.length;

			for ( ; i < j; i++ ) {
				elem = this[i];
				if ( elem.style ) {
					display = jQuery.css( elem, "display" );

					if ( display !== "none" && !jQuery._data( elem, "olddisplay" ) ) {
						jQuery._data( elem, "olddisplay", display );
					}
				}
			}

			// Set the display of the elements in a second loop
			// to avoid the constant reflow
			for ( i = 0; i < j; i++ ) {
				if ( this[i].style ) {
					this[i].style.display = "none";
				}
			}

			return this;
		}
	},

	// Save the old toggle function
	_toggle: jQuery.fn.toggle,

	toggle: function( fn, fn2, callback ) {
		var bool = typeof fn === "boolean";

		if ( jQuery.isFunction(fn) && jQuery.isFunction(fn2) ) {
			this._toggle.apply( this, arguments );

		} else if ( fn == null || bool ) {
			this.each(function() {
				var state = bool ? fn : jQuery(this).is(":hidden");
				jQuery(this)[ state ? "show" : "hide" ]();
			});

		} else {
			this.animate(genFx("toggle", 3), fn, fn2, callback);
		}

		return this;
	},

	fadeTo: function( speed, to, easing, callback ) {
		return this.filter(":hidden").css("opacity", 0).show().end()
					.animate({opacity: to}, speed, easing, callback);
	},

	animate: function( prop, speed, easing, callback ) {
		var optall = jQuery.speed( speed, easing, callback );

		if ( jQuery.isEmptyObject( prop ) ) {
			return this.each( optall.complete, [ false ] );
		}

		// Do not change referenced properties as per-property easing will be lost
		prop = jQuery.extend( {}, prop );

		function doAnimation() {
			// XXX 'this' does not always have a nodeName when running the
			// test suite

			if ( optall.queue === false ) {
				jQuery._mark( this );
			}

			var opt = jQuery.extend( {}, optall ),
				isElement = this.nodeType === 1,
				hidden = isElement && jQuery(this).is(":hidden"),
				name, val, p, e, hooks, replace,
				parts, start, end, unit,
				method;

			// will store per property easing and be used to determine when an animation is complete
			opt.animatedProperties = {};

			// first pass over propertys to expand / normalize
			for ( p in prop ) {
				name = jQuery.camelCase( p );
				if ( p !== name ) {
					prop[ name ] = prop[ p ];
					delete prop[ p ];
				}

				if ( ( hooks = jQuery.cssHooks[ name ] ) && "expand" in hooks ) {
					replace = hooks.expand( prop[ name ] );
					delete prop[ name ];

					// not quite $.extend, this wont overwrite keys already present.
					// also - reusing 'p' from above because we have the correct "name"
					for ( p in replace ) {
						if ( ! ( p in prop ) ) {
							prop[ p ] = replace[ p ];
						}
					}
				}
			}

			for ( name in prop ) {
				val = prop[ name ];
				// easing resolution: per property > opt.specialEasing > opt.easing > 'swing' (default)
				if ( jQuery.isArray( val ) ) {
					opt.animatedProperties[ name ] = val[ 1 ];
					val = prop[ name ] = val[ 0 ];
				} else {
					opt.animatedProperties[ name ] = opt.specialEasing && opt.specialEasing[ name ] || opt.easing || 'swing';
				}

				if ( val === "hide" && hidden || val === "show" && !hidden ) {
					return opt.complete.call( this );
				}

				if ( isElement && ( name === "height" || name === "width" ) ) {
					// Make sure that nothing sneaks out
					// Record all 3 overflow attributes because IE does not
					// change the overflow attribute when overflowX and
					// overflowY are set to the same value
					opt.overflow = [ this.style.overflow, this.style.overflowX, this.style.overflowY ];

					// Set display property to inline-block for height/width
					// animations on inline elements that are having width/height animated
					if ( jQuery.css( this, "display" ) === "inline" &&
							jQuery.css( this, "float" ) === "none" ) {

						// inline-level elements accept inline-block;
						// block-level elements need to be inline with layout
						if ( !jQuery.support.inlineBlockNeedsLayout || defaultDisplay( this.nodeName ) === "inline" ) {
							this.style.display = "inline-block";

						} else {
							this.style.zoom = 1;
						}
					}
				}
			}

			if ( opt.overflow != null ) {
				this.style.overflow = "hidden";
			}

			for ( p in prop ) {
				e = new jQuery.fx( this, opt, p );
				val = prop[ p ];

				if ( rfxtypes.test( val ) ) {

					// Tracks whether to show or hide based on private
					// data attached to the element
					method = jQuery._data( this, "toggle" + p ) || ( val === "toggle" ? hidden ? "show" : "hide" : 0 );
					if ( method ) {
						jQuery._data( this, "toggle" + p, method === "show" ? "hide" : "show" );
						e[ method ]();
					} else {
						e[ val ]();
					}

				} else {
					parts = rfxnum.exec( val.toString() );
					start = e.cur();

					if ( parts ) {
						end = parseFloat( parts[2] );
						unit = parts[3] || ( jQuery.cssNumber[ p ] ? "" : "px" );

						// We need to compute starting value
						if ( unit !== "px" ) {
							jQuery.style( this, p, (end || 1) + unit);
							start = ( (end || 1) / e.cur() ) * start;
							jQuery.style( this, p, start + unit);
						}

						// If a +=/-= token was provided, we're doing a relative animation
						if ( parts[1] ) {
							end = ( (parts[ 1 ] === "-=" ? -1 : 1) * end ) + start;
						}

						e.custom( start, end, unit );

					} else {
						e.custom( start, val, "" );
					}
				}
			}

			// For JS strict compliance
			return true;
		}

		return optall.queue === false ?
			this.each( doAnimation ) :
			this.queue( optall.queue, doAnimation );
	},

	stop: function( type, clearQueue, gotoEnd ) {
		if ( typeof type !== "string" ) {
			gotoEnd = clearQueue;
			clearQueue = type;
			type = undefined;
		}
		if ( clearQueue && type !== false ) {
			this.queue( type || "fx", [] );
		}

		return this.each(function() {
			var index,
				hadTimers = false,
				timers = jQuery.timers,
				data = jQuery._data( this );

			// clear marker counters if we know they won't be
			if ( !gotoEnd ) {
				jQuery._unmark( true, this );
			}

			function stopQueue( elem, data, index ) {
				var hooks = data[ index ];
				jQuery.removeData( elem, index, true );
				hooks.stop( gotoEnd );
			}

			if ( type == null ) {
				for ( index in data ) {
					if ( data[ index ] && data[ index ].stop && index.indexOf(".run") === index.length - 4 ) {
						stopQueue( this, data, index );
					}
				}
			} else if ( data[ index = type + ".run" ] && data[ index ].stop ){
				stopQueue( this, data, index );
			}

			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && (type == null || timers[ index ].queue === type) ) {
					if ( gotoEnd ) {

						// force the next step to be the last
						timers[ index ]( true );
					} else {
						timers[ index ].saveState();
					}
					hadTimers = true;
					timers.splice( index, 1 );
				}
			}

			// start the next in the queue if the last step wasn't forced
			// timers currently will call their complete callbacks, which will dequeue
			// but only if they were gotoEnd
			if ( !( gotoEnd && hadTimers ) ) {
				jQuery.dequeue( this, type );
			}
		});
	}

});

// Animations created synchronously will run synchronously
function createFxNow() {
	setTimeout( clearFxNow, 0 );
	return ( fxNow = jQuery.now() );
}

function clearFxNow() {
	fxNow = undefined;
}

// Generate parameters to create a standard animation
function genFx( type, num ) {
	var obj = {};

	jQuery.each( fxAttrs.concat.apply([], fxAttrs.slice( 0, num )), function() {
		obj[ this ] = type;
	});

	return obj;
}

// Generate shortcuts for custom animations
jQuery.each({
	slideDown: genFx( "show", 1 ),
	slideUp: genFx( "hide", 1 ),
	slideToggle: genFx( "toggle", 1 ),
	fadeIn: { opacity: "show" },
	fadeOut: { opacity: "hide" },
	fadeToggle: { opacity: "toggle" }
}, function( name, props ) {
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return this.animate( props, speed, easing, callback );
	};
});

jQuery.extend({
	speed: function( speed, easing, fn ) {
		var opt = speed && typeof speed === "object" ? jQuery.extend( {}, speed ) : {
			complete: fn || !fn && easing ||
				jQuery.isFunction( speed ) && speed,
			duration: speed,
			easing: fn && easing || easing && !jQuery.isFunction( easing ) && easing
		};

		opt.duration = jQuery.fx.off ? 0 : typeof opt.duration === "number" ? opt.duration :
			opt.duration in jQuery.fx.speeds ? jQuery.fx.speeds[ opt.duration ] : jQuery.fx.speeds._default;

		// normalize opt.queue - true/undefined/null -> "fx"
		if ( opt.queue == null || opt.queue === true ) {
			opt.queue = "fx";
		}

		// Queueing
		opt.old = opt.complete;

		opt.complete = function( noUnmark ) {
			if ( jQuery.isFunction( opt.old ) ) {
				opt.old.call( this );
			}

			if ( opt.queue ) {
				jQuery.dequeue( this, opt.queue );
			} else if ( noUnmark !== false ) {
				jQuery._unmark( this );
			}
		};

		return opt;
	},

	easing: {
		linear: function( p ) {
			return p;
		},
		swing: function( p ) {
			return ( -Math.cos( p*Math.PI ) / 2 ) + 0.5;
		}
	},

	timers: [],

	fx: function( elem, options, prop ) {
		this.options = options;
		this.elem = elem;
		this.prop = prop;

		options.orig = options.orig || {};
	}

});

jQuery.fx.prototype = {
	// Simple function for setting a style value
	update: function() {
		if ( this.options.step ) {
			this.options.step.call( this.elem, this.now, this );
		}

		( jQuery.fx.step[ this.prop ] || jQuery.fx.step._default )( this );
	},

	// Get the current size
	cur: function() {
		if ( this.elem[ this.prop ] != null && (!this.elem.style || this.elem.style[ this.prop ] == null) ) {
			return this.elem[ this.prop ];
		}

		var parsed,
			r = jQuery.css( this.elem, this.prop );
		// Empty strings, null, undefined and "auto" are converted to 0,
		// complex values such as "rotate(1rad)" are returned as is,
		// simple values such as "10px" are parsed to Float.
		return isNaN( parsed = parseFloat( r ) ) ? !r || r === "auto" ? 0 : r : parsed;
	},

	// Start an animation from one number to another
	custom: function( from, to, unit ) {
		var self = this,
			fx = jQuery.fx;

		this.startTime = fxNow || createFxNow();
		this.end = to;
		this.now = this.start = from;
		this.pos = this.state = 0;
		this.unit = unit || this.unit || ( jQuery.cssNumber[ this.prop ] ? "" : "px" );

		function t( gotoEnd ) {
			return self.step( gotoEnd );
		}

		t.queue = this.options.queue;
		t.elem = this.elem;
		t.saveState = function() {
			if ( jQuery._data( self.elem, "fxshow" + self.prop ) === undefined ) {
				if ( self.options.hide ) {
					jQuery._data( self.elem, "fxshow" + self.prop, self.start );
				} else if ( self.options.show ) {
					jQuery._data( self.elem, "fxshow" + self.prop, self.end );
				}
			}
		};

		if ( t() && jQuery.timers.push(t) && !timerId ) {
			timerId = setInterval( fx.tick, fx.interval );
		}
	},

	// Simple 'show' function
	show: function() {
		var dataShow = jQuery._data( this.elem, "fxshow" + this.prop );

		// Remember where we started, so that we can go back to it later
		this.options.orig[ this.prop ] = dataShow || jQuery.style( this.elem, this.prop );
		this.options.show = true;

		// Begin the animation
		// Make sure that we start at a small width/height to avoid any flash of content
		if ( dataShow !== undefined ) {
			// This show is picking up where a previous hide or show left off
			this.custom( this.cur(), dataShow );
		} else {
			this.custom( this.prop === "width" || this.prop === "height" ? 1 : 0, this.cur() );
		}

		// Start by showing the element
		jQuery( this.elem ).show();
	},

	// Simple 'hide' function
	hide: function() {
		// Remember where we started, so that we can go back to it later
		this.options.orig[ this.prop ] = jQuery._data( this.elem, "fxshow" + this.prop ) || jQuery.style( this.elem, this.prop );
		this.options.hide = true;

		// Begin the animation
		this.custom( this.cur(), 0 );
	},

	// Each step of an animation
	step: function( gotoEnd ) {
		var p, n, complete,
			t = fxNow || createFxNow(),
			done = true,
			elem = this.elem,
			options = this.options;

		if ( gotoEnd || t >= options.duration + this.startTime ) {
			this.now = this.end;
			this.pos = this.state = 1;
			this.update();

			options.animatedProperties[ this.prop ] = true;

			for ( p in options.animatedProperties ) {
				if ( options.animatedProperties[ p ] !== true ) {
					done = false;
				}
			}

			if ( done ) {
				// Reset the overflow
				if ( options.overflow != null && !jQuery.support.shrinkWrapBlocks ) {

					jQuery.each( [ "", "X", "Y" ], function( index, value ) {
						elem.style[ "overflow" + value ] = options.overflow[ index ];
					});
				}

				// Hide the element if the "hide" operation was done
				if ( options.hide ) {
					jQuery( elem ).hide();
				}

				// Reset the properties, if the item has been hidden or shown
				if ( options.hide || options.show ) {
					for ( p in options.animatedProperties ) {
						jQuery.style( elem, p, options.orig[ p ] );
						jQuery.removeData( elem, "fxshow" + p, true );
						// Toggle data is no longer needed
						jQuery.removeData( elem, "toggle" + p, true );
					}
				}

				// Execute the complete function
				// in the event that the complete function throws an exception
				// we must ensure it won't be called twice. #5684

				complete = options.complete;
				if ( complete ) {

					options.complete = false;
					complete.call( elem );
				}
			}

			return false;

		} else {
			// classical easing cannot be used with an Infinity duration
			if ( options.duration == Infinity ) {
				this.now = t;
			} else {
				n = t - this.startTime;
				this.state = n / options.duration;

				// Perform the easing function, defaults to swing
				this.pos = jQuery.easing[ options.animatedProperties[this.prop] ]( this.state, n, 0, 1, options.duration );
				this.now = this.start + ( (this.end - this.start) * this.pos );
			}
			// Perform the next step of the animation
			this.update();
		}

		return true;
	}
};

jQuery.extend( jQuery.fx, {
	tick: function() {
		var timer,
			timers = jQuery.timers,
			i = 0;

		for ( ; i < timers.length; i++ ) {
			timer = timers[ i ];
			// Checks the timer has not already been removed
			if ( !timer() && timers[ i ] === timer ) {
				timers.splice( i--, 1 );
			}
		}

		if ( !timers.length ) {
			jQuery.fx.stop();
		}
	},

	interval: 13,

	stop: function() {
		clearInterval( timerId );
		timerId = null;
	},

	speeds: {
		slow: 600,
		fast: 200,
		// Default speed
		_default: 400
	},

	step: {
		opacity: function( fx ) {
			jQuery.style( fx.elem, "opacity", fx.now );
		},

		_default: function( fx ) {
			if ( fx.elem.style && fx.elem.style[ fx.prop ] != null ) {
				fx.elem.style[ fx.prop ] = fx.now + fx.unit;
			} else {
				fx.elem[ fx.prop ] = fx.now;
			}
		}
	}
});

// Ensure props that can't be negative don't go there on undershoot easing
jQuery.each( fxAttrs.concat.apply( [], fxAttrs ), function( i, prop ) {
	// exclude marginTop, marginLeft, marginBottom and marginRight from this list
	if ( prop.indexOf( "margin" ) ) {
		jQuery.fx.step[ prop ] = function( fx ) {
			jQuery.style( fx.elem, prop, Math.max(0, fx.now) + fx.unit );
		};
	}
});

if ( jQuery.expr && jQuery.expr.filters ) {
	jQuery.expr.filters.animated = function( elem ) {
		return jQuery.grep(jQuery.timers, function( fn ) {
			return elem === fn.elem;
		}).length;
	};
}

// Try to restore the default display value of an element
function defaultDisplay( nodeName ) {

	if ( !elemdisplay[ nodeName ] ) {

		var body = document.body,
			elem = jQuery( "<" + nodeName + ">" ).appendTo( body ),
			display = elem.css( "display" );
		elem.remove();

		// If the simple way fails,
		// get element's real default display by attaching it to a temp iframe
		if ( display === "none" || display === "" ) {
			// No iframe to use yet, so create it
			if ( !iframe ) {
				iframe = document.createElement( "iframe" );
				iframe.frameBorder = iframe.width = iframe.height = 0;
			}

			body.appendChild( iframe );

			// Create a cacheable copy of the iframe document on first call.
			// IE and Opera will allow us to reuse the iframeDoc without re-writing the fake HTML
			// document to it; WebKit & Firefox won't allow reusing the iframe document.
			if ( !iframeDoc || !iframe.createElement ) {
				iframeDoc = ( iframe.contentWindow || iframe.contentDocument ).document;
				iframeDoc.write( ( jQuery.support.boxModel ? "<!doctype html>" : "" ) + "<html><body>" );
				iframeDoc.close();
			}

			elem = iframeDoc.createElement( nodeName );

			iframeDoc.body.appendChild( elem );

			display = jQuery.css( elem, "display" );
			body.removeChild( iframe );
		}

		// Store the correct default display
		elemdisplay[ nodeName ] = display;
	}

	return elemdisplay[ nodeName ];
}




var getOffset,
	rtable = /^t(?:able|d|h)$/i,
	rroot = /^(?:body|html)$/i;

if ( "getBoundingClientRect" in document.documentElement ) {
	getOffset = function( elem, doc, docElem, box ) {
		try {
			box = elem.getBoundingClientRect();
		} catch(e) {}

		// Make sure we're not dealing with a disconnected DOM node
		if ( !box || !jQuery.contains( docElem, elem ) ) {
			return box ? { top: box.top, left: box.left } : { top: 0, left: 0 };
		}

		var body = doc.body,
			win = getWindow( doc ),
			clientTop  = docElem.clientTop  || body.clientTop  || 0,
			clientLeft = docElem.clientLeft || body.clientLeft || 0,
			scrollTop  = win.pageYOffset || jQuery.support.boxModel && docElem.scrollTop  || body.scrollTop,
			scrollLeft = win.pageXOffset || jQuery.support.boxModel && docElem.scrollLeft || body.scrollLeft,
			top  = box.top  + scrollTop  - clientTop,
			left = box.left + scrollLeft - clientLeft;

		return { top: top, left: left };
	};

} else {
	getOffset = function( elem, doc, docElem ) {
		var computedStyle,
			offsetParent = elem.offsetParent,
			prevOffsetParent = elem,
			body = doc.body,
			defaultView = doc.defaultView,
			prevComputedStyle = defaultView ? defaultView.getComputedStyle( elem, null ) : elem.currentStyle,
			top = elem.offsetTop,
			left = elem.offsetLeft;

		while ( (elem = elem.parentNode) && elem !== body && elem !== docElem ) {
			if ( jQuery.support.fixedPosition && prevComputedStyle.position === "fixed" ) {
				break;
			}

			computedStyle = defaultView ? defaultView.getComputedStyle(elem, null) : elem.currentStyle;
			top  -= elem.scrollTop;
			left -= elem.scrollLeft;

			if ( elem === offsetParent ) {
				top  += elem.offsetTop;
				left += elem.offsetLeft;

				if ( jQuery.support.doesNotAddBorder && !(jQuery.support.doesAddBorderForTableAndCells && rtable.test(elem.nodeName)) ) {
					top  += parseFloat( computedStyle.borderTopWidth  ) || 0;
					left += parseFloat( computedStyle.borderLeftWidth ) || 0;
				}

				prevOffsetParent = offsetParent;
				offsetParent = elem.offsetParent;
			}

			if ( jQuery.support.subtractsBorderForOverflowNotVisible && computedStyle.overflow !== "visible" ) {
				top  += parseFloat( computedStyle.borderTopWidth  ) || 0;
				left += parseFloat( computedStyle.borderLeftWidth ) || 0;
			}

			prevComputedStyle = computedStyle;
		}

		if ( prevComputedStyle.position === "relative" || prevComputedStyle.position === "static" ) {
			top  += body.offsetTop;
			left += body.offsetLeft;
		}

		if ( jQuery.support.fixedPosition && prevComputedStyle.position === "fixed" ) {
			top  += Math.max( docElem.scrollTop, body.scrollTop );
			left += Math.max( docElem.scrollLeft, body.scrollLeft );
		}

		return { top: top, left: left };
	};
}

jQuery.fn.offset = function( options ) {
	if ( arguments.length ) {
		return options === undefined ?
			this :
			this.each(function( i ) {
				jQuery.offset.setOffset( this, options, i );
			});
	}

	var elem = this[0],
		doc = elem && elem.ownerDocument;

	if ( !doc ) {
		return null;
	}

	if ( elem === doc.body ) {
		return jQuery.offset.bodyOffset( elem );
	}

	return getOffset( elem, doc, doc.documentElement );
};

jQuery.offset = {

	bodyOffset: function( body ) {
		var top = body.offsetTop,
			left = body.offsetLeft;

		if ( jQuery.support.doesNotIncludeMarginInBodyOffset ) {
			top  += parseFloat( jQuery.css(body, "marginTop") ) || 0;
			left += parseFloat( jQuery.css(body, "marginLeft") ) || 0;
		}

		return { top: top, left: left };
	},

	setOffset: function( elem, options, i ) {
		var position = jQuery.css( elem, "position" );

		// set position first, in-case top/left are set even on static elem
		if ( position === "static" ) {
			elem.style.position = "relative";
		}

		var curElem = jQuery( elem ),
			curOffset = curElem.offset(),
			curCSSTop = jQuery.css( elem, "top" ),
			curCSSLeft = jQuery.css( elem, "left" ),
			calculatePosition = ( position === "absolute" || position === "fixed" ) && jQuery.inArray("auto", [curCSSTop, curCSSLeft]) > -1,
			props = {}, curPosition = {}, curTop, curLeft;

		// need to be able to calculate position if either top or left is auto and position is either absolute or fixed
		if ( calculatePosition ) {
			curPosition = curElem.position();
			curTop = curPosition.top;
			curLeft = curPosition.left;
		} else {
			curTop = parseFloat( curCSSTop ) || 0;
			curLeft = parseFloat( curCSSLeft ) || 0;
		}

		if ( jQuery.isFunction( options ) ) {
			options = options.call( elem, i, curOffset );
		}

		if ( options.top != null ) {
			props.top = ( options.top - curOffset.top ) + curTop;
		}
		if ( options.left != null ) {
			props.left = ( options.left - curOffset.left ) + curLeft;
		}

		if ( "using" in options ) {
			options.using.call( elem, props );
		} else {
			curElem.css( props );
		}
	}
};


jQuery.fn.extend({

	position: function() {
		if ( !this[0] ) {
			return null;
		}

		var elem = this[0],

		// Get *real* offsetParent
		offsetParent = this.offsetParent(),

		// Get correct offsets
		offset       = this.offset(),
		parentOffset = rroot.test(offsetParent[0].nodeName) ? { top: 0, left: 0 } : offsetParent.offset();

		// Subtract element margins
		// note: when an element has margin: auto the offsetLeft and marginLeft
		// are the same in Safari causing offset.left to incorrectly be 0
		offset.top  -= parseFloat( jQuery.css(elem, "marginTop") ) || 0;
		offset.left -= parseFloat( jQuery.css(elem, "marginLeft") ) || 0;

		// Add offsetParent borders
		parentOffset.top  += parseFloat( jQuery.css(offsetParent[0], "borderTopWidth") ) || 0;
		parentOffset.left += parseFloat( jQuery.css(offsetParent[0], "borderLeftWidth") ) || 0;

		// Subtract the two offsets
		return {
			top:  offset.top  - parentOffset.top,
			left: offset.left - parentOffset.left
		};
	},

	offsetParent: function() {
		return this.map(function() {
			var offsetParent = this.offsetParent || document.body;
			while ( offsetParent && (!rroot.test(offsetParent.nodeName) && jQuery.css(offsetParent, "position") === "static") ) {
				offsetParent = offsetParent.offsetParent;
			}
			return offsetParent;
		});
	}
});


// Create scrollLeft and scrollTop methods
jQuery.each( {scrollLeft: "pageXOffset", scrollTop: "pageYOffset"}, function( method, prop ) {
	var top = /Y/.test( prop );

	jQuery.fn[ method ] = function( val ) {
		return jQuery.access( this, function( elem, method, val ) {
			var win = getWindow( elem );

			if ( val === undefined ) {
				return win ? (prop in win) ? win[ prop ] :
					jQuery.support.boxModel && win.document.documentElement[ method ] ||
						win.document.body[ method ] :
					elem[ method ];
			}

			if ( win ) {
				win.scrollTo(
					!top ? val : jQuery( win ).scrollLeft(),
					 top ? val : jQuery( win ).scrollTop()
				);

			} else {
				elem[ method ] = val;
			}
		}, method, val, arguments.length, null );
	};
});

function getWindow( elem ) {
	return jQuery.isWindow( elem ) ?
		elem :
		elem.nodeType === 9 ?
			elem.defaultView || elem.parentWindow :
			false;
}




// Create width, height, innerHeight, innerWidth, outerHeight and outerWidth methods
jQuery.each( { Height: "height", Width: "width" }, function( name, type ) {
	var clientProp = "client" + name,
		scrollProp = "scroll" + name,
		offsetProp = "offset" + name;

	// innerHeight and innerWidth
	jQuery.fn[ "inner" + name ] = function() {
		var elem = this[0];
		return elem ?
			elem.style ?
			parseFloat( jQuery.css( elem, type, "padding" ) ) :
			this[ type ]() :
			null;
	};

	// outerHeight and outerWidth
	jQuery.fn[ "outer" + name ] = function( margin ) {
		var elem = this[0];
		return elem ?
			elem.style ?
			parseFloat( jQuery.css( elem, type, margin ? "margin" : "border" ) ) :
			this[ type ]() :
			null;
	};

	jQuery.fn[ type ] = function( value ) {
		return jQuery.access( this, function( elem, type, value ) {
			var doc, docElemProp, orig, ret;

			if ( jQuery.isWindow( elem ) ) {
				// 3rd condition allows Nokia support, as it supports the docElem prop but not CSS1Compat
				doc = elem.document;
				docElemProp = doc.documentElement[ clientProp ];
				return jQuery.support.boxModel && docElemProp ||
					doc.body && doc.body[ clientProp ] || docElemProp;
			}

			// Get document width or height
			if ( elem.nodeType === 9 ) {
				// Either scroll[Width/Height] or offset[Width/Height], whichever is greater
				doc = elem.documentElement;

				// when a window > document, IE6 reports a offset[Width/Height] > client[Width/Height]
				// so we can't use max, as it'll choose the incorrect offset[Width/Height]
				// instead we use the correct client[Width/Height]
				// support:IE6
				if ( doc[ clientProp ] >= doc[ scrollProp ] ) {
					return doc[ clientProp ];
				}

				return Math.max(
					elem.body[ scrollProp ], doc[ scrollProp ],
					elem.body[ offsetProp ], doc[ offsetProp ]
				);
			}

			// Get width or height on the element
			if ( value === undefined ) {
				orig = jQuery.css( elem, type );
				ret = parseFloat( orig );
				return jQuery.isNumeric( ret ) ? ret : orig;
			}

			// Set the width or height on the element
			jQuery( elem ).css( type, value );
		}, type, value, arguments.length, null );
	};
});




// Expose jQuery to the global object
window.jQuery = window.$ = jQuery;

// Expose jQuery as an AMD module, but only for AMD loaders that
// understand the issues with loading multiple versions of jQuery
// in a page that all might call define(). The loader will indicate
// they have special allowances for multiple jQuery versions by
// specifying define.amd.jQuery = true. Register as a named module,
// since jQuery can be concatenated with other files that may use define,
// but not use a proper concatenation script that understands anonymous
// AMD modules. A named AMD is safest and most robust way to register.
// Lowercase jquery is used because AMD module names are derived from
// file names, and jQuery is normally delivered in a lowercase file name.
// Do this after creating the global so that if an AMD module wants to call
// noConflict to hide this version of jQuery, it will work.
if ( typeof define === "function" && define.amd && define.amd.jQuery ) {
	define( "jquery", [], function () { return jQuery; } );
}



})( window );
// ColorBox v1.3.17.1 - a full featured, light-weight, customizable lightbox based on jQuery 1.3+
// Copyright (c) 2011 Jack Moore - jack@colorpowered.com
// Licensed under the MIT license: http://www.opensource.org/licenses/mit-license.php
// + minWidth&minHeight support
(function ($, document, window) {
	var
	// ColorBox Default Settings.	
	// See http://colorpowered.com/colorbox for details.
	defaults = {
		transition: "elastic",
		speed: 300,
		width: false,
		initialWidth: "600",
		innerWidth: false,
		maxWidth: false,
		minWidth:false,
		height: false,
		initialHeight: "450",
		innerHeight: false,
		maxHeight: false,
		minHeight:false,
		scalePhotos: true,
		scrolling: true,
		inline: false,
		html: false,
		iframe: false,
		fastIframe: true,
		photo: false,
		href: false,
		title: false,
		rel: false,
		opacity: 0.9,
		preloading: true,
		current: "image {current} of {total}",
		previous: "previous",
		next: "next",
		close: "close",
		open: false,
		returnFocus: true,
		loop: true,
		slideshow: false,
		slideshowAuto: true,
		slideshowSpeed: 2500,
		slideshowStart: "start slideshow",
		slideshowStop: "stop slideshow",
		onOpen: false,
		onLoad: false,
		onComplete: false,
		onCleanup: false,
		onClosed: false,
		overlayClose: true,		
		escKey: true,
		arrowKey: true,
        top: false,
        bottom: false,
        left: false,
        right: false,
        fixed: false,
        data: false
	},
	
	// Abstracting the HTML and event identifiers for easy rebranding
	colorbox = 'colorbox',
	prefix = 'cbox',
	
	// Events	
	event_open = prefix + '_open',
	event_load = prefix + '_load',
	event_complete = prefix + '_complete',
	event_cleanup = prefix + '_cleanup',
	event_closed = prefix + '_closed',
	event_purge = prefix + '_purge',
	
	// Special Handling for IE
	isIE = $.browser.msie && !$.support.opacity, // Detects IE6,7,8.  IE9 supports opacity.  Feature detection alone gave a false positive on at least one phone browser and on some development versions of Chrome, hence the user-agent test.
	isIE6 = isIE && $.browser.version < 7,
	event_ie6 = prefix + '_IE6',

	// Cached jQuery Object Variables
	$overlay,
	$box,
	$wrap,
	$content,
	$topBorder,
	$leftBorder,
	$rightBorder,
	$bottomBorder,
	$related,
	$window,
	$loaded,
	$loadingBay,
	$loadingOverlay,
	$title,
	$current,
	$slideshow,
	$next,
	$prev,
	$close,
	$groupControls,

	// Variables for cached values or use across multiple functions
	settings = {},
	interfaceHeight,
	interfaceWidth,
	loadedHeight,
	loadedWidth,
	element,
	index,
	photo,
	open,
	active,
	closing,
    handler,
    loadingTimer,
	
	publicMethod,
	boxElement = prefix + 'Element';
	
	// ****************
	// HELPER FUNCTIONS
	// ****************

	// jQuery object generator to reduce code size
	function $div(id, cssText) { 
		var div = document.createElement('div');
		if (id) {
            div.id = prefix + id;
        }
		div.style.cssText = cssText || '';
		return $(div);
	}

	// Convert % values to pixels
	function setSize(size, dimension) {
		dimension = dimension === 'x' ? $window.width() : $window.height();
		return (typeof size === 'string') ? Math.round((/%/.test(size) ? (dimension / 100) * parseInt(size, 10) : parseInt(size, 10))) : size;
	}
	
	// Checks an href to see if it is a photo.
	// There is a force photo option (photo: true) for hrefs that cannot be matched by this regex.
	function isImage(url) {
		return settings.photo || /\.(gif|png|jpg|jpeg|bmp)(?:\?([^#]*))?(?:#(\.*))?$/i.test(url);
	}
	
	// Assigns function results to their respective settings.  This allows functions to be used as values.
	function process(settings) {
		for (var i in settings) {
			if ($.isFunction(settings[i]) && i.substring(0, 2) !== 'on') { // checks to make sure the function isn't one of the callbacks, they will be handled at the appropriate time.
			    settings[i] = settings[i].call(element);
			}
		}
        
		settings.rel = settings.rel || element.rel || 'nofollow';
		settings.href = settings.href || $(element).attr('href');
		settings.title = settings.title || element.title;
        
        if (typeof settings.href === "string") {
            settings.href = $.trim(settings.href);
        }
	}

	function trigger(event, callback) {
		if (callback) {
			callback.call(element);
		}
		$.event.trigger(event);
	}

	// Slideshow functionality
	function slideshow() {
		var
		timeOut,
		className = prefix + "Slideshow_",
		click = "click." + prefix,
		start,
		stop,
		clear;
		
		if (settings.slideshow && $related[1]) {
			start = function () {
				$slideshow
					.text(settings.slideshowStop)
					.unbind(click)
					.bind(event_complete, function () {
						if (index < $related.length - 1 || settings.loop) {
							timeOut = setTimeout(publicMethod.next, settings.slideshowSpeed);
						}
					})
					.bind(event_load, function () {
						clearTimeout(timeOut);
					})
					.one(click + ' ' + event_cleanup, stop);
				$box.removeClass(className + "off").addClass(className + "on");
				timeOut = setTimeout(publicMethod.next, settings.slideshowSpeed);
			};
			
			stop = function () {
				clearTimeout(timeOut);
				$slideshow
					.text(settings.slideshowStart)
					.unbind([event_complete, event_load, event_cleanup, click].join(' '))
					.one(click, start);
				$box.removeClass(className + "on").addClass(className + "off");
			};
			
			if (settings.slideshowAuto) {
				start();
			} else {
				stop();
			}
		} else {
            $box.removeClass(className + "off " + className + "on");
        }
	}

	function launch(elem) {
		if (!closing) {
			
			element = elem;
			
			process($.extend(settings, $.data(element, colorbox)));
			
			$related = $(element);
			
			index = 0;
			
			if (settings.rel !== 'nofollow') {
				$related = $('.' + boxElement).filter(function () {
					var relRelated = $.data(this, colorbox).rel || this.rel;
					return (relRelated === settings.rel);
				});
				index = $related.index(element);
				
				// Check direct calls to ColorBox.
				if (index === -1) {
					$related = $related.add(element);
					index = $related.length - 1;
				}
			}
			
			if (!open) {
				open = active = true; // Prevents the page-change action from queuing up if the visitor holds down the left or right keys.
				
				$box.show();
				
				if (settings.returnFocus) {
					try {
						element.blur();
						$(element).one(event_closed, function () {
							try {
								this.focus();
							} catch (e) {
								// do nothing
							}
						});
					} catch (e) {
						// do nothing
					}
				}
				
				// +settings.opacity avoids a problem in IE when using non-zero-prefixed-string-values, like '.5'
				$overlay.css({"opacity": +settings.opacity, "cursor": settings.overlayClose ? "pointer" : "auto"}).show();
				
				// Opens inital empty ColorBox prior to content being loaded.
				settings.w = setSize(settings.initialWidth, 'x');
				settings.h = setSize(settings.initialHeight, 'y');
				publicMethod.position(0);
				
				if (isIE6) {
					$window.bind('resize.' + event_ie6 + ' scroll.' + event_ie6, function () {
						$overlay.css({width: $window.width(), height: $window.height(), top: $window.scrollTop(), left: $window.scrollLeft()});
					}).trigger('resize.' + event_ie6);
				}
				
				trigger(event_open, settings.onOpen);
				
				$groupControls.add($title).hide();
				
				$close.html(settings.close).show();
			}
			
			publicMethod.load(true);
		}
	}

	// ****************
	// PUBLIC FUNCTIONS
	// Usage format: $.fn.colorbox.close();
	// Usage from within an iframe: parent.$.fn.colorbox.close();
	// ****************
	
	publicMethod = $.fn[colorbox] = $[colorbox] = function (options, callback) {
		var $this = this, autoOpen;
		
		if (!$this[0] && $this.selector) { // if a selector was given and it didn't match any elements, go ahead and exit.
			return $this;
		}
		
		options = options || {};
		
		if (callback) {
			options.onComplete = callback;
		}
		
		if (!$this[0] || $this.selector === undefined) { // detects $.colorbox() and $.fn.colorbox()
			$this = $('<a/>');
			options.open = true; // assume an immediate open
		}
		
		$this.each(function () {
			$.data(this, colorbox, $.extend({}, $.data(this, colorbox) || defaults, options));
			$(this).addClass(boxElement);
		});
		
		autoOpen = options.open;
		
		if ($.isFunction(autoOpen)) {
			autoOpen = autoOpen.call($this);
		}
		
		if (autoOpen) {
			launch($this[0]);
		}
		
		return $this;
	};

	// Initialize ColorBox: store common calculations, preload the interface graphics, append the html.
	// This preps colorbox for a speedy open when clicked, and lightens the burdon on the browser by only
	// having to run once, instead of each time colorbox is opened.
	publicMethod.init = function () {
		// Create & Append jQuery Objects
		$window = $(window);
		$box = $div().attr({id: colorbox, 'class': isIE ? prefix + (isIE6 ? 'IE6' : 'IE') : ''});
		$overlay = $div("Overlay", isIE6 ? 'position:absolute' : '').hide();
		
		$wrap = $div("Wrapper");
		$content = $div("Content").append(
			$loaded = $div("LoadedContent", 'width:0; height:0; overflow:hidden'),
			$loadingOverlay = $div("LoadingOverlay").add($div("LoadingGraphic")),
			$title = $div("Title"),
			$current = $div("Current"),
			$next = $div("Next"),
			$prev = $div("Previous"),
			$slideshow = $div("Slideshow").bind(event_open, slideshow),
			$close = $div("Close")
		);
		$wrap.append( // The 3x3 Grid that makes up ColorBox
			$div().append(
				$div("TopLeft"),
				$topBorder = $div("TopCenter"),
				$div("TopRight")
			),
			$div(false, 'clear:left').append(
				$leftBorder = $div("MiddleLeft"),
				$content,
				$rightBorder = $div("MiddleRight")
			),
			$div(false, 'clear:left').append(
				$div("BottomLeft"),
				$bottomBorder = $div("BottomCenter"),
				$div("BottomRight")
			)
		).children().children().css({'float': 'left'});
		
		$loadingBay = $div(false, 'position:absolute; width:9999px; visibility:hidden; display:none');
		
		$('body').prepend($overlay, $box.append($wrap, $loadingBay));
		
		$content.children()
		.hover(function () {
			$(this).addClass('hover');
		}, function () {
			$(this).removeClass('hover');
		}).addClass('hover');
		
		// Cache values needed for size calculations
		interfaceHeight = $topBorder.height() + $bottomBorder.height() + $content.outerHeight(true) - $content.height();//Subtraction needed for IE6
		interfaceWidth = $leftBorder.width() + $rightBorder.width() + $content.outerWidth(true) - $content.width();
		loadedHeight = $loaded.outerHeight(true);
		loadedWidth = $loaded.outerWidth(true);
		
		// Setting padding to remove the need to do size conversions during the animation step.
		$box.css({"padding-bottom": interfaceHeight, "padding-right": interfaceWidth}).hide();
		
        // Setup button events.
        $next.click(function () {
            publicMethod.next();
        });
        $prev.click(function () {
            publicMethod.prev();
        });
        $close.click(function () {
            publicMethod.close();
        });
		
		$groupControls = $next.add($prev).add($current).add($slideshow);
		
		// Adding the 'hover' class allowed the browser to load the hover-state
		// background graphics.  The class can now can be removed.
		$content.children().removeClass('hover');
		


        
		$overlay.click(function () {
			if (settings.overlayClose) {
				publicMethod.close();
			}
		});
		
		// Set Navigation Key Bindings
		$(document).bind('keydown.' + prefix, function (e) {
            var key = e.keyCode;
			if (open && settings.escKey && key === 27) {
				e.preventDefault();
				publicMethod.close();
			}
			if (open && settings.arrowKey && $related[1]) {
				if (key === 37) {
					e.preventDefault();
					$prev.click();
				} else if (key === 39) {
					e.preventDefault();
					$next.click();
				}
			}
		});
	};
	
	publicMethod.remove = function () {
		$box.add($overlay).remove();
		$('.' + boxElement).removeData(colorbox).removeClass(boxElement);
	};

	publicMethod.position = function (speed, loadedCallback) {
        var animate_speed, top = 0, left = 0;
        
        // remove the modal so that it doesn't influence the document width/height        
        $box.hide();
        
        if (settings.fixed && !isIE6) {
            $box.css({position: 'fixed'});
        } else {
            top = $window.scrollTop();
            left = $window.scrollLeft();
            $box.css({position: 'absolute'});
        }
        
		// keeps the top and left positions within the browser's viewport.
        if (settings.right !== false) {
            left += Math.max($window.width() - settings.w - loadedWidth - interfaceWidth - setSize(settings.right, 'x'), 0);
        } else if (settings.left !== false) {
            left += setSize(settings.left, 'x');
        } else {
            left += Math.max($window.width() - settings.w - loadedWidth - interfaceWidth, 0) / 2;
        }
        
        if (settings.bottom !== false) {
            top += Math.max(document.documentElement.clientHeight - settings.h - loadedHeight - interfaceHeight - setSize(settings.bottom, 'y'), 0);
        } else if (settings.top !== false) {
            top += setSize(settings.top, 'y');
        } else {
            top += Math.max(document.documentElement.clientHeight - settings.h - loadedHeight - interfaceHeight, 0) / 2;
        }
        
        $box.show();
        
		// setting the speed to 0 to reduce the delay between same-sized content.
		animate_speed = ($box.width() === settings.w + loadedWidth && $box.height() === settings.h + loadedHeight) ? 0 : speed;
        
		// this gives the wrapper plenty of breathing room so it's floated contents can move around smoothly,
		// but it has to be shrank down around the size of div#colorbox when it's done.  If not,
		// it can invoke an obscure IE bug when using iframes.
		$wrap[0].style.width = $wrap[0].style.height = "9999px";
		
		function modalDimensions(that) {
			// loading overlay height has to be explicitly set for IE6.
			$topBorder[0].style.width = $bottomBorder[0].style.width = $content[0].style.width = that.style.width;
			$loadingOverlay[0].style.height = $loadingOverlay[1].style.height = $content[0].style.height = $leftBorder[0].style.height = $rightBorder[0].style.height = that.style.height;
		}
		
		$box.dequeue().animate({width: settings.w + loadedWidth, height: settings.h + loadedHeight, top: top, left: left}, {
			duration: animate_speed,
			complete: function () {
				modalDimensions(this);
				
				active = false;
				
				// shrink the wrapper down to exactly the size of colorbox to avoid a bug in IE's iframe implementation.
				$wrap[0].style.width = (settings.w + loadedWidth + interfaceWidth) + "px";
				$wrap[0].style.height = (settings.h + loadedHeight + interfaceHeight) + "px";
				
				if (loadedCallback) {
					loadedCallback();
				}
			},
			step: function () {
				modalDimensions(this);
			}
		});
	};

	publicMethod.resize = function (options) {
		if (open) {
			options = options || {};
			
			if (options.width) {
				settings.w = setSize(options.width, 'x') - loadedWidth - interfaceWidth;
			}
			if (options.innerWidth) {
				settings.w = setSize(options.innerWidth, 'x');
			}
			$loaded.css({width: settings.w});
			
			if (options.height) {
				settings.h = setSize(options.height, 'y') - loadedHeight - interfaceHeight;
			}
			if (options.innerHeight) {
				settings.h = setSize(options.innerHeight, 'y');
			}
			if (!options.innerHeight && !options.height) {				
				var $child = $loaded.wrapInner("<div style='overflow:auto'></div>").children(); // temporary wrapper to get an accurate estimate of just how high the total content should be.
				settings.h = $child.height();
				$child.replaceWith($child.children()); // ditch the temporary wrapper div used in height calculation
			}
			$loaded.css({height: settings.h});
			
			publicMethod.position(settings.transition === "none" ? 0 : settings.speed);
		}
	};

	publicMethod.prep = function (object) {
		if (!open) {
			return;
		}
		
		var speed = settings.transition === "none" ? 0 : settings.speed;
		
		$window.unbind('resize.' + prefix);
		$loaded.remove();
		$loaded = $div('LoadedContent').html(object);
		
		function getWidth() {
			settings.w = settings.w || $loaded.width();
			settings.w = settings.minw && settings.minw > settings.w ? settings.minw : settings.w;
			settings.w = settings.mw && settings.mw < settings.w ? settings.mw : settings.w;
			return settings.w;
		}
		function getHeight() {
			settings.h = settings.h || $loaded.height();
			settings.h = settings.minh && settings.minh > settings.h ? settings.minh : settings.h;
			settings.h = settings.mh && settings.mh < settings.h ? settings.mh : settings.h;
			return settings.h;
		}
		
		$loaded.hide()
		.appendTo($loadingBay.show())// content has to be appended to the DOM for accurate size calculations.
		.css({width: getWidth(), overflow: settings.scrolling ? 'auto' : 'hidden'})
		.css({height: getHeight()})// sets the height independently from the width in case the new width influences the value of height.
		.prependTo($content);
		
		$loadingBay.hide();
		
		// floating the IMG removes the bottom line-height and fixed a problem where IE miscalculates the width of the parent element as 100% of the document width.
		//$(photo).css({'float': 'none', marginLeft: 'auto', marginRight: 'auto'});
		
        $(photo).css({'float': 'none'});
        
		// Hides SELECT elements in IE6 because they would otherwise sit on top of the overlay.
		if (isIE6) {
			$('select').not($box.find('select')).filter(function () {
				return this.style.visibility !== 'hidden';
			}).css({'visibility': 'hidden'}).one(event_cleanup, function () {
				this.style.visibility = 'inherit';
			});
		}
		
		function setPosition(s) {
			publicMethod.position(s, function () {
				var prev, prevSrc, next, nextSrc, total = $related.length, iframe, complete;
				
				if (!open) {
					return;
				}
				
                function removeFilter() {
                    if (isIE) {
                        $box[0].style.removeAttribute('filter');
                    }
                }
                
				complete = function () {
                    clearTimeout(loadingTimer);
					$loadingOverlay.hide();
					trigger(event_complete, settings.onComplete);
				};
				
				if (isIE) {
					//This fadeIn helps the bicubic resampling to kick-in.
					if (photo) {
						$loaded.fadeIn(100);
					}
				}
				
				$title.html(settings.title).add($loaded).show();
				
				if (total > 1) { // handle grouping
					if (typeof settings.current === "string") {
						$current.html(settings.current.replace(/\{current\}/, index + 1).replace(/\{total\}/, total)).show();
					}
					
					$next[(settings.loop || index < total - 1) ? "show" : "hide"]().html(settings.next);
					$prev[(settings.loop || index) ? "show" : "hide"]().html(settings.previous);
					
					prev = index ? $related[index - 1] : $related[total - 1];
					next = index < total - 1 ? $related[index + 1] : $related[0];
					
					if (settings.slideshow) {
						$slideshow.show();
					}
					
					// Preloads images within a rel group
					if (settings.preloading) {
						nextSrc = $.data(next, colorbox).href || next.href;
						prevSrc = $.data(prev, colorbox).href || prev.href;
						
						nextSrc = $.isFunction(nextSrc) ? nextSrc.call(next) : nextSrc;
						prevSrc = $.isFunction(prevSrc) ? prevSrc.call(prev) : prevSrc;
						
						if (isImage(nextSrc)) {
							$('<img/>')[0].src = nextSrc;
						}
						
						if (isImage(prevSrc)) {
							$('<img/>')[0].src = prevSrc;
						}
					}
				} else {
					$groupControls.hide();
				}
				
				if (settings.iframe) {
					iframe = $('<iframe/>').addClass(prefix + 'Iframe')[0];
					
					if (settings.fastIframe) {
						complete();
					} else {
						$(iframe).one('load', complete);
					}
					iframe.name = prefix + (+new Date());
					iframe.src = settings.href;
					
					if (!settings.scrolling) {
						iframe.scrolling = "no";
					}
					
					if (isIE) {
                        iframe.frameBorder = 0;
						iframe.allowTransparency = "true";
					}
					
					$(iframe).appendTo($loaded).one(event_purge, function () {
						iframe.src = "//about:blank";
					});
				} else {
					complete();
				}
				
				if (settings.transition === 'fade') {
					$box.fadeTo(speed, 1, removeFilter);
				} else {
                    removeFilter();
				}
				
				$window.bind('resize.' + prefix, function () {
					publicMethod.position(0);
				});
			});
		}
		
		if (settings.transition === 'fade') {
			$box.fadeTo(speed, 0, function () {
				setPosition(0);
			});
		} else {
			setPosition(speed);
		}
	};

	publicMethod.load = function (launched) {
		var href, setResize, prep = publicMethod.prep;
		
		active = true;
		
		photo = false;
		
		element = $related[index];
		
		if (!launched) {
			process($.extend(settings, $.data(element, colorbox)));
		}
		
		trigger(event_purge);
		
		trigger(event_load, settings.onLoad);
		
		settings.h = settings.height ?
				setSize(settings.height, 'y') - loadedHeight - interfaceHeight :
				settings.innerHeight && setSize(settings.innerHeight, 'y');
		
		settings.w = settings.width ?
				setSize(settings.width, 'x') - loadedWidth - interfaceWidth :
				settings.innerWidth && setSize(settings.innerWidth, 'x');
		
		// Sets the minimum dimensions for use in image scaling
		settings.mw = settings.w;
		settings.mh = settings.h;
		settings.minw = settings.w;
		settings.minh = settings.h;

		// Re-evaluate the minimum width and height based on maxWidth and maxHeight values.
		// If the width or height exceed the maxWidth or maxHeight, use the maximum values instead.
		if (settings.maxWidth) {
			settings.mw = setSize(settings.maxWidth, 'x') - loadedWidth - interfaceWidth;
			settings.mw = settings.w && settings.w < settings.mw ? settings.w : settings.mw;
		}
		if(settings.minWidth){
			settings.minw = setSize(settings.minWidth, 'x') - loadedWidth - interfaceWidth;
		 	settings.minw = settings.w && settings.w > settings.minw ? settings.w : settings.minw;
		}
		if (settings.maxHeight) {
			settings.mh = setSize(settings.maxHeight, 'y') - loadedHeight - interfaceHeight;
			settings.mh = settings.h && settings.h < settings.mh ? settings.h : settings.mh;
		}
		if(settings.minHeight){
			settings.minh = setSize(settings.minHeight, 'y') - loadedHeight - interfaceHeight;
		 	settings.minh = settings.h && settings.h > settings.minh ? settings.h : settings.minh;
		}

		href = settings.href;
		
        loadingTimer = setTimeout(function () {
            $loadingOverlay.show();
        }, 100);
        
		if (settings.inline) {
			// Inserts an empty placeholder where inline content is being pulled from.
			// An event is bound to put inline content back when ColorBox closes or loads new content.
			$div().hide().insertBefore($(href)[0]).one(event_purge, function () {
				$(this).replaceWith($loaded.children());
			});
			prep($(href));
		} else if (settings.iframe) {
			// IFrame element won't be added to the DOM until it is ready to be displayed,
			// to avoid problems with DOM-ready JS that might be trying to run in that iframe.
			prep(" ");
		} else if (settings.html) {
			prep(settings.html);
		} else if (isImage(href)) {
			$(photo = new Image())
			.addClass(prefix + 'Photo')
			.error(function () {
				settings.title = false;
				prep($div('Error').text('This image could not be loaded'));
			})
			.load(function () {
				var percent;
				photo.onload = null; //stops animated gifs from firing the onload repeatedly.
				
				if (settings.scalePhotos) {
					setResize = function () {
						photo.height -= photo.height * percent;
						photo.width -= photo.width * percent;	
					};
					if (settings.mw && photo.width > settings.mw) {
						percent = (photo.width - settings.mw) / photo.width;
						setResize();
					}
					if (settings.mh && photo.height > settings.mh) {
						percent = (photo.height - settings.mh) / photo.height;
						setResize();
					}
				}
				
				if (settings.h) {
					photo.style.marginTop = Math.max(settings.h - photo.height, 0) / 2 + 'px';
				}
				
				if ($related[1] && (index < $related.length - 1 || settings.loop)) {
					photo.style.cursor = 'pointer';
					photo.onclick = function () {
                        publicMethod.next();
                    };
				}
				
				if (isIE) {
					photo.style.msInterpolationMode = 'bicubic';
				}
				
				setTimeout(function () { // A pause because Chrome will sometimes report a 0 by 0 size otherwise.
					prep(photo);
				}, 1);
			});
			
			setTimeout(function () { // A pause because Opera 10.6+ will sometimes not run the onload function otherwise.
				photo.src = href;
			}, 1);
		} else if (href) {
			$loadingBay.load(href, settings.data, function (data, status, xhr) {
				prep(status === 'error' ? $div('Error').text('Request unsuccessful: ' + xhr.statusText) : $(this).contents());
			});
		}
	};
        
	// Navigates to the next page/image in a set.
	publicMethod.next = function () {
		if (!active && $related[1] && (index < $related.length - 1 || settings.loop)) {
			index = index < $related.length - 1 ? index + 1 : 0;
			publicMethod.load();
		}
	};
	
	publicMethod.prev = function () {
		if (!active && $related[1] && (index || settings.loop)) {
			index = index ? index - 1 : $related.length - 1;
			publicMethod.load();
		}
	};

	// Note: to use this within an iframe use the following format: parent.$.fn.colorbox.close();
	publicMethod.close = function () {
		if (open && !closing) {
			
			closing = true;
			
			open = false;
			
			trigger(event_cleanup, settings.onCleanup);
			
			$window.unbind('.' + prefix + ' .' + event_ie6);
			
			$overlay.fadeTo(200, 0);
			
			$box.stop().fadeTo(300, 0, function () {
                 
				$box.add($overlay).css({'opacity': 1, cursor: 'auto'}).hide();
				
				trigger(event_purge);
				
				$loaded.remove();
				
				setTimeout(function () {
					closing = false;
					trigger(event_closed, settings.onClosed);
				}, 1);
			});
		}
	};

	// A method for fetching the current element ColorBox is referencing.
	// returns a jQuery object.
	publicMethod.element = function () {
		return $(element);
	};

	publicMethod.settings = defaults;
    
	// Bind the live event before DOM-ready for maximum performance in IE6 & 7.
    handler = function (e) {
        // checks to see if it was a non-left mouse-click and for clicks modified with ctrl, shift, or alt.
        if (!((e.button !== 0 && typeof e.button !== 'undefined') || e.ctrlKey || e.shiftKey || e.altKey)) {
            e.preventDefault();
            launch(this);
        }
    };
    
    if ($.fn.delegate) {
        $(document).delegate('.' + boxElement, 'click', handler);
    } else {
        $('.' + boxElement).live('click', handler);
    }
    
	// Initializes ColorBox when the DOM has loaded
	$(publicMethod.init);

}(jQuery, document, this));
/**
* hoverIntent is similar to jQuery's built-in "hover" function except that
* instead of firing the onMouseOver event immediately, hoverIntent checks
* to see if the user's mouse has slowed down (beneath the sensitivity
* threshold) before firing the onMouseOver event.
* 
* hoverIntent r6 // 2011.02.26 // jQuery 1.5.1+
* <http://cherne.net/brian/resources/jquery.hoverIntent.html>
* 
* hoverIntent is currently available for use in all personal or commercial 
* projects under both MIT and GPL licenses. This means that you can choose 
* the license that best suits your project, and use it accordingly.
* 
* // basic usage (just like .hover) receives onMouseOver and onMouseOut functions
* $("ul li").hoverIntent( showNav , hideNav );
* 
* // advanced usage receives configuration object only
* $("ul li").hoverIntent({
*	sensitivity: 7, // number = sensitivity threshold (must be 1 or higher)
*	interval: 100,   // number = milliseconds of polling interval
*	over: showNav,  // function = onMouseOver callback (required)
*	timeout: 0,   // number = milliseconds delay before onMouseOut function call
*	out: hideNav    // function = onMouseOut callback (required)
* });
* 
* @param  f  onMouseOver function || An object with configuration options
* @param  g  onMouseOut function  || Nothing (use configuration options object)
* @author    Brian Cherne brian(at)cherne(dot)net
*/
(function($) {
	$.fn.hoverIntent = function(f,g) {
		// default configuration options
		var cfg = {
			sensitivity: 7,
			interval: 100,
			timeout: 0
		};
		// override configuration options with user supplied object
		cfg = $.extend(cfg, g ? { over: f, out: g } : f );

		// instantiate variables
		// cX, cY = current X and Y position of mouse, updated by mousemove event
		// pX, pY = previous X and Y position of mouse, set by mouseover and polling interval
		var cX, cY, pX, pY;

		// A private function for getting mouse position
		var track = function(ev) {
			cX = ev.pageX;
			cY = ev.pageY;
		};

		// A private function for comparing current and previous mouse position
		var compare = function(ev,ob) {
			ob.hoverIntent_t = clearTimeout(ob.hoverIntent_t);
			// compare mouse positions to see if they've crossed the threshold
			if ( ( Math.abs(pX-cX) + Math.abs(pY-cY) ) < cfg.sensitivity ) {
				$(ob).unbind("mousemove",track);
				// set hoverIntent state to true (so mouseOut can be called)
				ob.hoverIntent_s = 1;
				return cfg.over.apply(ob,[ev]);
			} else {
				// set previous coordinates for next time
				pX = cX; pY = cY;
				// use self-calling timeout, guarantees intervals are spaced out properly (avoids JavaScript timer bugs)
				ob.hoverIntent_t = setTimeout( function(){compare(ev, ob);} , cfg.interval );
			}
		};

		// A private function for delaying the mouseOut function
		var delay = function(ev,ob) {
			ob.hoverIntent_t = clearTimeout(ob.hoverIntent_t);
			ob.hoverIntent_s = 0;
			return cfg.out.apply(ob,[ev]);
		};

		// A private function for handling mouse 'hovering'
		var handleHover = function(e) {
			// copy objects to be passed into t (required for event object to be passed in IE)
			var ev = jQuery.extend({},e);
			var ob = this;

			// cancel hoverIntent timer if it exists
			if (ob.hoverIntent_t) { ob.hoverIntent_t = clearTimeout(ob.hoverIntent_t); }

			// if e.type == "mouseenter"
			if (e.type == "mouseenter") {
				// set "previous" X and Y position based on initial entry point
				pX = ev.pageX; pY = ev.pageY;
				// update "current" X and Y position based on mousemove
				$(ob).bind("mousemove",track);
				// start polling interval (self-calling timeout) to compare mouse coordinates over time
				if (ob.hoverIntent_s != 1) { ob.hoverIntent_t = setTimeout( function(){compare(ev,ob);} , cfg.interval );}

			// else e.type == "mouseleave"
			} else {
				// unbind expensive mousemove event
				$(ob).unbind("mousemove",track);
				// if hoverIntent state is true, then call the mouseOut function after the specified delay
				if (ob.hoverIntent_s == 1) { ob.hoverIntent_t = setTimeout( function(){delay(ev,ob);} , cfg.timeout );}
			}
		};

		// bind the function to the two event listeners
		return this.bind('mouseenter',handleHover).bind('mouseleave',handleHover);
	};
})(jQuery);
/**
 * Cookie plugin
 *
 * Copyright (c) 2006 Klaus Hartl (stilbuero.de)
 * Dual licensed under the MIT and GPL licenses:
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
 *
 */

/**
 * Create a cookie with the given name and value and other optional parameters.
 *
 * @example $.cookie('the_cookie', 'the_value');
 * @desc Set the value of a cookie.
 * @example $.cookie('the_cookie', 'the_value', { expires: 7, path: '/', domain: 'jquery.com', secure: true });
 * @desc Create a cookie with all available options.
 * @example $.cookie('the_cookie', 'the_value');
 * @desc Create a session cookie.
 * @example $.cookie('the_cookie', null);
 * @desc Delete a cookie by passing null as value. Keep in mind that you have to use the same path and domain
 *       used when the cookie was set.
 *
 * @param String name The name of the cookie.
 * @param String value The value of the cookie.
 * @param Object options An object literal containing key/value pairs to provide optional cookie attributes.
 * @option Number|Date expires Either an integer specifying the expiration date from now on in days or a Date object.
 *                             If a negative value is specified (e.g. a date in the past), the cookie will be deleted.
 *                             If set to null or omitted, the cookie will be a session cookie and will not be retained
 *                             when the the browser exits.
 * @option String path The value of the path atribute of the cookie (default: path of page that created the cookie).
 * @option String domain The value of the domain attribute of the cookie (default: domain of page that created the cookie).
 * @option Boolean secure If true, the secure attribute of the cookie will be set and the cookie transmission will
 *                        require a secure protocol (like HTTPS).
 * @type undefined
 *
 * @name $.cookie
 * @cat Plugins/Cookie
 * @author Klaus Hartl/klaus.hartl@stilbuero.de
 */

/**
 * Get the value of a cookie with the given name.
 *
 * @example $.cookie('the_cookie');
 * @desc Get the value of a cookie.
 *
 * @param String name The name of the cookie.
 * @return The value of the cookie.
 * @type String
 *
 * @name $.cookie
 * @cat Plugins/Cookie
 * @author Klaus Hartl/klaus.hartl@stilbuero.de
 */
jQuery.cookie = function(name, value, options) {
    if (typeof value != 'undefined') { // name and value given, set cookie
        options = options || {};
        if (value === null) {
            value = '';
            options.expires = -1;
        }
        var expires = '';
        if (options.expires && (typeof options.expires == 'number' || options.expires.toUTCString)) {
            var date;
            if (typeof options.expires == 'number') {
                date = new Date();
                date.setTime(date.getTime() + (options.expires * 24 * 60 * 60 * 1000));
            } else {
                date = options.expires;
            }
            expires = '; expires=' + date.toUTCString(); // use expires attribute, max-age is not supported by IE
        }
        // CAUTION: Needed to parenthesize options.path and options.domain
        // in the following expressions, otherwise they evaluate to undefined
        // in the packed version for some reason...
        var path = options.path ? '; path=' + (options.path) : '';
        var domain = options.domain ? '; domain=' + (options.domain) : '';
        var secure = options.secure ? '; secure' : '';
        document.cookie = [name, '=', encodeURIComponent(value), expires, path, domain, secure].join('');
    } else { // only name given, get cookie
        var cookieValue = null;
        if (document.cookie && document.cookie != '') {
            var cookies = document.cookie.split(';');
            for (var i = 0; i < cookies.length; i++) {
                var cookie = jQuery.trim(cookies[i]);
                // Does this cookie string begin with the name we want?
                if (cookie.substring(0, name.length + 1) == (name + '=')) {
                    cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
                    break;
                }
            }
        }
        return cookieValue;
    }
};
/* jshint browser: true */
/* global define: false */
/* https://github.com/andris9/simpleStorage */

// AMD shim
(function(root, factory) {

    'use strict';

    if (typeof define === 'function' && define.amd) {
        define(factory);
    } else if (typeof exports !== 'undefined') {
        module.exports = factory();
    } else {
        root.simpleStorage = factory();
    }

}(this, function() {

    'use strict';

    var
        VERSION = '0.1.3',

    /* This is the object, that holds the cached values */
        _storage = false,

    /* How much space does the storage take */
        _storage_size = 0,

        _storage_available = false,

        _ttl_timeout = null;

    // This method might throw as it touches localStorage and doing so
    // can be prohibited in some environments
    function _init() {

        // If localStorage does not exist, the following throws
        // This is intentional
        window.localStorage.setItem('__simpleStorageInitTest', 'tmpval');
        window.localStorage.removeItem('__simpleStorageInitTest');

        // Load data from storage
        _load_storage();

        // remove dead keys
        _handleTTL();

        // start listening for changes
        _setupUpdateObserver();

        // handle cached navigation
        if ('addEventListener' in window) {
            window.addEventListener('pageshow', function(event) {
                if (event.persisted) {
                    _reloadData();
                }
            }, false);
        }

        _storage_available = true;
    }

    /**
     * Sets up a storage change observer
     */
    function _setupUpdateObserver() {
        if ('addEventListener' in window) {
            window.addEventListener('storage', _reloadData, false);
        } else {
            document.attachEvent('onstorage', _reloadData);
        }
    }

    /**
     * Reload data from storage when needed
     */
    function _reloadData() {
        try {
            _load_storage();
        } catch (E) {
            _storage_available = false;
            return;
        }
        _handleTTL();
    }

    function _load_storage() {
        var source = localStorage.getItem('simpleStorage');

        try {
            _storage = JSON.parse(source) || {};
        } catch (E) {
            _storage = {};
        }

        _storage_size = _get_storage_size();
    }

    function _save() {
        try {
            localStorage.setItem('simpleStorage', JSON.stringify(_storage));
            _storage_size = _get_storage_size();
        } catch (E) {
            return E;
        }
        return true;
    }

    function _get_storage_size() {
        var source = localStorage.getItem('simpleStorage');
        return source ? String(source).length : 0;
    }

    function _handleTTL() {
        var curtime, i, len, expire, keys, nextExpire = Infinity,
            expiredKeysCount = 0;

        clearTimeout(_ttl_timeout);

        if (!_storage || !_storage.__simpleStorage_meta || !_storage.__simpleStorage_meta.TTL) {
            return;
        }

        curtime = +new Date();
        keys = _storage.__simpleStorage_meta.TTL.keys || [];
        expire = _storage.__simpleStorage_meta.TTL.expire || {};

        for (i = 0, len = keys.length; i < len; i++) {
            if (expire[keys[i]] <= curtime) {
                expiredKeysCount++;
                delete _storage[keys[i]];
                delete expire[keys[i]];
            } else {
                if (expire[keys[i]] < nextExpire) {
                    nextExpire = expire[keys[i]];
                }
                break;
            }
        }

        // set next check
        if (nextExpire != Infinity) {
            _ttl_timeout = setTimeout(_handleTTL, Math.min(nextExpire - curtime, 0x7FFFFFFF));
        }

        // remove expired from TTL list and save changes
        if (expiredKeysCount) {
            keys.splice(0, expiredKeysCount);

            _cleanMetaObject();
            _save();
        }
    }

    function _setTTL(key, ttl) {
        var curtime = +new Date(),
            i, len, added = false;

        ttl = Number(ttl) || 0;

        // Set TTL value for the key
        if (ttl !== 0) {
            // If key exists, set TTL
            if (_storage.hasOwnProperty(key)) {

                if (!_storage.__simpleStorage_meta) {
                    _storage.__simpleStorage_meta = {};
                }

                if (!_storage.__simpleStorage_meta.TTL) {
                    _storage.__simpleStorage_meta.TTL = {
                        expire: {},
                        keys: []
                    };
                }

                _storage.__simpleStorage_meta.TTL.expire[key] = curtime + ttl;

                // find the expiring key in the array and remove it and all before it (because of sort)
                if (_storage.__simpleStorage_meta.TTL.expire.hasOwnProperty(key)) {
                    for (i = 0, len = _storage.__simpleStorage_meta.TTL.keys.length; i < len; i++) {
                        if (_storage.__simpleStorage_meta.TTL.keys[i] == key) {
                            _storage.__simpleStorage_meta.TTL.keys.splice(i);
                        }
                    }
                }

                // add key to keys array preserving sort (soonest first)
                for (i = 0, len = _storage.__simpleStorage_meta.TTL.keys.length; i < len; i++) {
                    if (_storage.__simpleStorage_meta.TTL.expire[_storage.__simpleStorage_meta.TTL.keys[i]] > (curtime + ttl)) {
                        _storage.__simpleStorage_meta.TTL.keys.splice(i, 0, key);
                        added = true;
                        break;
                    }
                }

                // if not added in previous loop, add here
                if (!added) {
                    _storage.__simpleStorage_meta.TTL.keys.push(key);
                }
            } else {
                return false;
            }
        } else {
            // Remove TTL if set
            if (_storage && _storage.__simpleStorage_meta && _storage.__simpleStorage_meta.TTL) {

                if (_storage.__simpleStorage_meta.TTL.expire.hasOwnProperty(key)) {
                    delete _storage.__simpleStorage_meta.TTL.expire[key];
                    for (i = 0, len = _storage.__simpleStorage_meta.TTL.keys.length; i < len; i++) {
                        if (_storage.__simpleStorage_meta.TTL.keys[i] == key) {
                            _storage.__simpleStorage_meta.TTL.keys.splice(i, 1);
                            break;
                        }
                    }
                }

                _cleanMetaObject();
            }
        }

        // schedule next TTL check
        clearTimeout(_ttl_timeout);
        if (_storage && _storage.__simpleStorage_meta && _storage.__simpleStorage_meta.TTL && _storage.__simpleStorage_meta.TTL.keys.length) {
            _ttl_timeout = setTimeout(_handleTTL, Math.min(Math.max(_storage.__simpleStorage_meta.TTL.expire[_storage.__simpleStorage_meta.TTL.keys[0]] - curtime, 0), 0x7FFFFFFF));
        }

        return true;
    }

    function _cleanMetaObject() {
        var updated = false,
            hasProperties = false,
            i;

        if (!_storage || !_storage.__simpleStorage_meta) {
            return updated;
        }

        // If nothing to TTL, remove the object
        if (_storage.__simpleStorage_meta.TTL && !_storage.__simpleStorage_meta.TTL.keys.length) {
            delete _storage.__simpleStorage_meta.TTL;
            updated = true;
        }

        // If meta object is empty, remove it
        for (i in _storage.__simpleStorage_meta) {
            if (_storage.__simpleStorage_meta.hasOwnProperty(i)) {
                hasProperties = true;
                break;
            }
        }

        if (!hasProperties) {
            delete _storage.__simpleStorage_meta;
            updated = true;
        }

        return updated;
    }

    ////////////////////////// PUBLIC INTERFACE /////////////////////////

    try {
        _init();
    } catch (E) {}

    return {

        version: VERSION,

        canUse: function() {
            return !!_storage_available;
        },

        set: function(key, value, options) {
            if (key == '__simpleStorage_meta') {
                return false;
            }

            if (!_storage) {
                return false;
            }

            // undefined values are deleted automatically
            if (typeof value == 'undefined') {
                return this.deleteKey(key);
            }

            options = options || {};

            // Check if the value is JSON compatible (and remove reference to existing objects/arrays)
            try {
                value = JSON.parse(JSON.stringify(value));
            } catch (E) {
                return E;
            }

            _storage[key] = value;

            _setTTL(key, options.TTL || 0);

            return _save();
        },

        get: function(key) {
            if (!_storage) {
                return false;
            }

            if (_storage.hasOwnProperty(key) && key != '__simpleStorage_meta') {
                // TTL value for an existing key is either a positive number or an Infinity
                if (this.getTTL(key)) {
                    return _storage[key];
                }
            }
        },

        deleteKey: function(key) {

            if (!_storage) {
                return false;
            }

            if (key in _storage) {
                delete _storage[key];

                _setTTL(key, 0);

                return _save();
            }

            return false;
        },

        setTTL: function(key, ttl) {
            if (!_storage) {
                return false;
            }

            _setTTL(key, ttl);

            return _save();
        },

        getTTL: function(key) {
            var ttl;

            if (!_storage) {
                return false;
            }

            if (_storage.hasOwnProperty(key)) {
                if (_storage.__simpleStorage_meta &&
                    _storage.__simpleStorage_meta.TTL &&
                    _storage.__simpleStorage_meta.TTL.expire &&
                    _storage.__simpleStorage_meta.TTL.expire.hasOwnProperty(key)) {

                    ttl = Math.max(_storage.__simpleStorage_meta.TTL.expire[key] - (+new Date()) || 0, 0);

                    return ttl || false;
                } else {
                    return Infinity;
                }
            }

            return false;
        },

        flush: function() {
            if (!_storage) {
                return false;
            }

            _storage = {};
            try {
                localStorage.removeItem('simpleStorage');
                return true;
            } catch (E) {
                return E;
            }
        },

        index: function() {
            if (!_storage) {
                return false;
            }

            var index = [],
                i;
            for (i in _storage) {
                if (_storage.hasOwnProperty(i) && i != '__simpleStorage_meta') {
                    index.push(i);
                }
            }
            return index;
        },

        storageSize: function() {
            return _storage_size;
        }
    };

}));

/*
 Textbox.io JavaScript Library
 Copyright (c) 2013-2017 Ephox Corp. All rights reserved.
 This software is provided "AS IS," without a warranty of any kind.

 Version: 2.2.1.73
 Client Build: 2.2.1.50
*/
(function(){var na,sa={},l=function(d,e,c){if("string"!==typeof d)throw"module id must be a string";if(void 0===e)throw"no dependencies for "+d;if(void 0===c)throw"no definition function for "+d;sa[d]={deps:e,defn:c,instance:void 0}},oa=function(d){var e=sa[d];if(void 0===e)throw"module ["+d+"] was undefined";if(void 0===e.instance){for(var c=sa[d],a=c.deps,b=c.defn,f=a.length,g=Array(f),h=0;h<f;++h)g[h]=oa(a[h]);a=b.apply(null,g);if(void 0===a)throw"module ["+d+"] returned undefined";c.instance=
a}return e.instance};na={define:l,require:function(d,e){for(var c=d.length,a=Array(c),b=0;b<c;++b)a.push(oa(d[b]));e.apply(null,e)},demand:oa};var ya=oa,aa=function(d,e){l(d,[],function(){return e})};l("1",[],function(){return Function("return this;")()});l("8",[],function(){return function(){return{major:"2",minor:"2",full:"2.2.1.73"}}});aa("9",Array);l("7",["9"],function(d){return{noop:function(){},compose:function(d,c){return function(){return d(c.apply(null,arguments))}},constant:function(d){return function(){return d}},
identity:function(d){return d},tripleEquals:function(d,c){return d===c},curry:function(e){for(var c=new d(arguments.length-1),a=1;a<arguments.length;a++)c[a-1]=arguments[a];return function(){for(var a=new d(arguments.length),f=0;f<a.length;f++)a[f]=arguments[f];a=c.concat(a);return e.apply(null,a)}},not:function(d){return function(){return!d.apply(null,arguments)}},die:function(d){return function(){throw d;}},apply:function(d){return d()},call:function(d){d()}}});l("2",["8","7"],function(d,e){return function(c){c=
e.die(c);return{replace:c,replaceAll:c,inline:c,inlineAll:c,get:c,getActiveEditor:c,definePlugin:c,version:d,isSupported:e.constant(!1)}}});aa("w",String);l("a",["9","w"],function(d,e){var c=function(a){return function(b){if(null===b)b="null";else{var c=typeof b;b="object"===c&&d.prototype.isPrototypeOf(b)?"array":"object"===c&&e.prototype.isPrototypeOf(b)?"string":c}return b===a}};return{isString:c("string"),isObject:c("object"),isArray:c("array"),isNull:c("null"),isBoolean:c("boolean"),isUndefined:c("undefined"),
isFunction:c("function"),isNumber:c("number")}});l("b",["9","w"],function(d,e){var c=function(a){return function(b){return a===b}},a=function(){var a=d.prototype.indexOf,b=function(b,c){return a.call(b,c)},e=function(a,b){return p(a,c(b))};return void 0===a?e:b}(),b=function(b,c){return-1<a(b,c)},f=function(a,b){for(var c=a.length,e=new d(c),f=0;f<c;f++)e[f]=b(a[f],f,a);return e},g=function(a,b){for(var c=0,d=a.length;c<d;c++)b(a[c],c,a)},h=function(a,b){for(var c=[],d=0,e=a.length;d<e;d++){var f=
a[d];b(f,d,a)&&c.push(f)}return c},k=function(a,b,c){g(a,function(a){c=b(c,a)});return c},m=function(a,b){for(var c=0,d=a.length;c<d;c++){var e=a[c];if(b(e,c,a))return e}},p=function(a,b){for(var c=b||q,d=0,e=a.length;d<e;++d)if(!0===c(a[d]))return d;return-1},n=d.prototype.push,r=function(a){for(var b=[],c=0,d=a.length;c<d;++c)n.apply(b,a[c]);return b},q=c(!0),t=function(a,b){for(var c=b||q,d=0,e=a.length;d<e;++d)if(!0!==c(a[d],d))return!1;return!0},s=d.prototype.slice,u=function(a){a=s.call(a,0);
a.reverse();return a};return{map:f,each:g,partition:function(a,b){for(var c=[],d=[],e=0,f=a.length;e<f;e++){var g=a[e];(b(g,e,a)?c:d).push(g)}return{pass:c,fail:d}},filter:h,groupBy:function(a,b){if(0===a.length)return[];for(var c=b(a[0]),d=[],e=[],f=0,g=a.length;f<g;f++){var h=a[f],k=b(h);k!==c&&(d.push(e),e=[]);c=k;e.push(h)}0!==e.length&&d.push(e);return d},indexOf:a,foldr:function(a,b,c){return k(u(a),b,c)},foldl:k,find:m,findIndex:p,findOr:function(a,b,c){a=m(a,b);return void 0!==a?a:c},findOrDie:function(a,
b,c){b=m(a,b);if(void 0===b)throw c||"Could not find element in array: "+e(a);return b},flatten:r,bind:function(a,b){var c=f(a,b);return r(c)},forall:t,exists:function(a,b){return-1<p(a,b)},contains:b,equal:function(a,b){return a.length===b.length&&t(a,function(a,c){return a===b[c]})},reverse:u,chunk:function(a,b){for(var c=[],d=0;d<a.length;d+=b){var e=a.slice(d,d+b);c.push(e)}return c},difference:function(a,c){return h(a,function(a){return!b(c,a)})},mapToObject:function(a,b){for(var c={},d=0,f=
a.length;d<f;d++){var g=a[d];c[e(g)]=b(g,d)}return c},pure:function(a){return[a]}}});l("x",["7"],function(d){return function(e,c,a){var b=e.isiOS()&&!0===/ipad/i.test(a),f=e.isiOS()&&!b,g=e.isAndroid()&&3===e.version.major,h=e.isAndroid()&&4===e.version.major,g=b||g||h&&!0===/mobile/i.test(a),k=(h=e.isiOS()||e.isAndroid())&&!g;c=c.isSafari()&&e.isiOS()&&!1===/safari/i.test(a);return{isiPad:d.constant(b),isiPhone:d.constant(f),isTablet:d.constant(g),isPhone:d.constant(k),isTouch:d.constant(h),isAndroid:e.isAndroid,
isiOS:e.isiOS,isWebView:d.constant(c)}}});l("y",[],function(){return{create:function(d,e,c){return{browser:{current:d,version:e},os:{current:c}}}}});l("1r",[],function(){var d=function(d){return function(){return d}};return{getter:d,attachGetters:function(e,c,a){for(var b=0;b<a.length;b++)e["is"+a[b].name]=d(a[b].name===c)}}});l("z",["1r"],function(d){return{create:function(e,c,a){var b=d.attachGetters,f={};f.current=c;f.version=a;b(f,f.current,e);return f}}});aa("1s",Math);aa("1t",isFinite);aa("1u",
isNaN);aa("1v",parseFloat);l("1k",["1s","1t","1u","1v"],function(d,e,c,a){var b=function(a){return function(b,c){var d=typeof c;if(d!==a)throw b+" was not a "+a+". Was: "+c+" ("+d+")";}},f=b("string"),g=b("number"),h=function(a,b){g(a,b);if(b!==d.abs(b))throw a+" was not an integer. Was: "+b;};return{vString:f,vChar:function(a,b){f(a,b);if(1!==b.length)throw a+" was not a single char. Was: "+b;},vInt:h,vNat:function(a,b){h(a,b);if(0>b)throw a+" was not a natural number. Was: "+b;},pNum:function(b){return!c(a(b))&&
e(b)}}});l("v",["1k"],function(d){var e=function(a,b,c){return""===b?!0:a.length<b.length?!1:a.substr(c,c+b.length)===b},c=function(a){var b=function(a,b){for(var c=[],d=0;d<a.length;d++)c.push(b(a[d]));return c};return function(){var c=b(arguments,function(a){return"string"===typeof a?a.toLowerCase():a});return a.apply(this,c)}},a=function(a,b){return e(a,b,0)},b=c(a),f=function(a,b){return e(a,b,a.length-b.length)},g=c(f),h=function(a,b){return a.substr(0,b)},k=function(a,b){return a.substr(a.length-
b,a.length)},m=function(a,b){return function(c,d){return a(c,d)?b(c,c.length-d.length):c}},p=m(a,k),m=m(f,h),n=function(a,b){return function(c,d){return a(c,d)?c:b(c,d)}},r=n(a,function(a,b){return b+a}),n=n(f,function(a,b){return a+b}),q=function(a,b){return-1!=a.indexOf(b)},t=c(q),s=function(a,b){return a===b},c=c(s),u=function(a){if(""===a)throw"head on empty string";return a.substr(0,1)},v=function(a){if(""===a)throw"tail on empty string";return a.substr(1,a.length-1)},w=function(a,b){d.vString("str",
a);d.vNat("num",b);for(var c="",e=0;e<b;e++)c+=a;return c},y=function(a){return function(b,c,e){d.vString("str",b);d.vChar("c",c);d.vNat("width",e);var f=b.length;return f>=e?b:a(b,w(c,e-f))}},x=y(function(a,b){return b+a}),y=y(function(a,b){return a+b});return{supplant:function(a,b){return a.replace(/\${([^{}]*)}/g,function(a,c){var d=b[c],e=typeof d;return"string"===e||"number"===e?d:a})},startsWith:a,startsWithIgnoringCase:b,endsWith:f,endsWithIgnoringCase:g,first:h,last:k,removeLeading:p,removeTrailing:m,
ensureLeading:r,ensureTrailing:n,trim:function(a){return a.replace(/^\s+|\s+$/g,"")},lTrim:function(a){return a.replace(/^\s+/g,"")},rTrim:function(a){return a.replace(/\s+$/g,"")},contains:q,containsIgnoringCase:t,htmlEncodeDoubleQuotes:function(a){return a.replace(/\"/gm,"&quot;")},equals:s,equalsIgnoringCase:c,head:u,repead:w,padLeft:x,padRight:y,toe:function(a){if(""===a)throw"toe on empty string";return a.substr(a.length-1,a.length)},tail:v,torso:function(a){if(""===a)throw"torso on empty string";
return a.substr(0,a.length-1)},capitalize:function(a){return""===a?a:u(a).toUpperCase()+v(a)}}});l("10",["v"],function(d){var e=d.contains,c=function(a){return function(c){return e(c,a)}},a=/.*?version\/\ ?([0-9]+)\.([0-9]+).*/;return{create:function(b){var d=[{name:"Spartan",versionRegexes:[/.*?edge\/ ?([0-9]+)\.([0-9]+)$/],search:function(a){return e(a,"edge/")&&e(a,"chrome")&&e(a,"safari")&&e(a,"applewebkit")}},{name:"ChromeFrame",versionRegexes:[/.*?chromeframe\/([0-9]+)\.([0-9]+).*/,a],search:function(a){return e(a,
"chromeframe")?b():!1}},{name:"Chrome",versionRegexes:[/.*?chrome\/([0-9]+)\.([0-9]+).*/,a],search:function(a){return e(a,"chrome")&&!e(a,"chromeframe")}},{name:"IE",versionRegexes:[/.*?msie\ ?([0-9]+)\.([0-9]+).*/,/.*?rv:([0-9]+)\.([0-9]+).*/],search:function(a){var c=e(a,"msie")||e(a,"trident");return e(a,"chromeframe")?c&&!b():c}},{name:"Opera",versionRegexes:[a,/.*?opera\/([0-9]+)\.([0-9]+).*/],search:c("opera")},{name:"Firefox",versionRegexes:[/.*?firefox\/\ ?([0-9]+)\.([0-9]+).*/],search:c("firefox")},
{name:"Safari",versionRegexes:[a,/.*?cpu os ([0-9]+)_([0-9]+).*/],search:function(a){return(e(a,"safari")||e(a,"mobile/"))&&e(a,"applewebkit")}},{name:"Envjs",versionRegexes:[/.*?envjs\/\ ?([0-9]+)\.([0-9]+).*/],search:c("envjs")}],g=[{name:"Windows",search:c("win"),versionRegexes:[/.*?windows\ nt\ ?([0-9]+)\.([0-9]+).*/]},{name:"iOS",search:function(a){return e(a,"iphone")||e(a,"ipad")},versionRegexes:[/.*?version\/\ ?([0-9]+)\.([0-9]+).*/,/.*cpu os ([0-9]+)_([0-9]+).*/,/.*cpu iphone os ([0-9]+)_([0-9]+).*/]},
{name:"Android",search:c("android"),versionRegexes:[/.*?android\ ?([0-9]+)\.([0-9]+).*/]},{name:"OSX",search:c("os x"),versionRegexes:[/.*?os\ x\ ?([0-9]+)_([0-9]+).*/]},{name:"Linux",search:c("linux")},{name:"Solaris",search:c("sunos")},{name:"FreeBSD",search:c("freebsd")}];return{browsers:d,oses:g}},chromeFrameChecker:function(){try{return!!new ActiveXObject("ChromeTab.ChromeFrame")}catch(a){return!1}}}});l("11",[],function(){return{meetsSpec:function(d,e){var c=typeof d;if("boolean"===c)return!!d;
if("object"===c)return c=d.minimum,e.major>c.major||e.major===c.major&&e.minor>=c.minor;throw"invalid spec";}}});l("1w",[],function(){return{findOneInArrayOr:function(d,e,c){for(var a=0;a<d.length;a++){var b=d[a];if(c(b,a,d))return b}return e}}});l("12",["1w"],function(d){return{detect:function(e,c){var a=d.findOneInArrayOr,b=String(c).toLowerCase();return a(e,{name:void 0},function(a){return a.search(b)})}}});l("13",[],function(){return{detectVersion:function(d,e){var c=String(e).toLowerCase(),a=
d.versionRegexes;if(a){a:{for(var b=0;b<a.length;b++){var f=a[b];if(f.test(c)){a=f;break a}}a=void 0}c=a?{major:Number(c.replace(a,"$1")),minor:Number(c.replace(a,"$2"))}:{major:0,minor:0}}else c={major:0,minor:0};return c}}});l("c","x y z 10 11 12 13".split(" "),function(d,e,c,a,b,f,g){var h=g.detectVersion,k=c.create,m=b.meetsSpec,p=f.detect,n=function(a,b,c,d){return a[b]?a[b][c]?m(a[b][c],d):!!a[b].All:!1},r=function(b,c){var e=a.create(c),f=e.browsers,e=e.oses,g=p(e,b),m=g.name,g=h(g,b),r=p(f,
b),x=r.name,z=h(r,b),e=k(e,m,g),f=k(f,x,z),g=d(e,f,b);return{browser:f,os:e,deviceType:g,isSupported:function(a){return n(a,m,x,z)}}};return{Platform:e,detect:function(){return r(navigator.userAgent,a.chromeFrameChecker)},doDetect:r,isSupported:n,isSupportedPlatform:function(a,b){var c=b.browser;return n(a,b.os.current,c.current,c.version)}}});l("4j",["b"],function(d){var e=function(c){return c.replace(/\./g,"-")};return{create:function(c){var a=e(c);return{resolve:function(b){b=b.split(" ");return d.map(b,
function(b){return a+"-"+b}).join(" ")}}},cssNamespace:e,cssClass:function(c,a){return c+"-"+a}}});l("34",["4j"],function(d){return{resolve:d.create("ephox-polish").resolve}});l("1x",["34"],function(d){return d});aa("19",Object);l("s",["7","19"],function(d,e){var c=d.constant(!1),a=d.constant(!0),b=function(){return f},f=function(){var f=function(a){return a.isNone()},g=function(a){return a()},m=function(a){return a},f={fold:function(a,b){return a()},is:c,isSome:c,isNone:a,getOr:m,getOrThunk:g,getOrDie:function(a){throw a||
"error: getOrDie called on none.";},or:m,orThunk:g,map:b,ap:b,each:b,bind:b,flatten:b,exists:c,forall:a,filter:b,equals:f,equals_:f,toArray:function(){return[]},toString:d.constant("none()")};e.freeze&&e.freeze(f);return f}(),g=function(d){var e=function(){return d},m=function(){return r},p=function(a){return g(a(d))},n=function(a){return a(d)},r={fold:function(a,b){return b(d)},is:function(a){return d===a},isSome:a,isNone:c,getOr:e,getOrThunk:e,getOrDie:e,or:m,orThunk:m,map:p,ap:function(a){return a.fold(b,
function(a){return g(a(d))})},each:p,bind:n,flatten:e,exists:n,forall:n,filter:function(a){return a(d)?r:f},equals:function(a){return a.is(d)},equals_:function(a,b){return a.fold(c,function(a){return b(d,a)})},toArray:function(){return[d]},toString:function(){return"some("+d+")"}};return r};return{some:g,none:b,from:function(a){return null===a||void 0===a?f:g(a)},equals:function(a,b){return a.equals(b)},equals_:function(a,b,c){return a.equals_(b,c)}}});l("2y",[],function(){return function(d,e,c){var a=
c||!1,b=function(){e();a=!0},f=function(){d();a=!1};return{on:b,off:f,toggle:function(){(a?f:b)()},isOn:function(){return a}}}});l("1o",["19"],function(d){var e=function(){var a=d.keys,b=function(a){var b=[],c;for(c in a)a.hasOwnProperty(c)&&b.push(c);return b};return void 0===a?b:a}(),c=function(a,b){for(var c=e(a),d=0,f=c.length;d<f;d++){var n=c[d];b(a[n],n,a)}},a=function(a,b){var d={};c(a,function(c,e){var f=b(c,e,a);d[f.k]=f.v});return d},b=function(a,b){var d=[];c(a,function(a,c){d.push(b(a,
c))});return d},f=function(a){return b(a,function(a){return a})};return{bifilter:function(a,b){var d={},e={};c(a,function(a,c){(b(a,c)?d:e)[c]=a});return{t:d,f:e}},each:c,map:function(b,c){return a(b,function(a,b,d){return{k:b,v:c(a,b,d)}})},mapToArray:b,tupleMap:a,find:function(a,b){for(var c=e(a),d=0,f=c.length;d<f;d++){var n=c[d],r=a[n];if(b(r,n,a))return r}},keys:e,values:f,size:function(a){return f(a).length}}});l("1q",[],function(){return{ATTRIBUTE:2,CDATA_SECTION:4,COMMENT:8,DOCUMENT:9,DOCUMENT_TYPE:10,
DOCUMENT_FRAGMENT:11,ELEMENT:1,TEXT:3,PROCESSING_INSTRUCTION:7,ENTITY_REFERENCE:5,ENTITY:6,NOTATION:12}});l("21",["1q"],function(d){var e=function(a){return a.dom().nodeName.toLowerCase()},c=function(a){return a.dom().nodeType},a=function(a){return function(b){return c(b)===a}},b=a(d.ELEMENT),f=a(d.TEXT),a=a(d.DOCUMENT);return{name:e,type:c,value:function(a){return a.dom().nodeValue},isElement:b,isText:f,isDocument:a,isComment:function(a){return c(a)===d.COMMENT||"#comment"===e(a)}}});aa("n",Error);
l("o",[],function(){"undefined"===typeof console&&(console={log:function(){}});return console});l("1a","a b 1o 21 n o".split(" "),function(d,e,c,a,b,f){var g=function(a,c,e){if(d.isString(e)||d.isBoolean(e)||d.isNumber(e))a.setAttribute(c,e+"");else throw f.error("Invalid call to Attr.set. Key ",c,":: Value ",e,":: Element ",a),new b("Attribute value was not simple");},h=function(a,b,c){g(a.dom(),b,c)},k=function(a,b){var c=a.dom().getAttribute(b);return null===c?void 0:c},m=function(a,b){var c=a.dom();
return c&&c.hasAttribute?c.hasAttribute(b):!1};return{clone:function(a){return e.foldl(a.dom().attributes,function(a,b){a[b.name]=b.value;return a},{})},set:h,setAll:function(a,b){var d=a.dom();c.each(b,function(a,b){g(d,b,a)})},get:k,has:m,remove:function(a,b){a.dom().removeAttribute(b)},hasNone:function(a){a=a.dom().attributes;return void 0===a||null===a||0===a.length},transfer:function(b,c,d){a.isElement(b)&&a.isElement(c)&&e.each(d,function(a){m(b,a)&&!m(c,a)&&h(c,a,k(b,a))})}}});l("4k",["b",
"1a"],function(d,e){var c=function(a,b){var c=e.get(a,b);return void 0===c||""===c?[]:c.split(" ")};return{read:c,add:function(a,b,d){d=c(a,b).concat([d]);e.set(a,b,d.join(" "))},remove:function(a,b,f){var g=d.filter(c(a,b),function(a){return a!==f});0<g.length?e.set(a,b,g.join(" ")):e.remove(a,b)}}});l("35",["b","4k"],function(d,e){var c=function(a){return e.read(a,"class")},a=function(a,b){return e.add(a,"class",b)},b=function(a,b){return e.remove(a,"class",b)};return{get:c,add:a,remove:b,toggle:function(e,
g){d.contains(c(e),g)?b(e,g):a(e,g)},supports:function(a){return void 0!==a.dom().classList}}});l("1y",["2y","1a","35"],function(d,e,c){var a=function(a,d){return c.supports(a)&&a.dom().classList.contains(d)};return{add:function(a,d){c.supports(a)?a.dom().classList.add(d):c.add(a,d)},remove:function(a,d){c.supports(a)?a.dom().classList.remove(d):c.remove(a,d);0===(c.supports(a)?a.dom().classList:c.get(a)).length&&e.remove(a,"class")},toggle:function(a,d){return c.supports(a)?a.dom().classList.toggle(d):
c.toggle(a,d)},toggler:function(b,e){var g=c.supports(b),h=b.dom().classList;return d(function(){g?h.remove(e):c.remove(b,e)},function(){g?h.add(e):c.add(b,e)},a(b,e))},has:a}});aa("q",document);l("l",["7","n","o","q"],function(d,e,c,a){var b=function(a){if(null===a||void 0===a)throw new e("Node cannot be null or undefined");return{dom:d.constant(a)}};return{fromHtml:function(d,e){var h=(e||a).createElement("div");h.innerHTML=d;if(!h.hasChildNodes()||1<h.childNodes.length)throw c.error("HTML does not have a single root node",
d),"HTML must have a single root node";return b(h.childNodes[0])},fromTag:function(c,d){var e=(d||a).createElement(c);return b(e)},fromText:function(c,d){var e=(d||a).createTextNode(c);return b(e)},fromDom:b}});l("14",["1x","7","s","1y","l"],function(d,e,c,a,b){return function(){var f=c.none(),g=d.resolve("layer-editor-active"),h=function(c){a.remove(b.fromDom(c.element()),g)},k=function(d){f.filter(function(a){return a!==d.api}).each(h);a.add(b.fromDom(d.api.element()),g);f=c.some(d.api)};return{add:function(a){var b=
e.curry(k,a);f=f.orThunk(function(){a.api.events.loaded.addListener(b);return c.some(a.api)});a.api.events.focus.addListener(b)},get:function(){return f},remove:function(a){f.is(a.api)&&(f=c.none())}}}});l("2i",["1"],function(d){var e=function(c,a){for(var b=a||d,e=0;e<c.length&&void 0!==b&&null!==b;++e)b=b[c[e]];return b};return{path:e,resolve:function(c,a){var b=c.split(".");return e(b,a)}}});l("2j",["2i"],function(d){return{getOrDie:function(e,c){var a=d.resolve(e,c);if(void 0===a)throw e+" not available on this browser";
return a}}});l("1p",["2i","2j"],function(d,e){return{isPrototypeOf:function(c){var a=d.resolve("ownerDocument.defaultView",c);return e.getOrDie("HTMLElement",a).prototype.isPrototypeOf(c)}}});l("i",["a","b","1p","7","n"],function(d,e,c,a,b){var f=function(c,d,e,f,g,h){return{name:a.constant(c),output:a.constant(h||c),required:a.constant(f),validate:function(a){if(!e(a))throw a=g(c,d),new b(a);}}},g=function(a,b){return'value of "'+a+'" is not a '+b},h=function(a,b){return'value of "'+a+'" is not an '+
b},k=function(a,b,c){return function(d,e){return f(d,a,b,!0,c,e)}},m=function(a){return c.isPrototypeOf(a)},p=function(a){return d.isString(a)||d.isArray(a)||d.isObject(a)},n=k("array",d.isArray,h),r=k("boolean",d.isBoolean,g),q=k("function",d.isFunction,g),t=k("number",d.isNumber,g),s=k("object",d.isObject,h),u=k("string",d.isString,g),g=k("DOM element",m,g),v=k("string or an array",function(a){return d.isString(a)||d.isArray(a)},h),k=k("string or a DOM element",function(a){return d.isString(a)||
m(a)},h);return{arrayOfStrings:function(a){return f(a,"array of strings",function(b){n(a).validate(b);return e.forall(b,d.isString)},!0,h)},arrayOfObjects:function(a){return f(a,"array of objects",function(b){n(a).validate(b);return e.forall(b,d.isObject)},!0,h)},arrayOfToolbarGroups:function(a){return f(a,"array of toolbar groups",function(b){n(a).validate(b);return e.forall(b,p)},!0,h)},bool:r,domElement:g,func:q,number:t,object:s,string:u,stringOrArray:v,stringOrDom:k,param:f}});l("2h",["i"],function(d){return{paramList:function(){return[d.object("aria"),
d.func("fetch"),d.func("menuComplete"),d.func("menuExtra"),d.func("menuHover"),d.string("hoverSelector"),d.func("hover")]},encodeWithEditorApi:function(){return["menuComplete"]}}});l("6",["a","9"],function(d,e){var c=function(a){return function(){for(var c=new e(arguments.length),d=0;d<c.length;d++)c[d]=arguments[d];if(0===c.length)throw"Can't merge zero objects";for(var d={},h=0;h<c.length;h++){var k=c[h],m;for(m in k)k.hasOwnProperty(m)&&(d[m]=a(d[m],k[m]))}return d}},a=c(function(b,c){return d.isObject(b)&&
d.isObject(c)?a(b,c):c}),c=c(function(a,c){return c});return{deepMerge:a,merge:c}});l("1z","a b 1o 2h 6 7".split(" "),function(d,e,c,a,b,f){var g=function(a,b,c){return e.map(a,function(a){return b(a,c)})},h=function(a,c){if(d.isString(a))return a;if(d.isArray(a))return g(a,h,c);if(d.isObject(a)&&void 0!==a.action){var e=f.compose(a.action,c);return b.merge(a,{action:e})}e=g(a.items,h,c);return b.deepMerge(a,{items:e})};return{mentions:function(b,d){var f=a.encodeWithEditorApi();return c.map(b,function(a,
b){return e.contains(f,b)?function(b){return a(d(),b)}:a})},toolbar:function(a,b){return void 0===a.items?a:{items:g(a.items,h,b)}}}});l("p",["7","s"],function(d,e){var c=function(a){return b(function(b,c){return c(a)})},a=function(a){return b(function(b,c){return b(a)})},b=function(b){var g=function(){return b(d.constant(!1),d.constant(!0))},h=d.not(g),k=function(a){return m(function(b){return c(a(b))})},m=function(c){return b(a,c)};return{is:function(a){return b(d.constant(!1),function(b){return b===
a})},isValue:g,isError:h,getOr:function(a){return b(d.constant(a),d.identity)},getOrThunk:function(a){return b(a,d.identity)},getOrDie:function(){return b(function(a){d.die(a)()},d.identity)},or:function(a){return b(d.constant(a),c)},orThunk:function(a){return b(a,c)},fold:b,map:k,each:k,bind:m,exists:function(a){return b(d.constant(!1),a)},forall:function(a){return b(d.constant(!0),a)},toOption:function(){return b(e.none,e.some)}}};return{value:c,error:a}});aa("20",Date);l("15","1z 6 s p 20 w".split(" "),
function(d,e,c,a,b,f){var g=function(){var a=(new b).getTime();return f(a).slice(-6)};return function(b,f,m){var p=c.from(b.ui.editorName).map(a.error);m=m.map(a.value);p=p.or(m).getOrThunk(function(){return a.value(g())});m=d.toolbar(b.platform.toolbar,f);f=d.mentions(b.mentions,f);return e.deepMerge(b,{ui:{editorName:p},platform:{toolbar:m},mentions:f})}});l("m","1q b s l n q".split(" "),function(d,e,c,a,b,f){var g=function(){var a=f.createElement("span");return void 0!==a.matches?0:void 0!==a.msMatchesSelector?
1:void 0!==a.webkitMatchesSelector?2:void 0!==a.mozMatchesSelector?3:-1}(),h=d.ELEMENT,k=d.DOCUMENT;return{all:function(b,c){var d=void 0===c?f:c.dom();return d.nodeType!==h&&d.nodeType!==k||0===d.childElementCount?[]:e.map(d.querySelectorAll(b),a.fromDom)},is:function(a,c){var d=a.dom();if(d.nodeType!==h)return!1;if(0===g)return d.matches(c);if(1===g)return d.msMatchesSelector(c);if(2===g)return d.webkitMatchesSelector(c);if(3===g)return d.mozMatchesSelector(c);throw new b("Browser lacks native selectors");
},one:function(b,d){var e=void 0===d?f:d.dom();return e.nodeType!==h&&e.nodeType!==k||0===e.childElementCount?c.none():c.from(e.querySelector(b)).map(a.fromDom)}}});l("16",["b","s","m"],function(d,e,c){return function(){var a=[];return{get:function(b){return e.from(d.find(a,function(a){return a.is(b)}))},findAll:function(b){var e=c.all(b);return d.filter(a,function(a){return d.exists(e,a.is)})},add:function(b){a.push(b)},remove:function(b){b=d.indexOf(a,b);a.splice(b,1)}}}});l("17",["s","21"],function(d,
e){return{one:function(c,a,b){var f=e.name(c);return d.from(a[f]).map(function(a){return a.replace(c,b)})}}});l("r",[],function(){return{cached:function(d){var e=!1,c;return function(){e||(e=!0,c=d.apply(null,arguments));return c}}}});l("2n",["r","l","21","q"],function(d,e,c,a){var b=function(a){a=a.dom().body;if(null===a||void 0===a)throw"Body is not available yet";return e.fromDom(a)};return{body:d.cached(function(){return b(e.fromDom(a))}),getBody:b,inBody:function(a){a=c.isText(a)?a.dom().parentNode:
a.dom();return void 0!==a&&null!==a&&a.ownerDocument.body.contains(a)}}});l("36",[],function(){return{isSupported:function(d){return void 0!==d.style}}});aa("37",window);l("2o","a b 1o s 1a 2n l 21 36 v n o 37".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){var q=function(a,b,c){if(!d.isString(c))throw n.error("Invalid call to CSS.set. Property ",b,":: Value ",c,":: Element ",a),new p("CSS value must be a string: "+c);k.isSupported(a)&&a.style.setProperty(b,c)},t=function(a,b,c){a=a.dom();q(a,b,c)},
s=function(a,b){return k.isSupported(a)?a.style.getPropertyValue(b):""},u=function(b,c){var d=b.dom(),d=s(d,c);return a.from(d).filter(function(a){return 0<a.length})},v=function(a,b,c){u(a,c).each(function(a){u(b,c).isNone()&&t(b,c,a)})};return{copy:function(a,b){var c=a.dom(),d=b.dom();k.isSupported(c)&&k.isSupported(d)&&(d.style.cssText=c.style.cssText)},set:t,preserve:function(a,c){var d=b.get(a,"style"),e=c(a);(void 0===d?b.remove:b.set)(a,"style",d);return e},setAll:function(a,b){var d=a.dom();
c.each(b,function(a,b){q(d,b,a)})},setOptions:function(a,b){var d=a.dom();c.each(b,function(a,b){a.fold(function(){k.isSupported(d)&&d.style.removeProperty(b)},function(a){q(d,b,a)})})},remove:function(a,c){var d=a.dom();k.isSupported(d)&&d.style.removeProperty(c);b.has(a,"style")&&""===m.trim(b.get(a,"style"))&&b.remove(a,"style")},get:function(a,b){var c=a.dom(),d=r.getComputedStyle(c).getPropertyValue(b),c=""!==d||f.inBody(a)?d:s(c,b);return null===c?void 0:c},getRaw:u,isValidValue:function(a,
b,c){a=g.fromTag(a);t(a,b,c);return u(a,b).isSome()},reflow:function(a){return a.dom().offsetWidth},transfer:function(a,b,c){h.isElement(a)&&h.isElement(b)&&e.each(c,function(c){v(a,b,c)})}}});l("2c",["2j"],function(d){return{documentPositionPreceding:function(e,c){var a=d.getOrDie("Node").DOCUMENT_POSITION_PRECEDING;return 0!==(e.compareDocumentPosition(c)&a)},documentPositionContainedBy:function(e,c){var a=d.getOrDie("Node").DOCUMENT_POSITION_CONTAINED_BY;return 0!==(e.compareDocumentPosition(c)&
a)}}});l("1b",["b","c","2c","7","m"],function(d,e,c,a,b){var f=function(a,b){return a.dom()===b.dom()},g=function(a,b){var c=a.dom(),d=b.dom();return c===d?!1:c.contains(d)},h=function(a,b){return c.documentPositionContainedBy(a.dom(),b.dom())};e=e.detect().browser.isIE()?h:g;return{eq:f,isEqualNode:function(a,b){return a.dom().isEqualNode(b.dom())},member:function(b,c){return d.exists(c,a.curry(f,b))},contains:e,is:b.is}});l("4i",["a","s"],function(d,e){return function(c,a,b,f,g){return c(b,f)?e.some(b):
d.isFunction(g)&&g(b)?e.none():a(b,f,g)}});l("4l","a b 7 s 2n 1b l 4i".split(" "),function(d,e,c,a,b,f,g,h){var k=function(b,e,f){b=b.dom();for(f=d.isFunction(f)?f:c.constant(!1);b.parentNode;){b=b.parentNode;var h=g.fromDom(b);if(e(h))return a.some(h);if(f(h))break}return a.none()},m=function(b,d){var f=e.find(b.dom().childNodes,c.compose(d,g.fromDom));return a.from(f).map(g.fromDom)},p=function(b,c){var d=function(b){for(var e=0;e<b.childNodes.length;e++){if(c(g.fromDom(b.childNodes[e])))return a.some(g.fromDom(b.childNodes[e]));
var f=d(b.childNodes[e]);if(f.isSome())return f}return a.none()};return d(b.dom())};return{first:function(a){return p(b.body(),a)},ancestor:k,closest:function(a,b,c){return h(function(a){return b(a)},k,a,b,c)},sibling:function(b,c){var d=b.dom();return d.parentNode?m(g.fromDom(d.parentNode),function(a){return!f.eq(b,a)&&c(a)}):a.none()},child:m,descendant:p}});l("38",["4l"],function(d){return{any:function(e){return d.first(e).isSome()},ancestor:function(e,c,a){return d.ancestor(e,c,a).isSome()},closest:function(e,
c,a){return d.closest(e,c,a).isSome()},sibling:function(e,c){return d.sibling(e,c).isSome()},child:function(e,c){return d.child(e,c).isSome()},descendant:function(e,c){return d.descendant(e,c).isSome()}}});l("3a",["b","1o","7","9"],function(d,e,c,a){return{product:function(b,f){return{nu:function(){for(var e=new a(arguments.length),f=0;f<e.length;f++)e[f]=arguments[f];if(b.length!==e.length)throw'Wrong number of arguments to struct. Expected "['+b.length+']", got '+e.length+" arguments";var k={};
d.each(b,function(a,b){k[a]=c.constant(e[b])});return k},eq:function(a,d){for(var e=0;e<b.length;e++){var m=b[e];if(!(f&&f[e]||c.tripleEquals)(a[m](),d[m]()))return!1}return!0},evaluate:function(a){return e.map(a,function(a){return a()})}}}}});l("39",["3a"],function(d){return function(){return d.product(arguments).nu}});l("4m",["a","b"],function(d,e){var c=function(a){return a.slice(0).sort()};return{sort:c,reqMessage:function(a,b){throw"All required keys ("+c(a).join(", ")+") were not specified. Specified keys were: "+
c(b).join(", ")+".";},unsuppMessage:function(a){throw"Unsupported keys for object: "+c(a).join(", ");},validateStrArr:function(a,b){if(!d.isArray(b))throw"The "+a+" fields must be an array. Was: "+b+".";e.each(b,function(b){if(!d.isString(b))throw"The value "+b+" in the "+a+" fields was not a string.";})},invalidTypeMessage:function(a,b){throw"All values need to be of type: "+b+". Keys ("+c(a).join(", ")+") were not.";},checkDupes:function(a){var b=c(a);a=e.find(b,function(a,c){return c<b.length-
1&&a===b[c+1]});if(void 0!==a&&null!==a)throw"The field: "+a+" occurs more than once in the combined fields: ["+b.join(", ")+"].";}}});l("3b","b 1o 7 s 4m 19".split(" "),function(d,e,c,a,b,f){return function(g,h){var k=g.concat(h);if(0===k.length)throw"You must specify at least one required or optional field.";b.validateStrArr("required",g);b.validateStrArr("optional",h);b.checkDupes(k);return function(m){var p=e.keys(m);d.forall(g,function(a){return d.contains(p,a)})||b.reqMessage(g,p);var n=d.filter(p,
function(a){return!d.contains(k,a)});0<n.length&&b.unsuppMessage(n);var r={};d.each(g,function(a){r[a]=c.constant(m[a])});d.each(h,function(b){r[b]=c.constant(f.prototype.hasOwnProperty.call(m,b)?a.some(m[b]):a.none())});return r}}});l("2v",["39","3a","3b"],function(d,e,c){return{immutable:d,immutable2:e,immutableBag:c}});l("3c",[],function(){return{toArray:function(d,e){var c=[],a=function(a){c.push(a);return e(a)},b=e(d);do b=b.bind(a);while(b.isSome());return c}}});l("2b","a b 7 s 2v 3c 1b l".split(" "),
function(d,e,c,a,b,f,g,h){var k=function(a){return h.fromDom(a.dom().ownerDocument)},m=function(b){b=b.dom();return a.from(b.parentNode).map(h.fromDom)},p=function(b){b=b.dom();return a.from(b.previousSibling).map(h.fromDom)},n=function(b){b=b.dom();return a.from(b.nextSibling).map(h.fromDom)},r=function(a){a=a.dom();return e.map(a.childNodes,h.fromDom)},q=function(b,c){var d=b.dom().childNodes;return a.from(d[c]).map(h.fromDom)},t=b.immutable("element","offset");return{owner:k,defaultView:function(a){a=
a.dom().ownerDocument.defaultView;return h.fromDom(a)},documentElement:function(a){a=k(a);return h.fromDom(a.dom().documentElement)},parent:m,findIndex:function(b){return m(b).bind(function(c){c=r(c);c=e.findIndex(c,function(a){return g.eq(b,a)});return-1<c?a.some(c):a.none()})},parents:function(a,b){for(var e=d.isFunction(b)?b:c.constant(!1),f=a.dom(),g=[];null!==f.parentNode&&void 0!==f.parentNode;){var f=f.parentNode,k=h.fromDom(f);g.push(k);if(!0===e(k))break}return g},siblings:function(a){return m(a).map(r).map(function(b){return e.filter(b,
function(b){return!g.eq(a,b)})}).getOr([])},prevSibling:p,offsetParent:function(b){b=b.dom();return a.from(b.offsetParent).map(h.fromDom)},prevSiblings:function(a){return e.reverse(f.toArray(a,p))},nextSibling:n,nextSiblings:function(a){return f.toArray(a,n)},children:r,child:q,firstChild:function(a){return q(a,0)},lastChild:function(a){return q(a,a.dom().childNodes.length-1)},leaf:function(a,b){var c=r(a);return 0<c.length&&b<c.length?t(c[b],0):t(a,b)}}});l("2z","7 s 1b l 38 2b q".split(" "),function(d,
e,c,a,b,f,g){var h=function(a){a.dom().focus()},k=function(b){b=void 0!==b?b.dom():g;return e.from(b.activeElement).map(a.fromDom)};return{hasFocus:function(a){var b=f.owner(a).dom();return a.dom()===b.activeElement},focus:h,blur:function(a){a.dom().blur()},active:k,search:function(a){return k(f.owner(a)).filter(function(b){return a.dom().contains(b.dom())})},focusInside:function(a){var e=f.owner(a);k(e).filter(function(e){return b.closest(e,d.curry(c.eq,a))}).fold(function(){h(a)},d.noop)}}});l("2p",
["2b"],function(d){var e=function(a,b){d.parent(a).each(function(c){c.dom().insertBefore(b.dom(),a.dom())})},c=function(a,b){a.dom().appendChild(b.dom())};return{before:e,after:function(a,b){d.nextSibling(a).fold(function(){d.parent(a).each(function(a){c(a,b)})},function(a){e(a,b)})},prepend:function(a,b){d.firstChild(a).fold(function(){c(a,b)},function(c){a.dom().insertBefore(b.dom(),c.dom())})},append:c,appendAt:function(a,b,f){d.child(a,f).fold(function(){c(a,b)},function(a){e(a,b)})},wrap:function(a,
b){e(a,b);c(b,a)}}});l("3d",["b","2p"],function(d,e){return{before:function(c,a){d.each(a,function(a){e.before(c,a)})},after:function(c,a){d.each(a,function(b,d){e.after(0===d?c:a[d-1],b)})},prepend:function(c,a){d.each(a.slice().reverse(),function(a){e.prepend(c,a)})},append:function(c,a){d.each(a,function(a){e.append(c,a)})}}});l("2r",["b","3d","2b"],function(d,e,c){var a=function(a){a=a.dom();null!==a.parentNode&&a.parentNode.removeChild(a)};return{empty:function(b){b.dom().textContent="";d.each(c.children(b),
function(b){a(b)})},remove:a,unwrap:function(b){var d=c.children(b);0<d.length&&e.before(b,d);a(b)}}});l("22","2o l 2z 2p 2r q 37".split(" "),function(d,e,c,a,b,f,g){return{blur:function(){var g=e.fromHtml('<input type="text" />');d.setAll(g,{"z-index":"-666",background:"transparent",border:"0px",height:"50px",position:"absolute",top:"25%",left:"50%"});a.append(e.fromDom(f.body),g);c.focus(g);b.remove(g)}}});l("j",["b","n"],function(d,e){return function(c,a){d.each(a,function(a,d){if(d>c.length-1){if(a.required())throw new e('missing parameter "'+
a.name()+'"');}else a.validate(c[d])})}});l("3e",["b","1o","i","j"],function(d,e,c,a){var b=function(a){return[e.map(a,function(a){return a()})]};return{create:function(){var e=[];return{eventRegistry:{addListener:function(b){a(arguments,[c.func("handler")]);e.push(b)},removeListener:function(a){a=d.indexOf(e,a);-1!==a&&e.splice(a,1)}},eventTrigger:function(a){d.each(e,function(c){var d=b(a);c.apply(null,d)})}}}}});l("4n",["b","7"],function(d,e){return function(){var c=[],a=[],b=function(a){return a.slice(0)},
f=function(a){return-1!==d.indexOf(c,a)};return{get:function(b){return a[d.indexOf(c,b)]},put:function(b,d){if(void 0===b||null===b)throw"Invalid key, no undefined or null.";if(f(b))throw"Invalid key, key already exists.";c.push(b);a.push(d)},contains:f,remove:function(b,e){var f=d.indexOf(c,b);if(-1===f)throw"Invalid key, does not exist.";c.splice(f,1);return a.splice(f,1)[0]},each:function(b){d.each(c,function(c,d){b(a[d],c,d)})},keys:e.curry(b,c),values:e.curry(b,a),reset:function(){c.splice(0,
c.length);a.splice(0,a.length)}}}});l("3f",["4n"],function(d){return{create:function(){var e=d();return{bind:function(c,a){e.put(c,a);c.bind(a)},unbind:function(c){var a=e.remove(c);c.unbind(a)},unbindAll:function(){e.each(function(c,a){a.unbind(c)});e.reset()}}}}});l("23",["1o","3e","3f"],function(d,e,c){return function(a){var b=c.create(),f=d.map(a,function(a){var c=e.create();b.bind(a,c.eventTrigger);return c});a=d.map(f,function(a){return a.eventRegistry});f=d.map(f,function(a){return a.eventTrigger});
return{registry:a,trigger:f,destroy:function(){b.unbindAll()}}}});l("f",["a","1o","19"],function(d,e,c){var a=function(b){c.freeze(b);e.each(b,function(b){d.isObject(b)&&a(b)});return b};return{makeReadOnly:a}});l("4z",["9"],function(d){return{bounce:function(e){return function(){var c=d.prototype.slice.call(arguments),a=this;setTimeout(function(){e.apply(a,c)},0)}}}});l("3u",[],function(){return function(d,e){return{get:e,map:function(c){return d(function(a){e(function(b){b=c(b);a(b)})})},bind:function(c){return d(function(a){e(function(b){c(b).get(a)})})},
anonBind:function(c){return d(function(a){e(function(b){c.get(a)})})}}}});l("3v",["b"],function(d){return function(e){var c=function(a){return e(function(b){var c=[],e=0,h=function(d){return function(h){c[d]=h;e++;e>=a.length&&b(c)}};0===a.length?b([]):d.each(a,function(a,b){a.get(h(b))})})};return{nu:e,pure:function(a){return e(function(b){b(a)})},par:c,mapM:function(a,b){return c(d.map(a,b))},lift2:function(a,b,c){return e(function(d){var e=!1,k=!1,m=void 0,p=void 0,n=function(){if(e&&k){var a=
c(m,p);d(a)}};a.get(function(a){m=a;e=!0;n()});b.get(function(a){p=a;k=!0;n()})})},compose:function(a,b){return function(c){return b(c).bind(a)}}}}});l("3w",["4z","3u","3v"],function(d,e,c){var a=function(b){return e(a,function(a){b(d.bounce(a))})};return c(a)});l("3r",["1o","3w"],function(d,e){return function(){var c={};return{getOrSetIndexed:function(a,b){if(void 0!==c[a])return c[a];var d=b();return c[a]=d},waitForLoad:function(){var a=d.values(c);return e.par(a)}}}});aa("3x",setTimeout);l("2m",
"b 6 3u 3v 3w s 3x".split(" "),function(d,e,c,a,b,f,g){var h=function(a){var m=f.none(),p=[],n=function(){return m.isSome()},r=function(a){m.each(function(b){g(function(){a(b)},0)})};b.nu(a).get(function(a){m=f.some(a);d.each(p,r);p=[]});a=c(h,function(a){n()?r(a):p.push(a)});return e.merge(a,{isSet:n})};return a(h)});l("6n",["1"],function(d){return{namespace:function(e,c){for(var a=c||d,b=e.split("."),f=0;f<b.length;++f){var g=b[f];if(void 0===a[g]||null===a[g])a[g]={};a=a[g]}return a}}});l("50",
["6n"],function(d){return{install:function(e){var c=d.namespace(e);c.callbacks={};var a=0,b=function(){var b="callback_"+a;a++;return b},f=function(a,d){var f=b();c.callbacks[f]=function(){d||g(f);a.apply(null,arguments)};return e+".callbacks."+f},g=function(a){a=a.substring(a.lastIndexOf(".")+1);void 0!==c.callbacks[a]&&delete c.callbacks[a]};c.ephemeral=function(a){return f(a,!1)};c.permanent=function(a){return f(a,!0)};c.unregister=g;return c}}});l("51",["7","l"],function(d,e){var c=function(a,
b,c,e,f,n,r){return{target:d.constant(a),x:d.constant(b),y:d.constant(c),stop:e,prevent:f,kill:n,raw:d.constant(r)}},a=function(a,b){return function(f){if(a(f)){var m=e.fromDom(f.target),p=function(){f.stopPropagation()},n=function(){f.preventDefault()},r=d.compose(n,p),m=c(m,f.clientX,f.clientY,p,n,r,f);b(m)}}},b=function(b,c,e,m,p){e=a(e,m);b.dom().addEventListener(c,e,p);return{unbind:d.curry(f,b,c,e,p)}},f=function(a,b,c,d){a.dom().removeEventListener(b,c,d)};return{bind:function(a,c,d,e){return b(a,
c,d,e,!1)},capture:function(a,c,d,e){return b(a,c,d,e,!0)}}});l("3y",["7","51"],function(d,e){var c=d.constant(!0);return{bind:function(a,b,d){return e.bind(a,b,c,d)},capture:function(a,b,d){return e.capture(a,b,c,d)}}});l("3s","2m 50 p 1a 3y l 2p q".split(" "),function(d,e,c,a,b,f,g,h){var k=e.install("ephox.henchman.features");return{download:function(e){return d.nu(function(d){var n=function(){q.unbind();t.unbind()},r=f.fromTag("script");a.set(r,"src",e);a.set(r,"type","text/javascript");a.set(r,
"async","async");a.set(r,"data-main",k.ephemeral(function(a){d(c.value(a))}));var q=b.bind(r,"error",function(){n();d(c.error("Error loading external script tag "+e))}),t=b.bind(r,"load",n);g.append(f.fromDom(h.head),r)})}}});l("52",["1a","l","2p","q"],function(d,e,c,a){return{addStylesheet:function(b,f){var g=f||e.fromDom(a),h=e.fromTag("link",g.dom());d.setAll(h,{rel:"stylesheet",type:"text/css",href:b});g=e.fromDom(g.dom().head);c.append(g,h);return h}}});l("3t","a b 2m 7 p 3y 52".split(" "),function(d,
e,c,a,b,f,g){return{download:function(h,k){return c.nu(function(c){var p=function(a){e.each(r,function(a){a.unbind()});c(a.orThunk(function(a){return b.error(a+'Unable to download editor stylesheets from "'+h+'"')}))},n=g.addStylesheet(h),r=[f.bind(n,"load",function(a){var c;a:{try{var e=a.target().dom().sheet.cssRules;c=d.isObject(e)&&0===e.length;break a}catch(f){}c=!1}c?p(b.error("")):k(p)}),f.bind(n,"error",a.curry(p,b.error("")))]})}}});l("2k",["3r","3s","3t","7"],function(d,e,c,a){return function(){var b=
d(),f=function(){return b.waitForLoad()};return{preload:function(){f().get(a.identity)},addStylesheet:function(a,d){return b.getOrSetIndexed(a,function(){return c.download(a,d)})},addScript:function(a,c){return b.getOrSetIndexed(a,function(){return e.download(a).map(c)})},waitForLoad:f}}});l("4o",["2k"],function(d){var e=d();return{addStylesheet:function(c,a){return e.addStylesheet(c,a)},addScript:function(c,a){return e.addScript(c,a)}}});l("1j",["b","7","s","2v"],function(d,e,c,a){var b=a.immutable("str",
"replace"),f=function(a,b){return"2.2.1"!==a?c.some(b+(void 0===a?"":" version "+a)+" appears to be cached, as it does not match editor version 2.2.1."):c.none()};return{aboutTags:function(a,c){var e=[b("@@FULL_VERSION@@","2.2.1.73"),b("@@CLIENT_VERSION@@","2.2.1.50")],f=a?[b("@@INTEGRATION_TYPE@@",c.type),b("@@INTEGRATION_VERSION@@",c.version)]:[];return d.flatten([e,f])},strictMatch:f,weakMatch:function(a,b){return f(a,b).map(function(a){return a+" This may produce unexpected results."})},resourceParam:e.constant("version=2.2.1"),
fullParam:e.constant("version=2.2.1.73")}});l("4p",[],function(){var d=function(e){var c=e;return{get:function(){return c},set:function(a){c=a},clone:function(){return d(c)}}};return d});l("3h",["4o","1j","4p","o","q"],function(d,e,c,a,b){var f=function(b){b.each(function(b){e.weakMatch(b.version,"Code view").each(function(b){a.warn(b)});g.set(b.codemirror());h.set(b.jsbeautify())});return b},g=c(null),h=c(null);return{use:{codemirror:g.get,jsbeautify:h.get},load:{codeview:function(a){a=a+"/codeview.js?"+
e.resourceParam();return d.addScript(a,f)}}}});l("3g",["3h"],function(d){return{beautify:function(e){return d.use.jsbeautify().html(e,{indent_size:"2",indent_char:" ",max_preserve_newlines:"5",preserve_newlines:!0,keep_array_indentation:!1,break_chained_methods:!1,indent_scripts:"normal",brace_style:"collapse",space_before_conditional:!0,unescape_strings:!1,jslint_happy:!1,end_with_newline:!1,wrap_line_length:0,indent_inner_html:!1,comma_first:!1,e4x:!1})}}});l("24",["i","j","3g","3h","n"],function(d,
e,c,a,b){var f=function(a){return a.map(function(a){return a.dom()}).getOr(null)};return{documentElement:function(a){if(a.content().isInline())throw new b("documentElement called on inline mode");return f(a.content().doc())},insertHtmlAtCursor:function(a,b){e(arguments,[d.object("polish"),d.string("html")]);a.content().focus();a.insertHtmlAtCursor(b)},uploadImages:function(a,b){e(arguments,[d.object("polish"),d.func("callback")]);return a.uploadImages(b)},get:function(b){var d=null!==a.use.jsbeautify()&&
b.isPrettyPrinting();b=b.getContent();return d?c.beautify(b):b},set:function(a,b){e(arguments,[d.object("polish"),d.string("html")]);a.setContent(b)},isDirty:function(a){e(arguments,[d.object("polish")]);return a.isDirty()},setDirty:function(a,b){e(arguments,[d.object("polish"),d.bool("state")]);a.setDirty(b)}}});l("4q",["a","b","1o","9"],function(d,e,c,a){return{generate:function(b){if(!d.isArray(b))throw"cases must be an array";if(0===b.length)throw"there must be at least one case";var f={};e.each(b,
function(e,h){var k=c.keys(e);if(1!==k.length)throw"one and only one name per case";var m=k[0],p=e[m];if(void 0!==f[m])throw"duplicate key detected:"+m;if("cata"===m)throw"cannot have a case named cata (sorry)";if(!d.isArray(p))throw"case arguments must be an array";f[m]=function(){var c=arguments.length;if(c!==p.length)throw"Wrong number of arguments to case "+m+". Expected "+p.length+" ("+p+"), got "+c;for(var d=new a(c),c=0;c<d.length;c++)d[c]=arguments[c];return{fold:function(){if(arguments.length!==
b.length)throw"Wrong number of arguments to fold. Expected "+b.length+", got "+arguments.length;return arguments[h].apply(null,d)}}}});return f}}});l("3i",["6","4q"],function(d,e){var c=e.generate([{inputSelector:["selector","callback"]},{outputSelector:["selector","callback"]},{inputPredicate:["predicate","callback"]},{outputPredicate:["predicate","callback"]}]);return d.merge(c,{cata:function(a,b,c,d,e){return a.fold(b,c,d,e)}})});l("25",["b","i","j","7","3i"],function(d,e,c,a,b){var f=function(a){return function(b){b=
d.map(b,function(a){return a.dom()});a(b)}},g=function(a){return function(b){return a(b.dom())}};return function(d){var k=function(a,b,g){c(arguments,[e.func("filter"),e.string("selector"),e.func("callback")]);var k=a(b,f(g));d.filter().customFilters().addFilter(k)},m=function(a,b,k){c(arguments,[e.func("filter"),e.func("predicate"),e.func("callback")]);var m=a(g(b),f(k));d.filter().customFilters().addFilter(m)};return{selector:{addInput:a.curry(k,b.inputSelector),addOutput:a.curry(k,b.outputSelector)},
predicate:{addInput:a.curry(m,b.inputPredicate),addOutput:a.curry(m,b.outputPredicate)}}}});l("84",[],function(){return{zeroWidth:function(){return"\ufeff"}}});l("c1",["84","7"],function(d,e){var c="\\w'\\-\\u0100-\\u017F\\u00C0-\\u00FF"+d.zeroWidth()+"\\u2018\\u2019",a="[^"+c+"]",b="["+c+"]";return{chars:e.constant(c),wordbreak:e.constant(a),wordchar:e.constant(b)}});aa("6p",RegExp);l("c2",["6p"],function(d){return function(e,c,a,b){return{term:function(){return new d(e,b.getOr("g"))},prefix:c,suffix:a}}});
l("c4",["7","s","c1","c2"],function(d,e,c,a){return{token:function(b){return a(b,d.constant(0),d.constant(0),e.none())},word:function(b){b="((?:^'?)|(?:"+c.wordbreak()+"+'?))"+b+"((?:'?$)|(?:'?"+c.wordbreak()+"+))";return a(b,function(a){return 1<a.length?a[1].length:0},function(a){return 2<a.length?a[2].length:0},e.none())}}});l("c3",["c4"],function(d){var e=function(c){return c.replace(/[-\[\]{}()*+?.,\\\^$|#\s]/g,"\\$&")};return{sanitise:e,word:function(c){c=e(c);return d.word(c)},token:function(c){c=
e(c);return d.token(c)}}});l("6o",["c1","c2","c3","c4"],function(d,e,c,a){return{safeword:function(a){return c.word(a)},safetoken:function(a){return c.token(a)},custom:function(a,c,d,h){return e(a,c,d,h)},unsafeword:function(b){return a.word(b)},unsafetoken:function(b){return a.token(b)},sanitise:function(a){return c.sanitise(a)},chars:function(){return d.chars()},wordbreak:function(){return d.wordbreak()},wordchar:function(){return d.wordchar()}}});l("4r",["7","6o","6p"],function(d,e,c){return function(a,
b,f){var g=e.sanitise(a),h=e.sanitise(b);return{patterns:function(){return[new c(g+"(.*?)"+h,"gi")]},useCursor:d.constant(!0),generate:function(a,b){return f.generate(a,b.key(),b.value())},derive:function(a){var b=a[1];return f.get(b).map(function(c){return{startIndex:d.constant(a.index),finishIndex:d.constant(a.index+a[0].length),key:d.constant(b),value:d.constant(c)}})}}}});l("57",["a","b","1o","7","4m"],function(d,e,c,a,b){var f=function(a,b){return g(a,b,{validate:d.isFunction,label:"function"})},
g=function(a,d,f){if(0===d.length)throw"You must specify at least one required field.";b.validateStrArr("required",d);b.checkDupes(d);return function(g){var h=c.keys(g);e.forall(d,function(a){return e.contains(h,a)})||b.reqMessage(d,h);a(d,h);var q=e.filter(d,function(a){return!f.validate(g[a],a)});0<q.length&&b.invalidTypeMessage(q,f.label);return g}},h=a.noop;return{exactly:a.curry(f,function(a,c){var d=e.filter(c,function(b){return!e.contains(a,b)});0<d.length&&b.unsuppMessage(d)}),ensure:a.curry(f,
h),ensureWith:a.curry(g,h)}});l("4s",["57"],function(d){var e=d.ensure(["elements","cursor","dictation","notify"]);d=d.ensure(["elements","cursor","dictation","range","notify"]);return{species:e,applicator:d}});l("3m",["b","l","2b","q"],function(d,e,c,a){return{fromHtml:function(b,d){var g=(d||a).createElement("div");g.innerHTML=b;return c.children(e.fromDom(g))},fromTags:function(a,c){return d.map(a,function(a){return e.fromTag(a,c)})},fromText:function(a,c){return d.map(a,function(a){return e.fromText(a,
c)})},fromDom:function(a){return d.map(a,e.fromDom)}}});l("3j",["4r","4s","7","s","3m"],function(d,e,c,a,b){return function(f,g,h){return d(f,g,{get:function(b){b=h(b);return a.some(b)},generate:function(d,f,g){d=b.fromHtml(g,d.dom());return e.species({elements:c.constant(d),cursor:a.none,dictation:a.none,notify:a.none})}})}});l("26",["i","j","3j"],function(d,e,c){return{addSimpleMacro:function(a,b,f,g){e(arguments,[d.object("polish"),d.string("startString"),d.string("endString"),d.func("callback")]);
var h=c(b,f,g);return a.macros().customMacros().add(h)},removeMacro:function(a,b){a.macros().customMacros().remove(b)}}});l("27",["b","i","j"],function(d,e,c){var a=["error","info","warning"];return{message:function(b,f,g,h){if(!d.contains(a,f))throw'Message level: "'+f+'" is not supported. Supported levels are: ['+a.join(", ")+"].";c(arguments,[e.object("polish"),e.string("level"),e.number("timeout"),e.string("msg")]);var k=b.ui().showMessage(f,g,h);return{hide:function(){k()}}}}});l("3k",["7"],
function(d){var e=d.constant("pencil"),c=d.constant("code"),a=d.constant("spin");d=d.constant("none");return{pencil:e,code:c,wait:a,none:d}});l("28",["i","j","3k","n"],function(d,e,c,a){return{get:function(a){return a.getMode()===c.pencil()?"design":"code"},set:function(b,f){e(arguments,[d.object("polish"),d.string("mode")]);var g=f.toLowerCase();if("code"!==g&&"design"!==g)throw new a('Editor mode "'+f+'" not supported. Must be either design or code.');b.setMode("design"===g?c.pencil():c.code())}}});
l("c5",[],function(){return"body p div article aside figcaption figure footer header nav section ol ul li table thead tbody tfoot caption tr td th h1 h2 h3 h4 h5 h6 blockquote pre address".split(" ")});l("6m",["b","2n","2b"],function(d,e,c){var a=function(b,e){var g=[];d.each(c.children(b),function(b){e(b)&&(g=g.concat([b]));g=g.concat(a(b,e))});return g};return{all:function(b){return a(e.body(),b)},ancestors:function(a,e,g){return d.filter(c.parents(a,g),e)},siblings:function(a,e){return d.filter(c.siblings(a),
e)},children:function(a,e){return d.filter(c.children(a),e)},descendants:a}});l("4h",["6m","m"],function(d,e){return{all:function(c){return e.all(c)},ancestors:function(c,a,b){return d.ancestors(c,function(b){return e.is(b,a)},b)},siblings:function(c,a){return d.siblings(c,function(b){return e.is(b,a)})},children:function(c,a){return d.children(c,function(b){return e.is(b,a)})},descendants:function(c,a){return e.all(a,c)}}});l("32",["s","4h","m","4i"],function(d,e,c,a){var b=function(a,b,c){return d.from(e.ancestors(a,
b,c)[0])};return{first:function(a){return d.from(e.all(a)[0])},ancestor:b,sibling:function(a,b){return d.from(e.siblings(a,b)[0])},child:function(a,b){return d.from(e.children(a,b)[0])},descendant:function(a,b){return d.from(e.descendants(a,b)[0])},closest:function(d,e,h){return a(c.is,b,d,e,h)}}});l("c6",["c","s","n"],function(d,e,c){return function(a,b){var f=function(a){try{return g(a)}catch(b){return e.none()}},g=function(b){return a(b)?e.from(b.dom().nodeValue):e.none()},h=d.detect().browser,
k=h.isIE()&&10===h.version.major?f:g;return{get:function(d){if(!a(d))throw new c("Can only get "+b+" value of a "+b+" node");return k(d).getOr("")},getOption:k,set:function(d,e){if(!a(d))throw new c("Can only set raw "+b+" value of a "+b+" node");d.dom().nodeValue=e}}}});l("az",["21","c6"],function(d,e){var c=e(d.isText,"text");return{get:function(a){return c.get(a)},getOption:function(a){return c.getOption(a)},set:function(a,b){c.set(a,b)}}});l("6q","c5 b 7 1a 1b 2o l 2p 3d 21 6m 4l 2r 4h 32 az 2b".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u){return function(){return{up:c.constant({selector:t.ancestor,closest:t.closest,predicate:n.ancestor,all:u.parents}),down:c.constant({selector:q.descendants,predicate:p.descendants}),styles:c.constant({get:f.get,getRaw:f.getRaw,set:f.set,remove:f.remove}),attrs:c.constant({get:a.get,set:a.set,remove:a.remove,copyTo:function(b,c){var d=a.clone(b);a.setAll(c,d)}}),insert:c.constant({before:h.before,after:h.after,afterAll:k.after,append:h.append,appendAll:k.append,
prepend:h.prepend,wrap:h.wrap}),remove:c.constant({unwrap:r.unwrap,remove:r.remove}),create:c.constant({nu:g.fromTag,clone:function(a){return g.fromDom(a.dom().cloneNode(!1))},text:g.fromText}),query:c.constant({comparePosition:function(a,b){return a.dom().compareDocumentPosition(b.dom())},prevSibling:u.prevSibling,nextSibling:u.nextSibling}),property:c.constant({children:u.children,name:m.name,parent:u.parent,isText:m.isText,isComment:m.isComment,isElement:m.isElement,getText:s.get,setText:s.set,
isBoundary:function(a){return m.isElement(a)?"body"===m.name(a)?!0:e.contains(d,m.name(a)):!1},isEmptyTag:function(a){return m.isElement(a)?e.contains(["br","img","hr","input"],m.name(a)):!1}}),eq:b.eq,is:b.is}}});l("f9",["2v"],function(d){var e=d.immutable("element","offset"),c=d.immutable("element","deltaOffset"),a=d.immutable("element","start","finish"),b=d.immutable("begin","end");d=d.immutable("element","text");return{point:e,delta:c,range:a,points:b,text:d}});l("k4",["7","s"],function(d,e){var c=
d.constant(!1),a=d.constant(!0),b=function(b){return{isBoundary:function(){return b(a,c,c)},fold:b,toText:function(){return b(e.none,e.none,function(a,b){return e.some(a)})},is:function(a){return b(c,c,function(b,c){return c.eq(b,a)})},len:function(){return b(d.constant(0),d.constant(1),function(a,b){return b.property().getText(a).length})}}};return{text:function(a,c){return b(function(b,d,e){return e(a,c)})},boundary:function(a,c){return b(function(b,d,e){return b(a,c)})},empty:function(a,c){return b(function(b,
d,e){return d(a,c)})},cata:function(a,b,c,d){return a.fold(b,c,d)}}});l("yo",["b","7"],function(d,e){return{boundAt:function(c,a,b,f){a=d.findIndex(c,e.curry(f,a));a=-1<a?a:0;b=d.findIndex(c,e.curry(f,b));return c.slice(a,-1<b?b+1:c.length)}}});l("yp",["b"],function(d){return{sliceby:function(e,c){var a=d.findIndex(e,c);return e.slice(0,a)}}});l("128",["4q"],function(d){d=d.generate([{include:["item"]},{excludeWith:["item"]},{excludeWithout:["item"]}]);return{include:d.include,excludeWith:d.excludeWith,
excludeWithout:d.excludeWithout,cata:function(d,c,a,b){return d.fold(c,a,b)}}});l("yq",["b","128"],function(d,e){var c=function(a,b){var c=[],g=[];d.each(a,function(a){var d=b(a);e.cata(d,function(){g.push(a)},function(){0<g.length&&c.push(g);c.push([a]);g=[]},function(){0<g.length&&c.push(g);g=[]})});0<g.length&&c.push(g);return c};return{splitby:function(a,b){return c(a,function(a){return b(a)?e.excludeWithout(a):e.include(a)})},splitbyAdv:c}});l("sg",["yo","yp","yq"],function(d,e,c){return{splitby:function(a,
b){return c.splitby(a,b)},splitbyAdv:function(a,b){return c.splitbyAdv(a,b)},sliceby:function(a,b){return e.sliceby(a,b)},boundAt:function(a,b,c,e){return d.boundAt(a,b,c,e)}}});l("k5",["b","7","s","f9","sg"],function(d,e,c,a,b){return{count:function(a){return d.foldr(a,function(a,b){return b.len()+a},0)},dropUntil:function(a,c){return b.sliceby(a,function(a){return a.is(c)})},gen:function(b,d){return b.fold(c.none,function(b){return c.some(a.range(b,d,d+1))},function(e){return c.some(a.range(e,d,
d+b.len()))})},justText:function(a){return d.bind(a,function(a){return a.fold(e.constant([]),e.constant([]),function(a){return[a]})})}}});l("c7",["b","f9","k4","k5"],function(d,e,c,a){var b=function(a,e,f){if(a.property().isText(e))return[c.text(e,a)];if(a.property().isEmptyTag(e))return[c.empty(e,a)];if(a.property().isElement(e)){var m=a.property().children(e),p=a.property().isBoundary(e)?[c.boundary(e,a)]:[];e=void 0!==f&&f(e)?[]:d.bind(m,function(c){return b(a,c,f)});return p.concat(e).concat(p)}return[]},
f=function(c,d,f,m,p){c=b(c,m,p);d=a.dropUntil(c,d);d=a.count(d);return e.point(m,d+f)};return{typed:b,items:function(a,c,e){a=b(a,c,e);var f=function(a,b){return a};return d.map(a,function(a){return a.fold(f,f,f)})},extractTo:function(a,b,c,d,p){return a.up().predicate(b,d).fold(function(){return e.point(b,c)},function(d){return f(a,b,c,d,p)})},extract:function(a,b,c,d){return a.property().parent(b).fold(function(){return e.point(b,c)},function(e){return f(a,b,c,e,d)})}}});l("c8",["b","7","c7"],
function(d,e,c){var a=function(a,c){return"img"===c.property().name(a)?" ":"\n"};return{from:function(b,f,g){f=c.typed(b,f,g);return d.map(f,function(c){return c.fold(e.constant("\n"),a,b.property().getText)}).join("")}}});l("k6",["b","7"],function(d,e){return{make:function(c,a,b){return d.foldl(c,function(b,c){return a(c,b.len).fold(e.constant(b),function(a){return{len:a.finish(),list:b.list.concat([a])}})},{len:void 0!==b?b:0,list:[]}).list}}});l("k7",["b","s"],function(d,e){var c=function(a,c){return c>=
a.start()&&c<=a.finish()},a=function(a,c){return d.findIndex(a,function(a){return a.start()===c})};return{get:function(a,f){var g=d.find(a,function(a){return c(a,f)});return e.from(g)},find:function(a,c){return e.from(d.find(a,c))},inUnit:c,sublist:function(b,c,d){c=a(b,c);var e=a(b,d);d=-1<e?e:b[b.length-1]&&b[b.length-1].finish()===d?b.length+1:-1;return-1<c&&-1<d?b.slice(c,d):[]}}});l("k9",["b","6","7"],function(d,e,c){return{translate:function(a,b){return d.map(a,function(a){return e.merge(a,
{start:c.constant(a.start()+b),finish:c.constant(a.finish()+b)})})}}});l("k8",["b","k7","k9"],function(d,e,c){var a=function(a,d,e){d=e(a,d);return c.translate(d,a.start())};return{splits:function(b,c,g){return 0===c.length?b:d.bind(b,function(b){var k=d.bind(c,function(a){return e.inUnit(b,a)?[a-b.start()]:[]});return 0<k.length?a(b,k,g):[b]})}}});l("hv",["k6","k7","k8","k9"],function(d,e,c,a){return{generate:function(a,c,e){return d.make(a,c,e)},get:function(a,c){return e.get(a,c)},find:function(a,
c){return e.find(a,c)},splits:function(a,d,e){return c.splits(a,d,e)},translate:function(b,c){return a.translate(b,c)},sublist:function(a,c,d){return e.sublist(a,c,d)}}});l("c9",["f9","c7","k5","hv"],function(d,e,c,a){return{find:function(b,f,g,h){b=e.typed(b,f,h);b=a.generate(b,c.gen);return a.get(b,g).map(function(a){return d.point(a.element(),g-a.start())})}}});l("6r",["c7","c8","c9"],function(d,e,c){return{extract:function(a,b,c,e){return d.extract(a,b,c,e)},extractTo:function(a,b,c,e,h){return d.extractTo(a,
b,c,e,h)},all:function(a,b,c){return d.items(a,b,c)},from:function(a,b,c){return d.typed(a,b,c)},find:function(a,b,d,e){return c.find(a,b,d,e)},toText:function(a,b,c){return e.from(a,b,c)}}});l("4t",["6q","6r"],function(d,e){var c=d();return{extract:function(a,b,d){return e.extract(c,a,b,d)},extractTo:function(a,b,d,g){return e.extractTo(c,a,b,d,g)},all:function(a,b){return e.all(c,a,b)},from:function(a,b){return e.from(c,a,b)},find:function(a,b,d){return e.find(c,a,b,d)},toText:function(a,b){return e.toText(c,
a,b)}}});l("2g","l 3m 2p 3d 2r 2b".split(" "),function(d,e,c,a,b,f){var g=function(a){return a.dom().innerHTML};return{get:g,set:function(g,k){var m=f.owner(g).dom(),p=d.fromDom(m.createDocumentFragment()),m=e.fromHtml(k,m);a.append(p,m);b.empty(g);c.append(g,p)},getOuter:function(a){var b=d.fromTag("div");a=d.fromDom(a.dom().cloneNode(!0));c.append(b,a);return g(b)}}});l("3l",["b","7","4t","2g"],function(d,e,c,a){return{toText:function(a){return d.map(a,function(a){return c.toText(a,e.constant(!1))}).join("").trim()},
toHtml:function(b){return d.map(b,a.getOuter).join("")}}});l("3n",[],function(){return{get:function(d){return d.dom().textContent},set:function(d,e){d.dom().textContent=e}}});l("29","a 1o f i j 3l 1a 3m 2g 3n n".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=function(r,q){return c.makeReadOnly({getAttributes:function(){return c.makeReadOnly(r.getFilteredAttributes(q))},setAttributes:function(c){b(arguments,[a.object("attributes")]);e.each(c,function(a,b){if(!d.isString(a))throw new p("attribute key "+
b+" does not have a string value: "+a);});g.setAll(q,c);r.domChanged();r.undoChanged()},getText:function(){return f.toText([q])},setText:function(c){b(arguments,[a.string("text")]);m.set(q,c)},getHtml:function(){return r.getFilteredContents(q)},setHtml:function(c){b(arguments,[a.string("html")]);k.set(q,c)},replaceElement:function(c){b(arguments,[a.string("html")]);var d=h.fromHtml(c);if(1!==d.length)throw new p("replacement html must be a single node");d=d[0];r.replaceElement(q,d);return n(r,d)}})};
return{getText:function(a){return a.content().getSelectedText().getOr("")},getHtml:function(a){return a.content().getSelectedHtml().getOr("")},findTagAtCursor:function(a,b){var c=a.content();return c.findTagAtCursor(b).map(function(a){return n(c,a)}).getOr(null)}}});l("g",["s","o"],function(d,e){var c=function(a){try{var b=ya(a);return d.some(b)}catch(c){return d.none()}};return{get:c,register:function(a,b){return l(a,[],function(){return b})},hookup:function(a,b){c(b).fold(function(){e&&e.error&&
e.error('textbox.io Could not find plugin "'+b+'". Have you declared it?')},function(b){a.events.loaded.addListener(function(){b.initialize(a)})})}}});l("3o",["7"],function(d){var e=function(c,a){return{left:d.constant(c),top:d.constant(a),translate:function(b,d){return e(c+b,a+d)}}};return e});l("4u","7 1b l 21 4l q".split(" "),function(d,e,c,a,b,f){return{attached:function(a,h){var k=h||c.fromDom(f.documentElement);return b.ancestor(a,d.curry(e.eq,k)).isSome()},windowOf:function(b){var c=b.dom();
return c===c.window?b:a.isDocument(b)?c.defaultView||c.parentWindow:null}}});l("3p",["3o","4u","l"],function(d,e,c){var a=function(a,b){return void 0!==a?a:void 0!==b?b:0},b=function(a){var b=a.dom(),h=b.ownerDocument,k=h.body,h=c.fromDom(h.documentElement);if(k===b)return d(k.offsetLeft,k.offsetTop);if(!e.attached(a,h))return d(0,0);a=b.getBoundingClientRect();return d(a.left,a.top)};return{absolute:function(d){var g=d.dom().ownerDocument,h=g.body,k=e.windowOf(c.fromDom(g)),m=g.documentElement,g=
a(k.pageYOffset,m.scrollTop),k=a(k.pageXOffset,m.scrollLeft),p=a(m.clientTop,h.clientTop),h=a(m.clientLeft,h.clientLeft);return b(d).translate(k-h,g-p)},relative:function(a){a=a.dom();return d(a.offsetLeft,a.offsetTop)},viewport:b}});l("2a",["3o","3p","q"],function(d,e,c){return{get:function(a){a=void 0!==a?a.dom():c;return d(a.body.scrollLeft||a.documentElement.scrollLeft,a.body.scrollTop||a.documentElement.scrollTop)},setToElement:function(a,b){var c=e.absolute(b);a.scrollTo(c.left(),c.top())}}});
l("18","b 22 23 f 24 25 26 27 28 29 g 7 r 2a 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t){return function(s,u,v){var w=c({loaded:s.events.loaded,focus:s.events.focus,dirty:s.events.dirty,internal:s.events.internal}),y=function(a,b){var c=t.owner(a),d=t.defaultView(a),c=q.get(c),e=b();d.dom().scrollTo(c.left(),c.top());return e},x=n.curry(m.getText,s),z=a.makeReadOnly({content:{documentElement:n.curry(b.documentElement,s),insertHtmlAtCursor:n.curry(b.insertHtmlAtCursor,s),uploadImages:n.curry(b.uploadImages,
s),get:n.curry(b.get,s),set:n.curry(b.set,s),isDirty:n.curry(b.isDirty,s),setDirty:n.curry(b.setDirty,s),selection:{findTagAtCursor:n.curry(m.findTagAtCursor,s),getText:x,getHtml:n.curry(m.getHtml,s)},getSelectedText:x},mode:{set:n.curry(k.set,s),get:n.curry(k.get,s)},filters:f(s),macros:{addSimpleMacro:n.curry(g.addSimpleMacro,s),removeMacro:n.curry(g.removeMacro,s)},message:n.curry(h.message,s),events:w.registry,element:function(){return s.element().dom()},focus:s.focus,restore:r.cached(function(){return y(s.element(),
function(){e.blur();var a=b.get(s);w.destroy();s.destroy();return v.restore(a)})})});d.each(u,function(a){p.hookup(z,a)});return z}});l("d","b 14 15 16 17 18 s 1a 1b".split(" "),function(d,e,c,a,b,f,g,h,k){return function(){var m=e(),p=a(),n=function(a){return a.api},r=function(a,d){var e=c(d.options(),function(){return n.getOrDie("Internal Error")},g.from(h.get(a,"id"))),n=b.one(a,d.constructors(),e).map(function(b){var c=f(b.polish,e&&e.plugins?e.plugins:[],{restore:function(a){p.remove(d);m.remove(d);
return b.restore(a).dom()}}),d={is:function(b){return k.eq(a,b)},api:c};p.add(d);m.add(d);return c});return n};return{getOrCreate:function(a,b){return p.get(a).map(n).orThunk(function(){return r(a,b)})},get:function(a){a=p.findAll(a);return d.map(a,n)},getActiveEditor:m.get}}});l("2d",["6","1a"],function(d,e){return{withOptions:function(c,a){return e.has(c,"tabindex")?d.deepMerge(a,{content:{tabindex:e.get(c,"tabindex")}}):a}}});l("2e",["1o","c","s","2o"],function(d,e,c,a){e=e.detect();var b=e.browser.isIE()&&
10===e.browser.version.major,f=function(c,d){var e=a.getRaw(c,d).getOrThunk(function(){return a.get(c,d)});return b&&"0px"===e?"auto":e},g=function(a,b,d){a=f(a,b);return void 0===a?d:c.some(a)},h=function(a){return{width:g(a,"width",c.none()),"max-width":g(a,"max-width",c.some("none")),"min-width":g(a,"min-width",c.some("none")),"max-height":g(a,"max-height",c.some("none")),"min-height":g(a,"min-height",c.some("none"))}},k=function(b,c){var e=a.getRaw(b,"display"),g=f(b,"height");a.set(b,"display",
"none");var k=f(b,"height"),g="auto"===k?g:k,k=h(b);e.fold(function(){a.remove(b,"display")},function(c){a.set(b,"display",c)});void 0!==g&&a.set(c,"height",g);d.each(k,function(b,d){b.each(function(b){a.set(c,d,b)})})};return{copyFrom:k,explicit:function(a){k(a,a)}}});l("4y",["4j","7"],function(d,e){var c=d.create("ephox-elder");return{resolve:c.resolve,scrollable:e.curry(c.resolve,"scrollable")}});l("4e",["b","1y","35","9"],function(d,e,c,a){return{add:function(a,c){d.each(c,function(c){e.add(a,
c)})},remove:function(a,c){d.each(c,function(c){e.remove(a,c)})},toggle:function(a,c){d.each(c,function(c){e.toggle(a,c)})},hasAll:function(a,c){return d.forall(c,function(c){return e.has(a,c)})},hasAny:function(a,c){return d.exists(c,function(c){return e.has(a,c)})},get:function(b){if(c.supports(b)){b=b.dom().classList;for(var d=new a(b.length),e=0;e<b.length;e++)d[e]=b.item(e);b=d}else b=c.get(b);return b}}});l("6s",["1y","4e"],function(d,e){return{addClass:function(c){return function(a){d.add(a,
c)}},removeClass:function(c){return function(a){d.remove(a,c)}},removeClasses:function(c){return function(a){e.remove(a,c)}},hasClass:function(c){return function(a){return d.has(a,c)}}}});l("4v","b 4y 7 s 3y l 6s 2a 3x 37".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=a.none();e=e.resolve("modal-scroll-lock");var n=function(a,b){d.each(b,function(b){a(b)})};return{block:function(){if(p.isNone()){var c=h.get(),d=b.bind(f.fromDom(m),"scroll",function(a){a=h.get();a.left()===c.left()&&a.top()===c.top()||
m.scrollTo(c.left(),c.top())});p=a.some(d)}},unblock:function(){p.each(function(b){p=a.none();k(function(){b.unbind()},250)})},lock:c.curry(n,g.addClass(e)),unlock:c.curry(n,g.removeClass(e))}});aa("6e",clearTimeout);l("6t",["6e","3x"],function(d,e){return function(c,a){var b=null;return{cancel:function(){null!==b&&(d(b),b=null)},schedule:function(){var d=arguments;b=e(function(){c.apply(null,d);b=null},a)}}}});l("59",["b","2v"],function(d,e){return function(c){var a=e.immutable.apply(null,c),b=[];
return{bind:function(a){if(void 0===a)throw"Event bind error: undefined handler";b.push(a)},unbind:function(a){b=d.filter(b,function(b){return b!==a})},trigger:function(){var c=a.apply(null,arguments);d.each(b,function(a){a(c)})}}}});l("4a",["1o"],function(d){return{create:function(e){var c=d.map(e,function(a){return{bind:a.bind,unbind:a.unbind}});e=d.map(e,function(a){return a.trigger});return{registry:c,trigger:e}}}});l("4w",["6t","59","4a","3y"],function(d,e,c,a){return function(b){var f=!1,g=
c.create({started:e([]),stopped:e([])}),h=d(function(){!0===f&&(f=!1,g.trigger.stopped())},250),k=a.bind(b,"scroll",function(){h.cancel();!1===f&&g.trigger.started();f=!0;h.schedule()});return{events:g.registry,destroy:function(){k.unbind()},isScrolling:function(){return f}}}});l("4x",["s","2a"],function(d,e){return{capture:function(c,a){var b=d.none();return{save:function(){b=d.some(e.get(c))},restore:function(){b.each(function(b){a.scrollTo(b.left(),b.top())})}}},preserve:function(c,a){var b=e.get(c);
a();var d=e.get(c);b.top()===d.top()&&b.left()===d.left()||c.dom().defaultView.scrollTo(b.left(),b.top())}}});l("3q",["4v","4w","4x","4y","1y"],function(d,e,c,a,b){return{register:function(c){b.add(c,a.scrollable())},deregister:function(c){b.remove(c,a.scrollable())},scrollable:a.scrollable,preserve:c.preserve,capture:c.capture,block:d.block,unblock:d.unblock,lock:d.lock,unlock:d.unlock,event:e}});l("1e",["2k"],function(d){var e=d();return{preload:function(){e.preload()},addStylesheet:function(c,
a){return e.addStylesheet(c,a)},addScript:function(c,a){return e.addScript(c,a)},waitForLoad:function(){return e.waitForLoad()}}});l("2l",["b","v"],function(d,e){var c=function(){return{zh_hk:"zh_tw",iw:"he",no:"nb",nn:"nb",en:"en",ar:"ar",ca:"ca",cs:"cs",da:"da",de:"de",el:"el",es:"es",fa:"fa",fi:"fi",fr:"fr",he:"he",hr:"hr",hu:"hu",it:"it",ja:"ja",kk:"kk",ko:"ko",nl:"nl",nb:"nb",pl:"pl",pt:"pt",pt_pt:"pt_pt",ro:"ro",ru:"ru",sl:"sl",sk:"sk",sv:"sv",th:"th",tr:"tr",uk:"uk",zh:"zh",zh_tw:"zh_tw"}},
a=function(a){a=a.toLowerCase().replace("-","_");var b=a.indexOf(";");a=-1<b?a.substring(0,b):a;a=e.trim(a);b=a.indexOf("_");b=-1<b?a.substring(0,b):a;return{full:a,languageCode:b}},b=function(b,c){var e=b.split(","),e=d.map(e,function(b){b=a(b);return c[b.full]||c[b.languageCode]||""});return d.find(e,function(a){return""!==a})};return{extract:a,determine:function(a){var d=c();return b(a,d)},determineFrom:b,localeList:c}});l("k",["s"],function(d){return{cat:function(d){for(var c=[],a=function(a){c.push(a)},
b=0;b<d.length;b++)d[b].each(a);return c},findMap:function(e,c){for(var a=0;a<e.length;a++){var b=c(e[a],a);if(b.isSome())return b}return d.none()},liftN:function(e,c){for(var a=[],b=0;b<e.length;b++){var f=e[b];if(f.isSome())a.push(f.getOrDie());else return d.none()}return d.some(c.apply(null,a))}}});l("1f","2i 2l 7 s k o".split(" "),function(d,e,c,a,b,f){var g=function(){var a=d.resolve("navigator")||{};return a.userLanguage||a.language||"en"}(),h=a.none();return{determine:function(d){var h=void 0!==
d?[d,g]:[g];return b.findMap(h,function(b){return a.from(e.determine(b))}).fold(function(){f.warn("WARNING: locales not supported: "+h.join(", "));return"en"},c.identity)},get:function(){return h.getOrDie("locale used before it has been set")},set:function(b){h=a.from(b)}}});l("1g","a 1o 2i 7 1f n o".split(" "),function(d,e,c,a,b,f,g){var h={font:{arial:"Arial",courier:"Courier New",comicsans:"Comic Sans MS",consolas:"Consolas",georgia:"Georgia",impact:"Impact",tahoma:"Tahoma",timesnr:"Times New Roman",
trebuchet:"Trebuchet MS",verdana:"Verdana"},error:{duplicate:{code:"That snippet code is already taken.",uuid:"That snippet uuid is already taken."},unknown:{uuid:"The snippet uuid cannot be found"},code:{duplicate:"That snippet code is already taken."}},cog:{login:"Log in",logout:"Log out","not-logged-in":"Not logged in",user:"User: {0}"},banner:{"logged-in":"Logged in as: {0}"}},k={},m="",p={},n=function(a){return c.resolve(a,p)||c.resolve(a,k)||c.resolve(a,h)};return{loadEnglish:function(a){k=
a},load:function(a,c){m=a;p=c;b.set(a)},isLoaded:function(a){return m===a&&0<e.keys(p).length},get:function(a){var b=n(a);if(d.isString(b))return b;throw new f("key "+a+" does not exist");},has:function(b){if(!d.isString(b))throw b.fold?g.error("object details were",b.fold(a.identity,a.identity,a.identity)):g.error("object key was",b),"key was an object";return d.isString(n(b))}}});l("1h",["s","o"],function(d,e){var c=d.none();return{set:function(a){c.fold(function(){c=d.some(a)},function(b){b!==
a&&e.error('Only one base URL supported per page. Requested value "'+a+'", already using "'+b+'"')})},get:function(){return c.getOrDie("Must begin loading with a base URL")}}});l("2q",["3y","l","q"],function(d,e,c){return{execute:function(a){if("complete"===c.readyState||"interactive"===c.readyState)a();else var b=d.bind(e.fromDom(c),"DOMContentLoaded",function(){a();b.unbind()})}}});l("3z",["a","b","2o","36"],function(d,e,c,a){return function(b,f){var g=function(a){var d=f(a);return 0>=d||null===
d?(a=c.get(a,b),parseFloat(a)||0):d},h=function(a,b){return e.foldl(b,function(b,d){var e=c.get(a,d),e=void 0===e?0:parseInt(e,10);return isNaN(e)?b:b+e},0)};return{set:function(c,e){if(!d.isNumber(e)&&!e.match(/^[0-9]+$/))throw b+".set accepts only positive integer values. Value was "+e;var f=c.dom();a.isSupported(f)&&(f.style[b]=e+"px")},get:g,getOuter:g,aggregate:h,max:function(a,b,c){a=h(a,c);return b>a?b-a:0}}}});l("2s",["2o","3z"],function(d,e){var c=e("width",function(a){return a.dom().offsetWidth});
return{set:function(a,b){c.set(a,b)},get:function(a){return c.get(a)},getOuter:function(a){return c.getOuter(a)},setMax:function(a,b){var e=c.max(a,b,"margin-left border-left-width padding-left padding-right border-right-width margin-right".split(" "));d.set(a,"max-width",e+"px")}}});aa("2t",clearInterval);aa("2u",setInterval);l("1i","2m r 2n 1y 2o l 2p 2q 2r 2s v 2t 2u".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){var q=function(){var d=f.fromTag("div");a.add(d,"ephox-textbox-font");var e=f.fromTag("span");
a.add(e,"ephox-chameleon-icon");g.append(d,e);g.append(c.body(),d);var h=m.get(e),e=b.get(e,"font-family");k.remove(d);return 0<h&&void 0!==e&&p.contains(e,"Textbox Icons")},t=function(a){var b=0,c=r(function(){b+=250;q()?(n(c),a(!0)):2E3<b&&(n(c),a(!1))},250)};return{wait:e.cached(function(){return d.nu(function(a){h.execute(function(){q()?a(!0):t(a)})})})}});l("t","b 1e 7 p 1f 1g 1h 1i 1j o".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=function(b){h.wait().get(function(c){b(c?a.value(!0):a.error("Stylesheet loaded, but did not contain Textbox.io styles"))})},
n=function(b,c){var d=b+"/i18n/tbio_"+c+".js?"+k.resourceParam();return e.addScript(d,function(b){return b.bind(function(b){return k.strictMatch(b.version,"Language strings").fold(function(){return a.value(b.strings())},a.error)})})},r=function(a){var b="/textboxio.css?"+k.fullParam();e.addStylesheet(a+b,p)};return{load:function(a){g.set(a);a=g.get();r(a+"/css");n(a,"en").get(function(a){a.each(f.loadEnglish)});return a},devLoad:r,setLanguage:function(a){var c=b.determine(a);f.isLoaded(c)||(a=g.get(),
n(a,c).get(function(a){a.each(function(a){f.load(c,a)})}))},waitForLoad:function(){return e.waitForLoad()},getFailures:function(a){return d.bind(a,function(a){return a.fold(function(a){return[a]},c.constant([]))})}}});l("53",["1a","l"],function(d,e){return{span:function(c){c=e.fromTag("span",c);d.set(c,"role","presentation");return c},div:function(c){c=e.fromTag("div",c);d.set(c,"role","presentation");return c},tag:function(c,a){var b=e.fromTag(c,a);d.set(b,"role","presentation");return b}}});l("6u",
["32"],function(d){return{any:function(e){return d.first(e).isSome()},ancestor:function(e,c,a){return d.ancestor(e,c,a).isSome()},sibling:function(e,c){return d.sibling(e,c).isSome()},child:function(e,c){return d.child(e,c).isSome()},descendant:function(e,c){return d.descendant(e,c).isSome()},closest:function(e,c,a){return d.closest(e,c,a).isSome()}}});l("54","c 7 34 1a 1y 2o l 2p 2r 6u q".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=c.resolve("highcontrast-mode"),r=function(a){var d=g.fromTag("div");
b.add(d,c.resolve("highcontrast-detect"));h.append(a,d);f.reflow(d);(!0===("none"===f.get(d,"background-image")?!0:!1)?b.add:b.remove)(a,n);k.remove(d)},q=function(c){var d=g.fromDom(p.documentElement);(!0===(a.has(d,"hc")&&a.has(d,"hcx"))?b.add:b.remove)(c,n)},t=e.noop;return{detect:function(a){var b=d.detect();b.os.isWindows()&&(b.browser.isIE()||b.browser.isSpartan()||b.browser.isFirefox()?r:b.browser.isChrome()?q:t)(a)},isHighContrast:function(a){return m.ancestor(a.uiContainer(),"."+n)}}});l("55",
["2v"],function(d){return d.immutableBag(["width","docWidth","height","docHeight"],[])});l("56",["4q"],function(d){d=d.generate([{unchanged:["html"]},{changed:["html"]}]);return{unchanged:d.unchanged,changed:d.changed,cata:function(d,c,a){return d.fold(c,a)}}});l("46",["a","57"],function(d,e){var c=function(){return{validate:function(a,b){return d.isFunction(a)||"events"===b&&d.isObject(a)},label:"Function (or events)"}}(),a="activateInline communication connect content deactivateInline element events filter focus getContent getMode insertHtmlAtCursor isDirty isPrettyPrinting keyboard macros operations setContent setDirty smartview state ui undo".split(" "),
b=e.ensureWith(a.concat([]),c),c=e.ensureWith(a.concat("blur destroy fromTransfer fullscreen uploader toTransfer viewport".split(" ")),c);return{external:b,internal:c}});l("6v",["b","7"],function(d,e){return function(c){return d.mapToObject(c,function(){return{bind:e.noop,unbind:e.noop}})}});l("ca",[],function(){return{create:function(){var d=!1;return{isBlocked:function(){return d},block:function(){d=!0},unblock:function(){d=!1}}}}});l("cb",[],function(){return{create:function(d,e){return{control:d,
instance:e}}}});l("br",["ca","cb"],function(d,e){return{tap:function(c){var a=d.create();return e.create(a,function(){a.isBlocked()||c.apply(null,arguments)})}}});l("6w",["br","59","4a","4p"],function(d,e,c,a){return function(b){b=a(b.dirty);var f=b.get,g=b.set,h=c.create({dirty:e([]),clean:e([])}),k=d.tap(function(a){var b=f();a!==b&&(g(a),!0===a?h.trigger.dirty():(k.control.block(),h.trigger.clean(),k.control.unblock()))});return{events:h.registry,isDirty:f,setDirty:k.instance,state:function(){return{dirty:f()}}}}});
l("6x",["b","7","3i"],function(d,e,c){return function(a,b,f){var g=[],h=e.curry(b,"input"),k=e.curry(b,"output"),m=e.curry(f,"input"),p=e.curry(f,"output");b=function(a){c.cata(a,h,k,m,p);g.push(a)};d.each(a.customs,b);return{state:function(){return{customs:g.slice(0)}},addFilter:b}}});l("30",[],function(){var d=0;return{generate:function(e){var c=(new Date).getTime(),a=Math.floor(1E9*Math.random());d++;return e+"_"+a+d+String(c)}}});l("6y",["1o","30","6"],function(d,e,c){return function(a){var b=
{};d.each(a,function(a,c){b[c]=a});return{get:function(){return d.values(b)},add:function(a){var c=e.generate("macro");b[c]=a;return c},remove:function(a){delete b[a]},state:function(){return c.merge({},b)}}}});l("hi",["a","b","1o"],function(d,e,c){return{isFunctionOrEvents:function(a){var b=function(b){return!0===e.forall(a,function(a){return void 0!==b[a]&&void 0!==b[a].bind&&d.isFunction(b[a].bind)})?!0:!1};return{validate:function(a,c){return d.isFunction(a)||"events"===c&&d.isObject(a)&&b(a)},
label:"Function (or events)"}}}});l("cc",["hi","57"],function(d,e){return e.ensureWith("events init ui check scanView situation hasDropdown hasAutocorrect handle assign lock destroy state lookup name".split(" "),d.isFunctionOrEvents(["analytics"]))});l("70",["7","s","6v"],function(d,e,c){return{noSituation:function(){return{primary:d.constant([]),secondary:d.constant([]),submenus:d.constant({})}},basic:function(){return{destroy:d.noop,ui:e.none,state:d.constant({}),events:c(["analytics"])}}}});l("6z",
"7 s 6v cc 70 1a".split(" "),function(d,e,c,a,b,f){return function(){var g=d.noop;return a({setAutocorrect:d.noop,setSpelling:d.noop,events:c(["analytics"]),init:function(a){a.body().each(function(a){f.set(a,"spellcheck","false");g=function(){f.remove(a,"spellcheck")}})},ui:e.none,check:d.noop,scanView:d.noop,situation:b.noSituation,hasDropdown:d.constant(!1),hasAutocorrect:d.constant(!1),handle:d.noop,assign:d.noop,lock:d.apply,destroy:function(){g()},state:d.constant({}),lookup:d.constant(e.none()),
name:d.constant("spelling-disabled")})}});l("71",["b","1o","6n","7","s"],function(d,e,c,a,b){var f=function(b,f){var k={};e.each(b,function(a,b){var d=b.split(".");if(1>=d.length)k[b]={finalvalue:a};else{var e=k;c.namespace(b,k);for(var f=0;f<d.length-1;f++)e=e[d[f]];e[d[d.length-1]]={finalvalue:a}}});var m=function(b){var c={},g=e.keys(b);d.each(g,function(d){c[d]=void 0!==b[d].finalvalue?f(b[d].finalvalue):a.constant(m(b[d]))});return c};return m(k)};return{ui:function(c,d){var e=f(c,void 0!==d?
d:a.constant);return a.constant(b.some(e))},actions:function(b){b=f(b,a.identity);return a.constant(b)}}});l("58","b 6 3w 7 s p 6v 6w 6x 6y 6z 70 71 59 4a".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t){return{basic:n.basic,draganddrop:function(){return{events:g(["insertAssets","insertHtml"]),destroy:a.noop}},communication:function(){return{headers:a.constant({}),destroy:a.noop}},fullscreen:function(){return{ui:b.none,actions:r.actions({maximize:a.noop,restore:a.noop}),select:a.noop,deselect:a.noop,
destroy:a.noop,events:g(["analytics","maximize","restore"])}},dialog:function(){return{destroy:a.noop,ui:b.none,events:g(["analytics"]),actions:r.actions({show:a.noop})}},spelling:function(){return p()},editorcontext:function(){return{events:g(["blockChanged","enterDown","enterUp"]),destroy:a.noop}},highlighter:function(){return{destroy:a.noop,run:a.noop}},linkvalidator:function(){return{destroy:a.noop,refresh:a.noop,ignore:a.noop,state:a.constant({ignore:[],cache:{}})}},macros:function(){return{events:g(["analytics"]),
state:a.constant({}),customMacros:a.constant(m({})),destroy:a.noop}},table:function(){return{ui:b.none,state:a.constant({}),events:g(["analytics"]),situation:n.noSituation,handle:a.noop,assign:a.noop,destroy:a.noop,name:a.constant("table-disabled")}},image:function(){return{events:g(["changed","contextmenu"]),situation:n.noSituation,handle:a.noop,assign:a.noop,destroy:a.noop,name:a.constant("image-disabled")}},imageEdit:function(){var e=function(b,e){return c.pure(d.map(e,a.compose(f.value,b)))},
g=a.curry(e,a.identity),e=a.curry(e,function(a){return a.asset()});return{situation:n.noSituation,handle:a.noop,assign:a.noop,ui:b.none,destroy:a.noop,insertResample:a.constant({assets:g,correlated:e,destroy:a.noop}),name:a.constant("imageEdit-disabled")}},mobile:function(){return{ui:b.none,events:g(["fullscreen"]),destroy:a.noop}},noAnalytics:function(){return{log:a.noop,register:a.noop}},state:function(b){var c=h(b.laundry),d=k(b.filters,a.noop,a.noop),f=m(b.macros.customs);return{filter:a.constant({customFilters:a.constant(d)}),
macros:a.constant({customMacros:a.constant(f)}),laundry:c,getState:function(a){return e.merge(b,void 0===a?{}:a,{laundry:c.state(),filters:d.state(),macros:{customs:f.state()}})}}},uploader:function(){var b=t.create({reconstitute:q([]),uploadAssets:q(["assets"])});return{destroy:a.noop,events:b.registry,reconstitute:a.noop,uploadAssets:a.noop}},undo:function(){return{reset:a.noop,disable:a.apply,save:a.noop}}}});l("49",["7","58","59","4a"],function(d,e,c,a){return{activateInline:d.noop,deactivateInline:d.noop,
communication:e.communication,events:function(){return a.create({loaded:c([]),focus:c([]),dirty:c([]),internal:c(["command","data"]),paint:c([])}).registry},keyboard:d.die("the keyboard feature is not implemented in this mode"),operations:d.die("the operations feature is not implemented in this mode"),smartview:d.die("the smartview feature is not implemented in this mode"),ui:d.die("the ui feature is not implemented in this mode")}});l("4b",["b","7","59"],function(d,e,c){return function(a,b){var f=
c(a),g=0,h=function(b){var c=d.map(a,function(a){return b[a]()});f.trigger.apply(null,c)};return{bind:function(a){f.bind(a);g++;1===g&&b.bind(h)},unbind:function(a){f.unbind(a);g--;0===g&&b.unbind(h)},trigger:e.die("Cannot trigger a source event.")}}});l("40","53 7 s 54 3g 55 56 3k 46 58 3h 49 34 59 4a 4b 4e l 2p 2r 2s".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v,w,y,x){return function(z,A,l){var B=m.state(l),C=c.none(),F=c.none(),E=t.create({loaded:q([]),focus:q([]),dirty:s([],B.laundry.events.dirty),
internal:q(["command","data"]),paint:q(["dimensions"])}),G=d.div();u.add(G,[r.resolve("source-container"),"ephox-textbox-font",r.resolve("layer-editor")]);l=function(){return G};var H=function(){return F.getOrDie("CodeMirror not added to DOM")},I=function(a){return N()?b.beautify(a):a},K=function(a){var b=H().doc;a=I(a);b.setValue(a);b.clearHistory()},J=function(a){var b=v.fromDom(a.getWrapperElement()),c=a.doc.lineCount();a.on("changes",function(){var d=a.doc.lineCount();d!=c&&(c=d,d=a.getScrollInfo(),
d=f({width:x.get(b),docWidth:d.width,height:d.height,docHeight:d.height}),E.trigger.paint(d))})},L=function(){H().focus()},N=function(){return!0===z.content.prettyprint};return k.internal({activateInline:n.activateInline,blur:e.die("blur is not supported in the API."),communication:m.communication,connect:function(b){w.append(b,G);A.updateUi(G);a.detect(G);b=p.use.codemirror()(G.dom(),{mode:"text/html",extraKeys:{"Ctrl-Space":"autocomplete"},lineWrapping:!0});b.on("focus",function(){E.trigger.focus()});
F=c.some(b);E.trigger.loaded();J(b);return!0},content:e.constant({body:e.constant(c.none()),doc:e.die("content.doc is not supported in code view"),execCommand:e.die("content.execCommand is not supported in code view"),getSelectedText:function(){var a=H().getSelection();return void 0!==a&&null!==a&&0<a.length?c.some(a):c.none()},focus:L,isInline:e.constant(!1)}),deactivateInline:n.deactivateInline,destroy:function(){y.remove(G);y.empty(G);F=c.none()},element:l,events:E.registry,filter:B.filter,focus:L,
fromTransfer:function(a){var b=function(a){K(a);C=c.some(a);F.bind(function(a){a.on("changes",function(a,b){B.laundry.setDirty(!0)})})};g.cata(a,b,b)},fullscreen:m.fullscreen,getContent:function(){return H().doc.getValue()},getMode:h.code,insertHtmlAtCursor:function(a){H().replaceSelection(a)},isDirty:B.laundry.isDirty,isPrettyPrinting:N,keyboard:n.keyboard,macros:B.macros,operations:n.operations,setContent:function(a){K(a);B.laundry.setDirty(!1)},setDirty:B.laundry.setDirty,smartview:n.smartview,
state:function(){return B.getState({content:{}})},toTransfer:function(){var a=H().doc.getValue();return C.filter(function(b){return I(b)===a}).fold(function(){return g.changed(a)},g.unchanged)},ui:n.ui,undo:e.constant(m.undo()),uploader:e.constant(m.uploader()),viewport:l})}});l("5a",[],function(){return"undo insert style emphasis align listindent format tools".split(" ")});l("75",["2v"],function(d){return d.immutable("x","y","width","height")});l("72",["75","1s"],function(d,e){return{intersect:function(c,
a){var b=e.max(c.x(),a.x()),f=e.max(c.y(),a.y()),g=e.min(c.x()+c.width(),a.x()+a.width()),g=e.max(0,g-b),h=e.min(c.y()+c.height(),a.y()+a.height()),h=e.max(0,h-f);return d(b,f,g,h)}}});l("sh",["b","4q"],function(d,e){var c=e.generate([{unbundled:[]},{unsupported:["message"]},{item:["info","blueprint"]},{customMenu:["info","groups","blueprint"]},{textboxMenu:["info","blueprint"]},{palette:["info","children","blueprint"]}]);return{create:function(a){var b=function(a,b){return a.feature.fold(function(){return void 0!==
a.unsupported?[c.unsupported(a.unsupported)]:[c.unbundled()]},function(c){if(void 0===c[a.command])return console.warn("unknown command: "+a.command),[];c=c[a.command]();return[b(c)]})},e=function(a,e){return b(e,function(b){return d.contains(["widget","inline-widget","split-widget"],e.type)?c.item({instance:b.widget},a[e.type]):c.item(b[e.type](),a[e.type])})},g={dropdown:e,general:e,widget:e,"split-widget":e,"inline-widget":e,palette:function(a,e){return b(e,function(b){b=b.palette();var e=d.map(b.items,
function(b){return d.contains(["widget","inline-widget","split-widget"],b.type)?c.item({instance:b.build},a[b.type]):c.item(b.spec,a[b.type])});return c.palette(b,e,a.palette)})},submenu:function(b,e){var f=d.map(e.commands,a);return[c.customMenu(e,f,b.menu)]},menu:function(a,d){return b(d,function(b){return c.textboxMenu(b[d.type](),a[d.type])})}};return{classify:function(a,b){var c=g[b.type];return void 0!==c?c(a,b):[]}}},cata:function(a,b,c,d,e,k,m){return a.fold(b,c,d,e,k,m)}}});l("ka",["sh",
"b","7"],function(d,e,c){return{fromConfig:function(a,b,f){var g=function(a,b){var d=c.curry(h.classify,a),d=e.bind(b.items,d);return{category:b.category,books:d}};a=c.curry(g,a);b=c.curry(g,b);var h=d.create(b);return e.map(f,a)}}});l("7d",["4j"],function(d){return{resolve:d.create("ephox-chameleon").resolve}});l("yr",["2o"],function(d){return{show:function(e){d.remove(e,"display")},hide:function(e){d.set(e,"display","none")},isShowing:function(e){return d.getRaw(e,"display").isNone()},isHiding:function(e){return d.getRaw(e,
"display").is("none")}}});l("sj",["57"],function(d){return{group:d.ensure(["component","isVisible","refreshUi","destroy"])}});l("si","7d yr sj b 53 1y 3d".split(" "),function(d,e,c,a,b,f,g){return function(h){var k=b.span();f.add(k,d.resolve("toolbar-group"));var m=a.map(h,function(a){return a.component()});g.append(k,m);return c.group({component:function(){return k},isVisible:function(){return a.exists(m,e.isShowing)},refreshUi:function(){a.each(h,function(a){a.refreshUi()})},destroy:function(){a.each(h,
function(a){a.destroy()})}})}});l("kb","si sj b 6 7 59 4a".split(" "),function(d,e,c,a,b,f,g){return{menu:function(d,e){var m=g.create({done:f([]),abort:f(["item"])}),p=function(b){b.done.bind(function(){m.trigger.done()});b.abort.bind(function(a){m.trigger.abort(a.item())});return a.merge(b,{done:m.registry.done,abort:m.registry.abort})},n=c.foldr(e,function(b,c){var d=a.merge(c.structure(),b.structures),e=c.submenus().concat(b.submenus),f=a.merge(c.handlers(),b.actions),g=[c.refreshMenu].concat(b.refreshMenu),
h=[c.destroyer].concat(b.destroyers),k=p(c.events);return{structures:d,submenus:e,refreshMenu:g,actions:f,destroyers:h,events:k}},{structures:{},submenus:[],actions:{},refreshMenu:[],destroyers:[]});return{structure:b.constant(n.structures),init:function(a){c.each(n.refreshMenu,b.apply)},name:b.constant(d),handlers:b.constant(n.actions),submenus:b.constant(n.submenus),events:n.events,destroy:function(){c.each(n.destroyers,b.apply)}}},toolbar:function(a){a=d(a);var b=g.create({escaped:f([]),executed:f([])});
return e.group({component:a.component,isVisible:a.isVisible,refreshUi:a.refreshUi,destroy:a.destroy,events:b.registry})}}});l("kk",["7d","1y","2o","32"],function(d,e,c,a){var b=function(a,b){e.add(a,d.resolve("user-icon"));c.setAll(a,{"background-image":"url("+b+")"})};return{setUrl:b,findAndSetUrl:function(c,d){a.descendant(c,".ephox-pastry-icon-content").each(function(a){b(a,d)})}}});l("fh",["b","1a","w"],function(d,e,c){var a=function(a,c){e.set(a,"aria-pressed",c?"true":"false")};return{expanded:function(a){e.set(a,
"aria-expanded","true")},collapsed:function(a){e.set(a,"aria-expanded","false")},checked:function(a,d){e.set(a,"aria-checked",c(d))},setPressed:a,press:function(b){a(b,!0)},release:function(b){a(b,!1)},pressed:function(b){a(b.element(),b.selected())},enable:function(a){e.set(a,"aria-disabled","false")},disable:function(a){e.set(a,"aria-disabled","true")},tabSelected:function(a,c){e.setAll(a,{"aria-selected":"true","aria-pressed":"true"});d.each(c,function(a){e.setAll(a,{"aria-selected":"false","aria-pressed":"false"})})},
showPanel:function(a){e.set(a,"aria-selected","true");e.set(a,"aria-hidden","false")},hidePanel:function(a){e.set(a,"aria-selected","false");e.set(a,"aria-hidden","true")}}});l("sk",["fh","7"],function(d,e){var c=function(a){a.enable();d.enable(a.element())},a=function(a){a.disable();d.disable(a.element())};return{control:function(b){return{enable:e.curry(c,b),disable:e.curry(a,b)}},ariaPressed:function(a){return{press:e.curry(d.press,a.element()),release:e.curry(d.release,a.element())}}}});l("d4",
["4j"],function(d){return{resolve:d.create("ephox-echo").resolve}});l("8b","a b d4 30 6 7 s 1a 1y l 2p 3d".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var r=c.resolve("aria-help"),q=c.resolve("aria-help-visible"),t=function(a){h.set(a,"role","presentation")},s=function(a,b){h.setAll(a,{role:"application","aria-label":b})},u=function(a){h.set(a,"role","button")},v=function(a,b){h.set(a,"aria-owns",b)},w=function(a,b){h.set(a,"aria-controls",b)},y=function(b,c){var d=a.generate("ephox-aria");h.set(c,
"id",d);w(b,d)},x=function(a,b){h.set(a,"aria-describedby",b)},z=function(a,b){h.set(a,"aria-labelledby",b)},A=function(a,b){h.set(a,"aria-label",b)};return{document:function(a){h.set(a,"role","document")},presentation:t,region:function(a){h.set(a,"role","region")},controls:w,owns:v,disown:function(a){h.remove(a,"aria-owns")},editor:function(b,c,d,e,f){s(b,d);e.each(function(d){var e=m.fromTag("span");t(e);p.append(e,m.fromText(d));d=a.generate("ephox-aria");h.set(e,"id",d);x(c,d);k.add(e,r);!0===
f&&k.add(e,q);p.append(b,e)});return{destroy:function(){h.remove(c,"aria-describedby")}}},inline:function(b,c,d,g,k){s(b,d);var m=[];h.has(c,"id")?v(b,h.get(c,"id")):(d=a.generate("ephox-aria-content"),h.set(c,"id",d),v(b,d),m.push(function(){h.remove(c,"id")}));g.each(function(a){if(h.has(c,"aria-label")){var b=h.get(c,"aria-label");A(c,a);m.push(function(){A(c,b)})}else A(c,a),m.push(function(){h.remove(c,"aria-label")})});return{destroy:function(){e.each(m,f.apply)}}},group:function(a){h.set(a,
"role","group")},toolbar:function(a,b){h.setAll(a,{role:"group","aria-label":b})},toolbarGroup:function(a,b){h.set(a,"role","toolbar");null===b||void 0===b||""===b||d.isArray(b)&&0===b.length||h.set(a,"aria-label",b)},toolbarButton:function(a,b,c,d){h.setAll(a,{role:"button","aria-label":b,"aria-haspopup":""+c});d&&h.set(a,"aria-pressed","false");c&&h.set(a,"aria-expanded","false")},textButton:function(a,b){u(a);t(b)},menu:function(a,b){h.setAll(a,{"aria-label":b,role:"menu"})},menuItem:function(a,
c,d){c=c.map(function(a){return{"aria-label":a}}).getOr({});h.setAll(a,b.merge(c,{role:"menuitem","aria-haspopup":d.getOr(!1)}))},menuItemCheckbox:function(a){h.setAll(a,{role:"menuitemcheckbox","aria-checked":!1})},checkbox:function(a,b){h.setAll(a,{role:"checkbox","aria-label":b,"aria-checked":!1})},dialog:function(a,b){h.setAll(a,{role:"dialog","aria-label":b})},buttonRole:u,button:function(a,b){h.setAll(a,{"aria-label":b,role:"button"})},labelledField:function(b,c,d){var e=m.fromTag("div");t(e);
c+=a.generate("");var g=a.generate("label");d=m.fromHtml("<label>"+d+"</label>");h.set(d,"for",c);h.set(d,"id",g);h.set(b,"id",c);z(b,g);n.append(e,[d,b]);return{element:f.constant(e),field:f.constant(b)}},multiline:function(a){h.set(a,"aria-multiline","true")},textarea:function(a){h.setAll(a,{"aria-multiline":"true",role:"textbox"})},label:A,widget:function(a){h.set(a,"role","widget")},option:function(a){h.set(a,"role","option")},listBox:function(a){h.set(a,"role","listbox")},live:function(a,b,c){h.setAll(a,
{"aria-live":c?c:"polite",id:b})},tabList:function(a){h.set(a,"role","tablist")},tabButton:function(a,b){h.setAll(a,{"aria-label":b,role:"tab"})},tabPanel:function(a){h.setAll(a,{role:"tabpanel"})},linkElements:y,linkTabToPanel:function(a,b){y(a,b)},describedBy:x,labelledBy:z,required:function(a){h.set(a,"aria-required","true")},hidden:function(a,b){b?h.set(a,"aria-hidden",b):h.remove(a,"aria-hidden")},invalid:function(a,b){!0===b?h.set(a,"aria-invalid","true"):h.remove(a,"aria-invalid")}}});l("sl",
["1a","2o","3y"],function(d,e,c){return{disable:function(a){d.set(a,"unselectable","on");e.setAll(a,{"-webkit-user-select":"none","user-select":"none","-ms-user-select":"none"});a.dom().style.setProperty("-moz-user-select","-moz-none");return c.bind(a,"onselectstart",function(){return!1})}}});l("lo",["4j"],function(d){return{resolve:d.create("ephox-pastry").resolve}});l("ln","sl lo 59 4a 1y 3y 2p 2r".split(" "),function(d,e,c,a,b,f,g,h){return function(k,m,p){b.add(k,e.resolve("button"));var n=d.disable(k);
m=m.getOr(k);var r=null,q=b.toggler(k,e.resolve("button-disabled")),t=function(){q.isOn()||u.trigger.click()},s=f.bind(m,"click",t),u=a.create({click:c([])});return{element:function(){return k},name:function(){return p},destroy:function(){s.unbind();n.unbind();h.remove(k)},content:function(a){null!==r&&h.remove(r.element());g.append(k,a.element());r=a},enable:q.off,disable:q.on,disabled:q.isOn,click:t,events:u.registry}}});l("hg",["ln","lo","s","1y","l"],function(d,e,c,a,b){return function(f){var g=
b.fromTag("span");a.add(g,e.resolve("independent-button"));return d(g,c.none(),f)}});l("hh",["53","lo","1a","4e","2r"],function(d,e,c,a,b){return function(f){var g=d.span();c.set(g,"aria-hidden",!0);a.add(g,[e.resolve("icon-content")].concat(f));return{element:function(){return g},destroy:function(){b.remove(g)}}}});l("p6","53 ln lo s 1y l 2p 2r".split(" "),function(d,e,c,a,b,f,g,h){return function(f){var m=d.span();b.add(m,c.resolve("statebutton"));var p=e(d.span(),a.some(m),f);b.add(p.element(),
c.resolve("dependent-button"));g.append(m,p.element());f=b.toggler(m,c.resolve("statebutton-selected"));var n=b.toggler(m,c.resolve("statebutton-disabled"));return{element:function(){return m},destroy:function(){p.destroy();h.remove(m)},name:p.name,content:p.content,enable:function(){n.off();p.enable()},disable:function(){n.on();p.disable()},disabled:function(){return n.isOn()&&p.disabled()},click:p.click,events:p.events,select:f.on,deselect:f.off,selected:f.isOn}}});l("lp",["p6","59","4a"],function(d,
e,c){return function(a){var b=d(a),f=c.create({click:e([])}),g=function(){b.selected()?b.deselect():b.select();f.trigger.click()};b.events.click.bind(g);return{element:b.element,name:b.name,content:b.content,destroy:function(){b.events.click.unbind(g);b.destroy()},enable:b.enable,disable:b.disable,disabled:b.disabled,click:b.click,events:f.registry,select:b.select,deselect:b.deselect,selected:b.selected}}});l("sm","53 hg hh lp lo 59 4a 1y 2p 3d 2r".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){return function(n){var r=
d.span();h.add(r,b.resolve("dropbutton"));var q=d.span();h.add(q,b.resolve("dropbutton-button"));var t=d.span();h.add(t,b.resolve("dropbutton-arrow"));m.append(r,[q,t]);var s=e(),u=a();u.content(c(["ephox-pastry-arrow-icon"]));k.append(q,s.element());k.append(t,u.element());var v=g.create({click:f([]),open:f([]),close:f([])}),w=function(){v.trigger.click()},y=function(){(u.selected()?v.trigger.open:v.trigger.close)()};s.events.click.bind(w);u.events.click.bind(y);return{element:function(){return r},
name:function(){return n},content:s.content,events:v.registry,open:function(){u.select();v.trigger.open()},close:function(){u.deselect();v.trigger.close()},destroy:function(){s.events.click.unbind(w);u.events.click.unbind(y);s.destroy();u.destroy();p.remove(r)},isOpen:function(){return u.selected()}}}});l("sn","53 hh lp lo 7 59 4a 1y 2p 3d 2r".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){return function(n){var r=d.span();h.add(r,a.resolve("dropbutton"));var q=d.span();h.add(q,a.resolve("dropbutton-button"));
var t=d.span();h.add(t,a.resolve("dropbutton-arrow"));m.append(r,[q,t]);var s=c(),u=c();u.content(e(["ephox-pastry-arrow-icon"]));k.append(q,s.element());k.append(t,u.element());var v=g.create({click:f([]),open:f([]),close:f([])}),w=function(){v.trigger.click()},y=function(){(u.selected()?v.trigger.open:v.trigger.close)()};s.events.click.bind(w);u.events.click.bind(y);return{element:b.constant(r),name:b.constant(n),content:s.content,events:v.registry,open:function(){u.select();v.trigger.open()},close:function(){u.deselect();
v.trigger.close()},destroy:function(){s.events.click.unbind(w);u.events.click.unbind(y);s.destroy();u.destroy();p.remove(r)},isOpen:function(){return u.selected()},click:s.click,enable:s.enable,disable:s.disable,disabled:s.disabled,select:s.select,deselect:s.deselect,selected:s.selected}}});l("eh","53 lo 1y l 2p 2r".split(" "),function(d,e,c,a,b,f){return function(g){var h=d.span();c.add(h,e.resolve("text-content"));b.append(h,a.fromText(g));return{element:function(){return h},destroy:function(){f.remove(h)}}}});
l("kl","sk 7d 8b hg sm sn hh eh lp s 1a 1y 3d 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q){var t=function(a,b,e,f){c.toolbarButton(a.element(),b,e,f);b=d.control(a);e=d.ariaPressed(a);return{enable:b.enable,disable:b.disable,press:e.press,release:e.release,destroy:function(){a.destroy()}}},s=function(a,b,c,d,f,k,n,q){n=m.from(n).fold(function(){return q(f)},function(a){return a(f,b)});k=m.from(k).getOr(!1);a=a(b);c=g([e.resolve("icon"),e.resolve(c)]);k=!0===k?[h(q(f)).element()]:[];r.append(c.element(),
k);a.content(c);a.events.click.bind(function(){d()});p.set(a.element(),"title",n);a.initAria=t;return a},u=function(a,b){q.descendant(a,b).bind(function(a){c.hidden(a,"true")})},v=function(a,b,c,d,f,g,h,k){a=s(a,b,c,d,f,g,h,k);n.add(a.element(),e.resolve("split-"+b));u(a.element(),".ephox-pastry-dropbutton-arrow");u(a.element(),".ephox-pastry-dropbutton-button");q.descendant(a.element(),".ephox-pastry-dropbutton-arrow .ephox-pastry-icon-content").bind(function(a){n.add(a,e.resolve("icon"));n.add(a,
e.resolve("arrow-"+b))});return a};return{aria:t,typical:function(b,c,d,e,f,g,h){return s(a,b,c,d,e,f,g,h)},toggle:function(a,b,c,d,e,f,g){return s(k,a,b,c,d,e,f,g)},splitToggle:function(a,b,c,d,e,g,h){return v(f,a,b,c,d,e,g,h)},split:function(a,c,d,e,f,g,h){return v(b,a,c,d,e,f,g,h)}}});l("km",["4j"],function(d){return{resolve:d.create("ephox-gopher").resolve}});l("so",["km","s","1y","4h","32"],function(d,e,c,a,b){return function(f){var g=d.resolve(f);return{set:function(a){c.add(a,g)},up:function(a){return c.has(a,
g)?e.some(a):b.ancestor(a,"."+g)},all:function(b){return a.descendants(b,"."+g)},first:function(a){return b.descendant(a,"."+g)},is:function(a){return c.has(a,g)}}}});l("kn",["km","so","1a","1y"],function(d,e,c,a){var b=e("item"),f=d.resolve("disabled-item"),g="data-"+d.resolve("item-value");return{set:function(a,d){b.set(a);c.set(a,g,d)},get:function(a){return c.get(a,g)},up:b.up,all:b.all,disable:function(b){a.add(b,f)},enable:function(b){a.remove(b,f)},isEnabled:function(b){return!a.has(b,f)}}});
l("ko","b km so kn s 1a 1y 32".split(" "),function(d,e,c,a,b,f,g,h){var k=c("menu"),m="data-"+e.resolve("menu-value"),p=e.resolve("active-menu");return{set:function(a,b){k.set(a);f.set(a,m,b)},active:function(a){return h.descendant(a,"."+p)},inactive:function(a){a=k.all(a);return d.filter(a,function(a){return!g.has(a,p)})},activate:function(a,b){var c=k.all(a);d.each(c,function(a){g.remove(a,p)});g.add(b,p)},up:k.up,all:k.all,submenu:function(c,d,e){e=a.get(e);return(d.hasOwnProperty(e)?b.from(d[e]):
b.none()).bind(function(a){return h.descendant(c,"["+m+'="'+a+'"]')})}}});l("kp",["so","7"],function(d,e){var c=d("submenu"),a=d("main-menu");return{main:e.constant(a),submenu:e.constant(c)}});l("gr","b km kn ko kp 53 7 1a 1y l 2p 3d".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var r=function(a,b,d){c.set(d,b);h.set(d,"tabindex",-1);return d},q=function(a,b,c){return t(a,b,c,!1)},t=function(a,b,c,d){var g=m.fromTag("li",a.dom()),h=f.span();k.add(h,e.resolve("item-text"));!0===d&&k.add(h,e.resolve("item-ellipsis"));
p.append(h,m.fromText(c));p.append(g,h);r(a,b,g);return g},s=function(a){a=m.fromTag("li",a.dom());k.add(a,e.resolve("separator"));return a},u=function(a,b){return"-"!==b.value()?q(a,b.value(),b.text()):s(a)},v=function(b,c,e){var f=m.fromTag("ol",b.dom());a.set(f,c);b=d.map(e,g.curry(u,b));n.append(f,b);return f},w=function(b,c){var d=m.fromTag("div",b.dom());a.set(d,c);return d};return{item:q,ellipsisItem:function(a,b,c){return t(a,b,c,!0)},mainmenu:function(a,c,d){a=v(a,c,d);b.main().set(a);return a},
submenu:function(a,c,d){a=v(a,c,d);b.submenu().set(a);return a},widget:w,widgetSubmenu:function(a,c){var d=w(a,c);b.submenu().set(d);return d},separator:s,custom:r,enableItem:c.enable,disableItem:c.disable}});l("kq",[],function(){var d=function(d,c){if(void 0===d)throw"Cannot intersperse undefined";if(1>=d.length)return d;var a=[];a.push(d[0]);for(var b=1;b<d.length;b++)a.push(c()),a.push(d[b]);return a};return{intersperse:function(e,c){return d(e,function(){return c})},intersperseThunk:d,untabulate:function(d){var c=
[],a;for(a in d)if(Object.prototype.hasOwnProperty.call(d,a))for(var b=d[a],f=0;f<b.length;f++){var g=b[f];c[f]=c[f]||{};c[f][a]=g}return c},tabulate:function(d){for(var c={},a=0;a<d.length;a++){var b=d[a],f;for(f in b)if(Object.prototype.hasOwnProperty.call(b,f)){var g=b[f];Object.prototype.hasOwnProperty.call(c,f)||(c[f]=[]);c[f][a]=g}}return c}}});l("sp",[],function(){return{css:function(d){var e=/^[a-zA-Z]/.test(d)?"":"e";d=d.replace(/[^\w]/gi,"-");return e+d}}});l("sq",["b"],function(d){return{splits:function(e,
c){if(0===c.length)return[e];var a=d.foldl(c,function(a,b){if(0===b)return a;var c=e.substring(a.prev,b);return{prev:b,values:a.values.concat([c])}},{prev:0,values:[]}),b=c[c.length-1];return b<e.length?a.values.concat(e.substring(b)):a.values}}});l("kr",["sp","sq"],function(d,e){return{cssSanitise:function(c){return d.css(c)},splits:function(c,a){return e.splits(c,a)}}});l("ck","kb kk kl a b 8b gr kq 7 s kr l 3d q".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q){var t=function(a,c){var e=b.flatten(c);
return d.menu(a,e)},s=function(a){return b.map(a,function(a){a=b.map(a,function(a){return a.items()});return b.flatten(a)})};return{create:function(d,v,w){var y=d.name,x=d.textkey,z=d.menuTextkey,A=d.tooltip,l=d.label,B=m.from(d.icon),C=k.constant(void 0!==d.contentFocus?d.contentFocus:!1),F=n.fromDom(q),E=a.isString(x)?p.cssSanitise(y):y,G=w(x),z=w(z),H=g.mainmenu(F,E+"-menu",[]),I=c.toggle(y,E,k.identity,x,l,A,w);B.filter(a.isString).each(function(a){e.findAndSetUrl(I.element(),a)});var K=I.initAria(I,
G,!0,d.toggle);d=s(v);var J=t(E,v);v=h.intersperseThunk(d,function(){return[g.separator(F)]});f.menu(H,z);r.append(H,b.flatten(v));return{button:k.constant(I),contentFocus:C,destroy:function(){I.destroy();J.destroy();K.destroy()},element:k.constant(H),events:J.events,handlers:J.handlers,icon:k.constant(B),init:J.init,label:k.constant(G),name:J.name,structure:J.structure,submenus:J.submenus,textkey:k.constant(x),menuTextkey:k.constant(z),updateMenu:k.noop,enable:K.enable,disable:K.disable}}}});l("kc",
["sh","ck","b","7","s"],function(d,e,c,a,b){var f=function(a,c){return b.some(c(a))},g=function(a,c){return b.some(c(a,[]))},h=function(k,m){var p=a.curry(h,k);return d.cata(m,b.none,b.none,f,function(a,d,f){d=c.map(d,function(a){return c.bind(a.books,p)});a=e.create(a,d,k);return b.some(f(a,[]))},g,function(a,d,e){d=c.bind(d,p);return b.some(e(a,d))}).toArray()};return{build:function(a,b){return{items:c.bind(a.books,function(a){return h(b,a)}),category:a.category}}}});l("cd",["ka","kb","kc","b",
"8b"],function(d,e,c,a,b){return{build:function(f,g,h){var k=h.translations();f=d.fromConfig(g.toolbar(),g.menu(),f);f=a.map(f,function(a){return c.build(a,k)});return a.map(f,function(a){var c=e.toolbar(a.items);a=a.category;b.toolbarGroup(c.component(),k(a));return c})}}});l("ce",["2v"],function(d){var e=d.immutable("toolbar","menu");d=d.immutable("smartview","translations");var c=function(a){return function(){return a.apply(null,arguments)}};return{blueprints:c(e),env:c(d)}});l("ci",["6p"],function(d){var e=
function(){return/(?:(?:[A-Za-z]{3,9}:(?:\/\/))(?:[-.~*+=!&;:'%@?^${}(),\w]+@)?[A-Za-z0-9-]+(?:\.[A-Za-z0-9-]+)*|(?:www\.|[-;:&=+$,.\w]+@)[A-Za-z0-9-]+(?:\.[A-Za-z0-9-]+)*)(?::[0-9]+)?(?:\/[-+~%.()\/\w]*)?(?:\?(?:[-.~*+=!&;:'%@?^${}(),\w]+))?(?:#(?:[-.~*+=!&;:'%@?^${}(),\/\w]+))?/g};return{tokens:function(c,a){return c.replace(/\{(\d+)\}/g,function(b,d,e,h){d=parseInt(d,10);if(void 0===a[d])throw"No value for token: "+b+" in translation: "+c;return a[d]})},link:e,autolink:function(){var c=e().source;
return new d("("+c+")[-.~*+=!&;:'%@?#^${}(),]*","g")}}});l("7b","a 7 ci 1g 4q 9".split(" "),function(d,e,c,a,b,f){var g=b.generate([{raw:["text"]},{key:["key"]},{pkey:["key","params"]}]),h=function(b){var d=a.get(b);if(1<arguments.length||/\{(\d+)\}/.test(d)){for(var e=new f(arguments.length-1),g=1;g<arguments.length;g++)e[g-1]=arguments[g];return c.tokens(d,e)}return d};return{get:function(a){if(d.isString(a))throw"string passed to I18n.get:"+a;return a.fold(e.identity,h,h)},has:a.has,translate:h,
raw:g.raw,key:function(b){a.get(b);return g.key(b)},pkey:function(b,c){a.get(b);return g.pkey(b,c)},cata:function(a,b,c,d){return a.fold(b,c,d)}}});l("kd","8b 53 7b 34 59 4a 1y 4e 3y l 2p 3d 2r".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){return function(q,t){var s=void 0!==t?t:"info",u=e.div();h.add(u,[a.resolve("banner"),a.resolve("banner-"+s)]);s=e.div();g.add(s,a.resolve("banner-message"));p.append(s,m.fromText(q));var v=e.div();g.add(v,a.resolve("banner-buttons"));var w=m.fromTag("span");
g.add(w,a.resolve("banner-close"));p.append(v,w);d.button(w,c.translate("banner.close"));n.append(u,[s,v]);var y=k.bind(w,"click",function(){x.trigger.close()}),x=f.create({close:b([])});return{element:function(){return u},action:function(a){p.prepend(v,a.element())},destroy:function(){y.unbind();r.remove(u)},events:x.registry}}});l("cf","7 s kd 1a 3y l 2p 37".split(" "),function(d,e,c,a,b,f,g,h){return function(k,m){var p=void 0!==m?m:"error",n=k.description(),r=k.link(),q=c(n,p),t=e.none(),s=function(a,
c){return b.bind(a,"click",function(a){a.kill();h.open(c.url())})},p=function(b){var c=f.fromTag("a");a.set(c,"href",b.url());a.set(c,"target","_blank");var h=f.fromText(b.text());t=e.some(s(c,b));g.append(c,h);q.action({element:d.constant(c)})};null!==r&&r.url()&&r.text()&&p(r);return{element:q.element,action:q.action,destroy:function(){q.destroy();t.each(function(a){a.unbind()})},events:q.events}}});l("sv",["57"],function(d){return{dropdown:d.exactly("enable disable select clear selectElement populate tick untick activate deactivate".split(" ")),
menu:d.exactly(["enable","disable"]),general:d.exactly("enable disable select deselect selected element".split(" ")),widget:d.exactly("enable disable select deselect press release".split(" ")),palette:d.exactly(["show","hide"])}});l("ys",["gr","l","2p"],function(d,e,c){return{generateItem:function(a,b,f,g){return f.fold(function(){return d.item(a,b.value(),g(b.textkey()))},function(f){f=f(b);var g=e.fromTag("li",a.dom());c.append(g,f);return d.custom(a,b.value(),g)})},generateSeparator:function(a,
b,f){var g=d.separator(a);c.append(g,e.fromText(f(b),a.dom()));return g}}});l("yt","a b fh lo 7 s 1a 1y 4h".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(a,b){var c=e.find(a,function(a){return a.value()===b});return f.from(c)},p=function(a){a=k.children(a,".ephox-pastry-toggle-list-item-selected");e.each(a,function(a){h.remove(a,"ephox-pastry-toggle-list-item-selected");c.checked(a,!1)})};return{updateDropdown:function(c,e,g,k,p){e.fold(c.clear,b.noop,function(b){p.fold(function(){(d.isString(b)?
m(k,b):f.some(b)).each(c.select)},function(d){d=d(b);var e=a.resolve("arrow-righticon");h.add(d,e);c.selectElement(d)})});g.fold(c.disable,b.noop,c.enable)},tick:function(a,b){p(a);var d=k.descendants(a,".ephox-gopher-item"),d=e.find(d,function(a){return g.get(a,"data-ephox-gopher-item-value")===b});void 0!==d&&null!==d&&(h.add(d,"ephox-pastry-toggle-list-item-selected"),c.checked(d,!0))},untick:p,activate:function(a){h.add(a,"ephox-pastry-statebutton-selected")},deactivate:function(a){h.remove(a,
"ephox-pastry-statebutton-selected")}}});l("su",["fh","gr","lo","7","1y"],function(d,e,c,a,b){var f=c.resolve("toggle-list-item-selected"),g=function(a){e.enableItem(a);d.enable(a)},h=function(a){e.disableItem(a);d.disable(a)},k=function(a){b.remove(a,f);d.checked(a,!1)},m=function(a){b.add(a,f);d.checked(a,!0)};return{control:function(b){return{enable:a.curry(g,b),disable:a.curry(h,b)}},selected:function(c){return{deselect:a.curry(k,c),select:a.curry(m,c),selected:a.curry(b.has,c,f)}}}});l("sw",
["kk","a","8b","53","4e"],function(d,e,c,a,b){var f=function(d){var e=a.span();c.hidden(e,!0);b.add(e,["ephox-pastry-icon-content","ephox-chameleon-icon"].concat([d]));return[e]},g=function(e){var f=a.span();c.hidden(f,!0);b.add(f,["ephox-pastry-icon-content","ephox-chameleon-"+e.value]);d.setUrl(f,e.icon);return[f]},h=function(a){return f(!0===a.icon?"ephox-chameleon-"+a.value:a.icon)};return{generate:f,generateFrom:function(a){return void 0===a.icon?[]:(e.isString(a.icon)?g:h)(a)}}});l("am","8b 30 c 7 1a 2o l 2p 2r 2b 3x".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p){var n=c.detect().browser.isFirefox(),r={position:"absolute",left:"-9999px"},q=function(a,b){var c=g.fromTag("span",a.dom());d.presentation(c);var e=g.fromText(b,a.dom());h.append(c,e);return c},t=function(a,c){var d=e.generate("ephox-echo-voice");b.set(c,"id",d);b.set(a,"aria-describedby",d)},s=function(a,c,d){var e=m.owner(c),g=q(e,d);n&&t(c,g);b.setAll(g,a(d));f.setAll(g,r);h.append(c,g);p(function(){b.remove(g,"aria-live");k.remove(g)},1E3)};c=a.curry(s,function(a){return{"aria-live":"polite",
"aria-atomic":"true","aria-label":a}});a=a.curry(s,a.constant({"aria-live":"assertive","aria-atomic":"true",role:"alert"}));return{describe:function(a,b){var c=m.owner(a),c=q(c,b);f.set(c,"display","none");d.hidden(c,!0);t(a,c);return c},speak:c,shout:a,tokenSelector:function(){return'span[id^="ephox-echo-voice"]'}}});l("yu","su sw 7d 8b am gr 7 s 59 4a 1y l 2p 3d 2r 32 q".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u){var v=n.fromDom(u),w=c.resolve("label-default");return function(u,x){var z=
m.create({populate:k(["items"])}),A=function(b){var d=u(b.textkey),d=f.item(v,b.name+"-menu-trigger",d);p.add(d,c.resolve("menu-more"));b=e.generate("ephox-chameleon-"+b.name);q.prepend(d,b);a.menuItem(d,h.none(),h.some(!0));return d}(x),l=function(a){a=n.fromText(a);B(a)},B=function(a){s.child(A,".ephox-gopher-item-text").each(function(b){t.empty(b);r.append(b,a);p.remove(b,w)})},C=d.control(A);return{element:g.constant(A),populate:function(a){z.trigger.populate(a)},select:function(a){s.child(A,
b.tokenSelector()).each(t.remove);var c=b.describe(A,x.describe(a));r.append(A,c);a=u(a.textkey());l(a)},selectElement:B,disable:C.disable,enable:C.enable,clear:function(){l(u(x.textkey));s.child(A,".ephox-gopher-item-text").each(function(a){p.add(a,w)})},destroy:function(){t.remove(A)},events:z.registry}}});l("sr","sv ys yt yu b 8b gr km 7 59 4a 1a 1y l 3d 2r q".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u){var v=q.fromDom(u),w="data-"+h.resolve("item-value"),y=function(a){a=g.submenu(v,
a+"-menu",[]);r.remove(a,"ephox-gopher-main-menu");r.add(a,"ephox-gopher-submenu");return a},x=function(a,b){var c=n.get(b,"data-ephox-gopher-menu-value"),d={};d[a.name+"-menu-trigger"]=c;return d};return{init:function(g,h){var r=y(h.name);f.menu(r,g(h.textkey,!1));var q=x(h,r),u=a(g,h),l=function(a){a=b.bind(a,function(a){var c=b.map(a.items(),function(a){a=e.generateItem(v,a,h.render,g);f.menuItemCheckbox(a);return a});return a.label().fold(k.constant(c),function(a){return[e.generateSeparator(v,
a,g)].concat(c)})});s.empty(r);t.append(r,a)},E=p.create({done:m([]),abort:m(["item"])}),G={};b.each(h.values,function(a){G[a.value()]=function(a){a=n.get(a,w);h.action(a);E.trigger.done()}});u.events.populate.bind(function(a){l(a.items())});return{items:k.constant([u.element()]),structure:k.constant(q),submenus:k.constant([r]),refreshMenu:function(){h.updateDropdown(d.dropdown({enable:u.enable,disable:u.disable,select:u.select,clear:u.clear,selectElement:u.selectElement,populate:u.populate,tick:k.curry(c.tick,
r),untick:k.curry(c.untick,r),activate:k.noop,deactivate:k.noop}))},destroyer:function(){u.destroy()},handlers:k.constant(G),events:E.registry}}}});l("ss","su sv sw 8b gr 7 s 59 4a l 3d q".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var r=m.fromDom(n);return{init:function(m,n){var s=m(n.textkey),u=(!0===n.hasDialog?b.ellipsisItem:b.item)(r,n.value,s),v=d.control(u),w=!0===n.toggle?d.selected(u):{select:f.noop,deselect:f.noop,selected:f.constant(!1)};!0===n.toggle?a.menuItemCheckbox(u):a.menuItem(u,
g.some(s),g.some(!1));var y=function(){n.updateGeneral(e.general({disable:v.disable,enable:v.enable,select:w.select,deselect:w.deselect,selected:w.selected,element:f.constant(u)}))},x=k.create({done:h([]),abort:h(["item"])}),s={};s[n.value]=function(){x.trigger.done();n.action();y()};var z=c.generateFrom(n);p.prepend(u,z);return{items:f.constant([u]),structure:f.constant({}),submenus:f.constant([]),refreshMenu:y,handlers:f.constant(s),destroyer:f.identity,events:x.registry}}}});l("st","su kk sw 7d 8b gr 6 7 s 1a 1y l 3d q".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,r,q){var t=n.fromDom(q),s=function(c){return{submenu:function(a){var d=a.textkey();a=a.element();b.menu(a,c(d));p.remove(a,"ephox-gopher-main-menu");p.add(a,"ephox-gopher-submenu");return a},item:function(d){var e=d.textkey(),e=c(e);d=f.item(t,d.name()+"-menu-trigger",e);p.add(d,a.resolve("menu-more"));b.menuItem(d,k.some(e),k.some(!0));return d}}};return{nested:function(a,b,f){f=s(a);a=f.submenu(b);var k=m.get(a,"data-ephox-gopher-menu-value");f=f.item(b);var p={};
p[b.name()+"-menu-trigger"]=k;var k=g.merge(p,b.structure()),n=c.generate("ephox-chameleon-"+b.name());r.prepend(f,n);b.icon().each(function(a){0<n.length&&e.setUrl(n[0],a)});var q=d.control(f),p=void 0!==b.destroyer?b.destroyer:void 0!==b.destroy?b.destroy:h.noop;return{items:h.constant([f]),structure:h.constant(k),submenus:h.constant([a].concat(b.submenus())),refreshMenu:function(){b.updateMenu({enable:q.enable,disable:q.disable})},destroyer:p,handlers:b.handlers,events:b.events}}}});l("kt","su sv sw 7d 8b gr 7 s 59 4a 4b 1y 4e 1b l 2z 2p 3d 38 q".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v,w,y){var x=t.fromDom(y),z=a.resolve("menu-widget"),A=function(a,b){var c=f.widgetSubmenu(x,b);u.append(c,a.element());r.add(a.element(),[z,"ephox-gopher-item"]);return c},l=function(b,d,e){b=b(d.textkey());b=f.item(x,e,b);n.add(b,a.resolve("menu-more"));e=c.generate(a.resolve(e));v.prepend(b,e);return b};y=function(a,c){var f=c.instance(),n=f.name(),r=n+"-submenu",q=A(f,r),s=l(a,f,n);b.menu(q,a(f.menuTextkey()));b.menuItem(s,h.some(a(f.textkey())),h.some(!0));
var t=d.control(s),u={};u[n]=r;var v=m.create({done:p([],f.events.done),abort:k(["item"])});f.events.abort.bind(function(){v.trigger.abort(s)});return{items:g.constant([s]),structure:g.constant(u),submenus:g.constant([q]),refreshMenu:function(){f.updateWidget(e.widget({enable:t.enable,disable:t.disable,select:g.noop,deselect:g.noop,press:g.noop,release:g.noop}))},destroyer:f.destroy,handlers:g.constant({}),events:v.registry}};return{widget:y,inline:function(c,r){var v=r.instance(),y=v.name();n.add(v.element(),
a.resolve("menu-inline-widget"));var z=t.fromTag("li");u.append(z,v.element());var A=f.custom(x,y,z),l=d.control(A);b.menuItem(A,h.some(c(v.textkey())),h.some(!1));z={};z[y]=function(a){var b=s.active().filter(function(b){return w.ancestor(b,g.curry(q.eq,a))});v.element().dom().click();b.each(s.focus)};var D=m.create({done:p([],v.events.done),abort:k(["item"])});v.events.abort.bind(function(){D.trigger.abort(A)});return{items:g.constant([A]),structure:g.constant({}),submenus:g.constant([]),refreshMenu:function(){v.updateInlineWidget(e.widget({enable:l.enable,
disable:l.disable,select:g.noop,deselect:g.noop,press:g.noop,release:g.noop}))},destroyer:v.destroy,handlers:g.constant(z),events:D.registry}},split:y,styles:g.constant(z)}});l("kx","7d 53 s 1y 2o 3y 2p 32 m".split(" "),function(d,e,c,a,b,f,g,h,k){var m=d.resolve("keyfocus"),p=function(c,d){var h=e.span();b.set(h,"display","none");a.add(h,m);g.append(c,h);return f.bind(h,"click",function(a){d();a.kill()})};return{onButton:function(a){return p(a.element(),a.click)},custom:p,trigger:function(a){var b=
"."+m;a=k.is(a,b)?c.some(a):h.descendant(a,b);a.each(function(a){a.dom().click()});return a}}});l("al",["2v"],function(d){return{menu:d.immutableBag(["focusActive"],[])}});l("t4","b km kn s 1y 32".split(" "),function(d,e,c,a,b,f){var g=e.resolve("item-selected"),h=function(a,c){b.add(c,g)},k=function(a,c){b.remove(c,g)};return{is:function(a){return b.has(a,g)},none:function(a){var b=c.all(a);d.each(b,function(b){k(a,b)})},selectAll:function(a,e){var f=c.all(a);d.each(f,function(a){b.remove(a,g)});
d.each(e,function(a){b.add(a,g)})},select:h,deselect:k,selected:function(a){return f.descendant(a,"."+g)},first:function(b){var d=c.all(b);return a.from(d[0]).map(function(a){h(b,a);return a})},last:function(b){var d=c.all(b);return a.from(d[d.length-1]).map(function(a){h(b,a);return a})}}});l("t3","b t4 kn 7 s 1b".split(" "),function(d,e,c,a,b,f){var g=function(e,g){var h=c.all(e),k=d.findIndex(h,function(a){return f.eq(g,a)});return 0<=k?b.some({index:a.constant(k),all:a.constant(h)}):b.none()},
h=function(a,b){return 0===b?a.length-1:b-1},k=function(a,b){return b===a.length-1?0:b+1},m=function(a,b,c){return g(a,b).map(function(d){var f=c(d.all(),d.index());d=d.all()[f];e.deselect(a,b);e.select(a,d);return d})};return{first:function(a){var d=c.all(a);return b.from(d[0]).map(function(b){e.select(a,b);return b})},prev:function(a,b){return m(a,b,h)},next:function(a,b){return m(a,b,k)}}});l("an",[],function(){var d=function(d){return function(){return d}};return{BACKSPACE:d([8]),TAB:d([9]),ENTER:d([13]),
SHIFT:d([16]),CTRL:d([17]),ALT:d([18]),CAPSLOCK:d([20]),ESCAPE:d([27]),SPACE:d([32]),PAGEUP:d([33]),PAGEDOWN:d([34]),END:d([35]),HOME:d([36]),LEFT:d([37]),UP:d([38]),RIGHT:d([39]),DOWN:d([40]),INSERT:d([45]),DEL:d([46]),META:d([91,93,224]),F10:d([121])}});l("wd",["b","an","w"],function(d,e,c){return{isCommand:function(a,b){var f=[];d.each(b,function(a){a="string"===typeof a?[a.toUpperCase().charCodeAt(0)]:a;f=f.concat(a)});var g=function(a){return 0<d.filter(f,function(b){return d.contains(e[a](),
b)}).length};if(!!a.altKey!==g("ALT")||!!a.shiftKey!==g("SHIFT")||!!a.ctrlKey!==g("CTRL")||!!a.metaKey!==g("META"))return!1;var g=null!==a.charCode&&void 0!==a.charCode&&0!==a.charCode?c.fromCharCode(a.charCode).toUpperCase().charCodeAt(0):a.which,h=e.CTRL().concat(e.ALT()).concat(e.SHIFT()).concat(e.META()),k=d.filter(f,function(a){return!d.contains(h,a)});return 1<k.length?!1:0===k.length&&void 0===a.which||k[0]===g}}});l("wf",[],function(){return{stop:function(d){d.preventDefault();d.stopPropagation&&
d.stopPropagation()}}});l("yw",["b","1o","an"],function(d,e,c){return function(a,b){var f=b?a.slice(0):[],g=b,h=b?d.map(e.values(c),function(a){return a()}):[];return{swallowShortcuts:function(a){f=a.slice(0)},yieldShortcuts:function(a){f=d.difference(f,a)},swallowChars:function(){g=!0},yieldChars:function(){g=!1},swallowKeys:function(a){h=a.slice(0)},yieldKeys:function(a){h=d.difference(h,a)},process:function(a,b){a.fold(function(a){d.contains(f,a)&&b()},function(a){d.contains(h,a)&&b()},function(){g&&
b()})}}}});l("wh",["b","1o","an"],function(d,e,c){var a={BACKSPACE:c.BACKSPACE,TAB:c.TAB,ENTER:c.ENTER,CAPSLOCK:c.CAPSLOCK,ESCAPE:c.ESCAPE,SPACE:c.SPACE,PAGEUP:c.PAGEUP,PAGEDOWN:c.PAGEDOWN,END:c.END,HOME:c.HOME,LEFT:c.LEFT,UP:c.UP,DOWN:c.DOWN,RIGHT:c.RIGHT,INSERT:c.INSERT,DEL:c.DEL};return{getSpecial:function(b){var c=null;e.each(a,function(a,e){d.contains(a(),b)&&(c=e)});return c},noModifiers:function(a){return!(a.metaKey||a.altKey||a.ctrlKey)},isCharCode:function(a){return a.charCode===a.keyCode}}});
l("yx","b wd wh an s w".split(" "),function(d,e,c,a,b,f){var g=function(a,c){return b.from(d.find(c,function(b){return e.isCommand(a,b)}))},h=function(a){return c.isCharCode(a)?b.none():b.from(c.getSpecial(a.keyCode))};return{identify:function(b,c){return{fold:function(d,e,r){g(b,c).fold(function(){h(b).fold(function(){r(b.which&&f.fromCharCode(b.which))},function(b){e(a[b]())})},d)}}},shortcut:g,special:h}});l("we",["wf","yw","yx","7"],function(d,e,c,a){return function(b,f){var g=!1,h=e(b,f);return{on:function(){g=
!0},off:function(){g=!1},isOn:function(){return g},handle:function(a){return function(b){g&&a(b.raw())}},stop:function(e){var f=c.identify(e,b);h.process(f,a.curry(d.stop,e))},swallowShortcuts:h.swallowShortcuts,yieldShortcuts:h.yieldShortcuts,swallowChars:h.swallowChars,yieldChars:h.yieldChars,swallowKeys:h.swallowKeys,yieldKeys:h.yieldKeys}}});l("wg",["59","4a"],function(d,e){return function(){return e.create({character:d(["character"]),space:d(["shift","stopper"]),left:d(["shift","stopper"]),right:d(["shift",
"stopper"]),backspace:d(["shift","stopper"]),tab:d(["shift","stopper"]),enter:d(["shift","stopper"]),capslock:d(["shift","stopper"]),escape:d(["shift","stopper"]),pageup:d(["shift","stopper"]),pagedown:d(["shift","stopper"]),end:d(["shift","stopper"]),home:d(["shift","stopper"]),down:d(["shift","stopper"]),up:d(["shift","stopper"]),insert:d(["shift","stopper"]),del:d(["shift","stopper"]),command:d(["command"])})}});l("oc","b 6 wd we wf wg wh w".split(" "),function(d,e,c,a,b,f,g,h){return function(k){var m=
e.merge({shortcuts:[],swallow:!1},k),p=f(),n=a(m.shortcuts,m.swallow),r=function(a){return d.find(m.shortcuts,function(b){return c.isCommand(a,b)})||null},q=function(a,b,c){s(a);p.trigger[b].apply(void 0,c)},t=function(a){return function(){n.isOn()&&b.stop(a)}};k=n.handle(function(a){var b=r(a);null!==b?q(a,"command",[b]):(b=g.getSpecial(a.keyCode),g.noModifiers(a)&&null!==b&&(b=b.toLowerCase(),q(a,b,[a.shiftKey,t(a)])))});var s=function(a){n.isOn()&&n.stop(a)},u=n.handle(function(a){if(g.noModifiers(a))g.isCharCode(a)||
null===g.getSpecial(a.keyCode)?null!==r(a)?s(a):a.which&&q(a,"character",[h.fromCharCode(a.which)]):s(a);else return!1});return{off:n.off,on:n.on,events:p.registry,swallowShortcuts:n.swallowShortcuts,yieldShortcuts:n.yieldShortcuts,swallowChars:n.swallowChars,yieldChars:n.yieldChars,swallowKeys:n.swallowKeys,yieldKeys:n.yieldKeys,keypress:u,keydown:k}}});l("t5","b kn an oc 7 59 4a 3y".split(" "),function(d,e,c,a,b,f,g,h){return function(k){var m=g.create({mouseover:f(["item"]),click:f(["item"])}),
p=[],n=a({shortcuts:k.shortcuts,swallow:k.swallow});k=k.tabs?[c.TAB()]:[];n.swallowKeys([c.UP(),c.DOWN(),c.ENTER(),c.SPACE(),c.ESCAPE()].concat(k));var r=function(){d.each(p,function(a){a.mouseover().unbind();a.click().unbind();a.keydown().unbind()});p=[];n.off()};return{destroy:function(){r()},attach:function(a){r();p=d.map(a,function(a){var c=h.bind(a,"mouseover",function(a){e.up(a.target()).each(m.trigger.mouseover)}),d=h.bind(a,"click",function(a){e.up(a.target()).each(m.trigger.click)});a=h.bind(a,
"keydown",function(a){n.keydown(a)});return{mouseover:b.constant(c),click:b.constant(d),keydown:b.constant(a)}});n.on()},detach:r,simulateKey:function(a){n.keydown(a)},events:m.registry,keys:n.events}}});l("bs",["2o"],function(d){var e=function(c){return"rtl"===d.get(c,"direction")?"rtl":"ltr"};return{onDirection:function(c,a){return function(b){return"rtl"===e(b)?a:c}},getDirection:e}});l("b0",["7","2y","2o"],function(d,e,c){var a=function(a,f,g,h){var k=c.get(a,f);void 0===k&&(k="");g=k===g?h:g;
k=d.curry(c.set,a,f,k);a=d.curry(c.set,a,f,g);return e(k,a,!1)};return{toggler:function(b){return a(b,"visibility","hidden","visible")},displayToggler:function(b,c){return a(b,"display","none",c)},isVisible:function(a){a=a.dom();return!(0>=a.offsetWidth&&0>=a.offsetHeight)}}});l("kj","b t3 t4 t5 kn ko kp 6 7 59 4a 1b bs l 2z 21 b0 q".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v){return function(w,y){var x=p.create({select:m(["item"]),active:m(["item"]),show:m(["menu"]),hide:m(["menu"]),
collapse:m(["menu"]),expand:m(["menu","trigger"]),escaped:m([])}),z=a({shortcuts:[],swallow:[],tabs:y.tabs}),A={},l=function(a){f.activate(w,a)},B=function(){var a=f.inactive(w);d.each(a,function(a){g.submenu().is(a)&&x.trigger.hide(a)})},C=function(a){b.isEnabled(a)&&f.submenu(w,A,a).each(function(b){x.trigger.expand(b,a)})},F=function(a){f.up(a).each(function(b){l(b);c.selectAll(b,[a]);x.trigger.active(a)})},E=function(a){f.active(w).bind(function(b){c.selected(b).orThunk(function(){return e.first(b)}).each(function(c){a(b,
c)})})},G=function(a){E(function(c,d){b.isEnabled(d)&&a(c,d)})},H=function(a){E(function(b,c){a(b,c).each(function(a){n.eq(c,a)||(f.submenu(w,A,c).each(x.trigger.collapse),x.trigger.active(a))})})},I=k.curry(H,e.prev),K=k.curry(H,e.next),J=function(){g.main().first(w).each(function(a){l(a);c.selected(a).each(x.trigger.active)})},L=function(a){t.active().fold(a.stopper(),function(b){!1===d.contains(["input"],s.name(b))&&a.stopper()()});G(function(a,b){f.submenu(w,A,b).fold(function(){g.submenu().is(a)&&
(x.trigger.collapse(a),J())},function(a){x.trigger.expand(a,b);c.none(a);c.first(a).each(x.trigger.active);l(a)})})},H=function(a){t.active().fold(a.stopper(),function(b){!1===d.contains(["input"],s.name(b))&&a.stopper()()});G(function(a,b){g.submenu().is(a)&&(x.trigger.collapse(a),J())})},N=function(a){G(function(c,d){var e=b.get(d);A.hasOwnProperty(e)&&void 0!==A[e]?L(a):x.trigger.select(d)})},M=function(a){a.shift()?I(a):K(a)};z.keys.up.bind(I);z.keys.down.bind(K);y.tabs&&z.keys.tab.bind(M);z.keys.enter.bind(N);
z.keys.space.bind(N);z.keys.escape.bind(function(a){a.stopper()();E(function(a,b){g.submenu().is(a)?(x.trigger.collapse(a),J()):x.trigger.escaped()})});"ltr"===r.getDirection(w)?(z.keys.left.bind(H),z.keys.right.bind(L)):(z.keys.right.bind(H),z.keys.left.bind(L));z.events.mouseover.bind(function(a){a=a.item();c.is(a)&&f.submenu(w,A,a).forall(u.isVisible)||(F(a),B(),C(a))});z.events.click.bind(function(a){a=a.item();var c=b.get(a);A.hasOwnProperty(c)&&void 0!==A[c]||!b.isEnabled(a)||x.trigger.select(a)});
return{destroy:function(){z.destroy()},populate:function(a){A=h.merge({},a)},on:function(a){a=void 0!==a?a:[q.fromDom(v)];z.attach(a)},off:function(){z.detach()},selectFirst:function(){f.active(w).each(function(a){c.none(a);c.first(a).each(x.trigger.active)})},select:function(a){F(a);B()},setActiveMenu:l,simulateKey:z.simulateKey,state:function(){return f.active(w).bind(function(a){return c.selected(a).map(function(b){return{menu:k.constant(a),item:k.constant(b)}})})},events:x.registry}}});l("cj",
"7d b 1o kj 53 7 s 59 4a 4b 4p 2v 1a 1y 2z 2p 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u){return function(v,w,y){var x=b.div();q.add(x,d.resolve("menu-"+w()+"-sandbox"));r.set(x,"tabindex",-1);s.append(v(),x);var z=g.none(),A=a(x,{tabs:!0}),l=p({}),B=function(){A.off();E();F.trigger.close()},C=function(a){var b=c.mapToArray(l.get(),n.immutable("submenu","item")),d=r.get(a,"data-ephox-gopher-menu-value"),b=e.find(b,function(a){return a.submenu()===d});return g.from(b).bind(function(b){return u.descendant(x,
"[data-ephox-gopher-item-value="+b.item()+"]").map(function(b){return{menu:f.constant(a),item:f.constant(b)}})})};v=function(a){var b=C(a.menu()).map(function(a){return a.item()});F.trigger.collapse(a.menu(),b)};var F=k.create({open:h([]),close:h([]),itemAction:h(["value","item"]),itemHover:m(["item"],A.events.active),reveal:m(["menu","trigger"],A.events.expand),collapse:h(["menu","item"]),escaped:m([],A.events.escaped)});A.events.hide.bind(v);A.events.collapse.bind(v);A.events.escaped.bind(function(){A.state().fold(B,
function(a){C(a.menu()).fold(function(){B()},function(a){F.trigger.collapse(a.menu(),g.some(a.item()));A.select(a.item())})})});A.events.select.bind(function(a){a=a.item();var b=r.get(a,"data-ephox-gopher-item-value");F.trigger.itemAction(b,a)});A.events.active.bind(function(a){y.focusActive()&&t.focusInside(a.item())});var E=function(){c.each(l.get(),function(a,b){u.descendant(x,'[data-ephox-gopher-menu-value="'+a+'"]').each(function(a){var c=u.descendant(x,'[data-ephox-gopher-item-value="'+b+'"]');
F.trigger.collapse(a,c)})})};return{update:function(a){l.set(a);A.populate(a)},setActiveMenu:function(a){z=g.from(a);A.setActiveMenu(a);A.selectFirst()},getActiveMenu:function(){return z},structure:l,destroy:function(){B();A.destroy()},open:function(a,b){t.focus(b);A.on(a);A.selectFirst();F.trigger.open()},close:B,events:F.registry,sandbox:f.constant(x),select:A.select,simulateKey:A.simulateKey}}});l("t6",["4q"],function(d){d=d.generate([{southeast:[]},{southwest:[]},{northeast:[]},{northwest:[]}]);
return{southeast:d.southeast,southwest:d.southwest,northeast:d.northeast,northwest:d.northwest,cata:function(d,c,a,b,f){return d.fold(c,a,b,f)}}});l("lh",["7","s"],function(d,e){var c=function(a,b){return a.view(b).fold(d.constant([]),function(b){var d=a.owner(b),d=c(a,d);return[b].concat(d)})};return{pathTo:function(a,b){var d=b.owner(a),d=c(b,d);return e.some(d)}}});l("li",["s","l","2b","q"],function(d,e,c,a){return{view:function(b){return(b.dom()===a?d.none():d.from(b.dom().defaultView.frameElement)).map(e.fromDom)},
owner:function(a){return c.owner(a)}}});l("ct","b 7 lh li 3o l 3p 2a q".split(" "),function(d,e,c,a,b,f,g,h,k){return{find:function(m){var p=f.fromDom(k),n=h.get(p);return c.pathTo(m,a).fold(e.curry(g.absolute,m),function(a){var c=g.viewport(m);a=d.foldr(a,function(a,b){var c=g.viewport(b);return{left:a.left+c.left(),top:a.top+c.top()}},{left:0,top:0});return b(a.left+c.left()+n.left(),a.top+c.top()+n.top())})}}});l("68",["2o","3z"],function(d,e){var c=e("height",function(a){return a.dom().offsetHeight});
return{set:function(a,b){c.set(a,b)},get:function(a){return c.get(a)},getOuter:function(a){return c.getOuter(a)},setMax:function(a,b){var e=c.max(a,b,"margin-top border-top-width padding-top padding-bottom border-bottom-width margin-bottom".split(" "));d.set(a,"max-height",e+"px")}}});l("76","ct 75 l 68 2a 2s q 37".split(" "),function(d,e,c,a,b,f,g,h){return{absolute:function(b){var c=d.find(b),g=f.getOuter(b);b=a.getOuter(b);return e(c.left(),c.top(),g,b)},view:function(){var a=h.innerWidth,d=h.innerHeight,
f=c.fromDom(g),f=b.get(f);return e(f.left(),f.top(),a,d)}}});l("t7","7 ct 75 76 3o 68 2a 2s".split(" "),function(d,e,c,a,b,f,g,h){return{toBox:function(a,b){var p=d.curry(e.find,b),p=a.fold(p,p,function(){var a=g.get();return e.find(b).translate(-a.left(),-a.top())}),n=h.getOuter(b),r=f.getOuter(b);return c(p.left(),p.top(),n,r)},viewport:function(b,d){return d.fold(function(){return b.fold(a.view,a.view,c)},function(a){return b.fold(a,a,c)})},translate:function(a,c,e,f){var h=b(e,f);return a.fold(d.constant(h),
d.constant(h),function(){var a=g.get();return h.translate(-a.left(),-a.top())})}}});l("t8",["2v"],function(d){var e=d.immutableBag("x y width height maxHeight direction classes label candidateYforTest".split(" "),[]);d=d.immutable("position","left","top","right","bottom");return{decision:e,css:d}});l("o5",["s","t6","t7","t8","4q"],function(d,e,c,a,b){b=b.generate([{none:[]},{relative:["x","y"]},{fixed:["x","y","width","height"]}]);return{none:b.none,relative:b.relative,fixed:b.fixed,reposition:function(b,
c){return b.fold(function(){return a.css("absolute",d.some(c.x()),d.some(c.y()),d.none(),d.none())},function(b,e){return a.css("absolute",d.some(c.x()-b),d.some(c.y()-e),d.none(),d.none())},function(b,f,m,p){b=c.x()-b;f=c.y()-f;var n=c.width(),r=c.height();m-=b+n;p-=f+r;var q=d.some(b),t=d.some(f),s=d.some(m),u=d.some(p),v=d.none();return e.cata(c.direction(),function(){return a.css("fixed",q,t,v,v)},function(){return a.css("fixed",v,t,s,v)},function(){return a.css("fixed",q,v,v,u)},function(){return a.css("fixed",
v,v,s,u)})})},viewport:function(a,b){return c.viewport(a,b)},toBox:function(a,b){return c.toBox(a,b)},translate:function(a,b,d,e){return c.translate(a,b,d,e)},cata:function(a,b,c,d){return a.fold(b,c,d)}}});l("o3",["o5","2v","37"],function(d,e,c){var a=e.immutable("anchorBox","origin"),b=function(){return d.fixed(0,0,c.innerWidth,c.innerHeight)};return{box:function(c){var d=b();return a(c,d)},element:function(c){var e=b();c=d.toBox(e,c);return a(c,e)},fixedOrigin:b}});l("fm",["7","3o"],function(d,
e){return function(c,a){return{southeast:d.constant(e(-c,a)),southwest:d.constant(e(c,a)),northeast:d.constant(e(-c,-a)),northwest:d.constant(e(c,-a))}}});l("yy",["4j"],function(d){return{resolve:d.create("ephox-repartee").resolve}});l("t9",["7","yy"],function(d,e){var c=e.resolve("caret-top-align"),a=e.resolve("caret-bottom-align"),b=e.resolve("caret-right-align"),f=e.resolve("caret-left-align"),g=e.resolve("caret-middle-align");return{east:d.constant(f),south:d.constant(c),west:d.constant(b),north:d.constant(a),
middle:d.constant(g),all:d.constant([c,a,f,b,g])}});l("ta",["2v"],function(d){return d.immutable("x","y","bubble","direction","anchors","label")});l("o4",["t6","t9","ta"],function(d,e,c){var a=function(a,b){return a.x()+a.width()-b.width()/2},b=function(a,b){return a.x()+a.width()-b.width()},f=function(a,b){return a.y()-b.height()},g=function(a){return a.y()+a.height()},h=function(a,b,f){return c(a.x(),g(a),f.southeast(),d.southeast(),[e.south(),e.east()],"layout-se")},k=function(a,f,h){return c(b(a,
f),g(a),h.southwest(),d.southwest(),[e.south(),e.west()],"layout-sw")},m=function(a,b,g){return c(a.x(),f(a,b),g.northeast(),d.northeast(),[e.north(),e.east()],"layout-ne")},p=function(a,g,h){return c(b(a,g),f(a,g),h.northwest(),d.northwest(),[e.north(),e.west()],"layout-nw")},n=function(b,g,h){return c(a(b,g),f(b,g),h.northeast(),d.northeast(),[e.north(),e.middle()],"layout-nm")},r=function(b,f,h){return c(a(b,f),g(b),h.southeast(),d.southeast(),[e.south(),e.middle()],"layout-sm")};return{southeast:h,
northeast:m,southwest:k,northwest:p,southmiddle:r,northmiddle:n,all:function(){return[h,k,m,p,r,n]},allRtl:function(){return[k,h,p,m,r,n]}}});l("tb",["t6","t9","ta"],function(d,e,c){var a=function(a){return a.x()+a.width()},b=function(a,b){return a.y()-b.height()+a.height()},f=function(b,f,g){return c(a(b),b.y(),g.southeast(),d.southeast(),[e.south(),e.east()],"link-layout-se")},g=function(a,b,f){b=a.x()-b.width();return c(b,a.y(),f.southwest(),d.southwest(),[e.south(),e.west()],"link-layout-sw")},
h=function(f,g,h){return c(a(f),b(f,g),h.northeast(),d.northeast(),[e.north(),e.east()],"link-layout-ne")},k=function(a,f,g){var h;h=a.x()-f.width();return c(h,b(a,f),g.northwest(),d.northwest(),[e.north(),e.west()],"link-layout-nw")};return{southeast:f,northeast:h,southwest:g,northwest:k,all:function(){return[f,g,h,k]},allRtl:function(){return[g,f,k,h]}}});l("ia",["7","2o","68","1s"],function(d,e,c,a){return{anchored:d.constant(function(b,d){c.setMax(b,a.floor(d));e.setAll(b,{"overflow-x":"hidden",
"overflow-y":"auto"})}),expandable:d.constant(function(b,d){c.setMax(b,a.floor(d))})}});l("yz","b 7 t6 t8 4q 1s".split(" "),function(d,e,c,a,b,f){var g=b.generate([{fit:["reposition"]},{nofit:["reposition","deltaW","deltaH"]}]),h=function(b,d,h,n){var r=b.x(),q=b.y(),t=b.bubble().left(),s=b.bubble().top(),u=n.x(),v=n.y(),w=n.width(),y=n.height(),t=r+t,r=q+s,x=t>=u,z=r>=v,q=x&&z,s=t+d<=u+w&&r+h<=v+y,u=x?f.min(d,u+w-t):f.abs(u-(t+d)),w=z?f.min(h,v+y-r):f.abs(v-(r+h));d=n.width()-d;n=f.max(0,t);d=f.min(n,
d);h=z?r:r+(h-w);n=e.constant(h+w-v);v=e.constant(v+y-h);v=c.cata(b.direction(),v,v,n,n);b=a.decision({x:d,y:h,width:u,height:w,maxHeight:v,direction:b.direction(),classes:b.anchors(),label:b.label(),candidateYforTest:r});return q&&s?g.fit(b):g.nofit(b,u,w)};return{attempts:function(b,f,p,n,r){var q=p.width(),t=p.height(),s=function(a,b,c,d){a=a(f,p,n);return h(a,q,t,r).fold(g.fit,function(a,e,f){return e>c||f>d?g.nofit(a,e,f):g.nofit(b,c,d)})};return d.foldl(b,function(a,b){var c=e.curry(s,b);return a.fold(g.fit,
c)},g.nofit(a.decision({x:f.x(),y:f.y(),width:p.width(),height:p.height(),maxHeight:p.height(),direction:c.southeast(),classes:[],label:"none",candidateYforTest:f.y()}),-1,-1)).fold(e.identity,e.identity)}}});l("z0","7 2o l 68 2p 3p 2r 2s".split(" "),function(d,e,c,a,b,f,g,h){return{measure:function(k){var m=c.fromTag("div");e.setAll(m,{position:"fixed",opacity:"0",top:"0",left:"0",bottom:"0",right:"0"});b.prepend(k,m);k=f.viewport(m);var p=h.get(m),n=a.get(m);g.remove(m);return{top:k.top,left:k.left,
width:d.constant(p),height:d.constant(n)}}}});l("tc","7 s o5 t9 yz z0 4e 2o 68 2s".split(" "),function(d,e,c,a,b,f,g,h,k,m){return{layout:function(a,c,e,f){h.remove(c,"max-height");c={width:d.constant(m.getOuter(c)),height:d.constant(k.getOuter(c))};return b.attempts(f.preference(),a,c,e,f.bounds())},setClasses:function(b,c){g.remove(b,a.all());g.add(b,c.classes())},setHeight:function(a,b,c){c.maxHeightFunction()(a,b.maxHeight())},position:function(a,b,g){var k=function(a){return a+"px"};g=g.origin();
var m=d.constant(g);g=g.fold(m,m,function(){var b=f.measure(a);return c.fixed(b.left(),b.top(),b.width(),b.height())});b=c.reposition(g,b,a);h.setOptions(a,{position:e.some(b.position()),left:b.left().map(k),top:b.top().map(k),right:b.right().map(k),bottom:b.bottom().map(k)})}}});l("o6","s 76 o4 ia o5 tc 2v".split(" "),function(d,e,c,a,b,f,g){var h=g.immutableBag(["bounds","origin","preference","maxHeightFunction"],[]),k=function(a,b,c){return void 0===a[b]?c:a[b]},m=function(a,b,c,d){a=f.layout(a,
b,c,d);f.position(b,a,d);f.setClasses(b,a);f.setHeight(b,a,d)};return{fixed:function(c,e,f,g,t){var s=k(t,"maxHeightFunction",a.anchored());t=c.anchorBox();c=c.origin();g=h({bounds:b.viewport(c,d.none()),origin:c,preference:g,maxHeightFunction:s});m(t,e,f,g)},relative:function(d,f,g,q){q=void 0!==q?q:{};q=h({bounds:k(q,"bounds",e.view()),origin:k(q,"origin",b.none()),preference:k(q,"preference",c.all()),maxHeightFunction:k(q,"maxHeightFunction",a.anchored())});m(d,f,g,q)}}});l("ku","c 7 s o3 fm o4 tb o5 o6 3o 3p 2b".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n){var r=function(b,e,f,g,r,q,t){var A=!d.detect().deviceType.isiOS();return function(d){var l,C;!0===A?C=a.fixedOrigin():(C=b(),C=n.offsetParent(C).map(p.absolute).getOr(m(0,0)),C=h.relative(C.left(),C.top()));var F=C;l=h.viewport(F,c.some(e));C=h.toBox(F,f());l={bounds:l,origin:F,preference:r.isRtl()?q.allRtl():q.all(),maxHeightFunction:t};d=d.panel();k.relative(C,d,g,l)}},q=function(b,c,d,e,f,g,h){return function(b){var c=f.isRtl()?g.allRtl():g.all(),m={maxHeightFunction:h},
p=a.element(d());b=b.panel();k.fixed(p,b,e,c,m)}},t=d.detect().deviceType.isiOS()?r:q;return{main:function(a,b,c,d,g,h){a=t(a,b,c,d,g,f,h);return{recalculate:a,isAnchored:e.constant(!0),place:a}},submenu:function(a,c,d,f,h){a=t(a,c,d,b(3,-2),f,g,h);return{recalculate:a,isAnchored:e.constant(!0),place:a}}}});l("z1",["3o"],function(d){return function(){return{northwest:function(){return d(-2,1)},northeast:function(){return d(0,1)},southwest:function(){return d(-2,-2)},southeast:function(){return d(0,
-2)}}}});l("ks",["b","s","2v"],function(d,e,c){var a=function(a){return function(b){return b.key()===a}},b=c.immutable("key","value");return{put:function(c,e,h,k,m){var p=void 0!==k?k:b,n=void 0!==m?m:a(e);c=d.foldl(c,function(a,b){var c=n(b)?p(e,h):b;return{updated:n(b)||a.updated,acc:a.acc.concat([c])}},{updated:!1,acc:[]});return c.updated?c.acc:c.acc.concat([p(e,h)])},get:function(b,c,h){c=void 0!==h?h:a(c);b=d.find(b,c);return e.from(b)}}});l("kv",["b","2n"],function(d,e){return{triage:function(c){c=
d.foldr(c,function(a,b){var c=e.inBody(b.menu());return{keep:c?[b].concat(a.keep):a.keep,throwaway:!1===c?[b].concat(a.throwaway):a.throwaway}},{throwaway:[],keep:[]});d.each(c.throwaway,function(a){a.popup().destroy()});return c.keep}}});l("m1",["b","7","1b","38"],function(d,e,c,a){var b=function(b,d){return a.ancestor(b,e.curry(c.eq,d))};return{ancestor:b,anyAncestor:function(a,c){return d.exists(c,function(c){return b(a,c)})},sibling:function(b,d){return a.sibling(b,e.curry(c.eq,d))},child:function(b,
d){return a.child(b,e.curry(c.eq,d))},descendant:function(b,d){return a.descendant(b,e.curry(c.eq,d))}}});l("d5","b 7 1b 3y l m1 q".split(" "),function(d,e,c,a,b,f,g){return function(h,k,m){m=m||[b.fromDom(g)];var p=[],n=function(a){var b=k();a=a.target();c.member(a,b)||f.anyAncestor(a,b)||h(a)};return{on:function(){d.each(m,function(b){p.push(a.bind(b,"mousedown",n).unbind)})},off:function(){d.each(p,e.apply)},mousedown:n}}});l("td","6 53 lo 1y 2o 2p 2r 32 b0".split(" "),function(d,e,c,a,b,f,g,h,
k){return function(m){var p=d.merge({layerClass:null,zindex:null},m),n=e.div();a.add(n,c.resolve("panel"));b.setAll(n,{position:"absolute",display:"none",top:"0px"});p.zindex&&b.set(n,"z-index",p.zindex);p.layerClass&&a.add(n,p.layerClass);m=void 0!==m.container?m.container:h.first("body").getOrDie();f.append(m,n);m=k.displayToggler(n,"block");return{element:function(){return n},destroy:function(){g.remove(n)},content:function(a){g.empty(n);f.append(n,a)},show:m.on,hide:m.off,toggle:m.toggle}}});
l("kw","7d d5 53 td 7 br 59 4a 1y 2o 2z 2p 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){return{create:function(q,t){var s=h.create({open:g([]),close:g([]),uistale:g([])});if(void 0===q)throw"uicontainer not specified";var u=a({layerClass:d.resolve("layer-menus"),container:q()}),v=c.div();k.add(v,d.resolve("popup-container"));u.content(v);var w=!1,y=function(){w&&(z.off(),u.hide(),w=!1,A.control.block(),s.trigger.close())},x=[v],z=e(function(a){!1===!w&&(y(),r.ancestor(a,"."+t).fold(function(){p.focus(a)},
b.noop))},function(){return x}),A=f.tap(function(){s.trigger.uistale()});A.control.block();return{element:function(){return v},panel:u.element,destroy:function(){u.hide();u.destroy();z.off()},open:function(){w||(A.control.unblock(),m.set(u.element(),"opacity","0"),u.show(),m.reflow(u.element()),z.on(),w=!0,s.trigger.open(),m.set(u.element(),"opacity","1"))},close:y,closed:function(){return!w},mousedown:function(a){z.mousedown(a.original())},uiStale:function(){A.instance()},setContent:function(a){n.append(v,
a)},setComponents:function(a){x=a.concat([v])},events:s.registry}}}});l("cl","ks kt ku kv kw b 7 ia 2v 1b 2o 6u".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var r=k.immutable("menu","popup"),q=function(a){return function(b){return m.eq(b.menu(),a)}};return function(k,m,u,v,w){var y=[],x=function(){var a=f.map(y,function(a){return a.popup().panel()}).concat(v);f.each(y,function(b){b.popup().setComponents(a)})},z=function(a){var b=d.get(y,a,q(a)).fold(function(){return l(a)},function(a){return a.popup()});
x();y=d.put(y,a,b,r,q(a));return b},A=function(a){d.get(y,a,q(a)).each(function(a){a.popup().close()});p.set(a,"display","none")},l=function(a){var c=b.create(k,w);c.setContent(a);y=d.put(y,a,c,r,q(a));x();return c};return{initMenu:l,registerMenus:function(b){y=a.triage(y);return f.map(b,z)},hideAll:function(){f.each(y,function(a){A(a.menu())})},hideMenu:A,expandMenu:function(a,b){var d=z(a),f=n.descendant(a,"."+e.styles())?h.expandable():h.anchored(),f=c.submenu(k,m,g.constant(b),u.uiDirection(),
f);p.set(a,"display","block");d.open();f.recalculate(d);return{popup:d,anchorage:f}}}}});l("129","53 lo 4e l 2p 2r".split(" "),function(d,e,c,a,b,f){return function(a,h){var k=d.span();c.add(k,[e.resolve("righticon-content"),h]);b.append(k,a);return{element:function(){return k},destroy:function(){f.remove(k)}}}});l("12a",["129","eh"],function(d,e){return function(c,a){var b=e(c),f=d(b.element(),a);return{element:f.element,destroy:function(){b.destroy();f.destroy()}}}});l("yv","al sk cj ys yt sw ku z1 cl 7d b 8b fh 30 c gr 53 129 12a lp 7 59 4a 4b ia 1a 1y 4e l 2p 3d 2r q".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v,w,y,x,z,A,l,B,C,F,E,G,H,I,K,J){var L=t.detect().deviceType.isiOS;return function(t,M,O,S,P,T,Q,V,W,$){var X=y(O);Q=e.control(X);E.add(X.element(),[m.resolve("dropdown-button"),m.resolve(O+"-dropdown-button")]);C.set(X.element(),"title",V(S));n.toolbarButton(X.element(),V(S),!0,W);var Y=c(t.uiContainer,x.constant("dropdown-"+O),d.menu({focusActive:!0})),da=G.fromDom(J),R=s.mainmenu(da,O+"-menu",[]),ca=k(Y.sandbox,t.bounds,M,[X.element()],$).initMenu(R);
O=h();var ea=g.main(t.uiContainer,t.bounds,X.element,O,M.uiDirection(),B.anchored());n.menu(R,V(P));var fa=q.generate("menu-control");C.set(R,"id",fa);n.controls(X.element(),fa);var ga=u.span();F.add(ga,m.resolve("dropdown-viewport"));X.content({element:x.constant(ga)});var ia=function(a,b){var c=b.map(f.generate).getOr([]);I.prepend(a,c)};M=function(){ha(V(S))};var ha=function(a){K.empty(ga);H.append(ga,w(a,"ephox-pastry-arrow-righticon").element())},Z=function(){X.deselect();W&&r.pressed(X);r.collapsed(X.element());
n.disown(X.element());ca.close();Y.close()},aa=function(){X.select();W&&r.pressed(X);r.expanded(X.element());n.owns(X.element(),fa);ca.open();var a=[t.uiContainer()];Y.open(a,X.element())},ja=A.create({select:l(["value","item"],Y.events.itemAction),itemHover:l(["item"],Y.events.itemHover),escaped:l([],Y.events.escaped),open:z(["menu","popup","anchor"]),close:l([],Y.events.close)});X.events.click.bind(function(){(X.selected()?aa:Z)()});ca.events.close.bind(Z);Y.events.open.bind(function(){ja.trigger.open(R,
ca,ea);Y.update({});L()||Y.setActiveMenu(R)});Y.events.escaped.bind(Z);M();return{element:x.constant(X.element()),menu:ca.element,list:x.constant(R),click:X.click,populate:function(b){K.empty(R);p.each(b,function(b){b.label().each(function(b){b=a.generateSeparator(da,b,V);H.append(R,b)});p.each(b.items(),function(b){var c=a.generateItem(da,b,T,V);n.menuItemCheckbox(c);ia(c,b.icon());H.append(R,c)})})},enable:Q.enable,disable:Q.disable,close:Z,uiStale:ca.uiStale,recalculate:function(){ea.recalculate(ca)},
clear:M,select:function(a){ha(V(a.textkey()));ia(ga,a.icon())},selectElement:function(a){a=v(a,"ephox-pastry-arrow-righticon");X.content({element:a.element,destroy:x.noop})},tick:x.curry(b.tick,R),untick:x.curry(b.untick,R),activate:x.curry(b.activate,X.element()),deactivate:x.curry(b.deactivate,X.element()),destroy:function(){Y.destroy();X.destroy()},events:ja.registry}}});l("sx","kx sv yv 4a 4b 1a".split(" "),function(d,e,c,a,b,f){return{init:function(g,h,k,m,p){var n=c(g,h,p.name,p.textkey,p.menuTextkey,
p.render,p.layout,k,p.toggle,m);g=function(){p.updateDropdown(e.dropdown({enable:n.enable,disable:n.disable,select:n.select,clear:n.clear,selectElement:n.selectElement,populate:n.populate,tick:n.tick,untick:n.untick,activate:n.activate,deactivate:n.deactivate}))};var r=d.onButton(n);n.events.select.bind(function(a){p.action(a.value());n.close()});var q=a.create({select:b(["value","item"],n.events.select),itemHover:b(["item"],n.events.itemHover),escaped:b([],n.events.escaped),open:b(["menu","popup",
"anchor"],n.events.open),close:b([],n.events.close)});g();f.set(n.element(),"tabindex","-1");return{dropdown:function(){return{events:q.registry,close:n.close,uiStale:n.uiStale,enable:n.enable,disable:n.disable,list:n.list,menu:n.menu,recalculate:n.recalculate}},component:n.element,refreshUi:g,destroy:function(){r.unbind();n.destroy()}}}}});l("sy","kx sv kk kl a fh 7 4a 4b 1a".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=function(b,c){var d=a.typical(b.value,b.value,b.action,b.textkey,b.label,b.tooltip,
c);b.setup&&b.setup(d,b);return d},n=function(b,c){var d=a.toggle(b.value,b.value,b.action,b.textkey,b.label,b.tooltip,c);b.setup&&b.setup(d,b);b.selected&&d.select();return d};return{init:function(a,q){var t=!0===q.hasPopup,s=(!0===q.toggle?n:p)(q,a);b.isString(q.icon)&&c.findAndSetUrl(s.element(),q.icon);var u=s.initAria(s,a(q.textkey),t,q.toggle);m.set(s.element(),"tabindex","-1");var v=function(){!0===q.toggle&&f.pressed(s)},w=d.onButton(s);s.events.click.bind(function(){v()});var y=!0===q.toggle?
s.select:g.noop,x=!0===q.toggle?s.deselect:g.noop,z=!0===q.toggle?s.selected:g.constant(!1);v();var A=h.create({click:k([],s.events.click)});return{generals:function(){return{events:A.registry,enableButton:s.enable,disableButton:s.disable}},component:s.element,refreshUi:function(){q.updateGeneral(e.general({disable:u.disable,enable:u.enable,select:y,deselect:x,selected:z,element:s.element}));v()},destroy:function(){w.unbind();s.destroy();u.destroy()}}}}});l("sz","al kx cj ku z1 cl 7d b fh c 53 59 4a 4b ia 1a 1y 2o 2z 2p 3d 2r 2b".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v,w,y,x,z,A){var l=m.detect().deviceType.isiOS;return{init:function(m,C,F,E,G,H){var I=G.button(),K=e.onButton(I),J=c(m.uiContainer,G.name,d.menu({focusActive:!0}));s.set(I.element(),"tabindex","-1");var L=p.div();u.add(L,g.resolve("menu-system-main"));var N=f(J.sandbox,m.bounds,C,[I.element()],E),M=N.initMenu(L);F=b();var O=a.main(m.uiContainer,m.bounds,I.element,F,C.uiDirection(),t.anchored()),S=function(){O.recalculate(M)},P=function(){var a=A.children(J.sandbox());
h.each(a,function(a){v.set(a,"display","none")})},T=function(a){J.update(a.structure());z.empty(L);y.append(L,a.element());a=N.registerMenus(a.submenus());a=h.map(a,function(a){return a.panel()});z.empty(J.sandbox());x.append(J.sandbox(),[M.panel()].concat(a));P()},Q=function(a){G.init(a)},V=r.create({open:n(["menu","popup","anchor"]),close:q([],J.events.close),itemAction:q(["value","item"],J.events.itemAction),itemHover:q(["item"],J.events.itemHover),reveal:n(["menu","trigger","popup","anchor"]),
collapse:q(["menu","item"],J.events.collapse),escaped:q([],J.events.escaped)});I.events.click.bind(function(){return(I.selected()?M.open:M.close)()});G.events.done.bind(function(){J.close()});G.events.abort.bind(function(a){J.select(a.item());w.focus(a.item())});M.events.uistale.bind(function(){J.getActiveMenu().bind(function(a){Q(a)})});M.events.close.bind(function(){J.close();k.collapsed(I.element())});M.events.open.bind(function(){var a=void 0!==H?H:[],a=[J.sandbox()].concat(a);T(G);Q(G);v.set(M.panel(),
"display","block");v.set(L,"display","block");J.open(a,L);k.expanded(I.element())});J.events.open.bind(function(){V.trigger.open(G.element(),M,O);l()||J.setActiveMenu(G.element())});J.events.close.bind(function(){N.hideAll();I.deselect()});J.events.itemAction.bind(function(a){var b=G.handlers();if(void 0!==b[a.value()])(0,b[a.value()])(a.item())});J.events.reveal.bind(function(a){k.expanded(a.trigger());var b=N.expandMenu(a.menu(),a.trigger(),M);V.trigger.reveal(a.menu(),a.trigger(),b.popup,b.anchorage)});
J.events.collapse.bind(function(a){N.hideMenu(a.menu());a.item().each(k.collapsed)});return{menus:function(){return{events:V.registry,enable:G.enable,disable:G.disable,close:M.close,uiStale:M.uiStale,mousedown:M.mousedown,contentFocus:G.contentFocus,menu:M.element,refreshMenus:Q,recalculate:S}},component:I.element,refreshUi:function(){G.updateMenu({enable:G.enable,disable:G.disable})},destroy:function(){K.unbind();J.destroy();G.destroy();M.destroy()}}}}});l("t0","sv 7d yr b am 53 7 s 2n 1y 3d".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p){return{init:function(n,r){var q=f.span();m.add(q,e.resolve("palette-group"));var t=g.curry(b.speak,k.body()),s=function(a){var b=c.isShowing(q);c.hide(q);b&&a.each(t);return b},u=d.palette({show:function(a){var b=c.isHiding(q);c.show(q);b&&a.each(t);return b},hide:s});s(h.none());p.append(q,a.map(r,function(a){return a.component()}));return{component:g.constant(q),destroy:function(){a.each(r,function(a){a.destroy()})},refreshUi:function(){n.updatePalette(u);a.each(r,
function(a){a.refreshUi()})}}}}});l("t1","kx sv ku z1 cl kl 8b fh 30 gr 7 59 4a 4b ia 1a l 2p q".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v,w){return{widget:function(y,x,z,A,l){var B=l.instance();l=u.fromDom(w);var C=(B.toggle?f.splitToggle:f.split)(B.name(),B.name(),p.identity,B.textkey(),B.label(),B.tooltip,z),F=d.custom(C.element(),function(){C.open();B.enter()});s.set(C.element(),"tabindex","-1");var E=C.initAria(C,z(B.textkey()),!0,B.toggle);A=b(y.uiContainer,y.bounds,x,[C.element()],
A);var G=a(),H=m.widget(l,B.name());l=k.generate("menu-control");s.set(H,"id",l);g.controls(C.element(),l);g.owns(C.element(),l);g.menu(H,z(B.menuTextkey()));v.append(H,B.element());var I=A.initMenu(H),K=c.main(y.uiContainer,y.bounds,C.element,G,x.uiDirection(),t.expandable()),J=function(){K.recalculate(I)};I.events.open.bind(function(){h.expanded(C.element());B.open();L.trigger.open(H,I,K)});I.events.close.bind(function(){h.collapsed(C.element());B.close();C.close()});B.events.done.bind(function(){I.close();
C.close()});B.events.abort.bind(function(){I.close();C.close();L.trigger.abort()});C.events.open.bind(function(){I.open();K.recalculate(I)});C.events.close.bind(function(){B.close();I.close()});C.events.click.bind(function(){B.action()});var L=r.create({abort:n([]),close:q([],B.events.close),open:n(["menu","popup","anchor"])});return{widgets:function(){return{events:L.registry,open:C.open,isOpen:C.isOpen,close:C.close,recalculate:J}},component:C.element,refreshUi:function(){B.updateWidget(e.widget({select:C.select,
deselect:C.deselect,enable:C.enable,disable:C.disable,press:E.press,release:E.release}))},destroy:function(){F.unbind();E.destroy();I.destroy();B.destroy();C.destroy()}}}}});l("t2","kx sv ku z1 cl 7d kl 8b fh 7 59 4a ia 1a 1y".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t){return{widget:function(h,u,v,w,y){var x=y.instance(),z=g.toggle(x.name(),x.name(),m.identity,x.textkey(),x.label(),x.tooltip,v),A=d.onButton(z),l=z.initAria(z,v(x.textkey()),!0,!0);v=b(h.uiContainer,h.bounds,u,[z.element()],
w);w=a();var B=v.initMenu(x.element()),C=c.main(h.uiContainer,h.bounds,z.element,w,u.uiDirection(),r.expandable());q.set(z.element(),"tabindex","-1");t.add(B.element(),f.resolve("toolbar-widget"));var F=function(){C.recalculate(B)};B.events.open.bind(function(){k.expanded(z.element());x.open();E.trigger.open(x.element(),B,C)});B.events.close.bind(function(){k.collapsed(z.element());x.close()});x.events.done.bind(function(){B.close();z.deselect()});x.events.abort.bind(function(){B.close();z.deselect();
E.trigger.abort()});z.events.click.bind(function(){z.selected()?(B.open(),C.recalculate(B)):B.close();k.pressed(z)});var E=n.create({abort:p([]),open:p(["menu","popup","anchor"])}),G=function(){z.deselect();B.close()};return{widgets:function(){return{events:E.registry,close:G,recalculate:F}},component:z.element,refreshUi:function(){x.updateWidget(e.widget({select:m.noop,deselect:m.noop,enable:l.enable,disable:l.disable,press:m.noop,release:m.noop}))},destroy:function(){A.unbind();l.destroy();B.destroy();
x.destroy();z.destroy()}}},inline:function(a,b){var c=b.instance(),g=d.custom(c.element(),function(){c.element().dom().click()});q.remove(c.element(),"tabindex");t.add(c.element(),f.resolve("toolbar-inline-widget"));h.toolbarButton(c.element(),a(c.textkey()),!1);var r=n.create({abort:p([]),open:p(["menu","popup","anchor"])});return{widgets:function(){return{events:r.registry,recalculate:m.noop,close:m.noop}},component:c.element,refreshUi:function(){c.updateInlineWidget(e.widget({select:m.noop,deselect:m.noop,
enable:m.curry(k.enable,c.element()),disable:m.curry(k.disable,c.element()),press:m.noop,release:m.noop}))},destroy:function(){g.unbind();c.destroy()}}}}});l("ke","sr ss st kt sx sy sz t0 t1 t2 7".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){return{menu:function(b){return{general:p.curry(e.init,b),menu:p.curry(c.nested,b),dropdown:p.curry(d.init,b),widget:p.curry(a.widget,b),"split-widget":p.curry(a.split,b),"inline-widget":p.curry(a.inline,b),palette:p.die("No palettes for menus yet")}},toolbar:function(a,
c,d,e){var s=function(b){return p.curry(b,a,c,d,e)};return{menu:s(g.init),dropdown:s(b.init),widget:s(m.widget),"split-widget":s(k.widget),"inline-widget":p.curry(m.inline,d),general:p.curry(f.init,d),palette:h.init}}}});l("hm",["4q"],function(d){d=d.generate([{toolbar:[]},{menu:[]}]);return{toolbar:d.toolbar,menu:d.menu,cata:function(d,c,a){return d.fold(c,a)}}});l("cg",["ke","hm"],function(d,e){return function(c){var a=d.menu(c);return{widget:a.widget,menu:a.menu,general:a.general,"inline-widget":function(b){return a["inline-widget"]({instance:function(){return b.instance(e.menu())}})},
"split-widget":a["split-widget"],dropdown:a.dropdown,palette:a.palette}}});l("kf",["b","c","3q","2z"],function(d,e,c,a){var b=function(b,c,d,e){b.events.escaped.bind(function(b){d.focused()&&a.focus(e.component())});b.events.close.bind(function(a){c.focus()})},f=function(a,b,d,e){a.events.open.bind(function(a){c.register(a.popup().panel())})};return{init:function(c,h,k,m,p,n,r,q,t){var s=c.dropdown(t),u=s.dropdown();c=k.toolbar;(e.detect().deviceType.isTouch()?f:b)(u,p,c,s);var v=!1;u.events.open.bind(function(a){p.toReading();
r.show(a.popup(),a.anchor());v=!0});u.events.close.bind(function(){v=!1});u.events.escaped.bind(function(){a.focus(s.component())});p.events.mousedown.bind(function(){v&&u.close()});p.events.uiStale.bind(u.uiStale);k.toolbar.events.transitionend.bind(function(a){d.contains(["top","height"],a.property())&&u.recalculate()});return{component:s.component,refreshUi:s.refreshUi,destroy:s.destroy}}}});l("kg",[],function(){return{init:function(d,e,c,a,b,f,g,h,k){d=d.general(k);e=d.generals();d.refreshUi();
return{generals:e,component:d.component,refreshUi:d.refreshUi,destroy:d.destroy}}}});l("fi",["s","2a"],function(d,e){var c=function(a,b){var c=d.none(),g=function(){c=d.none()};return{begin:function(){c=d.some(e.get(a))},end:function(){c.each(function(a){b.scrollTo(a.left(),a.top())});g()},destroy:g}};return{fromSafe:function(a){return c(a.doc(),a.win())},fromUnsafe:function(a){var b=a.doc().getOrDie();a=a.win().getOrDie();return c(b,a)}}});l("kh","7 s fi 3q l 2z 21 2b q".split(" "),function(d,e,
c,a,b,f,g,h,k){return{init:function(m,p,n,r,q,t,s,u,v){var w=m.menu(v,[]),y=w.menus(),x=c.fromUnsafe(q);y.events.open.bind(function(a){q.toReading();y.refreshMenus(a.menu());s.show(a.popup(),a.anchor())});y.events.close.bind(function(){q.focus();x.end()});y.events.escaped.bind(function(){f.focus(w.component())});y.events.reveal.bind(function(a){v.init(a.menu());s.show(a.popup(),a.anchor())});y.events.itemAction.bind(function(a){x.end()});y.events.itemHover.bind(function(c){x.begin();if(null!==k.activeElement&&
void 0!==k.activeElement){var e=b.fromDom(k.activeElement),m=h.owner(c.item());"input"!==g.name(e)&&a.preserve(m,d.curry(f.focusInside,c.item()))}else q.backupSelection(),f.focus(c.item())});q.events.mousedown.bind(y.mousedown);q.events.uiStale.bind(y.uiStale);q.events.focus.bind(y.enable);var z=!q.isInline()&&v.contentFocus();z&&y.disable();return{component:w.component,refreshUi:function(){w.refreshUi();var a=z?e.none():e.some(!0);q.getSelection().or(a).fold(y.disable,y.enable)},destroy:function(){x.destroy();
q.events.mousedown.unbind(y.mousedown);q.events.uiStale.unbind(y.update);w.destroy()}}}}});l("ki","c lo 7 hm 1y 3y 2z".split(" "),function(d,e,c,a,b,f,g){var h=function(a,b,c,e,f,h,u,v,w,y,x){var z=c[b]({instance:a(x.instance)});a=z.widgets();f=f.toolbar;a.events.open.bind(function(a){u.toReading();w.show(a.popup(),a.anchor())});a.events.abort.bind(function(){g.focus(z.component())});u.events.mousedown.bind(a.close);return(d.detect().deviceType.isTouch()&&"split-widget"===b?m:k)(a,u,f,z)},k=function(a,
b,c,d){return d},m=function(a,c,d,g){var h=f.capture(g.component(),"click",function(c){c.kill();b.add(g.component(),e.resolve("statebutton-selected"));a.isOpen()?a.close():a.open()});a.events.close.bind(function(){b.remove(g.component(),e.resolve("statebutton-selected"))});return{widgets:g.widgets,component:g.component,refreshUi:g.refreshUi,destroy:function(){h.unbind();g.destroy()}}};return{widget:c.curry(h,c.identity,"widget"),inlineWidget:c.curry(h,function(b){return function(){return b(a.toolbar())}},
"inline-widget"),splitWidget:c.curry(h,c.identity,"split-widget")}});l("ay",["7","34"],function(d,e){var c=e.resolve("editor-container");return{editorContainer:d.constant(c)}});l("ch","ke 7 kf kg kh ki ay".split(" "),function(d,e,c,a,b,f,g){return function(h,k,m,p,n,r,q){var t=d.toolbar(r,m,q,g.editorContainer()),s=function(a){return e.curry(a,t,h,k,m,p,n,r,q)};return{widget:s(f.widget),"inline-widget":s(f.inlineWidget),"split-widget":s(f.splitWidget),cards:t.cards,general:s(a.init),dropdown:s(c.init),
menu:s(b.init),palette:t.palette}}});l("96","c 7 s 7b 2v o".split(" "),function(d,e,c,a,b,f){var g=b.immutable("key","link"),h=b.immutable("url","text"),k=function(b,d,e){return function(f){var k=h(d,a.translate(e));return g(a.pkey(b,f),c.some(k))}},m=function(b){return function(d){return g(a.pkey(b,d),c.none())}};b=function(b){return function(d){var e=b(d);d=h(d[0].websiteUrl,a.translate("cloud.dashboard"));return g(e.key(),c.some(d))}};var p={"no.api.key":b(m("cloud.error.apikey")),"domain.not.supported":b(function(b){return g(a.pkey("cloud.error.domain",
[b[0].details.domain]),c.none())}),"plan.exceeded":b(m("cloud.error.plan")),"error.code.invalid.toolbar":m("errors.toolbar.invalid"),"error.code.spelling.not.found":m("errors.spelling.missing.service"),"error.code.images.not.found":m("errors.images.missing.service"),"safari.imagepaste":k("errors.safari.image","https://support.ephox.com/entries/88543243-Safari-Direct-paste-of-images-does-not-work","errors.safari.url"),"webview.imagepaste":m("errors.webview.image"),"flash.clipboard.no.rtf":function(a){return(d.detect().browser.isSafari()?
k("errors.safari.browser-settings","https://support.ephox.com/entries/59328357-Safari-6-1-and-7-Flash-Sandboxing","errors.safari.rtf"):m("errors.images.missing.flash"))(a)},"fileupload.invalidimages":m("errors.images.upload.invalid"),"error.imageupload":m("errors.images.upload.failed"),"error.imageupload.generic":m("errors.images.upload.unknown"),"error.imageupload.cors":m("errors.images.upload.cors"),"errors.paste.word.notready":m("errors.paste.notready"),"errors.paste.process.failure":m("errors.paste.generic"),
"flash.crashed":m("errors.flash.crashed"),"errors.imageimport.failed":m("errors.images.import.failed"),"errors.imageimport.unsupported":m("errors.images.import.unsupported"),"errors.imageimport.invalid":m("errors.images.import.invalid"),"imageedit.needsproxy":m("errors.images.edit.needsproxy"),"imageedit.proxyerror":m("errors.images.edit.proxyerror"),"imageedit.generic":m("errors.images.edit.generic")},n={"errors.local.images.disallowed":"Removing pasted images from content. Local image insert has been disabled.",
"errors.dragdrop.images.disallowed":"Blocking image drop operation. Local image insert has been disabled."},r=function(b,c){var d=(0,p[b])(c);return{description:e.constant(a.get(d.key())),link:e.constant(d.link().getOr(null))}};return{get:r,getOrLog:function(a,b){return c.from(n[a]).fold(function(){var d=r(a,b);return c.some(d)},function(a){f.warn(a);return c.none()})}}});l("73","cd ce a b 7 cf cg ch 7b 96 34 1y o".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){var q=function(c,d){var e=function(b){var d=
m.get("error.code.invalid.toolbar",[b.small()]),d=f(d);c.displayBanner(d);a.each(b.big(),function(a){r.error(a)})};return d.fold(function(a){e(a);return[]},b.identity)};return{setup:function(b,f,m,r,w,y){y=q(b,y);var x=function(a){a=c.isString(a)?k.has(a)?k.key(a):k.raw(a):a;return k.get(a)};n.add(b.toolbar.element(),p.resolve("layer-above-editor"));f=e.blueprints(h(w.uiContainer,b,f,m,r,w,x),g(x));w=e.env(w.uiContainer,x);w=d.build(y,f,w);a.each(w,b.toolbar.add);b.position();a.each(w,function(a){m.events.uiStale.bind(function(){a.refreshUi()})})}}});
l("ky","kx kb 7d kl p6 eh 7 1a 1y 2z".split(" "),function(d,e,c,a,b,f,g,h,k,m){return function(p){var n=b("overflower");k.add(n.element(),c.resolve("more-button"));n.content(f(p("toolbar.more")));var r=d.onButton(n);h.set(n.element(),"tabindex","-1");p=p("aria.label.more");h.set(n.element(),"title",p);var q=a.aria(n,p,!0,!0),t=e.toolbar([{component:n.element,destroy:n.destroy,refreshUi:g.noop}]);return{group:t.component,select:function(){n.select();q.press()},deselect:function(){q.release();n.deselect()},
focus:function(){m.focus(n.element())},destroy:function(){r.unbind();q.destroy();t.destroy()},events:n.events}}});l("lt",["s","1b","2z","4l","2b"],function(d,e,c,a,b){return{preserve:function(f,g){var h=b.owner(g),k=c.active(h).bind(function(b){var c=function(a){return e.eq(b,a)};return c(g)?d.some(g):a.descendant(g,c)}),m=f(g);k.each(function(a){c.active(h).filter(function(b){return e.eq(b,a)}).orThunk(function(){c.focus(a)})});return m}}});l("z2",["2v"],function(d){return d.immutable("component",
"index")});l("te",["b","z2"],function(d,e){return function(c){var a=[];return{add:function(b,d){var g=d?c.indexOf(a,d).getOrDie():a.length;a.splice(g,0,b);return e(b,g)},remove:function(b){b=c.resolve(a,b).getOrDie();var f=d.indexOf(a,b);a.splice(f,1);return e(b,f)},get:function(){return a.slice(0)},itemAt:function(b){return c.resolve(a,b)}}}});l("tf",["a","b","p"],function(d,e,c){return function(a){var b=function(a,b){return d.isNumber(b)?f(a,b):d.isString(b)?g(a,b):d.isObject(b)?h(a,b):c.error("Unsupported specifier type: "+
b)},f=function(a,b){return 0===a.length?c.error("Items is empty"):0>b||b>=a.length?c.error("Item index: "+b+" is out of range (0-"+(a.length-1)+")"):c.value(a[b])},g=function(b,d){var f=e.find(b,function(b){return a(b)===d});return void 0===f?c.error("No item with value: ["+d+"]"):c.value(f)},h=function(a,b){return-1===e.indexOf(a,b)?c.error("Specified object is not a registered item: "+b):c.value(b)};return{resolve:b,indexOf:function(a,d){return b(a,d).bind(function(b){b=e.indexOf(a,b);return-1<
b?c.value(b):c.error("Item not found: "+d)})},index:f,value:g,item:h}}});l("kz","7d b lt 8b te tf 7 59 4a 1y 4e 2o l 2p 3d 2r".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s){return function(u,v){var w=k.create({grow:h([]),shrink:h([]),exit:h([])}),y=b(f(g.identity)),x=r.fromTag("div");n.set(x,"overflow-x","auto");m.add(x,d.resolve("toolstrip"));a.toolbarGroup(x);var z=r.fromTag("div");p.add(z,[d.resolve("toolbar"),d.resolve("toolbar-primary")]);var A=r.fromTag("div");p.add(A,[d.resolve("toolbar"),
d.resolve("toolbar-more")]);q.append(x,z);q.append(x,A);var l=function(){var a=y.get();return e.bind(a,function(a){return a.isVisible()?[a.component()]:[]})};return{element:function(){return x},main:g.constant(z),mores:g.constant(A),destroy:function(){var a=y.get();e.each(a,function(a){a.destroy()})},focused:g.constant(!1),enter:g.noop,restore:g.noop,refocus:g.noop,refresh:g.curry(c.preserve,function(){var a=l(),a=u.build(a);s.empty(z);s.empty(A);t.append(z,a);n.reflow(z)},x),add:function(a){y.add(a)},
events:w.registry}}});l("l0",["7"],function(d){return{item:d.constant('.ephox-chameleon-toolbar-group [tabindex="-1"]'),group:d.constant(".ephox-chameleon-toolbar-group"),sector:d.constant(".ephox-chameleon-toolstrip > *")}});l("pe","7d 1y 4e 2o 3y 68".split(" "),function(d,e,c,a,b,f){var g=d.resolve("toolbar-more-closed"),h=d.resolve("toolbar-more-open"),k=d.resolve("toolbar-more-hide"),m=d.resolve("toolbar-more-show"),p=function(b,c){a.set(b,"height",c+"px");a.reflow(b)},n=function(a){e.remove(a,
h);e.add(a,g);p(a,0)},r=function(b){e.remove(b,g);e.add(b,h);a.remove(b,"height")};return function(d){n(d);var g=!1,h=b.bind(d,"transitionend",function(b){"height"===b.raw().propertyName&&(c.remove(d,[m,k]),g&&a.remove(d,"height"))});return{visible:function(){return g},hide:function(){g=!1;p(d,f.get(d));e.add(d,k);n(d)},show:function(){r(d);var a=f.get(d);n(d);e.add(d,m);r(d);p(d,a);g=!0},destroy:function(){h.unbind()}}}});l("z3",["2v"],function(d){return d.immutable("within","extra","withinWidth")});
l("tg",["b","z3","7","s","hv"],function(d,e,c,a,b){var f=function(e,f,g){var h=b.generate(e,function(b,d){var e=g(b);return a.some({element:c.constant(b),start:c.constant(d),finish:c.constant(d+e),width:c.constant(e)})});e=d.filter(h,function(a){return a.finish()<f});var k=d.foldr(e,function(a,b){return a+b.width()},0),h=h.slice(e.length);return{within:c.constant(e),extra:c.constant(h),withinWidth:c.constant(k)}},g=function(a){return d.map(a,function(a){return a.element()})},h=function(a,b,c){a=g(a.concat(b));
return e(a,[],c)},k=function(a,b,c,d){a=g(a).concat([c]);return e(a,g(b),d)},m=function(a,b,c){return e(g(a),[],c)},p=function(b,c,d){b=f(c,b,d);return 0===b.extra().length?a.some(b):a.none()};return{partition:function(a,b,c,d){var e=p(a,b,c).getOrThunk(function(){return f(b,a-c(d),c)}),g=e.within(),v=e.extra(),e=e.withinWidth();return 1===v.length&&v[0].width()<=c(d)?h(g,v,e):1<=v.length?k(g,v,d,e):m(g,v,e)}}});l("l1","7d pe b lt 8b te tf tg 7 59 4a 1y 4e 2o l 2p 3d 2r 2s".split(" "),function(d,
e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v,w){return function(y,x){var z=p.create({grow:m([]),shrink:m([]),exit:m([])}),A=f(g(k.identity)),l=t.fromTag("div");b.toolbarGroup(l);n.add(l,d.resolve("toolstrip"));var B=t.fromTag("div");r.add(B,[d.resolve("toolbar"),d.resolve("toolbar-primary")]);var C=t.fromTag("div");r.add(C,[d.resolve("toolbar"),d.resolve("toolbar-more")]);s.append(l,B);s.append(l,C);var F=e(C);x.events.click.bind(function(){F.visible()?(F.hide(),x.deselect(),z.trigger.shrink()):(F.show(),x.select(),
z.trigger.grow())});var E=function(){var a=A.get();return c.bind(a,function(a){return a.isVisible()?[a.component()]:[]})};return{element:function(){return l},main:k.constant(B),mores:k.constant(C),destroy:function(){var a=A.get();c.each(a,function(a){a.destroy()});x.destroy();F.destroy()},focused:k.constant(!1),enter:k.noop,restore:k.noop,refocus:k.noop,refresh:k.curry(a.preserve,function(){y.update();var a=E(),a=y.build(a);q.set(B,"visibility","hidden");y.clearWidth();v.empty(B);u.append(B,a);var b=
y.width(B);s.append(B,x.group());var a=h.partition(b,a,w.getOuter,x.group()),b=a.extra(),c=a.within();v.empty(B);v.empty(C);u.append(B,c);u.append(C,b);y.updateWidth(x,a);q.remove(B,"visibility")},l),add:function(a){A.add(a)},events:z.registry}}});l("gt",["2v"],function(d){return{grid:d.immutableBag(["trigger"],["isValid","first"]),flow:d.immutableBag(["trigger"],["first","executeOnArrow"]),sectors:d.immutableBag(["trigger","first"],[]),radio:d.immutableBag(["one"],[]),input:d.immutableBag([],["execute"]),
button:d.immutableBag(["execute"],["process"]),dialog:d.immutableBag(["execute","ok","cancel"],["index"]),inlineDialog:d.immutableBag(["ok","cancel"],["index"]),page:d.immutableBag(["trigger"],["first"]),tabular:d.immutableBag(["trigger"],["first","isValid"]),dynamic:d.immutableBag([],["execute"])}});l("l2",["57"],function(d){return d.ensure(["enter","exit","destroy"])});l("l3",["b"],function(d){var e=function(c){return function(a){return a.raw().which===c}};return{inSet:function(c){return function(a){return d.contains(c,
a.raw().which)}},and:function(c){return function(a){return d.forall(c,function(b){return b(a)})}},is:e,isShift:function(c){return!0===c.raw().shiftKey},basic:function(c,a){return{matches:e(c),run:a}},rule:function(c,a){return{matches:c,run:a}}}});l("l4",["b","1a","2z","4h"],function(d,e,c,a){var b=function(a){e.has(a,"tabIndex")||e.set(a,"tabIndex","-1")};return{set:function(a){b(a);c.focus(a)},find:function(a){return c.search(a)},isFocused:c.hasFocus,mark:b,markSelectors:function(c,e){d.each(e,function(e){e=
a.descendants(c,e);d.each(e,b)})}}});l("di","b l2 l4 7 59 4a 3y".split(" "),function(d,e,c,a,b,f,g){return function(h,k,m){var p=g.bind(h,"keydown",m.getOr(function(a){var b=d.find(k,function(b){return b.matches(a)});void 0!==b&&null!==b&&b.run(a).each(function(b){a.kill()})})),n=f.create({enter:b([]),exit:b([])});return e({isFocused:a.curry(c.isFocused,h),element:a.constant(h),clear:a.noop,enter:function(){c.set(h);n.trigger.enter()},refresh:a.noop,isEnabled:a.constant(!0),exit:function(){n.trigger.exit()},
events:n.registry,destroy:function(){p.unbind()}})}});l("d6","l2 l3 di an 7 s".split(" "),function(d,e,c,a,b,f){return function(g,h){var k=c(g,[e.rule(e.inSet(a.SPACE().concat(a.ENTER())),function(){h.execute()(g);return f.some(!0)})],h.process());return d({element:k.element,destroy:k.destroy,clear:k.clear,isFocused:k.isFocused,isEnabled:b.constant(!0),refresh:b.noop,enter:k.enter,exit:k.exit})}});l("l8",["b","s"],function(d,e){return{adjust:function(c,a,b,d){c+=a;return c>d?b:c<b?d:c},findPrev:function(c,
a,b){var f=d.reverse(c.slice(0,a));c=d.reverse(c.slice(a+1));b=d.find(f.concat(c),b);return void 0!==b&&null!==b?e.some(b):e.none()},findNext:function(c,a,b){var f=c.slice(0,a);c=c.slice(a+1);b=d.find(c.concat(f),b);return e.from(b)}}});l("l5","b l8 7 s 1b 2o 38 b0".split(" "),function(d,e,c,a,b,f,g,h){var k=function(b){b=d.find(b,m);return a.from(b)},m=function(a){return h.isVisible(a.element())&&a.isEnabled()&&"hidden"!==f.get(a.element(),"visibility")};return{exit:function(a){d.each(a,function(a){a.clear();
a.exit()})},clear:function(a){d.each(a,function(a){a.clear()})},refresh:function(a){d.each(a,function(a){a.refresh()})},first:k,enterFirst:function(b,c){c.index().bind(function(c){return a.from(b[c]).filter(m)}).orThunk(function(){return k(b)}).each(function(a){a.enter()})},isEnabled:function(a){return d.exists(a,function(a){return a.isEnabled()})},locate:function(a,e){return d.find(a,function(a){var d=e.target();a=a.element();return g.closest(d,c.curry(b.eq,a))})},next:function(a,b){var c=d.indexOf(a,
b);return e.findNext(a,c,m).getOr(b)},prev:function(a,b){var c=d.indexOf(a,b);return e.findPrev(a,c,m).getOr(b)},prevNoCycle:function(b,c){var e=d.indexOf(b,c);return 0<e?a.some(b[e-1]):a.none()},nextNoCycle:function(b,c){var e=d.indexOf(b,c);return e+1<b.length?a.some(b[e+1]):a.none()},progress:function(a,b){a.exit();b.enter()},destroy:function(a){d.each(a,function(a){a.destroy()})}}});l("d7","b l2 gt l3 d6 l4 l5 an 7 59 4a 3y 21".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){return function(q,
t,s){var u=s.execute(),v=c.button({execute:u}),w=t.slice(0).concat([b(s.cancel(),v),b(s.ok(),v)]),y=n.bind(q,"keydown",function(b){var c=g.locate(w,b);if(void 0!==c&&null!==c){var e=a.isShift(b);a.is(h.TAB()[0])(b)?(e=(e?g.prev:g.next)(w,c),g.progress(c,e),b.kill()):a.is(h.ESCAPE()[0])(b)?(x(),b.kill(),u(s.cancel())):(c=c.element(),"button"===r.name(c)||e||!a.is(h.ENTER()[0])(b)?(c=[h.UP()[0],h.DOWN()[0]],e=["textarea","select","input"],a.inSet(c)(b)&&!1===d.contains(e,r.name(b.target()))&&b.kill()):
(u(s.ok()),b.kill()))}}),x=function(){g.exit(w);z.trigger.exit()},z=p.create({enter:m([]),exit:m([])});return e({enter:function(){g.enterFirst(w,s)},exit:x,clear:k.curry(g.clear,w),refresh:k.curry(g.refresh,w),isEnabled:k.curry(g.isEnabled,w),isFocused:k.curry(f.isFocused,q),events:z.registry,destroy:function(){g.destroy(w);y.unbind()}})}});l("d8","l2 l3 l4 l5 an 7 59 4a 4p 3y".split(" "),function(d,e,c,a,b,f,g,h,k,m){return function(p){var n=k([]),r=function(c,d){e.is(b.TAB()[0])(d)&&(e.isShift(d)?
a.prevNoCycle:a.nextNoCycle)(n.get(),c).each(function(b){a.progress(c,b);d.kill()})},q=m.bind(p,"keydown",function(b){var c=a.locate(n.get(),b);void 0!==c&&null!==c&&r(c,b)}),t=h.create({enter:g([]),exit:g([])}),s=function(a){return function(){return a(n.get())}};return d({element:f.constant(p),enter:function(){a.first(n.get()).each(function(a){a.enter()})},exit:function(){a.exit(n.get());t.trigger.exit()},set:function(b){a.destroy(n.get());n.set(b)},clear:s(a.clear,n),refresh:s(a.refresh,n),isEnabled:s(a.isEnabled,
n),isFocused:s(c.isFocused,p),destroy:function(){a.destroy(n.get());q.unbind()},events:t.registry})}});l("la","b l4 7 s 2v 1b 4h 32 2b b0".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=b.immutableBag(["index","focused","group","items"],[]),n=b.immutableBag(["index","sectors","sector"],[]),r=b.immutableBag(["index","candidates"],[]);return{ofFocus:function(b,k,n){return e.find(b).bind(function(b){return h.closest(b,k).bind(function(e){var h=g.descendants(e,n),h=d.filter(h,m.isVisible),k=d.findIndex(h,
c.curry(f.eq,b));return-1<k?a.some(p({index:k,focused:b,group:e,items:h})):a.none()})})},ofSector:function(b,e,k){var m=g.descendants(b,e);return h.closest(k,e).bind(function(b){var e=d.findIndex(m,c.curry(f.eq,b));return-1<e?a.some(n({index:e,sectors:m,sector:b})):a.none()})},within:function(b,e,h){b=g.descendants(b,h);e=d.findIndex(b,c.curry(f.eq,e));return-1<e?a.some(r({index:e,candidates:b})):a.none()}}});l("l6",["l8","la","s"],function(d,e,c){return{horizontal:function(a,b,f,g){return e.within(a,
f,b).bind(function(a){var b=a.index();a=a.candidates();b=d.adjust(b,g,0,a.length-1);return c.from(a[b])})}}});l("l7",["7","bs"],function(d,e){return function(c,a){var b=d.curry(a,-1,0),f=d.curry(a,1,0),g=e.onDirection(b,f),h=e.onDirection(f,b),b=d.curry(a,0,-1),f=d.curry(a,0,1),k=function(a){return a(c)()},g=d.curry(k,g),h=d.curry(k,h);return{west:g,east:h,north:b,south:f}}});l("d9","l2 l3 di l6 l4 l7 an 7 s 32 m".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){return function(n,r,q){var t=k.none();b.markSelectors(n,
[r.item()]);var s=function(c){return b.find(n).bind(function(b){return a.horizontal(n,r.item(),b,c)})},u=f(n,function(a){return s(a).bind(function(a){y(a);return q.executeOnArrow().fold(function(){return k.some(!0)},v)})}),v=function(){return b.find(n).bind(q.trigger()).map(h.constant(!0))},w=c(n,[e.rule(e.inSet(g.LEFT().concat(g.UP())),u.west),e.rule(e.inSet(g.RIGHT().concat(g.DOWN())),u.east),e.rule(e.inSet(g.SPACE().concat(g.ENTER())),v)],k.none()),y=function(a){t=k.some(a);b.set(a)};return d({element:w.element,
destroy:w.destroy,clickFocus:function(a){p.is(a,r.item())&&y(a)},clear:function(){t=k.none()},isFocused:w.isFocused,isEnabled:h.constant(!0),refresh:h.noop,enter:function(){w.enter();t.orThunk(function(){return q.first().fold(function(){return m.descendant(n,r.item())},h.apply)}).bind(y)},exit:w.exit})}});l("l9","l3 di l4 an 7 s 32".split(" "),function(d,e,c,a,b,f,g){return{delegate:function(g,k,m){return e(g,[d.basic(a.LEFT()[0],k.west),d.basic(a.RIGHT()[0],k.east),d.basic(a.UP()[0],k.north),d.basic(a.DOWN()[0],
k.south),d.rule(d.inSet(a.SPACE().concat(a.ENTER())),function(){return c.find(g).bind(m.trigger()).map(b.constant(!0))})],f.none())},findRecent:function(a,c,d,e){return e.isValid().fold(b.constant(d),function(a){return d.filter(a)}).orThunk(function(){return e.first().bind(function(a){return a()}).orThunk(function(){return g.descendant(a,c)})})}}});l("da","l2 l8 l4 l9 l7 7 s 4p 2v 2z 4h 2b 1s".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){var q=k.immutable("row","column");return function(k,s,u,v,
w){var y=u,x=v;c.markSelectors(k,[s.cell()]);var z=h(g.none()),l=function(a){return n.findIndex(a).map(function(a){return q(r.floor(a/x),a%x)})},D=function(a,b){return c.find(k).bind(function(c){return l(c).bind(function(c){var d=e.adjust(c.row(),b,0,y-1),f=e.adjust(c.column(),a,0,x-1);c=p.descendants(k,s.cell());var h=c.length-1,d=d*x,d=d+f>h?0<a?d:h:d+f;return 0<=d&&d<c.length?g.some(c[d]):g.none()})})};u=b(k,function(a,b){return D(a,b).bind(function(a){c.set(a);z.set(g.some(a));return g.some(!0)})});
var B=a.delegate(k,u,w);return d({element:B.element,destroy:B.destroy,clear:function(){z.set(g.none())},isFocused:B.isFocused,isEnabled:f.constant(!0),refresh:f.noop,enter:function(){B.enter();z.set(a.findRecent(k,s.cell(),z.get(),w));z.get().each(m.focus)},exit:B.exit,resize:function(a,b){y=a;x=b}})}});l("db","b l2 l3 l4 l5 an 7 59 4a 3y 21".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){return function(n,r,q){var t=q.ok(),s=q.cancel(),u=m.bind(n,"keydown",function(a){var e=b.locate(r,a);if(void 0!==
e&&null!==e){var g=c.isShift(a);c.is(f.TAB()[0])(a)?(g=(g?b.prev:b.next)(r,e),b.progress(e,g),a.kill()):c.is(f.ESCAPE()[0])(a)?(v(),a.kill(),s(a.target())):!g&&c.is(f.ENTER()[0])(a)?(t(a.target()),a.kill()):(e=[f.UP()[0],f.DOWN()[0]],g=["textarea","select","input"],c.inSet(e)(a)&&!1===d.contains(g,p.name(a.target()))&&a.kill())}}),v=function(){b.exit(r);w.trigger.exit()},w=k.create({enter:h([]),exit:h([])});return e({enter:function(){b.enterFirst(r,q)},exit:v,clear:g.curry(b.clear,r),refresh:g.curry(b.refresh,
r),isEnabled:g.curry(b.isEnabled,r),isFocused:g.curry(a.isFocused,n),events:w.registry,destroy:function(){b.destroy(r);u.unbind()}})}});l("33",["n"],function(d){return{set:function(e,c){if(void 0===c)throw new d("Value.set was undefined");e.dom().value=c},get:function(d){return d.dom().value}}});l("dc","l2 l3 di an 7 s 1a 33".split(" "),function(d,e,c,a,b,f,g,h){return function(k,m){var p=c(k,[e.basic(a.ENTER()[0],function(a){return m.execute().map(function(c){var d={isShift:b.constant(e.isShift(a))},
f=h.get(k);c(f,d);return!0})})],f.none());return d({element:p.element,destroy:p.destroy,clear:p.clear,isFocused:p.isFocused,isEnabled:function(){return!g.has(k,"disabled")},refresh:b.noop,enter:function(){p.enter();k.dom().setSelectionRange(0,h.get(k).length)},exit:p.exit})}});l("dd","l2 l3 l4 l5 an 7 59 4a 3y".split(" "),function(d,e,c,a,b,f,g,h,k){return function(m,p){var n=k.bind(m,"keydown",function(c){var d=a.locate(p,c);if(e.is(b.ESCAPE()[0])(c))r(),c.kill();else if(void 0!==d&&null!==d&&e.is(b.TAB()[0])(c)){var f=
(e.isShift(c)?a.prev:a.next)(p,d);a.progress(d,f);c.kill()}}),r=function(){a.exit(p);q.trigger.exit()},q=h.create({enter:g([]),exit:g([])});return d({enter:function(){a.first(p).each(function(a){a.enter()})},exit:r,clear:f.curry(a.clear,p),refresh:f.curry(a.refresh,p),isEnabled:f.curry(a.isEnabled,p),isFocused:f.curry(c.isFocused,m),destroy:function(){a.destroy(p);n.unbind()},events:q.registry})}});l("de","l2 l3 l4 l5 an 7 59 4a 3y".split(" "),function(d,e,c,a,b,f,g,h,k){return function(m,p){var n=
k.bind(m,"keydown",function(c){var d=a.locate(p,c);if(e.is(b.ESCAPE()[0])(c))r(),c.kill();else if(void 0!==d&&null!==d)if(e.is(b.UP()[0])(c))a.progress(d,a.prev(p,d)),c.kill();else if(e.is(b.DOWN()[0])(c))a.progress(d,a.next(p,d)),c.kill();else if(e.is(b.TAB()[0])(c)){var f=(e.isShift(c)?a.prev:a.next)(p,d);a.progress(d,f);c.kill()}}),r=function(){a.exit(p);q.trigger.exit()},q=h.create({enter:g([]),exit:g([])});return d({enter:function(){a.first(p).each(function(a){a.enter()})},exit:r,clear:f.curry(a.clear,
p),refresh:f.curry(a.refresh,p),isEnabled:f.curry(a.isEnabled,p),isFocused:f.curry(c.isFocused,m),events:q.registry,destroy:function(){a.destroy(p);n.unbind()}})}});l("df","b l2 l3 di l4 an 7 s 1b 2z 4h 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){return function(r,q,t){var s=q.stops().join(","),u=function(){return t.first().bind(function(a){return n.descendant(r,a)}).getOr(r)},v=function(a){var c=u();return(m.hasFocus(c)?h.some:b.find)(c).bind(function(b){var c;c=u();if(k.eq(c,b)&&0>a)c=h.none();
else{var e=p.descendants(c,s);b=d.findIndex(e,g.curry(k.eq,b))+a;c=b>=e.length?h.none():0>b?h.some(c):0<=b&&b<e.length?h.some(e[b]):h.none()}return c})};q=function(a){return v(a).bind(function(a){b.set(a);return h.some(!0)})};var w=a(r,[c.rule(c.and([c.isShift,c.inSet(f.TAB())]),g.curry(q,-1)),c.rule(c.inSet(f.TAB()),g.curry(q,1)),c.rule(c.inSet(f.SPACE().concat(f.ENTER())),function(){return b.find(r).bind(t.trigger()).map(g.constant(!0))})],h.none());return e({element:w.element,destroy:w.destroy,
clear:g.noop,isFocused:w.isFocused,isEnabled:g.constant(!0),refresh:g.noop,enter:function(){w.enter();b.set(u())},exit:w.exit})}});l("dg","l2 l3 di l6 l4 l7 an 7 s 32 m".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){return function(n,r,q){var t=function(c){return b.find(n).bind(function(b){return a.horizontal(n,r.item(),b,c)})},s=f(n,function(a){return t(a).bind(function(a){b.set(a);q.one()(n,a);return k.some(!0)})}),u=c(n,[e.rule(e.inSet(g.LEFT().concat(g.UP())),s.west),e.rule(e.inSet(g.RIGHT().concat(g.DOWN())),
s.east),e.rule(e.inSet(g.SPACE()),h.curry(k.some,!0))],k.none());return d({element:u.element,destroy:u.destroy,clear:h.noop,refresh:function(){u.isFocused()&&m.descendant(n,r.selected()).each(b.set)},isFocused:u.isFocused,isEnabled:h.constant(!0),enter:function(){u.enter();m.descendant(n,r.selected()).orThunk(function(){return m.descendant(n,r.item())}).each(function(a){p.is(a,r.selected())||q.one()(n,a);b.set(a)})},exit:u.exit})}});l("dh","b l2 l3 di l8 l4 la l7 an 7 s 59 4a 68 6m 4l 4h m 2b b0".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v,w,y){return function(x,z,l){f.markSelectors(x,[z.sector(),z.group(),z.item()]);var D=function(a){return s.descendant(a,function(a){return v.is(a,z.item())&&G(a)})},B=function(a){return s.child(a,K)},C=function(a){a=t.children(a,K);return 0<a.length?p.some(a[a.length-1]):p.none()},F=h(x,function(a){return g.ofFocus(x,z.group(),z.item()).bind(function(c){var d=c.items();c=b.adjust(c.index(),a,0,d.length-1);return p.from(d[c])})}),E=function(a){return g.ofFocus(x,
z.group(),z.item()).bind(function(b){return a(b.group()).bind(D)})},G=function(a){return 0<q.get(a)},H=function(a){return g.ofSector(x,z.sector(),a).map(function(a){return b.findPrev(a.sectors(),a.index(),G).getOr(a.sector())})},I=function(a){return g.ofSector(x,z.sector(),a).map(function(a){return b.findNext(a.sectors(),a.index(),G).getOr(a.sector())})},K=function(a){var b;if(b=v.is(a,z.group()))a=u.descendants(a,z.item()),b=d.exists(a,y.isVisible);return b},J=function(a){return function(){return a().map(function(a){f.set(a);
L.trigger.active(a);return a})}},L=r.create({enter:n([]),exit:n([]),active:n(["element"])}),N=a(x,[c.rule(c.inSet(k.ESCAPE()),function(){N.exit();L.trigger.exit();return p.some(!0)}),c.rule(c.inSet(k.RIGHT().concat(k.DOWN())),J(F.east)),c.rule(c.inSet(k.LEFT().concat(k.UP())),J(F.west)),c.rule(c.and([c.isShift,c.inSet(k.TAB())]),J(m.curry(E,function(a){return w.prevSibling(a).filter(K).orThunk(function(){return H(a).bind(C)})}))),c.rule(c.inSet(k.TAB()),J(m.curry(E,function(a){return w.nextSibling(a).filter(K).orThunk(function(){return I(a).bind(B)})}))),
c.rule(c.inSet(k.SPACE().concat(k.ENTER())),function(){return f.find(x).bind(l.trigger()).map(m.constant(!0))})],p.none());return e({element:N.element,clear:m.noop,isFocused:N.isFocused,enter:function(){N.enter();L.trigger.enter();l.first()().orThunk(function(){return D(x)}).each(function(a){f.set(a);L.trigger.active(a)})},refresh:m.noop,isEnabled:m.constant(!0),exit:N.exit,destroy:N.destroy,events:L.registry})}});l("lb",["l8","2v","1s"],function(d,e,c){return{move:function(a,b,f){var g=e.immutable("row",
"col"),h=a.length-1,k=a[b.row()]-1,h=d.adjust(b.row(),f.dr(),0,h);a=a[h]-1;k=c.max(k,a);b=c.min(a,d.adjust(b.col(),f.dc(),0,k));return g(h,b)}}});l("dj","b l2 l4 l9 la lb l7 7 s 4p 2v 4h 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){return function(q,t,s){var u=t.row(),v=t.cell();c.markSelectors(q,[u,v]);var w=m(k.none()),y=g(q,function(a,b){return C(a,b).bind(function(a){c.set(a);w.set(k.some(a));return k.some(!0)})}),x=p.immutable("row","col"),z=p.immutable("dc","dr"),l=function(a){a=n.descendants(a,
u);return d.map(a,function(a){return n.descendants(a,v).length})},D=function(a){return r.closest(a,u).bind(function(c){return b.within(q,c,u).bind(function(d){return b.within(c,a,v).map(function(a){return x(d.index(),a.index())})})})},B=function(a){var b=n.descendants(q,u);return k.from(b[a.row()]).bind(function(b){b=n.descendants(b,v);return k.from(b[a.col()])})},C=function(a,b){return c.find(q).bind(function(c){return D(c).bind(function(c){var d=l(q);c=f.move(d,c,z(a,b));return B(c)})})},F=a.delegate(q,
y,s);return e({element:F.element,destroy:F.destroy,clear:function(){w.set(k.none())},isFocused:F.isFocused,isEnabled:h.constant(!0),refresh:h.noop,enter:function(){F.enter();w.set(a.findRecent(q,t.cell(),w.get(),s));w.get().each(c.set)},exit:F.exit})}});l("dk",["l4"],function(d){return function(e,c,a,b,f){d.markSelectors(e,[c.cell()])}});l("8y","1o c d6 d7 d8 d9 da db dc dd de df dg dh di dj dk 7 s 59 4a".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v,w,y,x){c={single:t,multiple:m,multipleAll:p,
flow:f,grid:g,sectors:q,radio:r,input:k,dialog:a,button:c,inlineDialog:h,tabular:s,page:n,dynamic:b};var z={grid:u};u=function(a,b){var c=w.from(z[b]).getOr(v.noop);return function(){c.apply(null,arguments);return{element:v.noop,clear:v.noop,isFocused:v.noop,isEnabled:v.noop,refresh:v.noop,enter:v.noop,exit:v.noop,events:x.create({enter:y([]),exit:y([]),active:y([])}).registry,destroy:v.noop,set:v.noop,clickFocus:v.noop,resize:v.noop}}};return e.detect().deviceType.isTouch()?d.map(c,u):c});l("cm",
"kx ky kz l0 l1 8b c gt 8y s 59 4a 4b 3y 2z".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t){return function(s,u){var v=e(u),w=g.detect().deviceType.isTouch()?c(s,v):b(s,v);f.toolbar(w.main(),u("aria.label.toolbar"));f.group(w.mores());var y=n.create({drawer:r(["delta","total"],w.events.drawer),grow:r([],w.events.grow),shrink:p([]),transitionend:p(["property"]),exit:p([])}),x=q.bind(w.element(),"transitionend",function(a){y.trigger.transitionend(a.raw().propertyName)}),z=m.none(),l=h.sectors({first:m.none,
trigger:d.trigger}),D=k.sectors(w.element(),a,l);D.events.exit.bind(function(){z=m.none();y.trigger.exit()});D.events.active.bind(function(a){z=m.some(a.element())});var B=function(){return D.isFocused()},C=function(){z.each(t.focus)};w.events.shrink.bind(function(){t.search(w.mores()).isSome()&&v.focus();y.trigger.shrink()});return{element:w.element,refresh:w.refresh,add:w.add,enter:function(){D.enter()},destroy:function(){D.exit();z=m.none();x.unbind();w.destroy();D.destroy()},focused:B,restore:C,
refocus:function(){B()&&C()},events:y.registry}}});l("ak",["cj","ck","cl","cm"],function(d,e,c,a){return{toolbar:function(b,c){return a(b,c)},menu:function(a,c,d){return e.create(a,c,d)},popup:function(a,d,e,h,k){return c(a,d,e,h,k)},menuSystem:function(a,c,e){return d(a,c,e)}}});l("ip",["b","c","s","37"],function(d,e,c,a){var b=e.detect(),f=b.deviceType.isTouch,g=function(b,c){return a.screen.width>=b&&a.screen.height>=c},h=function(){return!g(620,700)&&f()};return{isTouch:f,choice:function(a,b){return d.foldl(a,
function(a,b){return a.orThunk(function(){return b.predicate()?c.some(b.value()):c.none()})},c.none()).getOr(b)},isLarge:function(){return g(620,700)},isLargeTouch:function(){return g(620,700)&&f()},isSmallTouch:h,isLargeDesktop:function(){return g(620,700)&&!f()},isSmallAndroid:function(){return h()&&b.deviceType.isAndroid()}}});l("cn",["1o","c","4e","ip"],function(d,e,c,a){e=e.detect();a={"ephox-platform-desktop":!e.deviceType.isTouch(),"ephox-platform-touch":e.deviceType.isTouch(),"ephox-platform-small-touch":a.isSmallTouch(),
"ephox-platform-android":e.deviceType.isAndroid(),"ephox-platform-ios":e.deviceType.isiOS(),"ephox-platform-ie":e.browser.isIE()||e.browser.isSpartan(),"ephox-platform-firefox":e.browser.isFirefox()};var b=[];d.each(a,function(a,c){!0===a&&b.push(c)});return{addClasses:function(a){c.add(a,b)}}});l("lc","b 53 s 34 3f 59 4a 1y 2p 2r".split(" "),function(d,e,c,a,b,f,g,h,k,m){return function(){var p=e.div();h.add(p,a.resolve("bannerarium"));h.add(p,a.resolve("layer-above-editor"));var n=c.some([]),r=
b.create(),q=function(a){n=n.bind(function(b){b=d.filter(b,function(b){return b!==a});return c.some(b)});t(a)},t=function(a){a.destroy();r.unbind(a.events.close);m.remove(a.element())},s=g.create({close:f(["banner"])});return{element:function(){return p},display:function(a){n.fold(function(){a.destroy()},function(b){b.push(a);r.bind(a.events.close,function(){q(a);s.trigger.close(a)});k.append(p,a.element())})},hide:q,destroy:function(){m.remove(p);n=n.bind(function(a){d.each(a,t);return c.none()})},
events:s.registry}}});l("co",["lc","59","4a"],function(d,e,c){return function(){var a=d();a.events.close.bind(function(){b.trigger.resize()});var b=c.create({resize:e([])});return{element:a.element,display:function(c){a.display(c);b.trigger.resize()},hide:function(c){a.hide(c);b.trigger.resize()},destroy:a.destroy,events:b.registry}}});l("bq",["2j"],function(d){return{atob:function(e){return d.getOrDie("atob")(e)},requestAnimationFrame:function(e){d.getOrDie("requestAnimationFrame")(e)}}});l("aa",
["3x"],function(d){return function(e,c){var a=null,b=null;return{throttle:function(){b=arguments;null===a&&(a=d(function(){e.apply(null,b);b=a=null},c))}}}});l("th","bq 7 aa 2b b0 2t 2u 37".split(" "),function(d,e,c,a,b,f,g,h){var k=function(a,b){var c=g(b,500);return function(){f(c)}},m=function(b,c){var d=new h.MutationObserver(c);d.observe(a.owner(b).dom(),{attributes:!0,subtree:!0,childList:!0,attributeFilter:["style","class"]});return function(){d.disconnect()}},p=void 0!==h.MutationObserver&&
null!==h.MutationObserver?m:k;return{onShow:function(a,f){if(b.isVisible(a))return d.requestAnimationFrame(f),e.noop;var g=c(function(){b.isVisible(a)&&(h(),d.requestAnimationFrame(f))},100),h=p(a,g.throttle);return h}}});l("ti",["b","s","1b"],function(d,e,c){var a=[],b=function(b){return d.findIndex(a,function(a){return c.eq(a.element,b)})};return{begin:function(c,d){if(-1===b(c)){var e=d();a.push({element:c,unbind:e})}},query:function(c){c=b(c);return-1===c?e.none():e.some(a[c])},end:function(c){c=
b(c);if(-1!==c){var d=a[c];a.splice(c,1);d.unbind()}}}});l("ld","b bq 7 s 1b 3y l 68 th b0 2s ti 3x 37".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q){var t=function(a){return{element:a,handlers:[],lastWidth:p.get(a),lastHeight:h.get(a)}},s=[],u=function(a){return d.findIndex(s,function(c){return b.eq(c.element,a)})},v=function(a){var b=p.get(a.element),e=h.get(a.element);if(b!==a.lastWidth||e!==a.lastHeight)a.lastWidth=b,a.lastHeight=e,d.each(a.handlers,c.apply)},w=function(a){var b=a.element;
m.isVisible(b)?v(a):n.begin(b,function(){return k.onShow(b,function(){n.end(b);v(a)})})},y=!1,x=function(){y=!1;d.each(s,w)},z=function(){y||(y=!0,e.requestAnimationFrame(x))},l=a.none(),D=function(){l.each(function(b){b.unbind();l=a.none()})};return{bind:function(c,e){var h=d.find(s,function(a){return b.eq(a.element,c)});void 0===h&&(h=t(c),s.push(h));h.handlers.push(e);l.isNone()&&(l=a.some(f.bind(g.fromDom(q),"resize",z)));r(function(){-1!==u(h.element)&&w(h)},100)},unbind:function(a,b){n.end(a);
var c=u(a);if(-1!==c){var e=d.indexOf(s[c].handlers,b);-1!==e&&(s[c].handlers.splice(e,1),0===s[c].handlers.length&&s.splice(c,1),0===s.length&&D())}}}});l("cp","bq 7 s 59 4a 68 ld 2s".split(" "),function(d,e,c,a,b,f,g,h){return function(k){var m=b.create({change:a(["width","height","element"])}),p=void 0!==k.resize&&void 0!==k.resize.container?c.some(k.resize.container):c.none(),n=c.none();return{hookup:function(a){var b=p.getOr(a),t=function(){k.resize&&k.resize.callback&&k.resize.callback();var a=
h.get(b),c=f.get(b);m.trigger.change(a,c,b)};n=c.some({target:e.constant(b),f:t});d.requestAnimationFrame(function(){g.bind(b,t)})},destroy:function(){n.each(function(a){g.unbind(a.target(),a.f)})},events:m.registry}}});l("cq","1p 7 s 34 1y l 2p 3d 2b".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(c,d){var e=f.fromTag("div");b.add(e,a.resolve(d));g.append(e,c);return e};return{build:function(e,n,r){c.from(n).filter(d.isPrototypeOf).map(f.fromDom).each(function(c){var d=f.fromTag("div");b.add(d,
a.resolve("flex-row"));var n=f.fromTag("div");b.add(n,a.resolve("flex-column"));h.append(n,k.children(e));g.append(e,d);g.append(d,n);g.append(d,m(c,"side-bar"))});c.from(r).filter(d.isPrototypeOf).map(f.fromDom).each(function(a){g.append(e,m(a,"bottom-bar"))})}}});l("cr",["7","59","4a"],function(d,e,c){return function(){var a=c.create({change:e(["width","height","element"])});return{hookup:d.noop,destroy:d.noop,events:a.registry}}});l("le",["7","s","6v","3d","2s"],function(d,e,c,a,b){return function(){return{updateWidth:d.noop,
clearWidth:d.noop,build:d.identity,update:d.noop,width:b.getOuter,init:function(a,b,c,d,e){a.refresh()},state:d.constant({toolbar:{drag:e.none()}}),integrate:function(b,c,d,e){a.append(b,[c.element(),d.element(),e])},destroy:d.noop,events:c(["changed"])}}});l("xk",["57"],function(d){var e=d.exactly(["compare","extract","mutate","sink"]),c=d.exactly(["element","start","stop","destroy"]);d=d.exactly(["forceDrop","drop","move","delayDrop"]);return{mode:e,sink:c,api:d}});l("118",["4j"],function(d){return{resolve:d.create("ephox-dragster").resolve}});
l("xl","118 6 1y 2o l 2r".split(" "),function(d,e,c,a,b,f){return function(g){g=e.merge({layerClass:d.resolve("blocker")},g);var h=b.fromTag("div");a.setAll(h,{position:"fixed",left:"0px",top:"0px",width:"100%",height:"100%"});c.add(h,d.resolve("blocker"));c.add(h,g.layerClass);return{element:function(){return h},destroy:function(){f.remove(h)}}}});l("qv","xk xl s 3o 3y 2p 2r".split(" "),function(d,e,c,a,b,f,g){return d.mode({compare:function(b,c){return a(c.left()-b.left(),c.top()-b.top())},extract:function(b){return c.some(a(b.x(),
b.y()))},sink:function(a,c){var m=e(c),p=b.bind(m.element(),"mousedown",a.forceDrop),n=b.bind(m.element(),"mouseup",a.drop),r=b.bind(m.element(),"mousemove",a.move),q=b.bind(m.element(),"mouseout",a.delayDrop);return d.sink({element:m.element,start:function(a){f.append(a,m.element())},stop:function(){g.remove(m.element())},destroy:function(){m.destroy();n.unbind();r.unbind();q.unbind();p.unbind()}})},mutate:function(a,b){a.mutate(b.left(),b.top())}})});l("119",["s","59","4a"],function(d,e,c){return function(){var a=
d.none(),b=function(b,c){var e=a.map(function(a){return b.compare(a,c)});a=d.some(c);return e},f=c.create({move:e(["info"])});return{onEvent:function(a,c){c.extract(a).each(function(a){b(c,a).each(function(a){f.trigger.move(a)})})},reset:function(){a=d.none()},events:f.registry}}});l("11a",["7"],function(d){return function(e){return{onEvent:function(c,a){},reset:d.noop}}});l("xm",["119","11a"],function(d,e){return function(){var c=e(),a=d(),b=c;return{on:function(){b.reset();b=a},off:function(){b.reset();
b=c},isOn:function(){return b===a},onEvent:function(a,c){b.onEvent(a,c)},events:a.events}}});l("qw","xk xm 6t 59 4a 9".split(" "),function(d,e,c,a,b,f){return{setup:function(g,h,k){var m=!1,p=b.create({start:a([]),stop:a([])}),n=e(),r=function(){s.stop();n.isOn()&&(n.off(),p.trigger.stop())},q=c(r,200);n.events.move.bind(function(a){h.mutate(g,a.info())});var t=function(a){return function(){var b=f.prototype.slice.call(arguments,0);if(m)return a.apply(null,b)}},s=h.sink(d.api({forceDrop:r,drop:t(r),
move:t(function(a,b){q.cancel();n.onEvent(a,h)}),delayDrop:t(q.schedule)}),k);return{element:s.element,go:function(a){s.start(a);n.on();p.trigger.start()},on:function(){m=!0},off:function(){m=!1},destroy:function(){s.destroy()},events:p.registry}}}});l("iw",["qv","qw","9"],function(d,e,c){return{transform:function(a,b){var c=void 0!==b?b:{};return e.setup(a,void 0!==c.mode?c.mode:d,b)}}});l("12b",["59","4a","3p"],function(d,e,c){return{both:function(a){var b=e.create({relocate:d(["x","y","deltaX",
"deltaY"])});return{mutate:function(d,e){var h=c.absolute(a),k=h.left()+d,h=h.top()+e;b.trigger.relocate(k,h,d,e)},events:b.registry}}}});l("z4","iw 12b 59 4a 2o 3y l 6u q".split(" "),function(d,e,c,a,b,f,g,h,k){return function(m,p){var n=a.create({relocate:c(["x","y","deltaX","deltaY"]),dragend:c([])}),r=e.both(m);b.set(m,"position","absolute");var q=d.transform(r),t=f.bind(m,"mousedown",function(a){0!==a.raw().button||h.closest(a.target(),p)||(q.on(),q.go(g.fromDom(k.body)))});q.events.stop.bind(function(){n.trigger.dragend();
q.off()});r.events.relocate.bind(function(a){n.trigger.relocate(a.x(),a.y(),a.deltaX(),a.deltaY())});return{blocker:q.element,destroy:function(){t.unbind();q.destroy()},events:n.registry}}});l("12c",["b","s","2v","1s"],function(d,e,c,a){var b=c.immutable("hx","hy","position","x","y"),f=function(a,c,d,e,f,n){n=c.x();c=c.y()-d;return(c>=a.y()&&c<=a.y()+a.h()?[b(n,c,"absolute",n,c)]:[]).concat([b(f,a.y(),"fixed",f-e.left(),a.fy())])};return{detect:function(b,c,k,m,p,n){b=f(b,c,p,n,k,m);b=d.find(b,function(b){return 10>
a.abs(m-b.hy())&&38>a.abs(k-b.hx())});return e.from(b)}}});l("12d",["7"],function(d){return function(e,c,a,b){return{x:d.constant(e),y:d.constant(c),width:d.constant(a),height:d.constant(b),right:d.constant(e+a),bottom:d.constant(c+b)}}});l("z7",["12d","68","3p","2s"],function(d,e,c,a){return{box:function(b){var f=c.absolute(b),g=a.getOuter(b);b=e.getOuter(b);return d(f.left(),f.top(),g,b)}}});l("14t",["4j"],function(d){return{resolve:d.create("ephox-ego").resolve}});aa("e2",parseInt);l("12e","14t 7 s 1a 1u e2".split(" "),
function(d,e,c,a,b,f){return{make:function(g){var h="data-"+d.resolve(g+"-left"),k="data-"+d.resolve(g+"-top"),m="data-"+d.resolve(g+"-position");return{get:function(d){var g=f(a.get(d,h),10),r=f(a.get(d,k),10);d=a.get(d,m);return b(g)||b(r)?c.none():c.some({left:e.constant(g),top:e.constant(r),position:e.constant(d)})},set:function(b,c,d,e){a.set(b,m,c);a.set(b,h,d+"px");a.set(b,k,e+"px")},clear:function(b){a.remove(b,m);a.remove(b,h);a.remove(b,k)}}}}});l("z5","12c z7 12e 2v 3o 2a 2b".split(" "),
function(d,e,c,a,b,f,g){var h=c.make("pre-snap");a.immutable("fixed","loc");var k=function(a,b,c,d,e,f){return h.get(b).fold(function(){return a.fromLocation(b,c,d)},function(c){return a.fromFixed(b,c.left()+e,c.top()+f)})},m=function(a,b,c,h){var k=g.owner(b),k=f.get(k);b=e.box(b);c=c.loc();return d.detect(a,b,c.left(),c.top(),h,k)};return{move:function(a,c,d,e,f,g){var u=a.graph(),v=a.lazyTheatre(),w=a.lazyHeight();d=k(u,c,d,e,f,g);var y=d.loc(),x=d.fixed();return m(v,a.container(),d,w).fold(function(){var a=
u.boundToFixed(v,c,y.left(),y.top(),x.left(),x.top(),w);h.set(c,"fixed",a.left(),a.top());return{position:"fixed",left:a.left()+"px",top:a.top()+"px"}},function(a){var d=u.boundToFixed(v,c,y.left(),y.top(),x.left(),x.top(),w);h.set(c,"fixed",d.left()+"px",d.top()+"px");d="absolute"===a.position()?u.locationToAbsolute(c,a.x(),a.y()):b(a.x(),a.y());return{position:a.position(),left:d.left()+"px",top:d.top()+"px"}})},forget:function(a){h.clear(a)}}});l("z8",[],function(){return{isInside:function(d,e,
c){return!(e>d.y()+d.h()||c<d.y())},isAllInside:function(d,e,c){return e>d.y()&&e<d.y()+d.h()&&c>d.y()&&c<d.y()+d.h()}}});l("z6","12e z8 s 3o 2o 3p e2".split(" "),function(d,e,c,a,b,f,g){var h=d.make("old"),k=function(c,d,e){return b.getRaw(d,"left").bind(function(c){return b.getRaw(d,"top").map(function(b){var d=g(c,10);b=g(b,10);return a(d,b)})}).getOrThunk(function(){return c.locationToAbsolute(d,e.left(),e.top())})},m=function(a,d,g,m,p,u){g=f.absolute(m);p="absolute"===b.get(m,"position");var v=
e.isAllInside(d,g.top(),g.top()+u());return p&&!v?(p=k(a,m,g),h.set(m,"absolute",p.left(),p.top()),a=a.absoluteToFixed(m,g.left(),g.top()),d=g.top()<=d.y()?d.fy():d.fy()+d.h()-u(),c.some({position:"fixed",left:a.left()+"px",top:d+"px"})):c.none()},p=function(a,d,f,g,k,m){return h.get(g).bind(function(f){var k="fixed"===b.get(g,"position"),p=a.absoluteToLocation(g,f.left(),f.top()),p=e.isAllInside(d,p.top(),p.top()+m());return k&&p?(h.clear(g),c.some({position:"absolute",left:f.left()+"px",top:f.top()+
"px"})):c.none()})};return{forget:function(a){h.clear(a)},update:function(a,c,d,e,f,g){m(a,c,d,e,f,g).orThunk(function(){return p(a,c,d,e,f,g)}).each(function(a){b.setAll(e,a)})},state:function(a){return h.get(a)},set:function(a,b){h.set(a,b.position(),b.left(),b.top())}}});l("tj","z4 z5 z6 7 s 59 4a 4b 2o 3p".split(" "),function(d,e,c,a,b,f,g,h,k,m){return{none:function(b,c){var d=g.create({dragend:f([]),moved:f([])});return{blocker:a.die("no blocker"),setState:a.noop,getState:a.constant({}),init:function(a,
b){k.setAll(c,{left:a+"px",top:b+"px",position:"absolute"});d.trigger.moved()},update:a.noop,destroy:a.noop,events:d.registry}},except:function(b){return function(n,r){var q=d(r,b.join(",")),t=g.create({dragend:h([],q.events.dragend),moved:f([])});q.events.relocate.bind(function(a){var b=a.x(),d=a.y(),f=a.deltaX();a=a.deltaY();b=e.move(n,r,b,d,f,a);k.setAll(r,b);"absolute"!==b.position&&c.forget(r)});q.events.dragend.bind(function(){t.trigger.moved()});return{blocker:q.blocker,setState:function(a){k.setAll(r,
{position:a.position(),left:a.x()+"px",top:a.y()+"px"})},getState:function(){var b=m.viewport(r),c=k.get(r,"position");return{x:b.left,y:b.top,position:a.constant(c)}},init:function(a,b){k.setAll(r,{left:a+"px",top:b+"px",position:"absolute"});t.trigger.moved()},update:function(){e.forget(r)},destroy:function(){q.destroy()},events:t.registry}}}}});l("tk","6 s 4a 4b 2o 3p 2s 1s e2".split(" "),function(d,e,c,a,b,f,g,h){return{register:function(g,m,p,n){g.container();var r=p(g,m),q=n(g,m);p=c.create({dragend:a([],
r.events.dragend),appear:a(["element"],q.events.appear),disappear:a(["element"],q.events.disappear)});r.events.moved.bind(function(){s();t=!0});q.events.scrolled.bind(function(){s()});var t=!1,s=function(){r.update();q.update();var a=g.lazyTheatre(),c=f.absolute(m),a=h.max(0,a.x()+a.w()-c.left());b.set(m,"max-width",a+"px")};return{blocker:r.blocker,setState:function(a){r.setState(a);q.setState(a);s();t=!0},state:function(){if(!t)return e.none();var a=d.deepMerge(r.getState(),q.getState());return e.some(a)},
init:function(a,b){r.init(a,b);s()},update:s,destroy:function(){q.destroy();r.destroy()},events:p.registry}}}});l("tl","z6 z7 z8 7 59 4a 3y 2a 2b".split(" "),function(d,e,c,a,b,f,g,h,k){return{transitions:function(m,p){var n=m.container(),r=k.defaultView(p),q=f.create({appear:b(["element"]),disappear:b(["element"]),scrolled:b([])}),t=g.bind(r,"scroll",function(){q.trigger.scrolled()});return{update:function(){var a=m.lazyTheatre(),b=e.box(n);if(c.isInside(a,b.y(),b.bottom())){q.trigger.appear(p);
var f=m.graph(),g=k.owner(n),g=h.get(g);d.update(f,a,b,p,g,m.lazyHeight)}else q.trigger.disappear(p)},destroy:function(){t.unbind()},setState:function(b){b.transition().each(a.curry(d.set,p))},getState:function(){return{transition:a.constant(d.state(p))}},events:q.registry}}}});l("12f",["2v","3o","2a","2b"],function(d,e,c,a){var b=d.immutable("fixed","loc");return function(d){var g=function(b,d,f){b=a.owner(b);b=c.get(b);d-=b.left();f-=b.top();return e(d,f)},h=function(b,d,f){b=a.owner(b);b=c.get(b);
d+=b.left();f+=b.top();return e(d,f)};return{locationToFixed:g,fixedToLocation:h,absoluteToFixed:function(b,g,h){var n=d();b=a.owner(b);b=c.get(b);g-=b.left();return e(g,n.top()-h)},locationToAbsolute:function(a,b,c){a=d();return e(b,c).translate(-a.left(),-a.top())},absoluteToLocation:function(a,b,c){a=d();return e(b,c).translate(a.left(),a.top())},fromFixed:function(a,c,d){var f=e(c,d);a=h(a,c,d);return b(f,a)},fromLocation:function(a,c,d){a=g(a,c,d);c=e(c,d);return b(a,c)},boundToFixed:function(a,
b,c,d,f,g,h){b=c<a.x()?a.fx():c>a.x()+a.w()?a.fx()+a.w():f;a=d<a.y()?a.fy():d+h>a.y()+a.h()?a.fy()+a.h()-h:g;return e(b,a)}}}});l("z9",["12f","7"],function(d,e){return function(c,a,b,f){a=d(a);return{lazyTheatre:c,graph:e.constant(a),lazyHeight:b,container:e.constant(f)}}});l("tm","z9 7 3o 68 3p 2a 32 2b 37".split(" "),function(d,e,c,a,b,f,g,h,k){return function(m,p){var n=m.isInline()?m.element():h.parent(m.placeholder()).getOr(m.placeholder());return d(function(){var a=f.get();return{x:a.left,y:a.top,
w:e.constant(k.innerWidth),h:e.constant(k.innerHeight),fx:e.constant(0),fy:e.constant(0)}},function(){return m.isInline()?c(0,0):b.absolute(n)},function(){var b=g.descendant(p,".ephox-chameleon-toolbar").getOr(p);return a.getOuter(b)},n)}});l("6d","34 1y 2o 3p 2b 2s".split(" "),function(d,e,c,a,b,f){var g=d.resolve("drag-show"),h=d.resolve("fade-container");return{width:function(d,e){return c.getRaw(d,"max-width").fold(function(){return b.owner(e).dom().defaultView.innerWidth-a.absolute(e).left()},
function(a){return parseInt(a,10)})},updateWidth:function(a,b,d){b=0===d.extra().length?d.withinWidth():d.withinWidth()+f.getOuter(b.group());0<b&&c.set(a,"width",b+"px")},clearWidth:function(a){c.remove(a,"width")},offsetFrom:function(b,c,d,e){c=void 0!==e.toolbar.offset?e.toolbar.offset:{left:0,top:-1*d};d=a.absolute(b.element());b=b.isInline()?{left:d.left(),top:d.top()}:{left:0,top:0};return{left:b.left+c.left,top:b.top+c.top}},initFade:function(a,b){e.add(b,g)},fadeIn:function(a,b){e.remove(a,
h);e.add(b,g)},fadeOut:function(a,b){e.remove(b,g);e.add(a,h)}}});l("lf","8b tj tk tl c 53 7 34 tm 6d 4a 4b 1y 4e 2o 68 2p 3d".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v){return function(w,y){var x=f.div();t.set(x,"position","relative");r.add(x,h.resolve("dragging-container"));var z=f.div();r.add(z,h.resolve("draggable-container"));var l=w.isInline()?y:z,D=k(w,l,z),B=a.transitions,C=e.except([".ephox-pastry-button","."+h.resolve("banner-buttons")+" *",".ephox-polish-ui-container",".ephox-polish-socket"]),
F=c.register(D,l,C,B);m.initFade(l,z);F.events.appear.bind(g.curry(m.fadeIn,l,z));F.events.disappear.bind(g.curry(m.fadeOut,l,z));r.add(z,h.resolve("layer-above-editor"));q.add(F.blocker(),[h.resolve("above-outside"),h.resolve("dragging")]);var E=f.span();d.hidden(E,!0);q.add(E,[h.resolve("toolbar-drag-handle"),h.resolve("general-drag-handle"),"ephox-textbox-font",h.resolve("icon")]);D=b.detect();D.browser.isIE()&&10===D.browser.version.major&&r.add(E,h.resolve("ie10"));return{updateWidth:g.curry(m.updateWidth,
l),clearWidth:g.curry(m.clearWidth,l),build:function(a){return[E].concat(a)},width:g.curry(m.width,l),init:function(a,b,c,d,e){var f=t.preserve(l,function(){t.set(l,"visibility","hidden");t.remove(l,"display");a.refresh();return s.get(a.element())});e.toolbar.drag.fold(function(){var a=m.offsetFrom(w,l,f,d);F.init(a.left,a.top)},F.setState);v.append(z,[a.element(),b.element()])},update:function(){F.update()},state:function(){return{toolbar:{drag:F.state()}}},integrate:function(a,b,c,d){u.append(z,
b.element());w.isInline()?(v.append(x,[z,d]),u.append(y,x)):v.append(y,[z,d])},destroy:function(){F.destroy()},events:p.create({changed:n([],F.events.dragend)}).registry}}});l("lg","tj tk tl 7 s 34 tm 6d 4a 4b 1y 2o l 68 2p 3d".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s){return function(u,v){var w=r.fromTag("div");n.set(w,"position","relative");p.add(w,f.resolve("floating-container"));var y=r.fromTag("div");p.add(y,f.resolve("draggable-container"));var x=u.isInline()?v:y,l=g(u,x),A=e.register(l,
x,d.none,c.transitions);h.initFade(x,y);A.events.appear.bind(a.curry(h.fadeIn,x,y));A.events.disappear.bind(a.curry(h.fadeOut,x,y));p.add(y,f.resolve("layer-above-editor"));return{updateWidth:a.curry(h.updateWidth,x),clearWidth:a.curry(h.clearWidth,x),build:a.identity,width:a.curry(h.width,x),init:function(a,b,c,d,e){c=n.preserve(x,function(){n.set(x,"visibility","hidden");n.remove(x,"display");a.refresh();return q.get(a.element())});d=h.offsetFrom(u,x,c,d);A.init(d.left,d.top);s.append(y,[a.element(),
b.element()])},update:function(){A.update()},state:a.constant({toolbar:{drag:b.none()}}),integrate:function(a,b,c,d){t.append(y,b.element());u.isInline()?(s.append(w,[y,d]),t.append(v,w)):s.append(v,[y,d])},destroy:function(){A.destroy()},events:k.create({changed:m([],A.events.dragend)}).registry}}});l("cs",["le","lf","lg"],function(d,e,c){return{setup:function(a,b,f,g){return(!0===f.toolbar.draggable?e:void 0!==f.toolbar.offset||a.isInline()?c:d)(a,b)}}});l("74","ak 53 7 54 7b 1f cn 34 co cp cq cr ay cs 1a 1y 4e 2o l 2p 2r 2s".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v,w,y,x,l){return function(A,D,B,C,F,E){var G=w.fromTag("div");C.updateUi(G);u.add(G,[r.editorContainer(),"ephox-textbox-font",h.resolve("layer-editor")]);t.set(G,"lang",f.get());g.addClasses(G);var H=q.setup(A,G,F,E),I=d.toolbar(H,b.translate);!1===F.toolbar.visible&&s.add(G,"ephox-polish-no-toolbar");D.events.toolbar.bind(I.enter);I.events.exit.bind(A.focus);var K=k(),J=e.div();s.add(J,h.resolve("socket"));var L=F.autoresize?m(F):n();H.integrate(G,I,K,
J);p.build(G,F.sideBar,F.bottomBar);var N=A.isInline()?function(){v.set(K.element(),"min-width",l.getOuter(A.element())+"px")}:c.noop;L.events.change.bind(function(a){I.refresh();B.refresh();N()});H.events.changed.bind(function(){I.refresh()});return{element:function(){return G},socket:function(a){a.connect(J)},viewport:c.constant(J),connect:function(b){y.append(b,G);a.detect(G);L.hookup(A.element());return!0},destroy:function(){L.destroy();I.destroy();H.destroy();K.destroy();x.remove(G)},toolbar:I,
position:function(){N();H.init(I,K,J,F,E)},refresh:function(){H.update();I.refresh()},banners:K.element,displayBanner:K.display,hideBanner:K.hide,state:H.state}}});l("5b","a c 1p 7 s 72 73 74 75 76 l".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=function(a){a=m.absolute(a);var b=m.view();a=f.intersect(a,b);return k(a.x(),a.y(),a.width(),a.height())};return{build:function(a,b,c,d,e,f,k,m){var p=h(a,b,c,f,k,m),n=d.tabbed(p);n.init();return{element:p.element,socket:p.socket,viewport:p.viewport,init:function(b,
d,h){d=n.config(a.isInline(),d,e,h);g.setup(p,f,a,b,c,d);n.loaded()},connect:p.connect,destroy:function(){p.destroy();n.destroy()},displayBanner:p.displayBanner,hideBanner:p.hideBanner,position:p.position,refresh:p.refresh,tabstrip:p.toolbar,state:p.state}},bounds:function(){var f=function(a){var e=function(){return b.from(a.bounds()).filter(c.isPrototypeOf).map(p.fromDom).map(n).getOrThunk(m.view)};return d.isFunction(a.bounds)?e:m.view};return e.detect().deviceType.isTouch()?a.constant(m.view):
f}()}});l("41",["s","p","5a","5b"],function(d,e,c,a){return{settings:function(b){return{onprem:!0,blocktag:{styles:[{rule:"p"},{rule:"h1"},{rule:"h2"},{rule:"h3"},{rule:"h4"},{rule:"div"},{rule:"pre"}],bundled:!0},image:{bundled:!0},imageEdit:{bundled:!0},imageupload:{immediate:!1,bundled:!1},content:{css:b+"/css",tabindex:null,stylesheets:[],documentStyles:"",prettyprint:!0},ui:{layout:a,isFullScreen:!1,toolbar:{draggable:!1},autoresize:!0,locale:{},editorName:e.value("debug"),bounds:null,showHelpHint:!1},
shortcuts:{features:!0},spelling:{bundled:!0,autocorrect:!0,scanView:!0,multilingual:!0,menu:!0},specialchar:{bundled:!0},fileupload:{bundled:!0,allowLocalImages:!0},horizontalrule:{bundled:!0},media:{bundled:!0},mentions:{bundled:!1},registration:{bundled:!1},help:{baseUrl:b+"/html",integration:{},bundled:!0},draganddrop:{bundled:!0},wordcount:{bundled:!0},formatting:{bundled:!0},alignindent:{bundled:!0},directionality:{bundled:!0},parlance:{bundled:!0,languages:"en_us en_gb es fr de pt zh".split(" ")},
font:{faces:[],bundled:!0},lists:{bundled:!0},link:{bundled:!0},linkvalidator:{bundled:!1},removeformat:{bundled:!0},fullscreen:{bundled:!0,autoresize:!1},editorcontext:{bundled:!0},macros:{whitelist:d.none(),bundled:!0},highlighter:{external:[],bundled:!0},table:{bundled:!0},contextmenu:{bundled:!0},project:{apiKey:null},smartclipboard:{bundled:!0,copy:{},paste:{forceText:!1,baseUrl:b+"/js",swf:b+"/flash/textboxpaste.swf",officeStyles:"prompt",htmlStyles:"merge",allowLocalImages:!0,enableFlashImport:!0}},
resize:{bundled:!0},platform:{toolbar:{items:c,contextual:["table-tools","image-tools"]},allowLocalImages:!0,fillscreen:!1},codeview:{bundled:!0,showButton:!0,mode:"pencil",css:b+"/css",js:b+"/js"},findreplace:{bundled:!0},accessibility:{bundled:!0},plaincodeview:{bundled:!0},embed:{inlineStyles:!0,bundled:!1}}},state:function(){return{spelling:{words:{},language:d.none()},undo:{initial:{raw:"",marked:""},undo:[],redo:[]},profile:{spelling:!1,nativeSpelling:!0,autocorrect:!0,capitalisation:!1,linkpreviews:!1},
content:{raw:"",marked:""},ui:{toolbar:{drag:d.none()}},macros:{customs:{}},filters:{customs:[]},laundry:{dirty:!1},linkvalidator:{ignore:[],cache:{}},embed:{cache:{}}}}}});l("42",["s","46","59","4a"],function(d,e,c,a){return function(b){var f=d.none(),g=function(a){return function(){var c=b.get()[a];if(null===c||void 0===c)throw"can't find instance method: "+a;return c.apply(null,arguments)}},h=function(){var a=f.getOrDie("Cannot reconnect the editor before it has been connected the first time.");
g("connect")(a)&&k.trigger.connected()},k=a.create({connected:c([])});return e.external({activateInline:g("activateInline"),deactivateInline:g("deactivateInline"),content:g("content"),keyboard:g("keyboard"),smartview:g("smartview"),macros:g("macros"),ui:g("ui"),filter:g("filter"),undo:g("undo"),operations:g("operations"),getMode:g("getMode"),element:g("element"),connect:function(a){f=d.some(a);h()},reconnect:h,focus:g("focus"),getContent:g("getContent"),setContent:g("setContent"),insertHtmlAtCursor:g("insertHtmlAtCursor"),
state:g("state"),communication:g("communication"),uploader:g("uploader"),isDirty:g("isDirty"),setDirty:g("setDirty"),isPrettyPrinting:g("isPrettyPrinting"),events:k.registry})}});l("ok",["b","s","2v"],function(d,e,c){var a=c.immutable("item","mode");c=function(c,d,e,f){var g=void 0!==f?f:b;return c.property().parent(d).map(function(b){return a(b,g)})};var b=function(b,c,d,e){var g=void 0!==e?e:f;return d.sibling(b,c).map(function(b){return a(b,g)})},f=function(b,c,d,e){var g=void 0!==e?e:f;b=b.property().children(c);
return d.first(b).map(function(b){return a(b,g)})},g=[{current:c,next:b,fallback:e.none()},{current:b,next:f,fallback:e.some(c)},{current:f,next:f,fallback:e.some(b)}],h=function(a,b,c,f,r){var q=d.find(void 0!==r?r:g,function(a){return a.current===c});return void 0===q||null===q?e.none():q.current(a,b,f,q.next).orThunk(function(){return q.fallback.bind(function(c){return h(a,b,c,f)})})};return{backtrack:c,sidestep:b,advance:f,go:h}});l("ol",["s"],function(d){return{left:function(){return{sibling:function(d,
c){return d.query().prevSibling(c)},first:function(e){return 0<e.length?d.some(e[e.length-1]):d.none()}}},right:function(){return{sibling:function(d,c){return d.query().nextSibling(c)},first:function(e){return 0<e.length?d.some(e[0]):d.none()}}}}});l("oj",["s","ok","ol"],function(d,e,c){var a=function(b,c,g,h,k,m){return e.go(b,c,h,k).bind(function(c){return m(c.item())?d.none():g(c.item())?d.some(c.item()):a(b,c.item(),g,c.mode(),k,m)})};return{left:function(b,d,g,h){return a(b,d,g,e.sidestep,c.left(),
h)},right:function(b,d,g,h){return a(b,d,g,e.sidestep,c.right(),h)}}});l("is",["7","oj","ok","ol"],function(d,e,c,a){var b=function(a,b){return 0===a.property().children(b).length},f=function(a,b,c,d){return e.left(a,b,c,d)},g=function(a,b,c,d){return e.right(a,b,c,d)};return{before:function(a,c,e){return f(a,c,d.curry(b,a),e)},after:function(a,c,e){return g(a,c,d.curry(b,a),e)},seekLeft:f,seekRight:g,walkers:function(){return{left:a.left,right:a.right}},walk:function(a,b,d,e,f){return c.go(a,b,d,
e,f)},backtrack:c.backtrack,sidestep:c.sidestep,advance:c.advance}});l("jg",["6q","is"],function(d,e){var c=d();return{gather:function(a,b,d){return e.gather(c,a,b,d)},before:function(a,b){return e.before(c,a,b)},after:function(a,b){return e.after(c,a,b)},seekLeft:function(a,b,d){return e.seekLeft(c,a,b,d)},seekRight:function(a,b,d){return e.seekRight(c,a,b,d)},walkers:function(){return e.walkers()},walk:function(a,b,d,g){return e.walk(c,a,b,d,g)}}});l("69","1a l 2p 3d 2r 2b".split(" "),function(d,
e,c,a,b,f){var g=function(a){return e.fromDom(a.dom().cloneNode(!0))},h=function(a,b){var c=e.fromTag(b),f=d.clone(a);d.setAll(c,f);return c};return{shallow:function(a){return e.fromDom(a.dom().cloneNode(!1))},shallowAs:h,deep:g,copy:function(b,c){var d=h(b,c),e=f.children(g(b));a.append(d,e);return d},mutate:function(d,e){var g=h(d,e);c.before(d,g);var n=f.children(d);a.append(g,n);b.remove(d);return g}}});l("lj","b p jg l 2p 3d 21 2r 69 4h 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){return{convertToHeading:function(c,
g){var q=p.owner(c),q=a.fromTag(g,q.dom()),t=p.children(c),t=d.map(t,k.deep);f.append(q,t);t=m.descendants(q,"b,strong");d.each(t,h.unwrap);b.before(c,q);h.remove(c);return e.value(q)},joinLinks:function(a,b){return c.seekLeft(b,function(a){return"a"===g.name(a)},a).fold(function(){return e.value(b)},function(a){var c=p.children(b);f.append(a,c);h.remove(b);return e.value(a)})}}});l("tn",["7","p"],function(d,e){return function(c){var a=d.compose(e.error,c);return{invalidError:a,different:function(b,
c,d,h,k){return 0===c.length?a(h):c===d?a(k):e.value(b)}}}});l("lk",["tn","1a"],function(d,e){return function(c){var a=d(c);return{changeAlt:function(b,c,d,h){var k=e.get(b,"src");return a.different(b,c,k,d,h).map(function(a){e.set(a,"alt",c);return a})}}}});l("jt",["7","1b"],function(d,e){return function(c,a,b,f){var g=e.eq(c,b)&&a===f;return{startContainer:d.constant(c),startOffset:d.constant(a),endContainer:d.constant(b),endOffset:d.constant(f),collapsed:d.constant(g)}}});l("r3","1o 7 1a 2o l 2p 21 69 2b".split(" "),
function(d,e,c,a,b,f,g,h,k){var m=function(){var a=b.fromTag("td");f.append(a,b.fromTag("br"));return a},p=function(a,b,e){var f=h.copy(a,b);d.each(e,function(a,b){null===a?c.remove(f,b):c.set(f,b,a)});return f},n=function(a){return a},r=function(a){return function(){return b.fromTag("tr",a.dom())}};return{cellOperations:function(c,d){return{row:r(d),cell:function(d){var e=k.owner(d.element()),e=b.fromTag(g.name(d.element()),e.dom());f.append(e,b.fromTag("br"));a.copy(d.element(),e);a.remove(e,"height");
1!==d.colspan()&&a.remove(d.element(),"width");c(d.element(),e);return e},replace:p,gap:m}},paste:function(a){return{row:r(a),cell:m,replace:n,gap:m}}}});l("jw","b 7 2v 68 3p 2s".split(" "),function(d,e,c,a,b,f){var g=c.immutable("row","y"),h=c.immutable("col","x"),k=function(a){return b.absolute(a).left()+f.getOuter(a)},m=function(a){return b.absolute(a).left()},p=function(a,b){return h(a,m(b))},n=function(a,b){return h(a,k(b))},r=function(a){return b.absolute(a).top()},q=function(a,b,c){if(0===
c.length)return[];var e=d.map(c.slice(1),function(b,c){return b.map(function(b){return a(c,b)})}),f=c[c.length-1].map(function(a){return b(c.length-1,a)});return e.concat([f])};c={delta:e.identity,positions:e.curry(q,function(a,b){return g(a,r(b))},function(b,c){return g(b,r(c)+a.getOuter(c))}),edge:r};var t={delta:e.identity,edge:m,positions:e.curry(q,p,n)};e={delta:function(a,b){return-a},edge:k,positions:e.curry(q,n,p)};return{height:c,rtl:e,ltr:t}});l("jm",["jw"],function(d){return{ltr:d.ltr,
rtl:d.rtl}});l("bh",["jm"],function(d){return function(e){var c=function(a){return e.directionAt(a).isRtl()?d.rtl:d.ltr};return{delta:function(a,b){return c(b).delta(a,b)},edge:function(a){return c(a).edge(a)},positions:function(a,b){return c(b).positions(a,b)}}}});l("jn","jt s r3 bh l 2p 2r".split(" "),function(d,e,c,a,b,f,g){return{erase:function(a,c,m,p){a=b.fromText("");f.after(c,a);g.remove(c);return e.some(d(a,0,a,0))},execute:function(b,e,f,g){return function(n,r,q){var t=g(),s=n.doc().getOrDie();
n=a(b);s=c.cellOperations(f,s);return e(t,r,q,s,n).map(function(a){return d(a,0,a,0)})}}}});l("bk",["7","s","3o","l","3p"],function(d,e,c,a,b){return{only:function(b){var g=e.from(b.dom().documentElement).map(a.fromDom).getOr(b);return{parent:d.constant(g),view:d.constant(b),origin:d.constant(c(0,0))}},detached:function(a,c){var e=d.curry(b.absolute,c);return{parent:d.constant(c),view:d.constant(a),origin:e}}}});l("bc",["bk"],function(d){var e=function(c,a,b){return c.isInline()?d.detached(c.element(),
a.uiContainer()):d.only(b)};return{get:e,fromEngine:function(c){var a=c.content(),b=c.smartview();return a.doc().map(function(c){return e(a,b,c)})}}});l("gg",["2v"],function(d){var e=d.immutable("width","height"),c=d.immutable("rows","columns"),a=d.immutable("row","column"),b=d.immutable("x","y"),f=d.immutable("element","rowspan","colspan"),g=d.immutable("element","rowspan","colspan","row","column"),h=d.immutable("before","on","after"),k=d.immutable("element","cells"),m=d.immutableBag(["startRow",
"startCol","finishRow","finishCol"],[]);d=d.immutableBag(["row","col"],[]);return{dimensions:e,grid:c,address:a,coords:b,extended:g,detail:f,context:h,rowdata:k,bounds:m,cell:d}});l("gh",["b","7","m","2b"],function(d,e,c,a){var b=function(e,g,h){return d.bind(a.children(e),function(a){return c.is(a,g)?h(a)?[a]:[]:b(a,g,h)})};return{firstLayer:function(a,c){return b(a,c,e.constant(!0))},filterFirstLayer:b}});l("bl","b 7 s gg gh 1a 21 4h 32 m 2b e2".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var r=
function(a,b,f){var h=void 0!==f?f:e.constant(!1);return h(b)?c.none():d.contains(a,g.name(b))?c.some(b):k.ancestor(b,a.join(","),function(a){return m.is(a,"table")||h(a)})},q=function(a,b){return p.parent(b).map(function(b){return h.children(b,a)})},t=e.curry(q,"th,td"),q=e.curry(q,"tr"),s=function(a,b){return n(f.get(a,b),10)};return{cell:function(a,b){return r(["td","th"],a,b)},firstCell:function(a){return k.descendant(a,"th,td")},cells:function(a){return b.firstLayer(a,"th,td")},neighbourCells:t,
table:function(a,b){return k.closest(a,"table",b)},row:function(a,b){return r(["tr"],a,b)},rows:function(a){return b.firstLayer(a,"tr")},notCell:function(a,b){return r(["caption","tr","tbody","tfoot","thead"],a,b)},neighbourRows:q,attr:s,grid:function(b,c,d){c=s(b,c);b=s(b,d);return a.grid(c,b)}}});l("qx",["b","7","gg","bl","1a"],function(d,e,c,a,b){return{fromTable:function(f){f=a.rows(f);return d.map(f,function(f){var h=d.map(a.cells(f),function(a){var d=b.has(a,"rowspan")?parseInt(b.get(a,"rowspan"),
10):1,e=b.has(a,"colspan")?parseInt(b.get(a,"colspan"),10):1;return c.detail(a,d,e)});return{element:e.constant(f),cells:e.constant(h)}})}}});l("qy",["b","7","s","gg","1s"],function(d,e,c,a,b){var f=function(a,b){var c=d.bind(a.all(),function(a){return a.cells()});return d.filter(c,b)};return{generate:function(c){var f={},k=[],m=0,p=0;d.each(c,function(c,e){var g=[];d.each(c.cells(),function(c,d){for(var k=0;void 0!==f[e+","+k];)k++;for(var n=a.extended(c.element(),c.rowspan(),c.colspan(),e,k),w=
0;w<c.colspan();w++)for(var y=0;y<c.rowspan();y++){var x=e+y,l=k+w;f[x+","+l]=n;m=b.max(m,x+1);p=b.max(p,l+1)}g.push(n)});k.push(a.rowdata(c.element(),g))});c=a.grid(m,p);return{grid:e.constant(c),access:e.constant(f),all:e.constant(k)}},getAt:function(a,b,d){a=a.access()[b+","+d];return void 0!==a?c.some(a):c.none()},findItem:function(a,b,d){a=f(a,function(a){return d(b,a.element())});return 0<a.length?c.some(a[0]):c.none()},filterItems:f,justCells:function(a){a=d.map(a.all(),function(a){return a.cells()});
return d.flatten(a)}}});l("tp",["b","s","k","1s"],function(d,e,c,a){return{repeat:function(a,c){for(var d=[],e=0;e<a;e++)d.push(c(e));return d},range:function(a,c){for(var d=[],e=a;e<c;e++)d.push(e);return d},unique:function(a,c){var e=[];d.each(a,function(d,k){k<a.length-1&&!c(d,a[k+1])?e.push(d):k===a.length-1&&e.push(d)});return e},deduce:function(b,f){if(0>f||f>=b.length-1)return e.none();var g=b[f].fold(function(){var a=d.reverse(b.slice(0,f));return c.findMap(a,function(a,b){return a.map(function(a){return{value:a,
delta:b+1}})})},function(a){return e.some({value:a,delta:0})}),h=b[f+1].fold(function(){var a=b.slice(f+1);return c.findMap(a,function(a,b){return a.map(function(a){return{value:a,delta:b+1}})})},function(a){return e.some({value:a,delta:1})});return g.bind(function(b){return h.map(function(c){var d=c.delta+b.delta;return a.abs(c.value-b.value)/d})})}}});l("to",["b","7","s","qy","tp"],function(d,e,c,a,b){var f=function(a,b,e){var f=a();a=d.find(f,b);return c.from(a).orThunk(function(){return c.from(f[0]).orThunk(e)}).map(function(a){return a.element()})};
return{columns:function(c){var h=c.grid(),k=b.range(0,h.columns()),m=b.range(0,h.rows());return d.map(k,function(b){return f(function(){return d.bind(m,function(d){return a.getAt(c,d,b).filter(function(a){return a.column()===b}).fold(e.constant([]),function(a){return[a]})})},function(a){return 1===a.colspan()},function(){return a.getAt(c,0,b)})})},rows:function(c){var h=c.grid(),k=b.range(0,h.rows()),m=b.range(0,h.columns());return d.map(k,function(b){return f(function(){return d.bind(m,function(d){return a.getAt(c,
b,d).filter(function(a){return a.row()===b}).fold(e.constant([]),function(a){return[a]})})},function(a){return 1===a.rowspan()},function(){return a.getAt(c,b,0)})})}}});l("rg","bl 1a 2o 68 21 2s v 1s e2".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(a,b){c.set(a,"width",b+"px")},p=function(a,b){c.set(a,"height",b+"px")},n=function(a,b){return c.getRaw(a,b).getOrThunk(function(){return c.get(a,b)})},r=function(a,b,c,e){var f=d.table(a).map(function(a){a=c(a);return h.floor(b/100*a)}).getOr(b);
e(a,f);return f},q=function(a,c,d,e){var f=k(a,10);return g.endsWith(a,"%")&&"table"!==b.name(c)?r(c,f,d,e):f},t=function(a){var b=n(a,"width");return b?q(b,a,f.get,m):f.get(a)},s=function(b){var c=n(b,"height");return c?q(c,b,a.get,p):a.get(b)},u=function(a,b,c){c=c(a);a=e.has(a,b)?k(e.get(a,b),10):1;return c/a};return{setWidth:m,setHeight:p,getWidth:function(a){return u(a,"colspan",t)},getHeight:function(a){return u(a,"rowspan",s)}}});l("rh",["7","1a","2o","e2"],function(d,e,c,a){var b=function(b,
c){return e.has(b,c)&&1<a(e.get(b,c),10)};return{hasColspan:function(a){return b(a,"colspan")},hasRowspan:function(a){return b(a,"rowspan")},minWidth:d.constant(10),minHeight:d.constant(10),getInt:function(b,d){return a(c.get(b,d),10)}}});l("re","b 7 to rg rh tp 2o".split(" "),function(d,e,c,a,b,f,g){var h=function(a,b,c){return g.getRaw(a,b).fold(function(){return c(a)+"px"},function(a){return a})},k=function(b){return h(b,"width",a.getWidth)},m=function(b){return h(b,"height",a.getHeight)},p=function(b){return a.getWidth(b)},
n=function(a,g,h,k){a=c.columns(a);var m=d.map(a,function(a){return a.map(g.edge)});return d.map(a,function(a,c){return a.filter(e.not(b.hasColspan)).fold(function(){var a=f.deduce(m,c);return k(a)},function(a){return h(a)})})},r=function(a){return a.map(function(a){return a+"px"}).getOr("")},q=function(b){return a.getHeight(b)},t=function(a,g,h,k){a=c.rows(a);var m=d.map(a,function(a){return a.map(g.edge)});return d.map(a,function(a,c){return a.filter(e.not(b.hasRowspan)).fold(function(){var a=f.deduce(m,
c);return k(a)},function(a){return h(a)})})};return{getRawWidths:function(a,b){return n(a,b,k,r)},getPixelWidths:function(a,c){return n(a,c,p,function(a){return a.getOrThunk(b.minWidth)})},getPixelHeights:function(a,c){return t(a,c,q,function(a){return a.getOrThunk(b.minHeight)})},getRawHeights:function(a,b){return t(a,b,m,r)}}});l("s3","b 7 4q tp v 1s 1v e2".split(" "),function(d,e,c,a,b,f,g,h){var k=c.generate([{invalid:["raw"]},{pixels:["value"]},{percent:["value"]}]),m=function(a,b,c){a=c.substring(0,
c.length-a.length);var d=g(a);return a===d.toString()?b(d):k.invalid(c)},p=function(a){return b.endsWith(a,"%")?m("%",k.percent,a):b.endsWith(a,"px")?m("px",k.pixels,a):k.invalid(a)},n=function(a,b){return d.map(a,function(a){return p(a).fold(function(){return a},function(a){return a/b*100+"%"},function(a){return a+"%"})})},r=function(a,b,c){var e=c/b;return d.map(a,function(a){return p(a).fold(function(){return a},function(a){return a*e+"px"},function(a){return a/100*c+"px"})})},q=function(b,c){var d=
b.fold(function(){return e.constant("")},function(a){return e.constant(a/c+"px")},function(a){return e.constant(a/c+"px")});return a.repeat(c,d)},t=function(a,b,c){return a.fold(function(){return b},function(a){return r(b,c,a)},function(a){return n(b,c)})},s=function(a,b){var c=f.floor(a);return{value:c+b,remainder:a-c}},u=function(a,b){return p(a).fold(e.constant(a),function(a){return a+b+"px"},function(a){return a+b+"%"})},v=function(a){if(0===a.length)return a;a=d.foldr(a,function(a,b){var c=p(b).fold(function(){return{value:b,
remainder:0}},function(a){return s(a,"px")},function(a){return s(a,"%")});return{output:[c.value].concat(a.output),remainder:a.remainder+c.remainder}},{output:[],remainder:0});var b=a.output;return b.slice(0,b.length-1).concat([u(b[b.length-1],f.round(a.remainder))])};return{validate:p,redistribute:function(a,b,c){c=p(c);a=d.forall(a,function(a){return"0px"===a})?q(c,a.length):t(c,a,b);return v(a)},sum:function(a,b){return 0===a.length?b:d.foldr(a,function(a,b){return p(b).fold(e.constant(0),e.identity,
e.identity)+a},0)},toIntegers:v}});l("jr","b 7 qx qy jw re s3 rg rh 2o 68 2s".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var r=function(a,b,c){d.each(b,function(b){var d=a.slice(b.column(),b.colspan()+b.column()),d=g.sum(d,k.minWidth());m.set(b.element(),"width",d+c)})},q=function(a,b,c,e){d.each(c,function(b){var c=a.slice(b.row(),b.rowspan()+b.row()),c=g.sum(c,k.minHeight());m.set(b.element(),"height",c+e)});d.each(b,function(b,c){m.set(b.element(),"height",a[c])})},t=function(a){return g.validate(a).fold(e.constant("px"),
e.constant("px"),e.constant("%"))};return{setWidth:h.setWidth,getWidth:h.getWidth,setHeight:h.setHeight,getHeight:h.getHeight,redistribute:function(d,e,h,k){var y=c.fromTable(d),x=a.generate(y),l=x.all(),A=a.justCells(x);e.each(function(a){var b=t(a),c=n.get(d),e=f.getRawWidths(x,k),c=g.redistribute(e,c,a);r(c,A,b);m.set(d,"width",a)});h.each(function(a){var c=t(a),e=p.get(d),h=f.getRawHeights(x,b.height),e=g.redistribute(h,e,a);q(e,l,A,c);m.set(d,"height",a)})}}});l("r5","b 7 s 4p 57 1a 2o e2".split(" "),
function(d,e,c,a,b,f,g,h){var k=function(a){var b=f.has(a,"colspan")?h(f.get(a,"colspan"),10):1,c=f.has(a,"rowspan")?h(f.get(a,"rowspan"),10):1;return{element:e.constant(a),colspan:e.constant(b),rowspan:e.constant(c)}},m=b.exactly(["cell","row","replace","gap"]);return{modification:function(b,d){m(b);var e=a(c.none()),f=void 0!==d?d:k,g=function(a){var d;d=f(a);d=b.cell(d);e.get().isNone()&&e.set(c.some(d));h=c.some({item:a,replacement:d});return d},h=c.none();return{getOrInit:function(a,b){return h.fold(function(){return g(a)},
function(c){return b(a,c.item)?c.replacement:g(a)})},cursor:e.get}},transform:function(b,e){return function(f){var g=a(c.none());m(f);var h=[],k=function(a,b){var e=d.find(h,function(c){return b(c.item,a)});return c.from(e)},u=function(a){var d=f.replace(a,e,{scope:b});h.push({item:a,sub:d});g.get().isNone()&&g.set(c.some(d));return d};return{replaceOrInit:function(a,b){return k(a,b).fold(function(){return u(a)},function(c){return b(a,c.item)?c.sub:u(a)})},cursor:g.get}}},merging:function(b){m(b);
var d=a(c.none());return{combine:function(a){d.get().isNone()&&d.set(c.some(a));return function(){var c=b.cell({element:e.constant(a),colspan:e.constant(1),rowspan:e.constant(1)});g.remove(c,"width");g.remove(a,"width");return c}},cursor:d.get}}}});l("87",["b","21","az","2b"],function(d,e,c,a){var b=function(b){return"img"===e.name(b)?1:c.getOption(b).fold(function(){return a.children(b).length},function(a){return a.length})},f=function(a){return c.getOption(a).filter(function(a){return 0!==a.trim().length||
-1<a.indexOf("\u00a0")}).isSome()},g=["img","br"];return{getEnd:b,isEnd:function(a,c){return b(a)===c},isStart:function(a,b){return 0===b},isCursorPosition:function(a){return f(a)||d.contains(g,e.name(a))}}});l("e5",["87","s","4l","2b"],function(d,e,c,a){var b=function(b,c){var d=function(b){b=a.children(b);for(var f=b.length-1;0<=f;f--){var p=b[f];if(c(p))return e.some(p);p=d(p);if(p.isSome())return p}return e.none()};return d(b)};return{firstCursor:function(a){return c.descendant(a,d.isCursorPosition)},
lastCursor:function(a){return b(a,d.isCursorPosition)}}});l("mb",["b"],function(d){var e="body p div article aside figcaption figure footer header nav section ol ul table thead tfoot tbody caption tr td th h1 h2 h3 h4 h5 h6 blockquote pre address".split(" "),c=function(a,c){var g=a.property().name(c);return d.contains(e,g)},a=function(a,c){return d.contains(["br","img","hr","input"],a.property().name(c))};return{isBlock:c,isList:function(a,c){var e=a.property().name(c);return d.contains(["ol","ul"],
e)},isFormatting:function(a,c){var e=a.property().name(c);return d.contains("address pre p h1 h2 h3 h4 h5 h6".split(" "),e)},isHeading:function(a,c){var e=a.property().name(c);return d.contains("h1 h2 h3 h4 h5 h6".split(" "),e)},isContainer:function(a,c){return d.contains("div li td th blockquote body caption".split(" "),a.property().name(c))},isEmptyTag:a,isFrame:function(a,c){return"iframe"===a.property().name(c)},isInline:function(b,d){return!(c(b,d)||a(b,d))&&"li"!==b.property().name(d)}}});l("fg",
["6q","mb"],function(d,e){var c=d();return{isBlock:function(a){return e.isBlock(c,a)},isList:function(a){return e.isList(c,a)},isFormatting:function(a){return e.isFormatting(c,a)},isHeading:function(a){return e.isHeading(c,a)},isContainer:function(a){return e.isContainer(c,a)},isEmptyTag:function(a){return e.isEmptyTag(c,a)},isFrame:function(a){return e.isFrame(c,a)},isInline:function(a){return e.isInline(c,a)}}});l("r6","b e5 fg 1b l 3d 21 4l 2r az 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){return{merge:function(n){var r=
function(a){return d.forall(a,function(a){return"br"===g.name(a)||g.isText(a)&&0===m.get(a).trim().length})},q=function(a){return p.nextSibling(a).each(function(a){if(c.isBlock(a))return!0;if(c.isEmptyTag(a))return"img"===g.name(a)?!1:!0}).getOr(!1)},t=function(d){return e.lastCursor(d).bind(function(e){var f=q(e);return p.parent(e).map(function(k){var m;(m=!0===f)||(m="li"===g.name(k)||h.ancestor(k,c.isList).isSome()||"br"===g.name(e)||c.isBlock(k)&&!a.eq(d,k));return m?[]:[b.fromTag("br")]})}).getOr([])},
s=function(){var a=d.bind(n,function(a){var b=p.children(a);return r(b)?[]:b.concat(t(a))});return 0===a.length?[b.fromTag("br")]:a}();k.empty(n[0]);f.append(n[0],s)}}});l("tq",["b","7"],function(d,e){var c=function(a,c){return d.map(a,function(a){return a[c]})},a=function(a,c){if(0===a.length)return 0;var e=a[0],h=d.findIndex(a,function(a){return!c(e,a)});return-1===h?a.length:h};return{subgrid:function(b,d,g,h){var k=b[d].slice(g),k=a(k,h);b=c(b,g).slice(d);h=a(b,h);return{colspan:e.constant(k),
rowspan:e.constant(h)}}}});l("r9",["b","gg","tq","qy"],function(d,e,c,a){return{toDetails:function(a,f){var g=d.map(a,function(a,b){return d.map(a,function(a,b){return!1})});return d.map(a,function(h,k){return d.bind(h,function(d,h){if(!1===g[k][h]){for(var n=c.subgrid(a,k,h,f),r=n.rowspan(),q=n.colspan(),t=k;t<k+r;t++)for(var s=h;s<h+q;s++)g[t][s]=!0;return[e.detail(d,n.rowspan(),n.colspan())]}return[]})})},toGrid:function(b,c){for(var d=[],e=0;e<b.grid().rows();e++){for(var k=[],m=0;m<b.grid().columns();m++){var p=
a.getAt(b,e,m).map(function(a){return a.element()}).getOrThunk(c.gap);k.push(p)}d.push(k)}return d}}});l("tr","b 1a l 2p 3d 2r 32 2b".split(" "),function(d,e,c,a,b,f,g,h){return{render:function(k,m){var p=g.child(k,"tbody").getOrThunk(function(){var b=c.fromTag("tbody",h.owner(k).dom());a.append(k,b);return b});f.empty(p);var n=d.map(m,function(b){var c=b.element();f.empty(c);d.each(b.cells(),function(b){var d=b.element(),f=b.colspan();1===f?e.remove(d,"colspan"):e.set(d,"colspan",f);d=b.element();
f=b.rowspan();1===f?e.remove(d,"rowspan"):e.set(d,"rowspan",f);a.append(c,b.element())});return c});b.append(p,n)}}});l("ts",["1a","2o","l"],function(d,e,c){return{col:function(a,b,f,g,h){var k=c.fromTag("div");e.setAll(k,{position:"absolute",left:b-g/2+"px",top:f+"px",height:h+"px",width:g+"px"});d.set(k,"data-column",a);return k},row:function(a,b,f,g,h){var k=c.fromTag("div");e.setAll(k,{position:"absolute",left:b+"px",top:f-h/2+"px",height:h+"px",width:g+"px"});d.set(k,"data-row",a);return k}}});
l("s6",["4j"],function(d){return{resolve:d.create("ephox-snooker").resolve}});l("s5","b to qx qy ts s6 1y 2o 68 2p 3p 2r 4h 2s".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q){var t=f.resolve("resizer-bar"),s=f.resolve("resizer-rows"),u=f.resolve("resizer-cols"),v=function(a){a=r.descendants(a.parent(),"."+t);d.each(a,n.remove)},w=function(a,b,c){var e=a.origin();d.each(b,function(b,d){b.each(function(b){b=c(e,b);g.add(b,t);m.append(a.parent(),b)})})},y=function(a,c,d,e){w(a,c,function(a,c){var f=
b.col(c.col(),c.x()-a.left(),d.top()-a.top(),7,e);g.add(f,u);return f})},x=function(a,c,d,e){w(a,c,function(a,c){var f=b.row(c.row(),d.left()-a.left(),c.y()-a.top(),e,7);g.add(f,s);return f})},l=function(a,b){var c=r.descendants(a.parent(),"."+t);d.each(c,b)};return{refresh:function(b,d,f,g){v(b,d);var h=c.fromTable(d),h=a.generate(h),m=e.rows(h),n=e.columns(h),h=p.absolute(d);f=0<m.length?f.positions(m,d):[];x(b,f,h,q.getOuter(d));g=0<n.length?g.positions(n,d):[];y(b,g,h,k.getOuter(d))},hide:function(a){l(a,
function(a){h.set(a,"display","none")})},show:function(a){l(a,function(a){h.set(a,"display","block")})},destroy:v,isRowBar:function(a){return g.has(a,s)},isColBar:function(a){return g.has(a,u)}}});l("r7","b 6 7 s k bl qx r9 qy tr jw s5 1b 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q){var t=function(a,e){var f=function(a){return b.findMap(a,function(a){return q.parent(a.element())}).getOrThunk(function(){return e.row()})};return d.map(a,function(a){var b=f(a);return{element:c.constant(b),cells:c.constant(a)}})},
s=function(b,c){var e=d.flatten(d.map(b.all(),function(a){return a.cells()})),e=d.find(e,function(a){return r.eq(c,a.element())});return a.from(e)};return{run:function(b,d,e,f,q){return function(s,l,D,B,C){var F=g.fromTable(l),E=k.generate(F);return d(E,D).map(function(a){var d=h.toGrid(E,B);a=b(d,a,r.eq,q(B));d=a.grid();d=h.toDetails(d,r.eq);d=t(d,B);return{grid:c.constant(d),cursor:a.cursor}}).fold(function(){return a.none()},function(a){m.render(l,a.grid());e(a.grid(),C);f(l);n.refresh(s,l,p.height,
C);return a.cursor()})}},onCell:function(a,b){return f.cell(b.element()).bind(function(b){return s(a,b)})},onCells:function(c,e){var g=d.map(e.selection(),function(a){return f.cell(a).bind(function(a){return s(c,a)})}),g=b.cat(g);return 0<g.length?a.some(g):a.none()},onPaste:function(a,b){return f.cell(b.element()).bind(function(c){return s(a,c).map(function(a){return e.merge(a,{generators:b.generators,clipboard:b.clipboard})})})},onMergable:function(a,b){return b.mergable()},onUnmergable:function(a,
b){return b.unmergable()}}});l("tt","b 7 p tp 9 n 1s".split(" "),function(d,e,c,a,b,f,g){var h=function(a,b){return d.map(a,b.cell)},k=function(b,c,d){return b.concat(a.repeat(c,function(a){return h(b[0],d)}))},m=function(b,c,e){return d.map(b,function(b){return b.concat(h(a.range(0,c),e))})};return{measure:function(a,b,d){if(a.row()>=b.length||a.column()>b[0].length)return c.error("invalid start address out of table bounds, row: "+a.row()+", column: "+a.column());b=b.slice(a.row());a=b[0].slice(a.column());
var f=d[0].length;return c.value({rowDelta:e.constant(b.length-d.length),colDelta:e.constant(a.length-f)})},tailor:function(a,b,c,d){var f=0>c.colDelta()?m:e.identity;a=0>c.rowDelta()?k:e.identity;b=f(b,g.abs(c.colDelta()),d);return a(b,g.abs(c.rowDelta()),d)}}});l("ra",[],function(){return{merge:function(d,e,c,a){if(0===d.length)return d;for(c=e.startRow();c<=e.finishRow();c++)for(var b=e.startCol();b<=e.finishCol();b++)d[c][b]=a();return d},unmerge:function(d,e,c,a){for(var b=!0,f=0;f<d.length;f++)for(var g=
0;g<d[0].length;g++){var h=c(d[f][g],e);!0===h&&!1===b?d[f][g]=a():!0===h&&(b=!1)}return d}}});l("r8",["7","tt","ra"],function(d,e,c){return{merge:function(a,b,f,g,h){return e.measure(a,b,f).map(function(k){k=e.tailor(a,b,k,g);for(var m=a.row(),p=a.column(),n=m+f.length,r=p+f[0].length,q=m;q<n;q++)for(var t=p;t<r;t++){var s=k,u=q,v=t,w=d.curry(h,s[u][v]),y=s[u];1<s.length&&1<y.length&&(0<v&&w(y[v-1])||v<y.length-1&&w(y[v+1])||0<u&&w(s[u-1][v])||u<s.length-1&&w(s[u+1][v]))&&c.unmerge(k,k[q][t],h,g.cell);
k[q][t]=g.replace(f[q-m][t-p])}return k})}}});l("rb",["b"],function(d){return{insertRowAt:function(e,c,a,b,f){var g=e.slice(0,c),h=e.slice(c);a=d.map(e[a],function(a,d){return 0<c&&c<e.length&&b(e[c-1][d],e[c][d])?e[c][d]:f(a,b)});return g.concat([a]).concat(h)},insertColumnAt:function(e,c,a,b,f){return d.map(e,function(d){var e=0<c&&c<d.length&&b(d[c-1],d[c])?d[c]:f(d[a],b);return d.slice(0,c).concat([e]).concat(d.slice(c))})},splitCellIntoColumns:function(e,c,a,b,f){var g=a+1;return d.map(e,function(d,
e){var m=e===c?f(d[a],b):d[a];return d.slice(0,g).concat([m]).concat(d.slice(g))})},splitCellIntoRows:function(e,c,a,b,f){var g=c+1,h=e.slice(0,g),g=e.slice(g);e=d.map(e[c]||[],function(c,d){return d===a?f(c,b):c});return h.concat([e]).concat(g)},deleteRowAt:function(d,c){return d.slice(0,c).concat(d.slice(c+1))},deleteRowsAt:function(d,c,a){return d.slice(0,c).concat(d.slice(a+1))},deleteColumnAt:function(e,c){return d.map(e,function(a){return a.slice(0,c).concat(a.slice(c+1))})},deleteColumnsAt:function(e,
c,a){return d.map(e,function(b){return b.slice(0,c).concat(b.slice(a+1))})}}});l("rc",["b","7"],function(d,e){var c=function(a,b,c,g){return d.map(a,function(a){return d.map(a,function(a){return d.exists(b,e.curry(c,a))?g(a,c):a})})};return{replaceColumn:function(a,b,e,g){var h=d.bind(a,function(c,d){return void 0!==a[d][b]&&0<d&&e(a[d-1][b],a[d][b])||0<b&&e(c[b-1],c[b])?[]:[c[b]]});return c(a,h,e,g)},replaceRow:function(a,b,e,g){var h=a[b],k=d.bind(h,function(c,d){return void 0!==a[b][d]&&0<b&&e(a[b-
1][d],a[b][d])||0<d&&e(h[d-1],h[d])?[]:[c]});return c(a,k,e,g)}}});l("tu",[],function(){var d=function(d){return{fold:d}};return{none:function(){return d(function(d,c,a,b,f){return d()})},only:function(e){return d(function(c,a,b,d,g){return a(e)})},left:function(e,c){return d(function(a,b,d,g,h){return d(e,c)})},middle:function(e,c,a){return d(function(b,d,g,h,k){return h(e,c,a)})},right:function(e,c){return d(function(a,b,d,g,h){return h(e,c)})}}});l("rd",["b","7","tu","1s"],function(d,e,c,a){var b=
function(a,b){return 0===a.length?c.none():1===a.length?c.only(0):0===b?c.left(0,1):b===a.length-1?c.right(b-1,b):0<b&&b<a.length-1?c.middle(b-1,b,b+1):c.none()};return{determine:function(c,g,h,k){var m=c.slice(0);c=b(c,g);var p=function(a){return d.map(a,e.constant(0))};g=e.constant(p(m));var n=function(b,c){if(0<=h){var d=a.max(k,m[c]-h);return p(m.slice(0,b)).concat([h,d-m[c]]).concat(p(m.slice(c+1)))}var d=a.max(k,m[b]+h),e=m[b]-d;return p(m.slice(0,b)).concat([d-m[b],e]).concat(p(m.slice(c+1)))};
return c.fold(g,function(b){return[a.max(k,m[b]+h)-m[b]]},n,function(a,b,c){return n(b,c)},function(b,c){if(0<=h)return p(m.slice(0,c)).concat([h]);var d=a.max(k,m[c]+h);return p(m.slice(0,c)).concat([d-m[c]])})}}});l("rf",["b","7","qy","e2"],function(d,e,c,a){var b=function(b,c,d){for(var e=0;b<c;b++)e+=void 0!==d[b]?a(d[b],10):0;return e};return{recalculateWidth:function(a,g){var h=c.justCells(a);return d.map(h,function(a){var c=b(a.column(),a.column()+a.colspan(),g);return{element:a.element,width:e.constant(c),
colspan:a.colspan}})},recalculateHeight:function(a,g){var h=c.justCells(a);return d.map(h,function(a){var c=b(a.row(),a.row()+a.rowspan(),g);return{element:a.element,height:e.constant(c),rowspan:a.rowspan}})},matchRowHeight:function(a,b){return d.map(a.all(),function(a,c){return{element:a.element,height:e.constant(b[c])}})}}});l("ju","b rd qx qy re rf rg rh 32 1s".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=function(a){return d.foldr(a,function(a,b){return a+b},0)},n=function(b){b=c.fromTable(b);
return a.generate(b)};return{adjustWidth:function(a,c,k,m){var u=n(a),v=b.getPixelWidths(u,m);c=e.determine(v,k,c,h.minWidth());c=d.map(c,function(a,b){return a+v[b]});u=f.recalculateWidth(u,c);d.each(u,function(a){g.setWidth(a.element(),a.width())});u=p(c);g.setWidth(a,u)},adjustHeight:function(a,c,e,k){var u=n(a);k=b.getPixelHeights(u,k);k=d.map(k,function(a,b){return e===b?m.max(c+a,h.minHeight()):a});var v=f.recalculateHeight(u,k),u=f.matchRowHeight(u,k);d.each(u,function(a){g.setHeight(a.element(),
a.height())});d.each(v,function(a){g.setHeight(a.element(),a.height())});u=p(k);g.setHeight(a,u)},adjustWidthTo:function(c,e){var h=a.generate(c),m=b.getPixelWidths(h,e),h=f.recalculateWidth(h,m);d.each(h,function(a){g.setWidth(a.element(),a.width())});var p=d.foldr(m,function(a,b){return b+a},0);0<h.length&&k.ancestor(h[0].element(),"table").each(function(a){g.setWidth(a,p)})}}});l("js","b 7 s 2v r5 gg r6 bl qx r7 r8 r9 qy ra rb rc ju 2r".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v){var w=
function(a){0===h.cells(a).length&&v.remove(a)},y=a.immutable("grid","cursor"),x=function(a,b,c){return l(a,b,c).orThunk(function(){return l(a,0,0)})},l=function(a,b,d){return c.from(a[b]).bind(function(a){return c.from(a[d])})},A=function(a,b,c){return y(a,l(a,b,c))};a=u.adjustWidthTo;return{insertRowBefore:m.run(function(a,b,c,d){var e=b.row(),f=b.row();a=t.insertRowAt(a,f,e,c,d.getOrInit);return A(a,f,b.column())},m.onCell,e.noop,e.noop,b.modification),insertRowAfter:m.run(function(a,b,c,d){var e=
b.row(),f=b.row()+b.rowspan();a=t.insertRowAt(a,f,e,c,d.getOrInit);return A(a,f,b.column())},m.onCell,e.noop,e.noop,b.modification),insertColumnBefore:m.run(function(a,b,c,d){var e=b.column(),f=b.column();a=t.insertColumnAt(a,f,e,c,d.getOrInit);return A(a,b.row(),f)},m.onCell,a,e.noop,b.modification),insertColumnAfter:m.run(function(a,b,c,d){var e=b.column(),f=b.column()+b.colspan();a=t.insertColumnAt(a,f,e,c,d.getOrInit);return A(a,b.row(),f)},m.onCell,a,e.noop,b.modification),splitCellIntoColumns:m.run(function(a,
b,c,d){a=t.splitCellIntoColumns(a,b.row(),b.column(),c,d.getOrInit);return A(a,b.row(),b.column())},m.onCell,a,e.noop,b.modification),splitCellIntoRows:m.run(function(a,b,c,d){a=t.splitCellIntoRows(a,b.row(),b.column(),c,d.getOrInit);return A(a,b.row(),b.column())},m.onCell,e.noop,e.noop,b.modification),eraseColumns:m.run(function(a,b,c,e){c=d.foldl(b,function(a,b){return d.contains(a,b.column())?a:a.concat([b.column()])},[]).sort();a=t.deleteColumnsAt(a,c[0],c[c.length-1]);b=x(a,b[0].row(),b[0].column());
return y(a,b)},m.onCells,a,w,b.modification),eraseRows:m.run(function(a,b,c,e){c=d.foldl(b,function(a,b){return d.contains(a,b.row())?a:a.concat([b.row()])},[]).sort();a=t.deleteRowsAt(a,c[0],c[c.length-1]);b=x(a,b[0].row(),b[0].column());return y(a,b)},m.onCells,e.noop,w,b.modification),makeColumnHeader:m.run(function(a,b,c,d){a=s.replaceColumn(a,b.column(),c,d.replaceOrInit);return A(a,b.row(),b.column())},m.onCell,e.noop,e.noop,b.transform("row","th")),unmakeColumnHeader:m.run(function(a,b,c,d){a=
s.replaceColumn(a,b.column(),c,d.replaceOrInit);return A(a,b.row(),b.column())},m.onCell,e.noop,e.noop,b.transform(null,"td")),makeRowHeader:m.run(function(a,b,c,d){a=s.replaceRow(a,b.row(),c,d.replaceOrInit);return A(a,b.row(),b.column())},m.onCell,e.noop,e.noop,b.transform("col","th")),unmakeRowHeader:m.run(function(a,b,c,d){a=s.replaceRow(a,b.row(),c,d.replaceOrInit);return A(a,b.row(),b.column())},m.onCell,e.noop,e.noop,b.transform(null,"td")),mergeCells:m.run(function(a,b,d,f){f=b.cells();g.merge(f);
a=q.merge(a,b.bounds(),d,e.constant(f[0]));return y(a,c.from(f[0]))},m.onMergable,e.noop,e.noop,b.merging),unmergeCells:m.run(function(a,b,e,f){a=d.foldr(b,function(a,b){return q.unmerge(a,b,e,f.combine(b))},a);return y(a,c.from(b[0]))},m.onUnmergable,a,e.noop,b.merging),pasteCells:m.run(function(a,b,d,e){e=function(a,b){var c=k.fromTable(a),c=r.generate(c);return n.toGrid(c,b)}(b.clipboard(),b.generators());var g=f.address(b.row(),b.column());return p.merge(g,a,e,b.generators(),d).fold(function(){return y(a,
c.some(b.element()))},function(a){var c=x(a,b.row(),b.column());return y(a,c)})},m.onPaste,a,e.noop,b.modification)}});l("s2","b 7 p jn bc jm jr js 1a l 2g 2p 2r 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q){var t=function(a){return function(b,e){return d.foldl(a,function(a,c){return a.bind(function(a){return w(e,function(a){return v(c,b,e,a)})})},c.value(e))}},s=t([h.makeRowHeader,h.makeColumnHeader]),u=t([h.makeRowHeader]);h=t([h.makeColumnHeader]);var v=function(c,d,f,g){return b.fromEngine(d).bind(function(b){b=
e.constant(b);var h=e.noop;return a.execute(d.region(),c,h,b)(d.content(),f,{element:e.constant(g)})})},w=function(a,b){return q.descendant(a,"td,th").bind(function(a){return b(a)}).fold(function(){return c.error("Could not run the operation on table")},function(b){return c.value(a)})};return{setCaption:function(a,b){var c=q.child(a,"caption").fold(function(){return m.fromTag("caption")},function(a){r.empty(a);return a});p.set(c,b);n.prepend(a,c)},setSummary:function(a,b){k.set(a,"summary",b)},setDimensions:function(a,
b){g.redistribute(a,b.width(),b.height(),"rtl"===k.get(a,"dir")?f.rtl:f.ltr)},addBothHeaders:s,addRowHeader:u,addColumnHeader:h}});l("ll","7 p tn s2 1a 2g 32".split(" "),function(d,e,c,a,b,f,g){return function(h){var k=c(h);return{changeCaption:function(c,d,e,f){var g=b.get(c,"summary");return k.different(c,d,g,e,f).map(function(b){a.setCaption(b,d);return b})},changeSummary:function(b,c,d,e){var h=g.descendant(b,"caption").map(f.get).getOr("");return k.different(b,c,h,d,e).map(function(b){a.setSummary(b,
c);return b})},setHeaders:function(b,c,e,f){return(!0===e&&!0===f?a.addBothHeaders:!0===e?a.addRowHeader:!0===f?a.addColumnHeader:d.constant(k.invalidError("a11y.t4b.repair.errors.none")))(b,c)},setScope:function(a,c){b.set(a,"scope",c);return e.value(a)}}}});l("lm",["4q","2v"],function(d,e){var c=d.generate([{field:["name","textkey","f"]},{select:["name","textkey","values"]},{toggles:["name","textkey","options"]}]),a=e.immutable("value","text"),b=e.immutable("value","icon","textkey");return{field:c.field,
select:c.select,toggles:c.toggles,pair:a,toggle:b,cata:function(a,b,c,d){return a.fold(b,c,d)}}});l("cu","b 7 s p lj lk ll 2v 1a l lm".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){return function(n){var r=h.immutableBag("id description prompts element severity url repair".split(" "),[]),q=h.immutableBag(["ui","repair"],[]),t=f(n),s=g(n),u={I1:c.some(q({ui:[p.field("image-alt","a11y.i1.repair.info",e.constant(""))],repair:function(a,b,c){return t.changeAlt(b.element(),c["image-alt"](),"a11y.i1.repair.errors.empty",
"a11y.i1.repair.errors.duplicate")}})),I2:c.some(q({ui:[p.field("image-alt","a11y.i2.repair.info",function(a){return k.get(a.element(),"alt")})],repair:function(a,b,c){return t.changeAlt(b.element(),c["image-alt"](),"a11y.i2.repair.errors.empty","a11y.i2.repair.errors.duplicate")}})),T1:c.some(q({ui:[p.field("table-caption","a11y.t1.repair.info",e.constant(""))],repair:function(a,b,c){return s.changeCaption(b.element(),c["table-caption"](),"a11y.t1.repair.errors.empty","a11y.t1.repair.errors.duplicate")}})),
T2:c.some(q({ui:[p.field("table-summary","a11y.t2.repair.info",e.constant(""))],repair:function(a,b,c){return s.changeSummary(b.element(),c["table-summary"](),"a11y.t2.repair.errors.empty","a11y.t2.repair.errors.duplicate")}})),T3:c.some(q({ui:[p.field("table-caption","a11y.t3.repair.info",function(a){return k.get(a.element(),"summary")})],repair:function(a,b,c){return s.changeCaption(b.element(),c["table-caption"](),"a11y.t3.repair.errors.empty","a11y.t3.repair.errors.duplicate")}})),T4A:c.none(),
T4B:c.some(q({ui:[p.toggles("table-headers","a11y.t4b.repair.info",[p.toggle("row-header","ephox-polish-row-header","a11y.t4b.repair.row"),p.toggle("col-header","ephox-polish-column-header","a11y.t4b.repair.column")])],repair:function(a,b,c){var d=c["row-header"]();c=c["col-header"]();return s.setHeaders(a,b.element(),d,c)}})),T4C:c.some(q({ui:[p.select("scope-type","a11y.t4c.repair.info",[p.pair("row","a11y.t4c.repair.scope.row"),p.pair("col","a11y.t4c.repair.scope.col"),p.pair("rowgroup","a11y.t4c.repair.scope.rowgroup"),
p.pair("colgroup","a11y.t4c.repair.scope.colgroup")])],repair:function(a,b,c){return s.setScope(b.element(),c["scope-type"]())}})),D1:c.some(q({ui:[p.select("heading-type","a11y.d1.repair.info",[p.pair("h1","a11y.d1.repair.block.h1"),p.pair("h2","a11y.d1.repair.block.h2"),p.pair("h3","a11y.d1.repair.block.h3"),p.pair("h4","a11y.d1.repair.block.h4"),p.pair("h5","a11y.d1.repair.block.h5"),p.pair("h6","a11y.d1.repair.block.h6")])],repair:function(a,c,d){return b.convertToHeading(c.element(),d["heading-type"]())}})),
D2:c.none(),D3:c.some(q({ui:[],repair:function(a,c,d){return b.joinLinks(a.content().isRoot,c.element())}})),D4:c.none(),D5:c.none(),O1:c.none(),O2:c.none()};return{convert:function(b,e){var f=function(a){var c=a.repair();return function(a,d){return b.undo().transaction(function(){return c(b,a,d)})}};return d.map(e,function(b){var d=b.rule(),e=d.id().toUpperCase(),g=void 0!==u[e]?u[e]:c.none(),h=d.desckey();return r({id:e,description:h,prompts:g.map(function(a){return a.ui()}),element:m.fromDom(b.element()),
url:d.url(),severity:d.severity(),repair:g.map(f).getOr(function(){return a.error("no repair")})})})}}}});l("cv","b s 1a 4k 1y 4e 4h o".split(" "),function(d,e,c,a,b,f,g,h){var k=function(b,g){d.each(b,function(b){g.get(b.severity()).fold(function(){h.warn("unknown severity for accessibility rule: ",b.id(),b.severity())},function(c){f.add(b.element(),[g.violation(),c.style()]);a.add(b.element(),c.attribute(),b.id())})});e.from(b[0]).each(function(a){var b=a.element(),d=g.currentAttr();a=a.severity();
c.set(b,d,a)})},m=function(a,b,e,f){a=g.descendants(a,"["+b+"]");d.each(a,function(a){c.remove(a,b)});c.set(e,b,f)},p=function(a,e){var f=g.descendants(a,"."+e.violation());d.each(f,function(a){b.remove(a,e.violation());c.remove(a,e.currentAttr());d.each(e.all(),function(d){b.remove(a,d.style());c.remove(a,d.attribute())})})},n=function(c,e,f){var g=function(b){return 0===a.read(c,b.attribute()).length};e.get(f).each(function(a){g(a)&&b.remove(c,a.style())});d.forall(e.all(),g)&&b.remove(c,e.violation())},
r=function(b,d,e,f){d.get(f).each(function(f){a.remove(b,f.attribute(),e);a.add(b,d.ignoreAttr(),e);f=d.currentAttr();c.remove(b,f)})},q=function(b,d,e,f){d.get(f).each(function(f){a.remove(b,f.attribute(),e);f=d.currentAttr();c.remove(b,f)})};return{manager:function(a){var b=a.content();return{start:function(b){k(b,a)},moveTo:function(c,d){b.body().each(function(b){m(b,a.currentAttr(),c,d)})},stop:function(){b.body().each(function(b){p(b,a)})},ignore:function(b,c,d){r(b,a,c,d);n(b,a,d)},solve:function(b,
c,d){q(b,a,c,d);n(b,a,d)}}}}});l("cw","b 1a 1y 3d 2r 2b".split(" "),function(d,e,c,a,b,f){var g=function(a){return function(b){d.each(b,a)}},h=g(b.remove),k=g(function(a){e.set(a,"class","")}),m=g(function(c){var d=f.children(c);a.before(c,d);b.remove(c)});return{remove:h,clearClasses:k,removeClass:function(a){return g(function(b){c.remove(b,a)})},removeAttr:function(a){return g(function(b){e.remove(b,a)})},unwrap:m}});l("78","b 7 s cv 34 2v cw".split(" "),function(d,e,c,a,b,f,g){var h=function(a){return"data-"+
b.resolve(a)},k=h("a11y-current-violation"),m=b.resolve("a11y-violation"),p=b.resolve("a11y-severity-info"),n=b.resolve("a11y-severity-warn"),r=b.resolve("a11y-severity-error"),q=h("a11y-ignore"),t=h("a11y-error"),s=h("a11y-warning"),u=h("a11y-info");f=f.immutableBag(["style","attribute"],[]);var v=f({style:r,attribute:t}),w=f({style:n,attribute:s}),y=f({style:p,attribute:u}),x=function(a){return"error"===a?c.some(v):"warning"===a?c.some(w):"info"===a?c.some(y):c.none()};return{configure:function(a){a.addSelector(a.output(),
"["+q+"]",g.removeAttr(q));d.each([a.output(),a.input(),a.history(),a.internal()],function(b){d.each([m,p,n,r],function(c){a.add(b,c,g.removeClass(c))});d.each([k,t,s,u],function(c){a.addSelector(b,"["+c+"]",g.removeAttr(c))})})},ignoreAttr:e.constant(q),manager:function(b){return a.manager({content:e.constant(b),violation:e.constant(m),currentAttr:e.constant(k),ignoreAttr:e.constant(q),get:x,all:e.constant([v,w,y])})}}});l("fy","87 f9 1a 21 az 2b".split(" "),function(d,e,c,a,b,f){var g=function(a){return"false"===
c.get(a,"contenteditable")},h=function(a){a=a[a.length-1];var b=d.getEnd(a);return e.point(a,b)};return{descend:function(c,d){var g=f.children(c);if(0===g.length)return e.point(c,d);if(d<g.length)return e.point(g[d],0);var g=g[g.length-1],h=a.isText(g)?b.get(g).length:f.children(g).length;return e.point(g,h)},descendUntilLeaf:function(a,b){var c=e.point(a,b),d=function(a){return g(a.element())?c:f.child(a.element(),a.offset()).fold(function(){return a},function(a){return d(e.point(a,0))})},r=f.children(a);
return 0<r.length&&b<r.length?d(e.point(r[b],0)):0<r.length&&b===r.length?d(h(r)):c}}});l("cx","84 7 fy 2o l 68 2p 3p 21 2r 2a 2b 1s e2".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q){var t=function(b){var c=q(a.get(b,"padding-top"),10),d=q(a.get(b,"padding-bottom"),10);b=n.owner(b);return p.get(b).top()-(c+d)},s=function(a,k){var p=c.descend(a,k),n=b.fromText(d.zeroWidth()),r=b.fromTag("span");g.append(r,n);g.before(p.element(),r);p=h.absolute(r);n=f.get(r);return{element:e.constant(r),bottom:e.constant(p.top()+
n),pos:e.constant(p),cleanup:function(){m.remove(r)}}},u=function(a){var b=h.absolute(a),c=f.get(a);return{element:e.constant(a),bottom:e.constant(b.top()+c),pos:e.constant(b),cleanup:e.noop}},v=function(b,c){b.getSelection().each(function(d){b.body().each(function(e){b.win().each(function(b){a.reflow(e);var f=t(e),g=s(d.startContainer(),d.startOffset());c(b,f,g);g.cleanup()})})})},w=function(a,b,c){a.body().each(function(d){a.win().each(function(a){c(a,t(d),b)})})},y=function(a,b,c){var d=a.innerHeight,
e=c.pos();c.bottom()>d+b?(b=e.top()-d+1.5*f.get(c.element()),a.scrollTo(e.left(),b)):e.top()<b&&a.scrollTo(e.left(),e.top())},x=function(b,c,d,e){b.body().each(function(g){var h=f.get(b.element()),k;k=g.dom();k=r.max(k.offsetHeight,k.scrollHeight);var m=e.pos();e.bottom()>k?a.set(g,"min-height",e.bottom()+"px"):a.remove(g,"min-height");(m.top()>h+d||m.top()<d)&&c.scrollTo(m.left(),m.top())})},l=function(a){v(a,y)},A=function(a,b){w(a,u(b),y)},D=function(a){v(a,e.curry(x,a))},B=function(a,b){w(a,u(b),
e.curry(x,a))};return{cursorIntoView:function(a){(a.isInline()?l:D)(a)},elementIntoView:function(a,b){(a.isInline()?A:B)(a,b)},putInView:function(a,b,c,d){n.parent(d).each(function(e){var g=k.isText(d)||"br"===k.name(d)?e:d;e=f.get(c.element());var m=p.get(a),g=h.absolute(g),n=m.top(),q=n+e;(g.top()>q||g.top()<n)&&b.scrollTo(m.left(),r.max(0,g.top()-e/2))})},createMarker:s}});l("lq","8b 30 53 7 7b 34 1a 1y 4e l 2p 3d 21".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){var q=function(a,c,d){a=m.fromTag(a);
d=b.translate(d);return t(a,c,d)},t=function(a,b,e){e=d.labelledField(a,b,e);h.add(e.element(),f.resolve("form-group"));h.add(e.element(),f.resolve(b));"select"===r.name(a)&&(a=c.div(),h.add(a,f.resolve("select-wrap")),p.append(a,e.field()),p.append(e.element(),a));return e};return{input:function(a,b){var c=q("input",a,b);g.setAll(c.field(),{type:"text"});return{element:c.element,input:c.field}},textarea:function(a,b){var c=q("textarea",a,b);d.multiline(c.field());return{element:c.element,textarea:c.field}},
common:q,commonWith:t,comboBox:function(r,q,t){var w=m.fromTag("input"),y=b.translate(q);q=c.div();var x=r+e.generate(""),y=m.fromHtml("<label>"+y+"</label>");g.set(y,"for",x);g.set(w,"id",x);h.add(q,f.resolve("form-group"));h.add(q,f.resolve(r));r=c.span();d.hidden(r,!0);x=c.span();d.hidden(x,!0);k.add(x,["ephox-textbox-font",f.resolve("icon"),f.resolve("combo-drop-arrow-icon")]);h.add(r,f.resolve("combo-drop-arrow"));p.append(r,x);var l=c.div();h.add(l,f.resolve("label-wrap"));t.each(function(a){p.append(l,
a)});p.append(l,y);t=c.div();h.add(t,f.resolve("combo-wrap"));n.append(t,[w,r]);g.set(w,"type","text");n.append(q,[l,t]);return{element:a.constant(q),input:a.constant(w),dropArrow:a.constant(r)}}}});l("gw","8b fh 53 hg eh 7 7b 34 4a 4b 1a 1y 3d".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){var q=function(a){n.add(a,h.resolve("dialog-button-default"))},t=function(a){n.add(a,h.resolve("dialog-button"))},s=function(c,f,k){var m=a(c+f);n.add(m.element(),h.resolve("dialog-"+f));c=b(g.translate(k));m.content(c);
p.set(m.element(),"tabindex","-1");d.textButton(m.element(),c.element());return{enable:function(){m.enable();e.enable(m.element())},disable:function(){m.disable();e.disable(m.element())},element:m.element,name:m.name,destroy:m.destroy,content:m.content,disabled:m.disabled,click:m.click,events:m.events}},u=function(a){a=s(a,"ok","button.ok");q(a.element());return a},v=function(a){a=s(a,"cancel","button.cancel");t(a.element());return a};return{button:s,okCancel:function(a){var b=void 0!==a?a+"-":"";
a=c.div();n.add(a,h.resolve(b+"dialog-controls"));var d=v(b),e=u(b);r.append(a,[d.element(),e.element()]);b=k.create({ok:m([],e.events.click),cancel:m([],d.events.click)});return{element:f.constant(a),ok:f.constant(e),cancel:f.constant(d),destroy:function(){e.destroy();d.destroy()},events:b.registry}},makeNormal:t,makeDefault:q}});l("cy","8b hg hh eh lp lq gw 34 1a 1y 4e 2z".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var r=function(a,b){var c=a(),e=c.element();d.button(e,b);k.set(e,"tabindex","-1");
c.events.click.bind(function(){n.focus(e)});return c},q=function(a,b){var d=r(e,b);d.content(c([a,h.resolve("icon")]));k.set(d.element(),"title",b);return d};return{setDefaultAction:function(a){g.makeDefault(a)},setNormalButton:function(a){g.makeNormal(a)},makeTextButton:function(b,c,d){c=r(e,c);p.add(c.element(),b);c.content(a(d));return c},makeIconToggle:function(a,d,e){var f=r(b,e);f.content(c([d,h.resolve("icon")]));m.add(f.element(),h.resolve("choice-button"));k.set(f.element(),"data-value",
a);k.set(f.element(),"title",e);return f},makeField:function(a,b,c){return f.commonWith(a,b,c)},makeIconButton:q,makeIconStepperButton:function(a,b){var c=q(a,b);m.add(c.element(),h.resolve("stepper-button"));return c}}});l("cz",["s","7b","9"],function(d,e,c){var a={"a11y.widget.ok.label":"button.ok","a11y.widget.ok.text":"button.ok","a11y.widget.ignore.label":"a11y.widget.ignore","a11y.widget.ignore.text":"a11y.widget.ignore","a11y.widget.repair.label":"a11y.widget.repair","a11y.widget.repair.text":"a11y.widget.repair",
"a11y.widget.repair.available":"a11y.widget.available","a11y.i1.description":"a11y.image.alttext.empty","a11y.i1.repair.info":"a11y.image.alttext.set","a11y.i1.repair.errors.empty":"a11y.image.alttext.validation.empty","a11y.i1.repair.errors.duplicate":"a11y.image.alttext.validation.filenameduplicate","a11y.i2.description":"a11y.image.alttext.filenameduplicate","a11y.i2.repair.info":"a11y.image.alttext.set","a11y.i2.repair.errors.empty":"a11y.image.alttext.validation.empty","a11y.i2.repair.errors.duplicate":"a11y.image.alttext.validation.filenameduplicate",
"a11y.t1.description":"a11y.table.caption.empty","a11y.t1.repair.info":"a11y.table.caption.set","a11y.t1.repair.errors.empty":"a11y.table.caption.validation.empty","a11y.t1.repair.errors.duplicate":"a11y.table.caption.validation.summaryduplicate","a11y.t2.description":"a11y.table.summary.empty","a11y.t2.repair.info":"a11y.table.summary.set","a11y.t2.repair.errors.empty":"a11y.table.summary.validation.empty","a11y.t2.repair.errors.duplicate":"a11y.table.summary.validation.captionduplicate","a11y.t3.description":"a11y.table.caption.summaryduplicate",
"a11y.t3.repair.info":"a11y.table.caption.set","a11y.t3.repair.errors.empty":"a11y.table.caption.validation.empty","a11y.t3.repair.errors.duplicate":"a11y.table.caption.validation.summaryduplicate","a11y.t4a.description":"a11y.table.rowscells.none","a11y.t4b.description":"a11y.table.headers.none","a11y.t4b.repair.info":"a11y.table.headers.set","a11y.t4b.repair.row":"table.row-header","a11y.t4b.repair.column":"table.column-header","a11y.t4b.repair.errors.none":"a11y.table.headers.validation.none",
"a11y.t4c.description":"a11y.table.headerscope.none","a11y.t4c.repair.info":"a11y.table.headerscope.set","a11y.t4c.repair.scope.row":"a11y.table.headerscope.scope.row","a11y.t4c.repair.scope.col":"a11y.table.headerscope.scope.col","a11y.t4c.repair.scope.rowgroup":"a11y.table.headerscope.scope.rowgroup","a11y.t4c.repair.scope.colgroup":"a11y.table.headerscope.scope.colgroup","a11y.d1.description":"a11y.heading.paragraphmisuse","a11y.d1.repair.info":"a11y.heading.set","a11y.d1.repair.block.h1":"block.h1",
"a11y.d1.repair.block.h2":"block.h2","a11y.d1.repair.block.h3":"block.h3","a11y.d1.repair.block.h4":"block.h4","a11y.d1.repair.block.h5":"block.h5","a11y.d1.repair.block.h6":"block.h6","a11y.d2.description":"a11y.heading.nonsequential","a11y.d3.description":"a11y.link.adjacent","a11y.d4.description":"a11y.list.paragraphmisuse","a11y.d5a.description":"a11y.contrast.largetext","a11y.d5b.description":"a11y.contrast.smalltext"};return{get:function(b){return d.from(a[b])},translate:function(b){var d=c.prototype.slice.call(arguments,
1);return e.translate.apply(void 0,[void 0!==a[b]?a[b]:b].concat(d))}}});l("d0",["2v"],function(d){return d.immutableBag(["rules"],[])});l("tv",["2j"],function(d){return{filterAccept:function(){return d.getOrDie("NodeFilter").FILTER_ACCEPT},showElement:function(){return d.getOrDie("NodeFilter").SHOW_ELEMENT}}});l("tw",["2v"],function(d){return d.immutableBag(["rule","element"],[])});l("lr",["b","2c","tv","tw","q"],function(d,e,c,a,b){var f=function(a){return c.filterAccept()},g=function(b,c){return d.bind(c,
function(c){return c.check()(b)?[a({rule:c,element:b})]:[]})},h=function(b,c){return d.bind(c,function(c){return d.map(c.check()(b),function(b){return a({rule:c,element:b})})})};return{audit:function(a,m){for(var p=[],n=d.partition(m,function(a){return a.walkable()}),r=n.pass,n=n.fail,q=b.createTreeWalker(a,c.showElement(),f,!1);q.nextNode();)p=p.concat(g(q.currentNode,r));r=h(a,n);p=p.concat(r);p.sort(function(a,b){var c=a.element(),d=b.element();return c===d?0:e.documentPositionPreceding(c,d)?1:
-1});return p}}});l("d1",["lr"],function(d){return function(e){return{audit:function(c){return d.audit(c,e.rules())}}}});l("za",["2v"],function(d){return d.immutableBag("id wcag severity desckey url walkable check".split(" "),[])});l("zb",["7"],function(d){return{error:d.constant("error"),warning:d.constant("warning"),info:d.constant("info")}});l("zc",[],function(){return{match:function(d,e){return d.matches?d.matches(e):d.webkitMatchesSelector?d.webkitMatchesSelector(e):d.mozMatchesSelector?d.mozMatchesSelector(e):
d.msMatchesSelector?d.msMatchesSelector(e):!1}}});l("tx",["b","za","zb","zc"],function(d,e,c,a){var b=function(a){return d.forall(a.childNodes,function(a){return/^(b|strong)$/i.test(a.nodeName)})};return e({id:"D1",wcag:"1.3.1",severity:c.warning(),desckey:"a11y.d1.description",url:"http://www.w3.org/TR/UNDERSTANDING-WCAG20/content-structure-separation-programmatic.html",walkable:!0,check:function(c){return a.match(c,"p")?b(c):!1}})});l("ty",["b","za","zb"],function(d,e,c){return e({id:"D2",wcag:"1.3.1",
severity:c.error(),desckey:"a11y.d2.description",url:"http://www.w3.org/TR/UNDERSTANDING-WCAG20/content-structure-separation-programmatic.html",walkable:!1,check:function(a){a=a.querySelectorAll("h1, h2, h3, h4, h5, h6");var b,c=[];d.each(a,function(a){var d=parseInt(a.tagName.slice(1),10);b&&1<d-b&&c.push(a);b=d});return c}})});l("tz",["b","za","zb"],function(d,e,c){return e({id:"D3",wcag:"2.4.4",severity:c.error(),desckey:"a11y.d3.description",url:"http://www.w3.org/TR/UNDERSTANDING-WCAG20/navigation-mechanisms-refs.html",
walkable:!1,check:function(a){return d.filter(a.querySelectorAll("a + a"),function(a){return a.href===a.previousSibling.href})}})});l("zd",[],function(){var d=function(d){var c=d.nodeName;for(d=d.nextSibling;null!==d&&("#text"===d.nodeName||"BR"===d.nodeName);)d=d.nextSibling;return null!==d&&d.nodeName===c?d:!1};return{check:function(e,c){for(var a=e.querySelectorAll("p,h1,h2,h3,h4,h5,h6"),b=[],f=0;f<a.length;){var g,h=a[f];g=c;for(var k=d(h),h=g(h)?[h]:[];!1!==k&&g(k);)h.push(k),k=d(k);g=h;if(1<
g.length){b.push(g[0]);g=g[g.length-1];k=-1;for(h=0;h<a.length;h++)if(a[h]===g){k=h;break}g=k;f=-1===g?f+1:g}else f++}return b}}});l("u0",["za","zb","zd"],function(d,e,c){var a=function(a){return a.textContent.match(/^\s{0,}([a-z1-9]|i+)\s{0,}[.)-]/gmi)};return d({id:"D4o",wcag:"1.3.1",severity:e.error(),desckey:"a11y.d4.description",url:"http://www.w3.org/TR/UNDERSTANDING-WCAG20/content-structure-separation-programmatic.html",walkable:!1,check:function(b){return c.check(b,a)}})});l("u1",["za","zb",
"zd"],function(d,e,c){var a=function(a){return a.textContent.match(/^\s{0,}(\*|-)\s{0,}/gmi)};return d({id:"D4u",wcag:"1.3.1",severity:e.error(),desckey:"a11y.d4.description",url:"http://www.w3.org/TR/UNDERSTANDING-WCAG20/content-structure-separation-programmatic.html",walkable:!1,check:function(b){return c.check(b,a)}})});l("14u",["2v"],function(d){var e=d.immutable("red","green","blue","alpha");return{rgbaColour:e,white:function(){return e(255,255,255,1)}}});l("12h",["14u","1s"],function(d,e){return{calculateContrastRatio:function(c,
a){var b=e.max(c,a)+0.05,d=e.min(c,a)+0.05;return b/d},calculateLuminance:function(c){var a=function(a){return 0.03928>=a?a/12.92:e.pow((a+0.055)/1.055,2.4)},b=c.red()/255,d=c.green()/255;c=c.blue()/255;b=a(b);d=a(d);a=a(c);return 0.2126*b+0.7152*d+0.0722*a},composeColour:function(c,a){var b=c.alpha()+a.alpha()*(1-c.alpha()),f=(c.red()*c.alpha()+a.red()*a.alpha()*(1-c.alpha()))/b,g=(c.green()*c.alpha()+a.green()*a.alpha()*(1-c.alpha()))/b,h=(c.blue()*c.alpha()+a.blue()*a.alpha()*(1-c.alpha()))/b;
return d.rgbaColour(e.ceil(f),e.ceil(g),e.ceil(h),b)}}});l("14v",["s","14u"],function(d,e){return{parseColour:function(c){var a=function(a,b,c,k){a=parseInt(a,10);b=parseInt(b,10);c=parseInt(c,10);k=parseFloat(k);return d.some(e.rgbaColour(a,b,c,k))};if("transparent"===c)return a(0,0,0,0);var b=c.match(/^rgb\((\d+),\s*(\d+),\s*(\d+)\)/);if(null!==b)return a(b[1],b[2],b[3],1);c=c.match(/^rgba\((\d+),\s*(\d+),\s*(\d+),\s*(\d?(?:\.\d+)?)\)/);return null!==c?a(c[1],c[2],c[3],c[4]):d.none()}}});l("12g",
"b s 12h 14u 14v 2n 1b 2o 2b".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(b,c){var d=h.get(b,"opacity");return 1>d?a.rgbaColour(c.red(),c.green(),c.blue(),c.alpha()*d):c};return{getBackgroundColor:function(p){var n=k.owner(p),r=f.getBody(n);p=[p].concat(k.parents(p,function(a){return g.eq(a,r)}));p=d.foldl(p,function(a,d){if(1===a.alpha())return a;var f=h.get(d,"background-color");return b.parseColour(f).bind(function(b){b=m(d,b);return 0<b.alpha()?e.some(c.composeColour(a,b)):e.none()}).getOr(a)},
a.rgbaColour(0,0,0,0));return 1>p.alpha()?c.composeColour(p,a.white()):p},getForegroundColor:function(a,d){var f=h.get(a,"color");return b.parseColour(f).bind(function(b){b=m(a,b);b=1>b.alpha()?c.composeColour(b,d):b;return e.some(b)})}}});l("ze",["s","12g","12h"],function(d,e,c){var a=function(a){var d=e.getBackgroundColor(a);return e.getForegroundColor(a,d).map(function(a){var b=c.calculateLuminance(d);a=c.calculateLuminance(a);return c.calculateContrastRatio(a,b)})};return{check:function(b,c){return a(b).filter(function(a){return a<
c}).isSome()},getRatio:a}});aa("pi",Number);l("zf","7 s 2n 2o 2b pi 6p".split(" "),function(d,e,c,a,b,f,g){var h=function(b){b=a.get(b,"font-weight");return"bold"===b||"bolder"===b?!0:/^[0-9]*$/.test(b)?700<=parseInt(b,10):!1},k=function(b){var c=a.get(b,"font-size");b=(new g(".*px")).test(c);c=c.match(/(\d*\.?\d*)(.*)/);return b&&null!==c?e.some(f(c[1])):e.none()};return{isLargeFont:function(a){var e=h(a),f=b.owner(a),f=c.getBody(f),g=k(f);return k(a).fold(d.constant(!1),function(a){return g.fold(function(){return 24<=
a||e&&19<=a},function(b){return a>=1.5*b||e&&a>=1.2*b})})}}});l("zg",["b","21","2b"],function(d,e,c){return{hasNonEmptyTextChild:function(a){a=c.children(a);return 0<d.filter(a,function(a){return e.isText(a)&&0<e.value(a).trim().length}).length}}});l("u2","za zb ze zf zg l".split(" "),function(d,e,c,a,b,f){return d({id:"D5a",wcag:"1.4.3",severity:e.error(),desckey:"a11y.d5a.description",url:"https://www.w3.org/TR/UNDERSTANDING-WCAG20/visual-audio-contrast-contrast.html",walkable:!0,check:function(d){d=
f.fromDom(d);return b.hasNonEmptyTextChild(d)&&a.isLargeFont(d)&&c.check(d,3)}})});l("u3","za zb ze zf zg l".split(" "),function(d,e,c,a,b,f){return d({id:"D5b",wcag:"1.4.3",severity:e.error(),desckey:"a11y.d5b.description",url:"https://www.w3.org/TR/UNDERSTANDING-WCAG20/visual-audio-contrast-contrast.html",walkable:!0,check:function(d){d=f.fromDom(d);return b.hasNonEmptyTextChild(d)&&!a.isLargeFont(d)&&c.check(d,4.5)}})});l("u4",["za","zb","zc"],function(d,e,c){return d({id:"I1",wcag:"1.1.1",severity:e.error(),
desckey:"a11y.i1.description",url:"http://www.w3.org/TR/UNDERSTANDING-WCAG20/text-equiv-all.html",walkable:!0,check:function(a){return c.match(a,"img")&&(!1===a.hasAttribute("alt")||""===a.getAttribute("alt").trim())}})});l("u5",["za","zb","zc"],function(d,e,c){return d({id:"I2",wcag:"1.1.1",severity:e.error(),desckey:"a11y.i2.description",url:"http://www.w3.org/TR/UNDERSTANDING-WCAG20/text-equiv-all.html",walkable:!0,check:function(a){return c.match(a,"img[alt][src]")&&a.src.split("/").pop()===a.alt.split("/").pop()}})});
l("u6",["za","zb","zc"],function(d,e,c){return d({id:"T1",wcag:"1.3.1",severity:e.error(),desckey:"a11y.t1.description",url:"http://www.w3.org/TR/UNDERSTANDING-WCAG20/content-structure-separation-programmatic.html",walkable:!0,check:function(a){return c.match(a,"table")?(a=a.querySelector("caption"))?c.match(a,":empty"):!0:!1}})});l("u7",["za","zb","zc"],function(d,e,c){return d({id:"T2",wcag:"1.3.1",severity:e.warning(),desckey:"a11y.t2.description",url:"http://www.w3.org/TR/UNDERSTANDING-WCAG20/content-structure-separation-programmatic.html",
walkable:!0,check:function(a){return c.match(a,"table")&&(a.querySelector("[rowspan]")||a.querySelector("[colspan]"))&&!a.hasAttribute("summary")}})});l("u8",["za","zb","zc"],function(d,e,c){return d({id:"T3",wcag:"1.3.1",severity:e.error(),desckey:"a11y.t3.description",url:"http://www.w3.org/TR/UNDERSTANDING-WCAG20/content-structure-separation-programmatic.html",walkable:!0,check:function(a){return c.match(a,"table")&&a.hasAttribute("summary")&&0<a.querySelectorAll("caption").length&&a.getAttribute("summary")===
a.querySelector("caption").innerHTML}})});l("u9",["za","zb"],function(d,e){return d({id:"T4b",wcag:"1.3.1",severity:e.error(),desckey:"a11y.t4b.description",url:"http://www.w3.org/TR/UNDERSTANDING-WCAG20/content-structure-separation-programmatic.html",walkable:!0,check:function(c){return"table"===c.nodeName.toLowerCase()&&0===c.querySelectorAll("th").length}})});l("ua",["za","zb"],function(d,e){return d({id:"T4c",wcag:"1.3.1",severity:e.error(),desckey:"a11y.t4c.description",url:"http://www.w3.org/TR/UNDERSTANDING-WCAG20/content-structure-separation-programmatic.html",
walkable:!0,check:function(c){var a;"th"===c.nodeName.toLowerCase()?(a=!1===c.hasAttribute("scope"),c=!1===/row|col|rowgroup|colgroup/i.test(c.getAttribute("scope")),a=a||c):a=!1;return a}})});l("ub",["za","zb"],function(d,e){return d({id:"T4a",wcag:"1.3.1",severity:e.error(),desckey:"a11y.t4a.description",url:"http://www.w3.org/TR/UNDERSTANDING-WCAG20/content-structure-separation-programmatic.html",walkable:!0,check:function(c){return"table"===c.nodeName.toLowerCase()?0===c.querySelectorAll("tr").length||
0===c.querySelectorAll("td").length:!1}})});l("ls","b 7 s tx ty tz u0 u1 u2 u3 u4 u5 u6 u7 u8 u9 ua ub".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v){var w=[a,b,f,g,h,k,m,p,n,r,q,t,u,v,s];return{get:function(a){return c.from(d.find(w,function(b){return b.name()===a}))},all:e.constant(w)}});l("d2",["ls"],function(d){return{get:function(e){return d.get(e)},all:function(){return d.all().slice()}}});l("lu",["s","4p","2v","1s"],function(d,e,c,a){return function(){var b=e([]),f=e(0),g=c.immutable("index",
"total","detail"),h=function(a){var c=b.get();if(0===c.length)return d.none();var e,h=f.get();e=c.length-1;a=h+a;e=a>e?0:0>a?e:a;f.set(e);return d.some(g(e,c.length,c[e]))};return{load:function(a){if(0===a.length)return d.none();f.set(0);b.set(a);return d.some(g(f.get(),a.length,a[0]))},backwards:function(){return h(-1)},current:function(){var a=b.get();return 0===a.length?d.none():d.some(g(f.get(),a.length,a[f.get()]))},resolve:function(){var c=b.get();if(0===c.length)return d.none();var c=c.slice(0,
f.get()).concat(c.slice(f.get()+1)),e=a.min(c.length-1,f.get());f.set(e);b.set(c);return 0===c.length?d.none():d.some(g(f.get(),c.length,c[f.get()]))},forwards:function(){return h(1)}}}});l("uc",["4j"],function(d){return{resolve:d.create("ephox-wheel").resolve}});l("lv",["v","uc","9"],function(d,e,c){return{resolve:function(a,b){return e.resolve(a.prefix()+"-"+b)},translate:function(a,b){var e=[(d.startsWith(b,a.tnames())?"":a.tnames()+".")+b].concat(c.prototype.slice.call(arguments,2));return a.translate.apply(null,
e)}}});l("uf",["lv"],function(d){var e=function(c,a,b,e,g){b=d.translate(g,b);e=d.translate(g,e);return c.makeTextButton(a,b,e)};return{defaultActionButton:function(c,a,b,d,g){a=e(c,a,b,d,g);c.setDefaultAction(a.element());return a},normalButton:function(c,a,b,d,g){a=e(c,a,b,d,g);c.setNormalButton(a.element());return a},button:e,toggleButton:function(c,a,b,e,g){e=d.translate(g,e);return c.makeIconToggle(a,b,e)},field:function(c,a,b,e,g){e=d.translate(g,e);return c.makeField(a,b,e)},icon:function(c,
a,b,e){b=d.translate(e,b);return c.makeIconStepperButton(a,b)}}});l("ud","b gt 8y 6 53 7 s 59 4a 2v 1a 1y l 2g 3d 32 33 lv uf".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v,w){var y=function(a,b,d,g,h,k){var m=r.fromTag("input");a=w.field(a,m,d,g,k);n.add(m,v.resolve(k,"input"));b=[c.input(m,e.input({execute:b}))];return{element:a.element,get:function(){var a={};a[d]=u.get(m);return a},update:function(a){a=h(a);u.set(m,a)},keylayouts:f.constant(b),destroy:f.noop}},x=function(a,b,e,h,k){var m=
r.fromTag("select");a=w.field(a,m,b,e,k);h=d.map(h,function(a){var b=r.fromTag("option");u.set(b,a.value());q.set(b,v.translate(k,a.text()));return b});t.append(m,h);h=[c.single(m,[],g.none())];return{element:a.element,get:function(){var a={};a[b]=u.get(m);return a},update:f.noop,keylayouts:f.constant(h),destroy:f.noop}},l=function(g,h,k,m,r){var q=b.div();n.add(q,v.resolve(r,"flow"));var u=d.map(m,function(a){return w.toggleButton(g,a.value(),a.icon(),a.textkey(),r)});m=d.map(u,function(a){return a.element()});
t.append(q,m);m=[c.flow(q,{item:f.constant(".ephox-pastry-statebutton")},e.flow({trigger:function(a){return s.descendant(a,".ephox-pastry-button").map(function(a){a.dom().click();return a})}}))];return{element:w.field(g,q,h,k,r).element,get:function(){return d.foldr(u,function(b,c){var d={};d[p.get(c.element(),"data-value")]=c.selected();return a.deepMerge(b,d)},{})},update:f.noop,keylayouts:f.constant(m),destroy:function(){d.each(u,function(a){a.destroy()})}}};return{generate:function(b,c,e,g){c=
c.getOr([]);var p=d.bind(c,function(a){return a.fold(function(a,b,c){return[a]},function(a,b,c){return[a]},function(a,b,c){return d.map(c,function(a){return a.value()})})}),n=0<p.length?m.immutableBag(p,[]):f.constant({}),r=k.create({execute:h([])}),q=function(){r.trigger.execute()},t=d.map(c,function(a){return a.fold(function(a,c,d){return y(b,q,a,c,d,g)},function(a,c,d){return x(b,a,c,d,g)},function(a,c,d){return l(b,a,c,d,g)})});d.each(t,function(a){a.update(e)});c=d.map(t,function(a){return a.element()});
var s=d.bind(t,function(a){return a.keylayouts()});return{elements:f.constant(c),get:function(){var b=d.foldr(t,function(b,c){return a.deepMerge(b,c.get())},{});return n(b)},keylayouts:f.constant(s),destroy:function(){d.each(t,function(a){a.destroy()});d.each(s,function(a){a.destroy()})},events:r.registry}}}});l("lw","am gt 8y 53 7 s 59 4a 1a 1y l 2g 2p 3d 2r lv ud".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u){return function(v,w){var y=a.div();m.add(y,s.resolve(w,"assistance"));var x=s.resolve(w,
"assistance-invalid"),l=f.none(),A=p.fromTag("p");m.add(A,s.resolve(w,"repair-error"));k.set(A,"aria-live","polite");var D=function(){m.remove(y,x);t.remove(A)},B=h.create({execute:g([])}),C=c.dynamic(y,e.dynamic({})),F=[C];return{element:b.constant(y),keylayouts:b.constant(F),markInvalid:function(a){m.add(y,x);d.shout(y,a);n.set(A,a);r.append(y,A)},markValid:D,getChange:function(){return l.map(function(a){return a.get()})},destroy:function(){l.each(function(a){a.destroy()})},update:function(a){D();
a=a.detail();var b=a.prompts();l.each(function(a){a.destroy()});a=u.generate(v,b,a,w);l=f.some(a);t.empty(y);q.prepend(y,a.elements());a.events.execute.bind(function(){B.trigger.execute()});C.set(a.keylayouts())},events:B.registry}}});l("ue",["7"],function(d){return{title:d.constant("widget.title"),running:d.constant("widget.running"),previous:d.constant("widget.previous"),next:d.constant("widget.next"),issueCounter:d.constant("widget.issue.counter"),issueHelp:d.constant("widget.issue.help"),noIssue:d.constant("widget.issue.none"),
severity:function(d){return"severity."+d},repairLabel:d.constant("widget.repair.label"),repairText:d.constant("widget.repair.text"),repairAvailable:d.constant("widget.repair.available"),ignoreLabel:d.constant("widget.ignore.label"),ignoreText:d.constant("widget.ignore.text"),okLabel:d.constant("widget.ok.label"),okText:d.constant("widget.ok.text")}});l("lx","fh am gt 8y 53 7 4a 4b 2n 1y 2z 2p 3d 2r b0 lv ue uf".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v){return function(w,y){var l=b.div();
m.add(l,s.resolve(y,"commands"));var z=b.div();m.add(z,s.resolve(y,"commands-buttons"));var A=v.defaultActionButton(w,[s.resolve(y,"repair")],u.repairLabel(),u.repairText(),y),D=v.normalButton(w,[s.resolve(y,"ignore")],u.ignoreLabel(),u.ignoreText(),y),B=v.defaultActionButton(w,[s.resolve(y,"ok")],u.okLabel(),u.okText(),y),C=function(){r.append(z,[D.element(),A.element()])};C();var F=c.button({execute:function(a){a.dom().click()}}),F=[a.button(D.element(),F),a.button(A.element(),F),a.button(B.element(),
F)];n.append(l,z);var E=g.create({repair:h([],A.events.click),ignore:h([],D.events.click),done:h([],B.events.click)});return{element:f.constant(l),destroy:function(){A.destroy();D.destroy();B.destroy()},keylayouts:f.constant(F),focus:function(){var a=A.disabled()?A.element():D.element();p.focus(a)},update:function(a){q.remove(B.element());a=a.detail();t.isVisible(D.element())||C();a.prompts().fold(function(){A.disable();d.disable(A.element())},function(a){A.enable();d.enable(A.element());e.speak(k.body(),
s.translate(y,u.repairAvailable()))})},zero:function(a){q.empty(z);n.append(z,B.element());p.focus(B.element())},events:E.registry}}});l("ly","am 8y 53 7 s 1a 2n 1y 3y l 2g 2p 3d 2r lv ue 37".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u){return function(v,w){var y=c.div();h.add(y,t.resolve(w,"information"));f.set(y,"data-severity","info");var l=c.div();h.add(l,t.resolve(w,"icon"));var z=c.div();h.add(z,t.resolve(w,"description"));n.append(z,m.fromText(""));var A=m.fromTag("a");h.add(A,t.resolve(w,
"help-icon"));f.set(A,"href","javascript:void(0)");r.append(y,[l,z,A]);var D=k.bind(A,"click",function(){var a=f.get(A,"data-url");u.open(a,"","height=700,width=820,resizable=yes,scrollbars=yes")}),l=[e.single(A,[],b.none())];return{element:a.constant(y),destroy:function(){D.unbind()},keylayouts:a.constant(l),update:function(a){a=a.detail();var b=a.severity();f.set(y,"data-severity",b);d.speak(g.body(),t.translate(w,s.severity(b)));b=t.translate(w,a.description());p.set(z,b);d.speak(g.body(),b);f.set(A,
"title",t.translate(w,s.issueHelp()));f.set(A,"data-url",a.url());n.after(z,A)},zero:function(){f.set(y,"data-severity","success");var a=t.translate(w,s.noIssue());p.set(z,a);d.speak(g.body(),a);q.remove(A)}}}});l("lz",["53","7","1y","2p","lv"],function(d,e,c,a,b){return function(f,g){var h=d.div(),k=d.span();c.add(k,b.resolve(g,"spin"));c.add(h,b.resolve(g,"loading"));a.append(h,k);return{element:e.constant(h),destroy:e.noop}}});l("m0","b lt fh am gt 8y 53 7 s 4a 4b 2n 1y l 2g 2p 3d lv ue uf".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v,w,y){var l=function(a,b,c){var d=g.div();r.add(d,v.resolve(c,a));b.each(function(a){s.append(d,q.fromText(v.translate(c,a)))});return d};return function(q,A){var D=l("titlebar",k.none(),A),B=l("title",k.none(),A),C=l("title-text",k.some(w.title()),A),F=l("issue",k.some(w.running()),A);u.append(B,[C,F]);var E=g.div();r.add(E,v.resolve(A,"navigation"));var C=y.icon(q,v.resolve(A,"previous"),w.previous(),A),G=y.icon(q,v.resolve(A,"next"),w.next(),A),H=[C,
G],C=m.create({previous:p([],C.events.click),next:p([],G.events.click)});u.append(E,d.map(H,function(a){return a.element()}));s.append(D,B);var I=b.button({execute:function(a){a.dom().click()}}),G=d.map(H,function(a){return f.button(a.element(),I)}),K=function(a){a.disable();c.disable(a.element())},J=function(a){a.enable();c.enable(a.element())},L=function(){d.each(H,K)},N=function(){d.each(H,J)},M=function(){e.preserve(function(){s.after(B,E)},E)};return{element:h.constant(D),update:function(b){var c=
b.index()+1;b=b.total();c=v.translate(A,w.issueCounter(),c,b);t.set(F,c);a.speak(n.body(),c);(1===b?L:N)();M()},zero:function(){t.set(F,"&nbsp;");M();L()},keylayouts:h.constant(G),destroy:function(){d.each(H,function(a){a.destroy()})},events:C.registry}}});l("d3","b lt 53 7 59 4a 4p 1y 2p 3d 2r lu lv lw lx ly lz m0".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v){return function(w,y){var l=c.div();h.add(l,r.resolve(y,"widget"));var z=r.resolve(y,"loading");h.add(l,z);var A=v(w,y),D=s(w,y),
B=q(w,y),C=t(w,y),F=u(w,y);m.append(l,[A.element(),F.element()]);var E=f.create({showcase:b(["detail"]),ignored:b(["detail"]),solved:b(["detail"]),done:b([])}),G=function(a){d.each([A,D,B,C],function(b){b.update(a)});E.trigger.showcase(a.detail());e.preserve(function(){k.after(A.element(),D.element());k.after(D.element(),B.element());k.after(B.element(),C.element())},l)},H=function(a){a.fold(function(){k.after(A.element(),D.element());k.after(D.element(),C.element());p.remove(B.element());A.zero();
D.zero();C.zero()},G)},I=g(n());A.events.previous.bind(function(){I.get().backwards().each(G)});A.events.next.bind(function(){I.get().forwards().each(G)});var K=function(){var a=B.getChange().getOr({});I.get().current().each(function(b){var c=b.detail();c.repair()(c,a).fold(function(a){B.markInvalid(a)},function(a){B.markValid();a=I.get().resolve();E.trigger.solved(c);H(a);C.focus()})})};B.events.execute.bind(K);C.events.repair.bind(K);C.events.ignore.bind(function(){I.get().current().each(function(a){var b=
I.get().resolve();E.trigger.ignored(a.detail());H(b)})});C.events.done.bind(function(){E.trigger.done()});K=d.flatten([A.keylayouts(),D.keylayouts(),B.keylayouts(),C.keylayouts()]);return{element:a.constant(l),destroy:function(){d.each([A,D,B,C],function(a){a.destroy()})},load:function(a){p.remove(F.element());h.remove(l,z);a=I.get().load(a);H(a)},open:function(){k.append(l,F.element());h.add(l,z)},skip:function(){var a=I.get().resolve();H(a)},keylayouts:a.constant(K),events:E.registry}}});l("77",
"b 7 cu 78 cx cy cz 4a 4b d0 d1 d2 4k 2n d3".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t){return function(s){var u=a.ignoreAttr(),v={prefix:e.constant("accessibility-check"),translate:g.translate,tnames:e.constant("a11y")},w=t(f,v),v=n.all(),v=m({rules:v}),y=p(v),l=c(g.translate),z=a.manager(s.content()),A=function(a){a=y.audit(a.dom());a=l.convert(s,a);return d.filter(a,function(a){var b=a.element(),b=r.read(b,u);return!d.contains(b,a.id())})};w.events.showcase.bind(function(a){s.content().body().each(function(c){c=
a.detail().element();q.inBody(c)?(z.moveTo(c,a.detail().severity()),b.elementIntoView(s.content(),c)):w.skip()})});w.events.ignored.bind(function(a){a=a.detail();z.ignore(a.element(),a.id(),a.severity())});w.events.solved.bind(function(a){a=a.detail();z.solve(a.element(),a.id(),a.severity())});v=h.create({done:k([],w.events.done)});return{element:w.element,anchorName:e.constant("a11y-widget-anchor"),textkey:e.constant("action.a11ycheck"),dialogTextkey:e.constant("a11y.widget.title"),destroy:function(){w.destroy()},
keylayouts:w.keylayouts,openWidget:function(){s.content().hideInlineSelection();w.open();s.content().body().each(function(a){a=A(a);z.start(a);w.load(a)})},closeWidget:function(){z.stop()},events:v.registry}}});l("79",["s","4p"],function(d,e){var c=function(a){var b=e(d.none());return{clear:function(){b.get().each(a);b.set(d.none())},isSet:function(){return b.get().isSome()},set:function(c){b.get().each(a);b.set(d.some(c))}}};return{destroyable:function(){return c(function(a){a.destroy()})},unbindable:function(){return c(function(a){a.unbind()})},
api:function(){var a=e(d.none()),b=function(){a.get().each(function(a){a.destroy()})};return{clear:function(){b();a.set(d.none())},isSet:function(){return a.get().isSome()},set:function(c){b();a.set(d.some(c))},run:function(b){a.get().each(b)}}},value:function(){var a=e(d.none());return{clear:function(){a.set(d.none())},set:function(b){a.set(d.some(b))},isSet:function(){return a.get().isSome()},on:function(b){a.get().each(b)}}}}});l("dl","7d 59 4a 1y 2o 3y l 2p 2r 3x".split(" "),function(d,e,c,a,
b,f,g,h,k,m){return function(m,n){var r=c.create({open:e([]),close:e([])}),q=g.fromTag("div");a.add(q,d.resolve("layer-menus"));a.add(q,d.resolve("toolstrip"));h.append(m(),q);var t=!1,s=f.bind(q,"transitionend",function(){t||(b.remove(q,"display"),r.trigger.close())});return{element:function(){return q},destroy:function(){s.unbind();k.remove(q)},open:function(){t||(t=!0,b.set(q,"display","block"),b.reflow(q),r.trigger.open(),b.set(q,"opacity","1"))},close:function(){t&&(t=!1,b.remove(q,"opacity"))},
isClosed:function(){return!t},setContent:function(a){h.append(q,a)},events:r.registry}}});l("7a","7d 8b d5 8y 79 dl 7b 34 59 4a 1y 4e 4h".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){return function(q,t,s,u){var v=q.content(),w=q.ui().tabstrip.element(),y=[t.element()],l="."+h.resolve(s)+", ."+d.resolve("more-button"),z=function(){var a=r.descendants(w,l);return y.concat(a)},A=b.api(),D=m.create({abort:k([]),open:k([]),close:k([])}),B=function(){v.events.mousedown.unbind(C);A.clear();F.off()},C=
function(){A.isSet()&&(t.closeWidget(),A.run(function(a){a.close()}))},F=c(C,z);t.events.done.bind(function(){C()});var E=a.multiple(t.element(),t.keylayouts());E.events.exit.bind(function(){D.trigger.abort()});return{destroy:function(){B();E.destroy();t.destroy();F.off()},events:D.registry,open:function(){F.on();t.openWidget();var a=f(q.ui().viewport,z);a.setContent(t.element());p.add(a.element(),u);var b=a.element();n.add(b,[h.resolve(t.anchorName()),h.resolve("side-widget-anchor")]);e.dialog(b,
g.translate(t.dialogTextkey()));a.open();a.events.close.bind(function(){v.focus();D.trigger.close();B()});A.set(a);E.enter();D.trigger.open();v.events.mousedown.bind(C)},close:C,isOpen:A.isSet}}});l("7c",["b","c","6","7b","1f"],function(d,e,c,a,b){var f=e.detect(),g=(e=f.os.isOSX())?"\u2318":"Ctrl",h=e?"\u21e7":"Shift",k={blockquote:[g,h,"9"],bold:[g,"B"],italic:[g,"I"],underline:[g,"U"],link:[g,"K"],help:[g,"?"],fullscreen:[g,h,"F"],indent:[g,"]"],outdent:[g,"["],undo:[g,"Z"],redo:e?[g,h,"Z"]:[g,
"Y"],search:[g,"F"]},m="fr nl sv ru de es it".split(" "),p=c.merge(k,{indent:[g,"M"],outdent:[g,h,"M"]}),n=function(a){var c=b.get();return d.contains(m,c)?p[a]:k[a]};c=function(a){a=n(a);return void 0===a?"":" "+a.join("")};var g=function(a){a=n(a);return void 0===a?"":" ("+a.join(" ")+")"},r=e?c:g;return{get:function(b,c){return f.os.isiOS()?a.get(b):a.get(b)+r(c)}}});l("5c","77 78 79 7a 7b 34 71 7c 1y".split(" "),function(d,e,c,a,b,f,g,h,k){var m=f.resolve("inverted-dialog-widget");return function(p){var n=
p.filter();e.configure(n);var r=c.api(),q=function(){var b;b=d(p);b=a(p,b,"a11y-check",m);b.events.abort.bind(b.close);b.events.close.bind(s);r.set(b);b.open()},t=function(){r.run(function(a){a.close()})},s=function(){r.clear()};return{ui:g.ui({"a11ycheck.general":{toggle:!1,hasPopup:!1,value:"a11y-check",textkey:b.key("action.a11ycheck"),action:function(){(r.isSet()?t:q)()},updateGeneral:function(a){k.add(a.element(),f.resolve("a11y-check"))},icon:!0,tooltip:h.get}}),destroy:s}}});l("m2",["7","2o"],
function(d,e){var c=function(a,c,d){var h=e.get(c,a);d=parseInt(h,10)+40*d;(0<d?e.set:e.remove)(c,a,d+"px")},a={change:d.curry(c,"margin-right")};return{ltr:{change:d.curry(c,"margin-left")},rtl:a}});l("dm",["m2"],function(d){return function(e){return{change:function(c,a){return(e.directionAt(c).isRtl()?d.rtl:d.ltr).change(c,a)}}}});l("dn",["7","3x"],function(d,e){return{runTransaction:function(c,a,b,f){f=void 0!==f?f:d.noop;a.save();c.focus();b=b();e(function(){c.domChanged();c.uiChanged()},0);f();
a.save();return b}}});l("m3",["2v"],function(d){return d.immutable("startContainer","startOffset","endContainer","endOffset")});l("ug",["s","f9"],function(d,e){var c=function(a,b){if(a.property().isText(b))return e.point(b,a.property().getText(b).length);var d=a.property().children(b);return 0<d.length?c(a,d[d.length-1]):e.point(b,d.length)},a=function(b,d,f){var g=b.property().children(d);return 0<g.length&&f<g.length?a(b,g[f],0):0<g.length&&b.property().isElement(d)&&g.length===f?c(b,g[g.length-
1]):e.point(d,f)},b=function(a,c,e){return a.property().isText(c)&&0===a.property().getText(c).trim().length||a.property().isComment(c)?e(c).bind(function(c){return b(a,c,e).orThunk(function(){return d.some(c)})}):d.none()},f=function(a,c){var d=b(a,c,a.query().nextSibling).getOr(c);if(a.property().isText(d))return e.point(d,0);var g=a.property().children(d);return 0<g.length?f(a,g[0]):e.point(d,0)},g=function(a,b){return a.property().isText(b)?a.property().getText(b).length:a.property().children(b).length},
h=function(a,c){var d=b(a,c,a.query().prevSibling).getOr(c);if(a.property().isText(d))return e.point(d,g(a,d));var f=a.property().children(d);return 0<f.length?h(a,f[f.length-1]):e.point(d,g(a,d))};return{toLast:c,toLeaf:a,toLower:function(a,b){var c=a.property().isText(b)?a.property().getText(b).length:a.property().children(b).length;return e.point(b,c)},freefallLtr:f,freefallRtl:h}});l("m4",["ug"],function(d){return{toLeaf:function(e,c,a){return d.toLeaf(e,c,a)},freefallLtr:function(e,c){return d.freefallLtr(e,
c)},freefallRtl:function(e,c){return d.freefallRtl(e,c)}}});l("ft",["6q","m4"],function(d,e){var c=d();return{toLeaf:function(a,b){return e.toLeaf(c,a,b)},freefallLtr:function(a){return e.freefallLtr(c,a)},freefallRtl:function(a){return e.freefallRtl(c,a)}}});l("do","b m3 ft dn 2n 2b".split(" "),function(d,e,c,a,b,f){var g=function(a,c){return b.inBody(a)&&0<=c&&c<f.children(a).length};return{multiple:function(b,k,m){return function(p,n){var r=b.getSelection(),q=r.map(function(a){return{left:f.parent(a.startContainer()).getOrDie(),
right:f.parent(a.endContainer()).getOrDie()}}),t=a.runTransaction(b,k,function(){return d.bind(n,function(a){return a.getSelection().bind(function(a){return m(a.startContainer(),a.startOffset(),a.endContainer(),a.endOffset()).map(function(a){return a.all()})}).getOr([])})},b.toEditing),r=r.filter(function(a){return g(a.startContainer(),a.startOffset())&&g(a.endContainer(),a.endOffset())}).getOrThunk(function(){var a=c.freefallLtr(0<t.length?t[0]:q.getOrDie().left),b=c.freefallRtl(0<t.length?t[t.length-
1]:q.getOrDie().right);return e(a.element(),a.offset(),b.element(),b.offset())});b.setSelection(r.startContainer(),r.startOffset(),r.endContainer(),r.endOffset());return t}},single:function(b,c,d,e,f){return function(g,q){var t=e(b,g.startContainer(),g.startOffset()),s=e(b,g.endContainer(),g.endOffset()),u=a.runTransaction(b,c,function(){return d(t.element(),t.offset(),s.element(),s.offset())},b.toEditing);return f(b,u,t,s,g)}}}});l("dp",["b","dn"],function(d,e){return{multiple:function(c,a,b){return function(f,
g){return e.runTransaction(c,a,function(){return d.bind(g,function(a){return a.getSelection().bind(function(a){return b(a.startContainer(),a.startOffset(),a.endContainer(),a.endOffset()).map(function(a){return a.all()})}).getOr([])})},c.toEditing)}},single:function(c,a,b,d,g){return function(h,k){var m=d(c,h.startContainer(),h.startOffset()),p=d(c,h.endContainer(),h.endOffset()),n=e.runTransaction(c,a,function(){return b(m.element(),m.offset(),p.element(),p.offset())},c.toEditing);return g(c,n,m,
p,h)}}}});l("dq",[],function(){return{update:function(d,e,c,a,b){return e.map(function(a){d.setSelection(a.start(),a.soffset(),a.finish(),a.foffset());return a.all()}).getOr([])}}});l("dr",["f9"],function(d){return{spot:function(e,c,a){return d.point(c,a)}}});l("7l",["s","4q"],function(d,e){var c=e.generate([{none:[]},{multiple:["elements","environments"]},{single:["selection","environment"]}]);return{cata:function(a,b,c,d){return a.fold(b,c,d)},none:c.none,multiple:c.multiple,single:c.single,toSelection:function(a){return a.fold(d.none,
function(a,c){return d.from(c[0]).bind(function(a){return a.getSelection()})},d.some)}}});l("9o",[],function(){var d=function(d){return{fold:d}};return{on:function(e,c){return d(function(a,b,d){return b(e,c)})},before:function(e){return d(function(c,a,b){return c(e)})},after:function(e){return d(function(c,a,b){return b(e)})}}});l("9k",["7","34","cw"],function(d,e,c){var a=e.resolve("highlight-common"),b=e.resolve("highlight-placeholder");return{configure:function(d){d.add(d.output(),a,c.unwrap);
d.add(d.history(),b,c.unwrap);d.add(d.output(),b,c.unwrap);d.add(d.output(),"ephox-custom-highlight",c.unwrap);d.add(d.history(),"ephox-custom-highlight",c.unwrap)},highlightClass:d.constant(a),customHighlightClass:d.constant("ephox-custom-highlight"),placeholderClass:d.constant(b)}});l("7j",["7"],function(d){var e=function(){return b(function(a,b,c){return a()},"off")},c=function(){return b(function(a,b,c){return b()},"unchanged")},a=function(a){return b(function(b,c,d){return d(a)},"on")},b=function(b,
g){return{fold:b,map:function(d){return b(e,c,function(b){return a(d(b))})},label:d.constant(g)}};return{off:e,unchanged:c,on:a}});l("7w","9k 7j 2v 1y 21 az".split(" "),function(d,e,c,a,b,f){var g=c.immutable("content");return{hasSelection:function(a){return a.getSelection().fold(function(){return g(e.off())},function(){return g(e.on(!0))})},isAnnotation:function(b){return a.has(b,"ephox-cram-annotation-wrap")||a.has(b,d.customHighlightClass())},isEmptyText:function(a){return b.isText(a)&&0===f.get(a).length}}});
l("es",["9o","2v","l"],function(d,e,c){var a=e.immutable("start","soffset","finish","foffset"),b=e.immutable("start","soffset","finish","foffset"),f=e.immutable("start","finish");return{read:a,general:b,write:f,writeFromNative:function(a){var b=c.fromDom(a.startContainer),e=c.fromDom(a.endContainer);return f(d.on(b,a.startOffset),d.on(e,a.endOffset))}}});l("et",[],function(){return{run:function(d,e){if(d.getSelection)return e(d,d.getSelection());throw"No selection model supported.";}}});l("dy",["1b",
"l","2b"],function(d,e,c){var a=function(a,d,e,h){var k=c.owner(a).dom().createRange();k.setStart(a.dom(),d);k.setEnd(e.dom(),h);return k};return{after:function(b,c,e,h){var k=a(b,c,e,h);b=d.eq(b,e)&&c===h;return k.collapsed&&!b},commonAncestorContainer:function(b,c,d,h){b=a(b,c,d,h);return e.fromDom(b.commonAncestorContainer)}}});l("m5",["es","dy","l","2b"],function(d,e,c,a){var b=function(a){return e.after(c.fromDom(a.anchorNode),a.anchorOffset,c.fromDom(a.focusNode),a.focusOffset)},f=function(a,
e){var f=c.fromDom(e.startContainer),g=c.fromDom(e.endContainer);return b(a)?d.read(g,e.endOffset,f,e.startOffset):d.read(f,e.startOffset,g,e.endOffset)},g=function(a){return b(a)},h=function(b,c,d,e){return function(f){if(f.extend)f.collapse(b.dom(),c),f.extend(d.dom(),e);else{var g=a.owner(b).dom().createRange();g.setStart(d.dom(),e);g.setEnd(b.dom(),c);f.removeAllRanges();f.addRange(g)}}},k=function(a,b,c,d){return e.after(a,b,c,d)};return{read:function(){return{flip:f,isRtl:g}},write:function(){return{flip:h,
isRtl:k}}}});l("ev",["es","m5","s","dy","l"],function(d,e,c,a,b){var f=function(a,e){if(!0===g(a,e.start(),e.finish()).collapsed){var f=g(a,e.finish(),e.start());return!0===f.collapsed?c.none():c.some(d.general(b.fromDom(f.endContainer),f.endOffset,b.fromDom(f.startContainer),f.startOffset))}return c.none()},g=function(a,b,c){var d=m(a);b.fold(function(a){d.setStartBefore(a.dom())},function(a,b){d.setStart(a.dom(),b)},function(a){d.setStartAfter(a.dom())});c.fold(function(a){d.setEndBefore(a.dom())},
function(a,b){d.setEnd(a.dom(),b)},function(a){d.setEndAfter(a.dom())});return d},h=function(a,b){return g(a,b.start(),b.finish())},k=function(a,b){var c=h(a,b);return function(a){a.addRange(c)}},m=function(a){return a.document.createRange()};return{create:m,build:function(a,b){return f(a,b).fold(function(){return k(a,b)},function(a){return e.write().flip(a.start(),a.soffset(),a.finish(),a.foffset())})},toNative:h,forceRange:function(a,b){var c=g(a,b.start(),b.finish());return!0===c.collapsed?g(a,
b.finish(),b.start()):c},toExactNative:function(b,c,d,e,f){var g=a.after(c,d,e,f);b=b.document.createRange();g?(b.setStart(e.dom(),f),b.setEnd(c.dom(),d)):(b.setStart(c.dom(),d),b.setEnd(e.dom(),f));return b}}});l("eu","b ev l 21 4h m".split(" "),function(d,e,c,a,b,f){var g=function(a,c,e,g){var n=a.document.createRange();a=(f.is(c,g)?[c]:[]).concat(b.descendants(c,g));return d.filter(a,function(a){n.selectNodeContents(a.dom());return 1>n.compareBoundaryPoints(e.END_TO_START,e)&&-1<n.compareBoundaryPoints(e.START_TO_END,
e)})};return{find:function(b,d,f){d=e.forceRange(b,d);var p=c.fromDom(d.commonAncestorContainer);return a.isElement(p)?g(b,p,d,f):[]}}});l("m6",["b","es","9o","21"],function(d,e,c,a){var b=function(b,e){var h=a.name(b);return"input"===h?c.after(b):d.contains(["br","img"],h)?0===e?c.before(b):c.after(b):c.on(b,e)};return{beforeSpecial:b,preprocess:function(a){var d=a.start().fold(c.before,b,c.after);a=a.finish().fold(c.before,b,c.after);return e.write(d,a)}}});l("m7",["b","l","q"],function(d,e,c){return{fromElements:function(a,
b){var f=(b||c).createDocumentFragment();d.each(a,function(a){f.appendChild(a.dom())});return e.fromDom(f)}}});l("ew","es m5 ev m6 s l m7".split(" "),function(d,e,c,a,b,f,g){var h=function(a,b){var c=b.getRangeAt(0),d=b.getRangeAt(b.rangeCount-1),e=a.document.createRange();e.setStart(c.startContainer,c.startOffset);e.setEnd(d.endContainer,d.endOffset);return e},k=function(a,c){return void 0!==c&&null!==c&&0<c.rangeCount?b.from(h(a,c)):b.none()};return{get:function(a,b){return k(a,b).map(function(a){var c=
f.fromDom(a.startContainer),g=f.fromDom(a.endContainer);return e.read().isRtl(b)?e.read().flip(b,a):d.read(c,a.startOffset,g,a.endOffset)})},set:function(b){return function(d,e){var f=a.preprocess(b),f=c.build(d,f);void 0!==e&&null!==e&&(e.removeAllRanges(),f(e))}},selectElementContents:function(a){return function(b,d){var e=c.create(b);e.selectNodeContents(a.dom());d.removeAllRanges();d.addRange(e)}},replace:function(a){return function(b,c){k(b,c).each(function(c){var d=g.fromElements(a,b.document);
c.deleteContents();c.insertNode(d.dom())})}},replaceRange:function(b,d){return function(e,f){var h=a.preprocess(b),h=c.toNative(e,h),k=g.fromElements(d,e.document);h.deleteContents();h.insertNode(k.dom())}},deleteRange:function(a,b,d,e){return function(f,g){c.toExactNative(f,a,b,d,e).deleteContents()}},cloneFragment:function(a,b,d,e){return function(g,h){var k=c.toExactNative(g,a,b,d,e).cloneContents();return f.fromDom(k)}},rectangleAt:function(a,d,e,f){return function(g,h){var k=c.toExactNative(g,
a,d,e,f),u=k.getClientRects(),k=0<u.length?u[0]:k.getBoundingClientRect();return 0<k.width||0<k.height?b.some(k):b.none()}},bounds:function(a){return function(d,e){var f=c.create(d);f.selectNode(a.dom());f=f.getBoundingClientRect();return 0<f.width||0<f.height?b.some(f):b.none()}},clearSelection:function(a,b){a.getSelection().removeAllRanges()},stringAt:function(a,b,d,e){return function(f,g){return c.toExactNative(f,a,b,d,e).toString()}}}});l("81","es 9o et eu ev ew 1b l".split(" "),function(d,e,
c,a,b,f,g,h){var k=function(a,b){c.run(a,f.set(b))},m=function(b,c,d){return a.find(b,c,d)};return{get:function(a){return c.run(a,f.get)},set:k,setExact:function(a,b,c,f,g){b=d.write(e.on(b,c),e.on(f,g));k(a,b)},selectElementContents:function(a,b){c.run(a,f.selectElementContents(b))},replace:function(a,b){c.run(a,f.replace(b))},replaceRange:function(a,b,d){c.run(a,f.replaceRange(b,d))},deleteRange:function(a,b,d,e,g){c.run(a,f.deleteRange(b,d,e,g))},isCollapsed:function(a,b,c,d){return g.eq(a,c)&&
b===d},cloneFragment:function(a,b,d,e,g){return c.run(a,f.cloneFragment(b,d,e,g))},rectangleAt:function(a,b,d,e,g){return c.run(a,f.rectangleAt(b,d,e,g))},bounds:function(a,b){return c.run(a,f.bounds(b))},findWithin:m,findWithinExact:function(a,b,c,f,g,h){b=d.write(e.on(b,c),e.on(f,g));return m(a,b,h)},deriveExact:function(a,c){var e=b.forceRange(a,c);return d.general(h.fromDom(e.startContainer),e.startOffset,h.fromDom(e.endContainer),e.endOffset)},clearAll:function(a){c.run(a,f.clearSelection)},
stringAt:function(a,b,d,e,g){return c.run(a,f.stringAt(b,d,e,g))}}});l("ds","81 87 7 s 2n 1b 32 2b 1s".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(c,d){return b.inBody(c)?a.some(k.max(0,k.min(d,e.getEnd(c)))):a.none()};return{findDescendants:function(a,b,c,e,f){var g=h.defaultView(a);return m(a,b).bind(function(b){return m(c,e).map(function(e){return d.findWithinExact(g.dom(),a,b,c,e,f)})}).getOr([])},findAncestors:function(a,b,d){return g.ancestor(a,d).fold(function(){return g.ancestor(b,
d).toArray()},function(a){return g.ancestor(b,d).fold(c.constant([a]),function(b){return f.eq(a,b)?[a]:[a,b]})})}}});l("7i","c 9o 7 s 7w ds 1b l 2p 21 2r az 2b 1s".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q){var t=d.detect().browser.isFirefox(),s=function(a,b){return l(a).filter(function(a){return g.eq(a.image(),b)}).isSome()};d=function(a,b){var c=function(){a.setRelativeSelection(e.before(b),e.after(b))},d=t?function(){a.getSelection().fold(c,function(c){u(a,c,b)})}:c;a.focus();d()};var u=
function(a,c,d){2===q.abs(c.startOffset()-c.endOffset())&&s(c,d)||(c=r.nextSibling(d).filter(b.isEmptyText).getOrThunk(function(){var a=h.fromText("");k.after(d,a);return a}),a.setRelativeSelection(e.before(d),e.after(c)))},v=function(a){return a.filter(function(a){return"img"===m.name(a)})},w=function(b){var c=v(r.child(b.startContainer(),b.startOffset()));return v(r.nextSibling(b.startContainer())).orThunk(function(){return c}).bind(function(d){return v(r.prevSibling(b.endContainer())).bind(function(e){e=
g.eq(d,e);var f=b.startContainer().dom().length===b.startOffset(),h=0===b.endOffset();return e&&(f||c.isSome())&&h?a.some(d):a.none()})})},y=function(c){if(!g.eq(c.startContainer(),c.endContainer()))return a.none();var d=q.min(c.startOffset(),c.endOffset()),e=q.max(c.startOffset(),c.endOffset()),f=v(r.child(c.startContainer(),d));return e===d+1?f.orThunk(function(){return v(a.some(c.startContainer()))}):t&&e===d+2?f.filter(function(a){return r.nextSibling(a).filter(b.isEmptyText).isSome()}):a.none()},
l=function(b){return b.collapsed()?a.none():y(b).orThunk(function(){return w(b)}).map(function(a){return{image:c.constant(a)}})};return{detect:l,selectionContains:function(b){b=f.findDescendants(b.startContainer(),b.startOffset(),b.endContainer(),b.endOffset(),"img");return 1===b.length?a.some(b[0]):a.none()},remove:function(a,b){a.setRelativeSelection(e.before(b),e.before(b));p.remove(b)},select:d,reselect:t?d:c.noop}});l("un",["b","7","s","2v"],function(d,e,c,a){var b=a.immutable("left","right"),
f=function(a,b,f){b=a.property().children(b);a=d.findIndex(b,e.curry(a.eq,f));return-1<a?c.some({before:e.constant(b.slice(0,a)),after:e.constant(b.slice(a+1))}):c.none()};return{breakToLeft:function(a,c,d){return f(a,c,d).map(function(e){var f=a.create().clone(c);a.insert().appendAll(f,e.before().concat([d]));a.insert().appendAll(c,e.after());a.insert().before(c,f);return b(f,c)})},breakToRight:function(a,c,d){return f(a,c,d).map(function(d){var e=a.create().clone(c);a.insert().appendAll(e,d.after());
a.insert().after(c,e);return b(c,e)})},breakPath:function(b,d,e,f){var p=a.immutable("first","second","splits"),n=function(a,d,h){var s=p(a,c.none(),h);return e(a)?p(a,d,h):b.property().parent(a).bind(function(d){return f(b,d,a).map(function(a){var b=[{first:a.left,second:a.right}],f=e(d)?d:a.left();return n(f,c.some(a.right()),h.concat(b))}).getOr(s)})};return n(d,c.none(),[])}}});l("uo",["b","7","s"],function(d,e,c){var a=function(a,c,e,k){e=c(a,e);return d.foldr(k,function(d,e){var h=c(a,e);return b(a,
d,h)},e)},b=function(a,b,c){return b.bind(function(b){return c.filter(e.curry(a.eq,b))})};return{oneAll:function(b,d,e){if(0<e.length){var k=e[0];e=e.slice(1);b=a(b,d,k,e)}else b=c.none();return b}}});l("up",["b","7","s","1s"],function(d,e,c,a){var b=function(b,f,k,m){var p=b.property().children(f);if(b.eq(f,k[0]))return c.some([k[0]]);if(b.eq(f,m[0]))return c.some([m[0]]);var n=function(a){a=d.reverse(a);var c=d.findIndex(a,e.curry(b.eq,f));return d.findIndex(p,e.curry(b.eq,c<a.length-1?a[c+1]:a[c]))};
k=n(k);m=n(m);var n=a.min(k,m),r=a.max(k,m);return-1<k&&-1<m?c.some(p.slice(n,r+1)):c.none()},f=function(a,b,f,m){var p=void 0!==m?m:e.constant(!1);b=[b].concat(a.up().all(b));m=[f].concat(a.up().all(f));var n=function(a){var b=d.findIndex(a,p);return-1<b?a.slice(0,b+1):a};f=n(b);var r=n(m);b=d.find(f,function(b){return d.exists(r,e.curry(a.eq,b))});b=c.from(b);return{firstpath:e.constant(f),secondpath:e.constant(r),shared:e.constant(b)}};return{subset:function(a,c,d){var e=f(a,c,d);return e.shared().bind(function(c){return b(a,
c,e.firstpath(),e.secondpath())})},ancestors:f}});l("mn",["un","uo","up"],function(d,e,c){return{sharedOne:function(a,b,c){return e.oneAll(a,b,c)},subset:function(a,b,d){return c.subset(a,b,d)},ancestors:function(a,b,d,e){return c.ancestors(a,b,d,e)},breakToLeft:function(a,b,c){return d.breakToLeft(a,b,c)},breakToRight:function(a,b,c){return d.breakToRight(a,b,c)},breakPath:function(a,b,c,e){return d.breakPath(a,b,c,e)}}});l("gf",["6q","mn"],function(d,e){var c=d();return{sharedOne:function(a,b){return e.sharedOne(c,
function(b,c){return a(c)},b)},subset:function(a,b){return e.subset(c,a,b)},ancestors:function(a,b,d){return e.ancestors(c,a,b,d)},breakToLeft:function(a,b){return e.breakToLeft(c,a,b)},breakToRight:function(a,b){return e.breakToRight(c,a,b)},breakPath:function(a,b,d){return e.breakPath(c,a,b,function(a,b,c){return d(b,c)})}}});l("zh",["1b","l","2p","21","2r"],function(d,e,c,a,b){return{forceAddBr:function(f,g){if("br"!==a.name(f)){var h=e.fromTag("br");a.isText(f)?(c.after(f,h),d.eq(g,f)||b.remove(f)):
c.prepend(f,h)}},rootBr:function(a,b){c.before(a,e.fromTag("br"))}}});l("zi",["b","2b"],function(d,e){var c=function(a,f,g){var h=[];d.each(e.children(a),function(a){f(a)&&(h=h.concat([a]));h=g(a)?h:h.concat(c(a,f,g))});return h},a=function(b,c){var d=e.children(b);return 0<d.length?(d=d[0],c(d)?b:a(d,c)):0<d.length?a(d[0]):b};return{descendants:c,plunge:a}});l("je",["e5","87","1b"],function(d,e,c){var a=function(a,d,e,h,k){return h(a).fold(function(){return!0},function(a){return c.eq(d,a)&&k(d,e)})};
return{isLeft:function(b,c){return a(b,c.startContainer(),c.startOffset(),d.firstCursor,e.isStart)},isAtLeftEdge:function(b,c,g){return a(b,c,g,d.firstCursor,e.isStart)},isRight:function(b,c){return a(b,c.startContainer(),c.startOffset(),d.lastCursor,e.isEnd)},isAtRightEdge:function(b,c,g){return a(b,c,g,d.lastCursor,e.isEnd)}}});l("o8","a b je 7 fg 2v 1b 21 6m 4l az v".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var r=function(a){a=h.name(a);return"td"===a||"th"===a},q=function(a){return"li"===
h.name(a)||b.isBlock(a)},t=function(a){return"a"===h.name(a)},s=function(b,c,d){return m.closest(b,c,d).filter(a.not(d)).filter(a.not(r))};return{stopAt:function(b){return a.curry(g.eq,b)},isList:function(a){a=h.name(a);return"ol"===a||"ul"===a},isAnchor:t,isHeading:function(a,b){var c=d.isArray(b)?b:[],c="h1 h2 h3 h4 h5 h6".split(" ").concat(c),f=h.name(a);return e.contains(c,f)},isCollapsed:function(a){return g.eq(a.startContainer(),a.endContainer())&&a.startOffset()===a.endOffset()},isRightEdge:function(a,
b,d){var e=f.immutable("startContainer","startOffset");return c.isRight(a,e(b,d))},exitList:function(a){return 0===k.descendants(a,function(a){return h.isText(a)&&0<p.get(a).length&&0<n.trim(p.get(a)).length||h.isElement(a)&&e.contains("hr img input video iframe picture audio embed map object".split(" "),h.name(a))}).length},findBlock:function(a,b){return m.closest(a,q,b)},findValidHardBreak:function(a,b){return s(a,q,b)},findAnchorBreak:function(a,b){return s(a,t,b)}}});l("vs","84 b 1a 2g 21 4h az 2b v".split(" "),
function(d,e,c,a,b,f,g,h,k){var m=function(a){if(!b.isText(a))return!1;a=g.get(a).trim();return 0===a.length||0===a.replace(d.zeroWidth(),"").length},p=function(c){if(b.isText(c))return m(c);var d=a.get(c);c=h.children(c);return""===k.trim(d)||e.forall(c,m)};return{vacant:function(a){a=f.descendants(a,"span,a");return e.filter(a,function(a){return"span"===b.name(a)?!(c.has(a,"class")&&0<c.get(a,"class").length)&&!c.has(a,"style")&&p(a):p(a)})},isEmpty:p,hasCursor:function(a,c){var d=void 0!==c?c:
["hr","br","img","input","textarea"];return b.isText(a)?!1===m(a):e.contains(d,b.name(a))},isVacantText:m,hasNoContent:p}});l("ui","b 7 s zh zi o8 vs 1a 21 2r 4h".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=function(a){var d="li"===k.name(a)?f.isList:e.constant(!1);return 0<b.descendants(a,g.hasCursor,d).length?c.none():c.some(b.plunge(a,d))},r=function(a){a=g.vacant(a);d.each(a,m.remove)},q=function(a,b){var c=p.descendants(b,a),c=d.filter(c,g.isEmpty);d.each(c,m.remove);g.isEmpty(b)&&m.remove(b)};
return{vacate:r,emptyStyles:function(a){!0===h.has(a,"style")&&0===h.get(a,"style").length&&h.remove(a,"style")},needsCursor:n,postprocess:function(b,c,d){r(b);n(b).each(function(b){a.forceAddBr(b,c)})},lists:e.curry(q,"ul,ol"),blockquotes:e.curry(q,"blockquote")}});l("uh",["b","7","gf","ui","1a"],function(d,e,c,a,b){var f=function(f,h){var k=c.breakToRight(f,h);k.each(function(c){c=c.right();d.each(["id"],e.curry(b.remove,c));a.emptyStyles(c)});return k};return{breakPath:function(a,b){return c.breakPath(a,
b,f)}}});l("m8","b 9o 7 uh ui o8 2p".split(" "),function(d,e,c,a,b,f,g){return{breakQuote:function(h,k){var m=a.breakPath(k,f.stopAt(h));return m.second().map(function(a){var f=m.first();g.before(a,k);d.each([f,a],b.blockquotes);return{start:c.constant(e.on(k,0)),finish:c.constant(e.on(k,0))}})}}});l("dt",["m8"],function(d){return{breakQuote:d.breakQuote}});l("m9",["21","2b"],function(d,e){var c=function(a){return d.isElement(a)?a:e.parent(a).getOr(a)};return{bothMatch:function(a,b,d){a=c(a);b=c(b);
return d(a)&&d(b)}}});l("mi",["fg","m"],function(d,e){return{isRootOrCell:function(c){return function(a){return c(a)||e.is(a,"td,th")}},isRootOrContainer:function(c){return function(a){return c(a)||d.isContainer(a)}}}});l("uj",["s"],function(d){var e=function(c,a){return 0===c.length?!0:0===a.length?!1:c[0]<a[0]?!0:a[0]<c[0]?!1:e(c.slice(1),a.slice(1))};return{head:function(c){return 0<c.length?d.some(c[0]):d.none()},tail:function(c){return 0<c.length?d.some(c.slice(1)):d.none()},toLast:function(c){return 0<
c.length?d.some(c[c.length-1]):d.none()},box:function(c){return[c]},isBefore:e}});l("n7",["b","7","4q","uj"],function(d,e,c,a){c=c.generate([{quasi:["elements"]},{block:["element"]},{container:["element","children"]},{fixture:["element"]}]);var b=function(a){return a.fold(function(a){return"@q["+d.map(a,function(a){return a.dom().outerHTML||'"'+a.dom().nodeValue+'"'}).join(",")+"]"},function(a){return"@"+a.dom().nodeName.toLowerCase()+"("+a.dom().innerHTML+")"},function(a,c){return"#"+a.dom().nodeName.toLowerCase()+
"("+d.map(c,b).join(",")+")"},function(a){return a.dom().nodeName.toLowerCase()})},f=function(a){var b=function(a){return[a]};return a.fold(e.identity,b,b,b)},g=e.constant(!0),h=e.constant(!1);return{cata:function(a,b,c,d,e){return a.fold(b,c,d,e)},quasi:c.quasi,block:c.block,container:c.container,fixture:c.fixture,isQuasi:function(a){return a.fold(g,h,h,h)},isFixture:function(a){return a.fold(h,h,h,g)},isQuasiOrFixture:function(a){return a.fold(g,h,h,g)},toTarget:f,toString:b,toLastTarget:function(b){return a.toLast(f(b))}}});
l("12i",["7"],function(d){var e=function(c,a){return{fold:c,label:d.constant(a)}};return{before:function(c){return e(function(a,b,d,e,h){return a(c)},"before")},after:function(c){return e(function(a,b,d,e,h){return b(c)},"after")},rest:function(c){return e(function(a,b,d,e,h){return d(c)},"rest")},last:function(c){return e(function(a,b,d,e,h){return e(c)},"last")},invalid:function(c,a){return e(function(b,d,e,h,k){return k(c,a)},"invalid")}}});l("v1",["b","s","f9","hv","kr"],function(d,e,c,a,b){return{subdivide:function(f,
g,h){var k=f.property().getText(g);h=d.filter(b.splits(k,h),function(a){return 0<a.length});if(1>=h.length)return[c.range(g,0,k.length)];f.property().setText(g,h[0]);var k=a.generate(h.slice(1),function(a,b){var d=f.create().text(a),d=c.range(d,b,b+a.length);return e.some(d)},h[0].length),m=d.map(k,function(a){return a.element()});f.insert().afterAll(g,m);return[c.range(g,0,h[0].length)].concat(k)}}});l("zn",["7"],function(d){var e=function(c,a){return{fold:c,label:d.constant(a)}};return{none:function(){return e(function(c,
a,b,d){return c()},"none")},start:function(c){return e(function(a,b,d,e){return b(c)},"start")},middle:function(c,a){return e(function(b,d,e,h){return e(c,a)},"middle")},end:function(c){return e(function(a,b,d,e){return e(c)},"end")}}});l("v2",["zn"],function(d){return{determine:function(e){return e.before().fold(function(){return e.after().fold(function(){return d.none()},function(c){return d.start(c)})},function(c){return e.after().fold(function(){return d.end(c)},function(a){return d.middle(c,
a)})})}}});l("12j",["b","6r","k4","sg","128"],function(d,e,c,a,b){return{group:function(f,g,h){g=d.bind(g,function(a){return e.from(f,a,h)});g=a.splitbyAdv(g,function(a){return c.cata(a,function(){return b.excludeWithout(a)},function(){return b.excludeWith(a)},function(){return b.include(a)})});return d.filter(g,function(a){return 0<a.length})}}});l("14w",["b","s"],function(d,e){return{common:function(c,a,b){a=[a].concat(c.up().all(a));var f=[b].concat(c.up().all(b));b=d.find(a,function(a){return d.exists(f,
function(b){return c.eq(b,a)})});return e.from(b)}}});l("14x",["b"],function(d){var e="table tbody thead tfoot tr ul ol".split(" ");return function(c){var a=c.property(),b=function(b,c){return a.parent(b).map(a.name).map(function(a){return!d.contains(c,a)}).getOr(!1)};return{validateText:function(c){return a.isText(c)&&b(c,e)}}}});l("12k",["b","7","6r","14w","14x"],function(d,e,c,a,b){return{range:function(f,g,h,k,m){return f.eq(g,k)?[g]:a.common(f,g,k).fold(function(){return[]},function(a){a=[a].concat(c.all(f,
a,e.constant(!1)));var n=d.findIndex(a,e.curry(f.eq,g)),r=d.findIndex(a,e.curry(f.eq,k));a=-1<n&&-1<r?n<r?a.slice(n+h,r+m):a.slice(r+m,n+h):[];n=b(f);return d.filter(a,n.validateText)})}}});l("zo",["12j","12k"],function(d,e){return{range:function(c,a,b,d,g){return e.range(c,a,b,d,g)},group:function(c,a,b){return d.group(c,a,b)}}});l("zp",["2v"],function(d){return d.immutable("before","after")});l("v4",["b","s","zp","kr"],function(d,e,c,a){var b=function(b,c,d){b=b.property().getText(c);return a.splits(b,
d)},f=function(a,c,e,m){if(!a.property().isText(c)||e===m)return c;if(e>m)return f(a,c,m,e);var p=a.property().getText(c).length;if(0===e&&m===p)return c;m=b(a,c,[e,m]);a.property().setText(c,m[0]);m=d.map(m.slice(1),function(b){return a.create().text(b)});p=m[0];a.insert().afterAll(c,m);return 0===e?c:p};return{split:function(a,d,f){if(!a.property().isText(d)||0>=f)return c(e.none(),e.some(d));if(f>=a.property().getText(d).length)return c(e.some(d),e.none());f=b(a,d,[f]);a.property().setText(d,f[0]);
f=a.create().text(f[1]);a.insert().after(d,f);return c(e.some(d),e.some(f))},splitByPair:f}});l("v3",["f9","zo","v4"],function(d,e,c){var a=function(a,b,h,k,m){h=c.split(a,b,h).after().fold(function(){return d.delta(b,1)},function(a){return d.delta(a,0)});m=c.split(a,k,m).before().fold(function(){return d.delta(k,0)},function(a){return d.delta(a,1)});return e.range(a,h.element(),h.deltaOffset(),m.element(),m.deltaOffset())},b=function(a,b,d,e,m){return[c.splitByPair(a,b,d,m)]};return{nodes:function(c,
d,e,k,m){return(c.eq(d,k)?b:a)(c,d,e,k,m)}}});l("pq",["v1","v2","v3","v4"],function(d,e,c,a){return{split:function(b,c,d){return a.split(b,c,d)},splitByPair:function(b,c,d,e){return a.splitByPair(b,c,d,e)},range:function(a,d,e,h,k){return c.nodes(a,d,e,h,k)},subdivide:function(a,c,e){return d.subdivide(a,c,e)},position:function(a,c){return e.determine(c)}}});l("zj",["7","12i","pq"],function(d,e,c){var a=function(a,b,d){var k=c.split(a,b,d);return c.position(a,k).fold(function(){return e.invalid(b,
d)},e.before,e.after,e.after)},b=function(a,b,c){a=a.property().children(b);return c===a.length?e.last(b):c<a.length?e.rest(a[c]):e.invalid(b,c)};return{atStartOf:function(c,e,h,k){var m=function(a){c.insert().before(a,k)};(c.property().isText(e)?a:b)(c,e,h).fold(m,function(a){c.insert().after(a,k)},m,function(a){c.insert().append(a,k)},d.noop)}}});l("uv",["zj"],function(d){return{atStartOf:function(e,c,a,b){d.atStartOf(e,c,a,b)}}});l("uq",["6","7","4q"],function(d,e,c){c=c.generate([{none:[]},{root:["target",
"block"]},{created:["target","block"]},{actual:["target","block"]}]);return d.merge(c,{toString:function(a){return a.fold(function(){return["block.none"]},function(a,c){return["block.root",a,c]},function(a,c){return["block.created",a,c]},function(a,c){return["block.actual",a,c]})},cata:function(a,b,c,d,e){return a.fold(b,c,d,e)},extract:function(a){var b=e.constant([]),c=function(a,b){return[b]};return a.fold(b,b,c,c)},extractEvenRoot:function(a){var b=e.constant([]),c=function(a,b){return[b]};return a.fold(b,
c,c,c)}})});l("um","b 7 s m4 is mn".split(" "),function(d,e,c,a,b,f){var g=function(a,b){return function(c){return a.eq(c,b)||a.property().parent(c).map(function(c){return a.eq(c,b)}).getOr(!1)}},h=function(a,b,d){return a.eq(b,d)?c.none():a.property().isBoundary(d)?a.query().nextSibling(d):a.property().isEmptyTag(d)?(b=g(a,b),b(d)?a.query().nextSibling(d):f.breakPath(a,d,b,f.breakToRight).second()):c.none()},k=function(a,b,d){if(a.eq(b,d))return c.none();if(a.property().isBoundary(d))return a.query().prevSibling(d);
if(a.property().isEmptyTag(d)){var e=g(a,b);return e(d)?a.query().prevSibling(d):a.query().prevSibling(d).map(function(b){return f.breakPath(a,b,e,f.breakToRight).first()})}return c.none()},m=function(a,b,e,f){return e(a,b,f).bind(function(e){var f=a.property().children(b),f=d.findIndex(f,function(b){return a.eq(b,e)});return-1<f?c.some(f):c.none()})},p=function(a,b){return a.property().isEmptyTag(b)||a.property().isBoundary(b)};return{create:function(c,d,f){if(p(c,f)||p(c,a.toLeaf(c,f,0).element()))return[f];
var g=e.curry(p,c),s=e.curry(c.eq,d),u=b.seekLeft(c,f,g,s).bind(function(a){return m(c,d,h,a)}).getOr(0),v=c.property().children(d);f=b.seekRight(c,f,g,s).bind(function(a){return m(c,d,k,a)}).getOr(v.length-1);return c.property().children(d).slice(u,f+1)}}});l("uk","b s uv uq um 1s".split(" "),function(d,e,c,a,b,f){var g=function(a,b,c,d){return c(b)||d(b)?e.some(b):a.up().predicate(b,c,d)},h=function(b,c,d){d=d();b.insert().wrap(c,d);return a.created(c,d)},k=function(b,c,e,f){var g=f();b.insert().before(e[0],
g);d.each(e,function(a){b.insert().append(g,a)});return a.created(c,g)},m=function(d,e,g,m,t,s,u){if(s(g)){var v=d.property().children(e);if(m<v.length&&u(v[m]))return a.actual(g,v[m])}return t(e).fold(function(){return a.root(g,e)},function(t){if(s(g)){var u=t(),v=d.property().children(e),l=v[m];void 0!==l&&(t=b.create(d,e,l,t),d.insert().appendAll(u,0<t.length?t:[l]));c.atStartOf(d,e,f.min(v.count,m),u);return a.created(e,u)}d.property().isEmptyTag(g)?t=h(d,g,t):(u=b.create(d,e,g),t=0<u.length?
k(d,g,u,t):h(d,g,t));return t})};return{single:function(b,c,d,e,f,h){return g(b,d,c,h).fold(a.none,function(g){return h(g)?m(b,g,d,e,f,h,c):a.actual(d,g)})}}});l("mt",["4j"],function(d){return{resolve:d.create("ephox-soldier").resolve}});l("me","b 7 s mt 1y 21 2r 4h 2b".split(" "),function(d,e,c,a,b,f,g,h,k){var m=a.resolve("quasi-block"),p=function(a){a=k.children(a);return 1===a.length&&"br"===f.name(a[0])},n=function(a){return b.has(a,m)&&!p(a)};return{condense:function(a){a=d.filter(a,function(a,
c){if(!f.isElement(a))return!0;var d;b.has(a,m)&&p(a)&&(k.prevSibling(a).exists(n)||k.nextSibling(a).exists(n))?(g.remove(a),d=!1):d=!0;return d});return d.map(a,function(a){var c=f.isElement(a)?[a].concat(h.descendants(a,"."+m)):[];d.each(c,function(a){b.remove(a,m)});return a})},register:function(a){return function(c){return a(c).map(function(a){return function(){var c=a();b.add(c,m);return c}})}},style:e.constant(m)}});l("ov",["6q","b","uk","me","21"],function(d,e,c,a,b){var f=d();return{single:function(b,
d,e,m,p){return c.single(f,b,d,e,a.register(m),p)},isBlock:function(a){return e.contains("ol p div ul table caption td th h1 h2 h3 h4 h5 h6 body blockquote pre".split(" "),b.name(a))}}});l("n6",["7"],function(d){return{tag:function(){return"p"},nu:function(e){return d.curry(e.create().nu,"p")}}});l("ul",["s","4q"],function(d,e){var c=function(a){return 0<a.length?d.some(a[0]):d.none()},a=e.generate([{descend:["index"]},{leftOf:["rindex"]},{bounded:["lindex","rindex"]},{rightOf:["lindex"]},{all:[]}]);
return{derive:function(b,d){return b.bind(c).fold(function(){return d.bind(c).fold(function(){return a.all()},function(b){return a.leftOf(b)})},function(b){return d.bind(c).fold(function(){return a.rightOf(b)},function(c){return b===c?a.descend(b):a.bounded(b,c)})})},cata:function(a,c,d,e,k,m){return a.fold(c,d,e,k,m)}}});l("md","s is mb uj n7 ul um".split(" "),function(d,e,c,a,b,f,g){var h=function(a,b,c){return d.from(a.property().children(b)[c])},k=function(a,c,d){var e=a.property().children(d),
f=h(a,d,0).bind(function(b){return h(a,d,e.length-1).map(function(e){return m(a,c,d,b,e)})}).getOr([]);return b.container(d,f)},m=function(a,c,f,g,h){var k=p(a,f,c,g);return b.toLastTarget(k).filter(function(b){return!a.eq(h,b)}).bind(function(b){return e.walk(a,b,e.sidestep,e.walkers().right()).bind(function(b){if(a.eq(f,b.item()))return d.none();b=m(a,c,f,b.item(),h);return d.some([k].concat(b))})}).getOrThunk(function(){return[k]})},p=function(a,d,e,f){if(c.isFormatting(a,f))return b.block(f);
if(c.isEmptyTag(a,f))return b.fixture(f);if(c.isBlock(a,f)||c.isContainer(a,f))return k(a,e,f);a=g.create(a,d,f);return b.quasi(0<a.length?a:[f])},n=function(a,b,c){return p(a,c,b,c)},r=function(c,e,f,g,h,k,p,n){f=f.map(function(b){return q(c,e,b,p.bind(a.tail),d.none())}).getOr([]);h=h.map(function(b){return q(c,e,b,d.none(),n.bind(a.tail))}).getOr([]);g=0===g.length?[]:m(c,e,k,g[0],g[g.length-1]);return[b.container(k,f.concat(g).concat(h))]},q=function(b,c,e,g,h){var k=b.property().children(e);
g.bind(a.head).getOr(0);h.bind(a.head).getOr(k.length-1);var m=f.derive(g,h);return f.cata(m,function(d){return q(b,c,k[d],g.bind(a.tail),h.bind(a.tail))},function(a){return r(b,c,d.none(),k.slice(0,a),d.from(k[a]),e,g,h)},function(a,f){return r(b,c,d.from(k[a]),k.slice(a+1,f),d.from(k[f]),e,g,h)},function(a){return r(b,c,d.from(k[a]),k.slice(a+1),d.none(),e,g,h)},function(){return[n(b,c,e)]})};return{categorise:n,within:function(b,c,e,f,g){return!0===a.isBefore(f,g)?q(b,c,e,d.some(f),d.some(g)):
q(b,c,e,d.some(g),d.some(f))}}});l("n8","6q b 7 s n6 n7 md me 1y 1b l 2p 3d 21 2r az".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s){var u=function(a,b){if("li"!==q.name(a))return!1;var c=e.foldl(b,function(a,b){return 1<a.quasi||0<a.nonlist?a:f.cata(b,function(){return{quasi:1+a.quasi,nonlist:a.nonlist}},function(){return{quasi:a.quasi,nonlist:1+a.nonlist}},function(b){return{quasi:a.quasi,nonlist:(e.contains(["ul","ol"],q.name(b))?0:1)+a.nonlist}},function(){return{quasi:1+a.quasi,nonlist:a.nonlist}})},
{quasi:0,nonlist:0});return 1>=c.quasi&&0===c.nonlist},v=function(a,b,c){return 0>=c.length?!0:e.contains(a,q.name(b))?2<c.length?!1:1===c.length?f.isQuasiOrFixture(c[0]):f.isQuasiOrFixture(c[0])&&f.isQuasiOrFixture(c[1])&&!e.forall(c,f.isFixture):!1};return{wrap:function(a){if(0===a.length||1===a.length&&q.isText(a[0])&&0===s.get(a[0]).trim().length)return[];var c=p.fromTag(b.tag());k.add(c,h.style());n.before(a[0],c);r.append(c,a);return[c]},handleContainer:function(a,b,c,d){if(v(a,b,c))return[b];
var f=u(b,c)?[b]:[];return f.concat(e.bind(c,function(a){return d(a,0<f.length)}))},hasSimpleContent:v,isNestedList:u,handleRoot:function(e,h){var k=g.categorise(d(),c.curry(m.eq,h),h,h,h),p=function(){return a.some(b.nu(d()))},n=a.none;return f.cata(k,p,n,function(a,b){return v(e,a,b)||u(a,b)?n():p()},p)}}});l("ma","b 7 fg mi n7 ov n8 21".split(" "),function(d,e,c,a,b,f,g,h){var k=["li","td","th","caption"],m=function(a,c){return b.cata(a,function(a){return!0===c?[]:g.wrap(a)},function(a){return[a]},
function(a,b){return g.handleContainer(k,a,b,m)},function(a){return!0===c?[]:g.wrap([a])})};return{isRootContainer:a.isRootOrContainer,extract:function(a){return m(a,!1)},isCapable:function(a){return f.isBlock(a)||d.contains(k,h.name(a))},canUse:function(a){return c.isFormatting(a)||d.contains(k,h.name(a))},quasi:e.curry(g.handleRoot,k),ascend:e.identity}});l("e6",["87","s","2v"],function(d,e,c){var a=c.immutableBag(["start","soffset","finish","foffset","all"],[]),b=c.immutableBag(["start","soffset",
"finish","foffset"],[]);return{block:a,inline:b,blockFrom:function(b){return 0<b.length?e.some(a({start:b[0],soffset:0,finish:b[b.length-1],foffset:d.getEnd(b[b.length-1]),all:b})):e.none()},inlineFrom:function(a){return a.map(function(a){return b({start:a.start(),soffset:a.soffset(),finish:a.finish(),foffset:a.foffset()})})}}});l("mo","87 7 s f9 ft 1b m".split(" "),function(d,e,c,a,b,f,g){var h=function(a){return g.is(a,"td,th")},k=function(a){return f.eq(a.startContainer(),a.endContainer())&&a.startOffset()===
a.endOffset()},m=function(a,d){return a(d.startContainer())?c.some(b.freefallLtr(d.startContainer())):c.none()},p=function(d,e){return(d(e.endContainer())?c.some(b.freefallRtl(e.endContainer())):c.none()).map(function(b){return g.is(b.element(),"br")&&!1===k(e)?a.point(b.element(),1):b})};return{is:h,isCollapsed:k,isWholeCell:function(a){return h(a.startContainer())&&f.eq(a.startContainer(),a.endContainer())&&0===a.startOffset()&&a.endOffset()===d.getEnd(a.endContainer())},left:e.curry(m,h),leftWith:m,
right:e.curry(p,h),rightWith:p}});l("e9",["87","s","2v","2b"],function(d,e,c,a){var b=c.immutable("startContainer","startOffset","endContainer","endOffset"),f=c.immutable("start","soffset","finish","foffset");return{hare:b,fussy:f,fromHare:function(a){return f(a.startContainer(),a.startOffset(),a.endContainer(),a.endOffset())},fromFussy:function(a){return b(a.start(),a.soffset(),a.finish(),a.foffset())},fussyFromElements:function(b){if(0===b.length)return e.none();var c=b[0];b=b[b.length-1];c=a.firstChild(c).getOr(c);
b=a.lastChild(b).getOr(b);return e.some(f(c,0,b,d.getEnd(b)))}}});l("nv",["7","s","1b","2b"],function(d,e,c,a){var b=function(c,d){return d(c)?e.some([]):a.parent(c).bind(function(e){return a.findIndex(c).bind(function(a){return b(e,d).map(function(b){return b.concat([a])})})})},f=function(b,c){return 0===c.length?e.some(b):a.child(b,c[0]).bind(function(a){return f(a,c.slice(1))})};return{path:function(a,f){var k=d.curry(c.eq,a);return c.eq(a,f)?e.some([]):b(f,k)},follow:f}});l("mc","87 7 s f9 ft gf 2v mo uq ov e9 1b l nv 2p".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t){var s=g.immutable("ancestor","startPath","finishPath"),u=function(a,b,c){return f.ancestors(b,c,a).shared().bind(function(a){return q.path(a,b).bind(function(b){return q.path(a,c).map(function(c){return s(a,b,c)})})})},v=function(a,b,d,e){var f=b.isRootContainer(a);d=m.single(b.isCapable,d,e,b.quasi,f);d=k.extractEvenRoot(d);return 1===d.length?c.some(d[0]).map(function(c){return b.ascend(c,a)}):c.none()},w=function(c,e,f,g){if(!1===e(f))return a.point(f,g);
g<d.getEnd(f)||c.isCapable(f)&&c.canUse(f)?f=b.toLeaf(f,g):(c=r.fromTag("br"),t.append(f,c),f=a.point(c,0));return f};return{branch:function(a,b,d,f,g,k){var m=b.isRootContainer(a),r=p.hare(d,f,g,k),q=e.constant(!0===h.isWholeCell(r)),t=h.left(r).filter(q).getOrThunk(function(){return w(b,m,d,f)}),l=h.right(r).filter(q).getOrThunk(function(){return w(b,m,g,k)});return v(a,b,t.element(),t.offset()).bind(function(d){return(n.eq(t.element(),l.element())&&t.offset()===l.offset()?c.some(d):v(a,b,l.element(),
l.offset())).bind(function(b){return n.eq(d,b)?c.some(s(d,[],[])):u(a,d,b)})})}}});l("em","6q b 87 s f9 ft fg e6 mc md me 2n dy l 2p 21 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u){var v=function(d,g,h,k,m,p,r){d=g.isRootContainer(d)(h);g=!d&&n.inBody(h)?b.point(h,k):d||!g.isCapable(h)||n.inBody(h)?n.inBody(m.element())&&e.contains(["td","th"],s.name(h))?m:!n.inBody(h)&&n.inBody(p.element())&&"br"==s.name(p.element())?p:f.toLeaf(r,0):b.point(r,k);c.getEnd(g.element());return g.offset()<=
c.getEnd(g.element())?a.some(g):a.none()};return{applyOn:function(c,n,s,l,A,D,B){var C=r.after(s,l,A,D),F=n.isRootContainer(c)(s)?f.toLeaf(s,l):b.point(s,l),E=n.isRootContainer(c)(A)?f.toLeaf(A,D):b.point(A,D),G=f.toLeaf(s,l),H=f.toLeaf(A,D),I=k.branch(c,n,s,l,A,D).map(function(a){return m.within(d(),c,a.ancestor(),a.startPath(),a.finishPath())}).getOr([]),I=e.bind(I,n.extract);e.each(I,function(a){0===u.children(a).length&&g.isFormatting(a)&&t.append(a,q.fromTag("br"))});var I=p.condense(I),K=B(I);
return 0===K.length?a.none():v(c,n,s,l,F,G,K[C?K.length-1:0]).bind(function(a){return v(c,n,A,D,E,H,K[C?0:K.length-1]).map(function(b){return h.block({start:a.element(),soffset:a.offset(),finish:b.element(),foffset:b.offset(),all:K})})})}}});l("mf",["2o","bs","21"],function(d,e,c){var a=function(a){return function(b){return a}},b={start:e.onDirection("left","right"),end:e.onDirection("right","left"),justify:a("justify"),center:a("center"),"match-parent":a("match-parent")};return{hasAlignment:function(a,
e,h){c.isText(a)?a=!1:(e=d.get(a,e),a=(void 0!==b[e]?b[e](a):e)===h);return a}}});l("mg",["2o"],function(d){return function(e,c){return{is:function(a){return d.get(a,e)===c},remove:function(a){d.remove(a,e)},set:function(a){d.set(a,e,c)}}}});l("du","b 7 m9 ma em mf mg".split(" "),function(d,e,c,a,b,f,g){var h=function(a,b,c){return f.hasAlignment(c,a,b)},k=function(f,k,m){var p=g(k,m);return{run:function(c,e,f,g,h){return b.applyOn(c,a,e,f,g,h,function(a){var b=d.forall(a,p.is)?p.remove:p.set;d.each(a,
b);return a})},query:function(a,b){var d=e.curry(h,k,m);return c.bothMatch(a,b,d)},name:e.constant(f)}},m=k("JustifyLeft","text-align","left"),p=k("JustifyCenter","text-align","center"),n=k("JustifyRight","text-align","right"),k=k("JustifyFull","text-align","justify");return{justifyleft:e.constant(m),justifycentre:e.constant(p),justifyright:e.constant(n),justifyfull:e.constant(k)}});l("e1",["s","2o","36"],function(d,e,c){var a=function(a){a=a.dom();if(c.isSupported(a)){var d=a.style.marginLeft;return"auto"===
a.style.marginRight&&"auto"===d}return!1};return{isCentered:a,divine:function(b){if(a(b))return d.some("center");var c=e.getRaw(b,"float").getOrThunk(function(){return e.get(b,"float")});return void 0!==c&&null!==c&&0<c.length?d.some(c):d.none()},getRaw:function(a){return e.getRaw(a,"float").getOr(null)},setCentered:function(a){e.setAll(a,{"margin-left":"auto","margin-right":"auto"})}}});l("dv",["7","s","2o","e1","21"],function(d,e,c,a,b){var f={left:{"float":"left",margin:""},right:{"float":"right",
margin:""},none:{"float":"none",margin:""},center:{"float":"",margin:"0 auto"}},g={none:{display:""},left:{display:""},right:{display:""},center:{display:"block"}},h=function(b,c){return a.divine(b).is(c)},k=function(a,d){var h="img"===b.name(a)&&void 0!==g[d]?g[d]:{};e.from(f[d]).each(function(b){c.setAll(a,b);c.setAll(a,h)})},m=function(a,b){return{run:function(a){k(a,b);return e.none()},query:function(a){return h(a,b)},name:d.constant(a)}},p=m("JustifyLeft","left"),n=m("JustifyCenter","center"),
r=m("JustifyRight","right"),m=m("FloatNone","none");return{floatnone:d.constant(m),floatleft:d.constant(p),floatcentre:d.constant(n),floatright:d.constant(r),queryIsFloat:h,runFloat:k}});l("ur",["2v"],function(d){return d.immutable("level","content","cruft","list","item")});l("mh",["ur"],function(d){return{level:function(e,c){return d(e.level()+c,e.content(),e.cruft(),e.list(),e.item())},list:function(e,c){return d(e.level(),e.content(),e.cruft(),c,e.item())}}});l("mj","6q b 7 s fg n6 mi n7 ov n8 21".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p){var n=function(a){return h.cata(a,function(a){return m.wrap(a)},function(a){return[a]},function(a,b){return e.bind(b,n)},function(a){return m.wrap([a])})};return{isRootContainer:g.isRootOrContainer,extract:n,isCapable:function(a){return k.isBlock(a)||"li"===p.name(a)},canUse:function(a){return b.isFormatting(a)},quasi:function(b){return a.some(f.nu(d()))},ascend:c.identity}});l("ut",["b","mb","2v","21"],function(d,e,c,a){var b=c.immutable("elements","elementsTransformed"),
f=c.immutable("original","replaced"),g=c.immutable("result","items");return{answer:b,write:function(a,c){var m=[],p=function(b){var c=a.create().nu("p");a.insert().appendAll(c,b);return c},n=function(a){if(0===a.length)throw"Cannot get tail of an empty array";return a.slice(1)},r=function(b,c){for(var e=a.create().clone(c[0].list()),f=[],k=c[0];0<c.length&&c[0].level()>=b&&a.property().name(k.list())===a.property().name(c[0].list());){var m;if(c[0].level()===b){m=b;var p=c,q=p[0],l;l=q;var D=l.item(),
B=D,B=a.property().children(B);d.each(B,a.remove().remove);a.insert().appendAll(D,l.content());l=D;q=q.cruft();for(p=n(p);0<p.length&&p[0].level()>m;)D=r(m+1,p),p=D.items(),a.insert().append(l,D.result());a.insert().appendAll(l,q);m=g(l,p);m=g([m.result()],m.items())}else m=r(b+1,c),p=a.create().nu("li"),a.styles().set(p,"list-style-type","none"),a.attrs().remove(e,"id"),a.insert().append(p,m.result()),m=g([p],m.items());c=m.items();f=f.concat(m.result())}a.insert().appendAll(e,f);return g(e,c)},
q=function(b){for(var c=[];0<b.length;){var d=b[0];if(0===d.level()){var k;k=b[0];var q=k.content(),q=1===q.length&&e.isBlock(a,q[0])?q[0]:p(q);m.push(f(k.item(),q));k=g([q],n(b));b=k.items();c=c.concat(k.result());for(k=[];0<b.length&&0<b[0].level();)q=r(1,b),b=q.items(),k=k.concat([q.result()]);k=g(k,b);b=k.items();c=c.concat(k.result());0<d.cruft().length&&(c=c.concat([p(d.cruft())]))}else d=r(1,b),b=d.items(),c=c.concat([d.result()])}return g(c,b)}(c);if(0!==q.items().length)throw"Error - there should not be any remaining items to parse";
return b(q.result(),m)}}});l("us",["b","ut"],function(d,e){var c=function(a){return d.foldl(a,function(a,c){var d=a.elements().concat(c.elements()),h=a.elementsTransformed().concat(c.elementsTransformed());return e.answer(d,h)},e.answer([],[]))};return{combine:c,write:function(a,b){var f=d.groupBy(b,function(b){return a.property().name(b.list())+"-"+a.styles().getRaw(b.list(),"list-style-type").getOr("default")}),f=d.map(f,function(b){return e.write(a,b)});return c(f)}}});l("n9",["6q","us","ut"],
function(d,e,c){var a=d();return{groupWrite:function(b){return e.write(a,b)},write:function(b){return c.write(a,b)}}});l("na","b 7 s fg 1b 21 6m 4h 32 1s".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=function(a,b,c){return k.closest(a,"li",c).bind(function(a){return b(a,c).map(function(b){return{item:e.constant(a),outerlist:e.constant(b)}})})},n=function(a,c){return d.findIndex(a,function(a){return b.eq(a,c)})};return{context:function(a,d,f,g,k){return p(a,f,k).bind(function(v){return p(d,f,k).bind(function(f){if(b.eq(v.outerlist(),
f.outerlist())){var k;if(b.eq(a,d))k=[v.item()];else{k=v.outerlist();var p=v.item(),t=f.item();k=h.descendants(k,"li");var p=n(k,p),u=n(k,t),t=m.min(p,u),p=m.max(p,u);k=(-1<t&&-1<p?c.some(k.slice(t,p+1)):c.none()).getOr([])}f=c.some({outerlist:v.outerlist,startItem:v.item,finishItem:f.item,writer:e.constant(g),selected:e.constant(k)})}else f=c.none();return f})})},immediate:function(a,b){return k.closest(a,"ul,ol",b)},topmost:function(b,e){var h=g.ancestors(b,function(b){return a.isList(b)||a.isContainer(b)},
e),k=d.findIndex(h,function(a){return!d.contains(["li","ol","ul"],f.name(a))});return 0<k&&k-1<h.length?c.some(h[k-1]):0<h.length?c.some(h[h.length-1]):c.none()}}});l("mk",["mh","n9","na"],function(d,e,c){return{context:function(a,b,d){return c.context(a,b,c.topmost,e.write,d)},indent:function(a){return d.level(a,1)},outdent:function(a){return d.level(a,-1)}}});l("ml",["b","1b"],function(d,e){var c=function(a,b){var c=d.find(a,function(a){return e.eq(b,a)});return null!==c&&void 0!==c};return{operate:function(a,
b,e){return d.map(b,function(b){return c(e,b.item())?a(b):b})}}});l("uu",["b","s","k","2v"],function(d,e,c,a){var b=a.immutable("before","on","after"),f=function(a,c){var f=e.from(d.map(c,function(b){return a[b]})),m=a.slice(0,c[0]),p=a.slice(c[c.length-1]+1);return b(m,f,p)};return{refine:function(a,h){var k=d.map(a,function(a,b){return h(a)?e.some(b):e.none()}),k=c.cat(k),m=b(a,e.none(),[]);return 0===k.length?m:f(a,k)}}});l("mm","b ur uu 2o 21 4h m 2b".split(" "),function(d,e,c,a,b,f,g,h){var k=
function(a,c){var e=f.children(a,"li,ol,ul");return d.bind(e,function(d){return"li"===b.name(d)?m(a,d,c):k(d,c+1)})},m=function(b,c,f){var g=n(c),h="none"===a.get(c,"list-style-type")?[]:[e(f,g.before(),g.after(),b,c)];return g.on().fold(function(){return h},function(a){a=d.bind(a,function(a){return k(a,f+1)});return h.concat(a)})},p=function(a){return g.is(a,"ol,ul")},n=function(a){a=h.children(a);return c.refine(a,p)};return{read:function(a){return k(a,1)}}});l("eo","b ml mm 7 s e6 1a 1b 2o 3d 2r 1s".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n){var r=function(a){a=a.elementsTransformed();d.each(a,function(a){k.transfer(a.original(),a.replaced(),["text-align"]);g.transfer(a.original(),a.replaced(),["dir"])})},q=function(a,b){var c=d.find(b,function(b){return h.eq(b.original(),a)});return void 0!==c&&null!==c?c.replaced():a},t=function(a,d,g,h,k,n){if(0===a.selected().length)return b.none();var t=a.writer(),l=a.outerlist();a=a.selected();var D=c.read(l);n=n(a);n=e.operate(n,D,a);t=t(n);r(t);m.before(l,t.elements());
p.remove(l);l=t.elementsTransformed();d=q(d,l);h=q(h,l);return b.some(f.block({start:d,soffset:g,finish:h,foffset:k,all:t.elements()}))};return{execute:function(b,c,d,e,f,g){return t(b,c,d,e,f,a.constant(g))},executeUsing:t}});l("dw","6q b mh mi em mj mk eo".split(" "),function(d,e,c,a,b,f,g,h){d();var k=function(a,c,d,g,h,k,m){return b.applyOn(a,f,c,d,g,h,function(a){e.each(a,function(a){m.change(a,k)});return a})},m=function(b,c){return function(d,e,f,m,u,v){var w=a.isRootOrCell(d);return g.context(e,
m,d).fold(function(){return k(w,e,f,m,u,b,v)},function(a){return h.execute(a,e,f,m,u,c)})}};return{indent:function(a,b,c,d,e,f){return m(1,g.indent)(a,b,c,d,e,f)},outdent:function(a,b,c,d,e,f){return m(-1,g.outdent)(a,b,c,d,e,f)}}});l("mp","6q b 7 s fg n6 n7 21".split(" "),function(d,e,c,a,b,f,g,h){return{isRootContainer:function(a){return function(b){return a(b)||e.contains(["td","th","caption"],h.name(b))}},extract:function(a){return g.cata(a,function(a){return[a]},function(a){return[a]},function(a,
b){return e.contains(["ol","ul"],h.name(a))?[a]:e.bind(b,g.toTarget)},function(a){return[a]})},isCapable:function(a){return b.isBlock(a)},canUse:c.constant(!1),quasi:function(b){return a.some(f.nu(d()))},ascend:c.identity}});l("dx","b s gf mo e6 mp em 1b l 2p 3d 2r 4h 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q){var t=function(b){return a.is(b)?q.descendant(b,"blockquote"):q.closest(b,"blockquote")},s=function(a){return c.sharedOne(t,a)},u=function(a,b,c,e,h){return g.applyOn(a,f,b,c,e,h,
function(a){var b=k.fromTag("blockquote");0<a.length&&(m.before(a[0],b),p.append(b,a),b=r.descendants(b,"blockquote"),d.map(b,n.unwrap));return a})};return{toggle:function(a,c,d,f,g){return(h.eq(c,f)?t(c):s([c,f])).fold(function(){return u(a,c,d,f,g)},function(a){n.unwrap(a);return e.some(b.block({start:c,soffset:d,finish:f,foffset:g,all:[]}))})},queryPoint:t,queryAll:s}});l("7e","7 dm dn do dp dq dr 7l 7i dt du dv dw dx 3x".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t){var s=function(b,c,e,
f){var g=b.content(),k=b.undo();h.cata(b.selections().get(),d.noop,a.multiple(g,b.undo(),f),a.single(g,k,f,c,e))};t=function(a){return function(b){var c=0<a?r.indent:r.outdent,d=e(b.region()),h=b.content();s(b,g.spot,f.update,function(a,b,e,f){return c(h.isRoot,a,b,e,f,d)})}};var u=function(a){return function(c){var e=c.content(),k=function(b,c,d,f){return a.run(e.isRoot,b,c,d,f)};h.cata(c.selections().get(),d.noop,b.multiple(e,c.undo(),k),b.single(e,c.undo(),k,g.spot,f.update))}},v=function(a){return function(b){b.content().getSelection().bind(k.detect).each(function(d){c.runTransaction(b.content(),
b.undo(),function(){(a.query(d.image())?n.floatnone():a).run(d.image())},b.content().toEditing)})}};return{indent:t(1),outdent:t(-1),blockquote:function(a){var b=a.content();s(a,g.spot,f.update,function(a,c,d,e){return q.toggle(b.isRoot,a,c,d,e)})},justifyLeft:u(p.justifyleft()),justifyCentre:u(p.justifycentre()),justifyRight:u(p.justifyright()),justifyFull:u(p.justifyfull()),imageNone:v(n.floatnone()),imageLeft:v(n.floatleft()),imageCentre:v(n.floatcentre()),imageRight:v(n.floatright()),breakQuote:function(a,
b,c){m.breakQuote(b,c).each(function(b){a.content().setRelativeSelection(b.start(),b.finish());a.content().uiChanged()})}}});l("7f",["a","b","7","s"],function(d,e,c,a){var b=function(b,c){var d=e.find(b,function(a){return a.value()===c});return a.from(d)};return{updateMenu:function(e,g,h,k,m){g.fold(e.clear,c.noop,function(c){(d.isString(c)?b(k,c):a.some(c)).each(e.select);m.each(function(a){a=a(c);e.selectElement(a)})});h.fold(e.disable,c.noop,e.enable);g.fold(e.untick,c.noop,function(a){a=d.isString(a)?
a:a.value();e.tick(a)})}}});l("7g","b 7 4q dy 21 32".split(" "),function(d,e,c,a,b,f){var g=c.generate([{table:["selection"]},{list:["selection"]}]),h=function(a,c){return a.isRoot(c)||d.contains(["table","ul","ol"],b.name(c))};return{context:function(c){return c.getSelection().bind(function(d){if(d.collapsed())return f.closest(d.startContainer(),"td,th,li",e.curry(h,c)).map(function(a){return"li"===b.name(a)?g.list(d):g.table(d)});var p=a.commonAncestorContainer(d.startContainer(),d.startOffset(),
d.endContainer(),d.endOffset());return f.closest(p,"ol,ul",c.isRoot).map(function(a){return g.list(d)})})},cata:function(a,b,c){return a.fold(b,c)}}});l("dz",["7","1a","2o"],function(d,e,c){return{attr:function(a,b,c){var g=d.curry(e.set,a,b,c);a=d.curry(e.remove,a,b);0<c.length?g():a()},css:function(a,b,e){var g=d.curry(c.set,a,b,e);a=d.curry(c.remove,a,b);0<e.length?g():a()}}});l("k3",["4j"],function(d){return{resolve:d.create("ephox-salmon").resolve}});l("e0",["7","k3"],function(d,e){var c=e.resolve("upload-image-in-progress"),
a="data-"+e.resolve("image-blob");return{uploadInProgress:d.constant(c),blobId:d.constant(a)}});l("9q","dz e0 2v dv 1a 2o e1 68 2s e2".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=c.immutableBag("url alt width height isLocal align".split(" "),["computedWidth","computedHeight"]),n=function(a,c){var d=b.get(a,c);return void 0!==d?d:""};return{divine:function(a){var c=f.getRaw(a,"width").getOr(""),d=f.getRaw(a,"height").getOr(""),m=f.getRaw(a,"width").getOrThunk(function(){return k.get(a)+"px"}),u=
f.getRaw(a,"height").getOrThunk(function(){return h.get(a)+"px"}),v=g.divine(a);return p({url:n(a,"src"),alt:n(a,"alt"),width:c,height:d,computedWidth:m,computedHeight:u,isLocal:b.has(a,e.blobId()),align:v})},properties:p,apply:function(c,e){b.get(c,"src")===e.url()||e.isLocal()||b.set(c,"src",e.url());d.attr(c,"alt",e.alt());d.css(c,"width",e.width());d.css(c,"height",e.height());e.align().each(function(b){a.runFloat(c,b)})}}});l("e3",["21","2b"],function(d,e){return{hasNoContent:function(c){var a=
e.children(c);return d.isElement(c)&&(0===a.length||1===a.length&&"br"===d.name(a[0]))}}});l("7h","b 7 s 9q e3 7i 7j 2v du dx 1b 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var r=h.immutable("alignment","quoted"),q=function(a){return a.getSelection().fold(function(){return!1},function(a){var b=a.startContainer();a=a.endContainer();return p.eq(b,a)?m.queryPoint(b).isSome():m.queryAll([b,a]).isSome()})},t=[k.justifyleft(),k.justifycentre(),k.justifyright(),k.justifyfull()],s=function(b){return b.getSelection().bind(f.detect).fold(function(){return b.getSelection().bind(function(a){var b=
d.find(t,function(b){return b.query(a.startContainer(),a.endContainer())});return null!==b&&void 0!==b?c.some(b.name()):c.none()}).fold(g.off,g.on)},function(b){return a.divine(b.image()).align().fold(g.off,function(a){return"center"===a?g.on(k.justifycentre().name()):"right"===a?g.on(k.justifyright().name()):g.on(k.justifyleft().name())})})};return{read:function(a){var b=s(a);a=q(a)?g.on({}):g.off();return r(b,a)},alignment:s,inQuote:q,atQuoteBreak:function(a){return a.getSelection().bind(function(a){var d=
a.startContainer();return a.collapsed()?n.closest(d,"blockquote").bind(function(a){return b.hasNoContent(d)?c.some({quote:e.constant(a),element:e.constant(d)}):c.none()}):c.none()})}}});l("5d","7d 7 s 7e 7f 7b 7g 7h 7i 71 7c 7j 59 4a 2v q".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s){return function(s){var v=s.content(),w=s.keyboard(),l=s.shortcuts(),x=s.context(),z=q.create({analytics:r(["message","properties"])}),A=e.curry(a.indent,s),D=e.curry(a.outdent,s),B=e.curry(a.blockquote,s);l.events.indent.bind(A);
l.events.outdent.bind(D);l.events.blockquote.bind(B);var C=function(a){var b=a.stopper();g.context(v).bind(function(c){g.cata(c,e.noop,function(c){(a.shift()?D:A)();b()})})},F=w.editor();F.on();F.events.tab.bind(C);x.events.preLinebreak.bind(function(b){h.atQuoteBreak(s.content()).each(function(c){a.breakQuote(s,c.quote(),c.element());b.handler().handle()})});var E=t.immutable("value","icon","textkey"),w=E("justifyleft",c.some(d.resolve("justifyleft")),f.key("alignment.left")),l=E("justifycenter",
c.some(d.resolve("justifycenter")),f.key("alignment.center")),x=E("justifyright",c.some(d.resolve("justifyright")),f.key("alignment.right")),G=E("justifyfull",c.some(d.resolve("justifyfull")),f.key("alignment.justify")),H=E("justifyleft",c.some(d.resolve("justifyleft")),f.key("alignment.left")),I=E("justifycenter",c.some(d.resolve("justifycenter")),f.key("alignment.center")),E=E("justifyright",c.some(d.resolve("justifyright")),f.key("alignment.right")),K=[w,l,x,G],J=[H,I,E],L=function(){return v.getSelection().bind(k.detect).fold(function(){return K},
function(a){return J})},N={justifyleft:e.curry(a.imageLeft),justifycenter:e.curry(a.imageCentre),justifyright:e.curry(a.imageRight)},M={justifyleft:a.justifyLeft,justifycenter:a.justifyCentre,justifyright:a.justifyRight,justifyfull:a.justifyFull},O=function(a){return a.toLowerCase()},S=c.none();return{ui:m.ui({"indent.general":{value:"indent",textkey:f.key("action.indent"),action:A,updateGeneral:e.identity,tooltip:p.get,toggle:!1},"outdent.general":{value:"outdent",textkey:f.key("action.outdent"),
action:D,updateGeneral:e.identity,tooltip:p.get,toggle:!1},"blockquote.general":{value:"blockquote",textkey:f.key("action.blockquote"),action:B,updateGeneral:function(a){h.read(v).quoted().fold(a.deselect,e.noop,a.select)},tooltip:p.get,toggle:!0},"alignment.dropdown":{name:"alignment",textkey:f.key("alignment.toolbar"),menuTextkey:f.key("alignment.menu"),action:function(a){var b=v.getSelection().bind(k.detect).fold(e.constant(M),e.constant(N));(void 0!==b[a]?b[a]:e.noop)(s)},updateDropdown:function(a){var d=
L(),f=h.read(v).alignment().fold(function(){return 0<d.length?n.on(d[0].value()):n.off()},n.unchanged,n.on);a.populate([{label:c.none,items:e.constant(d)}]);b.updateMenu(a,f.map(O),n.on(),d,S)},values:K,render:S,tooltip:p.get,toggle:!1,describe:function(a){return f.translate("alignment.describe",f.get(a.textkey()))}}}),events:z.registry,destroy:function(){F.off();F.events.tab.unbind(C);F.destroy()}}}});l("7k",["b","dn"],function(d,e){return{multiple:function(c,a,b){return function(f,g){e.runTransaction(c,
a,function(){d.each(g,b)},c.toEditing)}},single:function(c,a,b){return function(d,g){e.runTransaction(c,a,function(){b(g).each(function(a){c.setSelection(a.start(),a.soffset(),a.finish(),a.foffset())});c.backupSelection()},c.toEditing)}}}});l("mv",["6q","uv"],function(d,e){var c=d();return{atStartOf:function(a,b,d){e.atStartOf(c,a,b,d)}}});l("e7",["7","me","mt"],function(d,e,c){c=c.resolve("style-marker");return{styleSpan:d.constant(c),overrideSpan:d.constant("data-ephox-override"),quasiBlock:e.style}});
l("uw",["81","4q"],function(d,e){var c=e.generate([{none:[]},{tempIn:["selection"]},{tempOut:["selection"]},{rangedIn:["selection"]},{rangedOut:["selection"]}]);return{detect:function(a,b){return a.getSelection().fold(function(){return c.none()},function(a){var e=b(a);return d.isCollapsed(a.startContainer(),a.startOffset(),a.endContainer(),a.endOffset())?e?c.tempIn(a):c.tempOut(a):e?c.rangedIn(a):c.rangedOut(a)})}}});l("ux",["1a","2o","l"],function(d,e,c){var a=function(a,b){return c.fromTag(a,b.dom())},
b=function(a,b,d){d=c.fromTag("span",d.dom());e.set(d,a,b);return d};return{nu:function(c,d,e,k){return"span"===e?b(c,d,k):a(e,k)},nuTag:a,nuAttr:function(a,b,e){e=c.fromTag("span",e.dom());d.set(e,a,b);return e},nuStyle:b}});l("hr",["b","s","2o","21","2b"],function(d,e,c,a,b){var f={"font-weight":{700:"bold",400:"normal"}},g=function(a,b){if(a===b&&""!==b&&void 0!==b)return!0;var c=a.toLowerCase(),e=b.toLowerCase().split(" ");return d.contains(e,c)},h=function(a,b){if(void 0!==f[a]){var c=f[a][b];
return void 0!==c?c:b}return b},k=function(a,b){var c=m(a,b);return h(b,c)},m=function(d,f){return(a.isText(d)?b.parent(d):e.some(d)).map(function(a){return c.get(a,f)}).getOr(void 0)};return{state:function(a,b,c){a=k(a,b);return"text-decoration"===b?g(c,a):c===a&&""!==a&&void 0!==a},rawState:function(a,b,d){a=h(b,c.getRaw(a,b).getOr(void 0));return"text-decoration"===b?g(d,a):d===a&&""!==a&&void 0!==a},value:k}});l("zk",["b","s","2o","21","4l"],function(d,e,c,a,b){var f={"text-decoration":function(e,
f,k,m){var p=function(m){return b.closest(m,function(b){return a.isElement(b)&&(d.contains(k,a.name(b))||c.getRaw(b,e).exists(function(a){return-1!==a.indexOf(f)}))}).toArray()};m=p(m.startContainer()).concat(p(m.endContainer()));return d.exists(m,function(b){return d.contains(k,a.name(b))?!0:c.getRaw(b,e).exists(function(a){return f===a})})}};return{handle:function(a,b,c){return void 0!==f[a]?e.some(f[a]):e.none()}}});l("uy","b 7 s f9 fg mo hr e9 zk 1a 21 6u 32".split(" "),function(d,e,c,a,b,f,g,
h,k,m,p,n,r){var q=function(a,b){return b.getSelection().map(function(b){return a(b)}).getOr(!1)},t=function(c,d,e,m){var p=f.leftWith(b.isBlock,m).getOrThunk(function(){return a.point(m.startContainer(),m.startOffset())}),n=f.rightWith(b.isBlock,m).getOrThunk(function(){return a.point(m.endContainer(),m.endOffset())});return k.handle(c,d).fold(function(){var a=g.state(p.element(),c,d),b=g.state(n.element(),c,d);return a||b},function(a){return a(c,d,e,h.hare(p.element(),p.offset(),n.element(),n.offset()))})},
s=function(a,b,c,d){return q(e.curry(t,a,b,c),d)},u=function(a,b){return w(a,b)},v=function(a,b){return q(e.curry(u,a),b)},w=function(a,c){var d=f.leftWith(b.isBlock,c).fold(c.startContainer,function(a){return a.element()}),e=f.rightWith(b.isBlock,c).fold(c.endContainer,function(a){return a.element()}),d=n.closest(d,a),e=n.closest(e,a);return d||e},l=function(a,b){return d.contains(a,p.name(b))},x=function(a,b){var d="["+a+"]";return r.closest(b.startContainer(),d).bind(function(e){return r.closest(b.endContainer(),
d).bind(function(b){var d=m.get(e,a);b=m.get(b,a);d=d.toLowerCase();b=b.toLowerCase();return d===b?c.some(d):c.none()})})};return{queriesStyle:function(a,b,c){return{queryOn:e.curry(t,a,b,c),query:e.curry(s,a,b,c)}},queryStyleOn:t,queriesTag:function(a){return{queryOn:e.curry(u,a),query:e.curry(v,a)}},relatedStyle:function(a,b,c,d){(c=l(c,d))||(c="span"===p.name(d)&&g.state(d,a,b));return c},relatedTags:l,queryAttrSame:function(a,b){return b.getSelection().bind(function(b){return x(a,b)})},queryAttrIs:function(a,
b,c){var d=b.toLowerCase(),e=function(b){return m.get(b,a).toLowerCase()===d};return r.closest(c.startContainer(),"["+a+"]").filter(e).orThunk(function(){return r.closest(c.endContainer(),"["+a+"]").filter(e)}).isSome()}}});l("14y","b s f9 m4 is mb 4q 2v".split(" "),function(d,e,c,a,b,f,g,h){var k=g.generate([{none:["last","mode"]},{running:["next","mode"]},{split:["boundary","last","mode"]},{finished:["element","mode"]}]),m=h.immutable("start","soffset","finish","foffset"),p=function(b,d,e){e=a.toLeaf(b,
e,0);return q(b,e.element())?r(b,d,e.element()).map(function(a){return c.point(a,0)}).getOr(e):e},n=function(a,b){return f.isFrame(a,b)||f.isBlock(a,b)||d.contains(["li"],a.property().name(b))},r=function(a,c,d){return b.seekRight(a,d,function(b){return!q(a,b)&&!n(a,b)},c)},q=function(a,b){return a.property().isText(b)?a.property().parent(b).exists(function(b){return d.contains("table tbody thead tfoot tr ul ol".split(" "),a.property().name(b))}):!1},t=function(a,c,d,e,f){return b.walk(a,e,d,b.walkers().right()).fold(function(){return k.none(e,
b.sidestep)},function(b){return a.eq(b.item(),f)?k.finished(f,b.mode()):n(a,b.item())?k.split(b.item(),e,b.mode()):k.running(b.item(),b.mode())})},s=function(a,b,c,d){return r(a,b,c).fold(function(){return e.none()},function(f){return a.eq(f,d)?e.some(d):u(a,c,f)?s(a,b,f,d):n(a,f)?(f=p(a,b,f),e.some(f.element())):e.some(f)})},u=function(a,b,c){return a.property().parent(b).exists(function(b){return a.eq(b,c)})},v=function(a,c,d,f,g,h){return t(a,c,d,g,h).fold(function(a,b){return[{start:f,finish:a}]},
function(b,d){return v(a,c,d,f,b,h)},function(d,k,m){var n={start:f,finish:k};return(u(a,g,d)?s(a,c,d,h):function(){var f=p(a,c,d);return a.eq(f.element(),d)?b.walk(a,d,b.advance,b.walkers().right()).map(function(a){return a.item()}):e.some(f.element())}()).fold(function(){return[n]},function(d){return a.eq(d,h)?[n].concat({start:h,finish:h}):[n].concat(v(a,c,b.advance,d,d,h))})},function(a,b){return[{start:f,finish:a}]})},w=function(a,b,c){if(n(a,b)){var d=a.property().children(b);return 0<=c&&c<
d.length?w(a,d[c],0):c===d.length?w(a,d[d.length-1],0):b}return b},l=function(a,b,c,d){c=w(a,c,d);return q(a,c)?r(a,b,c).getOr(c):c},x=function(a,c,e,f,g,h){var k=l(a,c,e,f),p=l(a,c,g,h);c=v(a,c,b.sidestep,k,k,p);return d.map(c,function(b,c){var d=a.eq(b.start,e)?f:0,k;a.eq(b.finish,g)?k=h:(k=b.finish,k=a.property().isText(k)?a.property().getText(k).length:a.property().children(k).length);return m(b.start,d,b.finish,k)})},z=function(b,c,d,e,f,g){b.eq(d,f)?n(b,d)?(e=a.toLeaf(b,d,e),g=a.toLeaf(b,d,
g),b=b.eq(e.element(),d)&&b.eq(g.element(),d)?[m(e.element(),e.offset(),g.element(),g.offset())]:z(b,c,e.element(),e.offset(),g.element(),g.offset())):b=[m(d,e,d,g)]:b=x(b,c,d,e,f,g);return b};return{collect:z}});l("14z",["is","pq","4q"],function(d,e,c){var a=c.generate([{leftEdge:["element"]},{between:["before","after"]},{rightEdge:["element"]}]),b=function(b,c,d){d=e.split(b,c,d);var f=function(){return a.rightEdge(c)};return e.position(b,d).fold(f,function(){return a.leftEdge(c)},a.between,f)},
f=function(c,d,e,f){if(c.property().isText(d))return b(c,d,e);if(c.property().isEmptyTag(d))return f(d);c=c.property().children(d);d=0===e?a.leftEdge(d):e===c.length?a.rightEdge(d):0<e&&e<c.length?a.between(c[e-1],c[e]):a.rightEdge(d);return d};return{toLeft:function(b,c,e,m){return f(b,e,m,a.leftEdge).fold(function(a){return a},function(a,b){return b},function(a){return d.after(b,a,c).getOr(a)})},toRight:function(b,c,e,m){return f(b,e,m,a.rightEdge).fold(function(a){return d.before(b,a,c).getOr(a)},
function(a,b){return a},function(a){return a})}}});l("150","b 7 s mn un up".split(" "),function(d,e,c,a,b,f){var g=function(a,b,f,g){var h=a.property().children(b);b=function(b){b=d.findIndex(h,e.curry(a.eq,b));return-1<b?c.some(b):c.none()};f=f.bind(b).getOr(0);g=g.bind(b).getOr(h.length-1);return-1<f&&-1<g?c.some(h.slice(f,g+1)):c.none()},h=function(b,c,d,f){return a.breakPath(b,c,function(a){return b.property().parent(a).fold(e.constant(!0),e.curry(b.eq,d))},f)},k=function(a,d,e,f){a.eq(d,f)?f=
c.none():(f=h(a,f,d,b.breakToRight),f=c.some(f.first()));if(a.eq(d,e))e=c.none();else{var k=h(a,e,d,b.breakToLeft);0<k.splits().length&&a.insert().prepend(k.splits()[0].second(),e);e=c.some(k.second().getOr(e))}return g(a,d,e,f)},m=function(b,d,e,g,h){return f.ancestors(b,e,g,d).shared().orThunk(function(){return a.sharedOne(b,function(a,e){return d(e)?c.some(e):b.up().predicate(e,d)},[e,g])}).map(h)},p=function(a,b,c,d,e){return m(a,b,c,d,e).bind(function(b){return k(a,b,c,d)})};return{fracture:function(a,
b,d,f,g){g=void 0!==g?g:e.identity;a.eq(d,f)?(b=g(d),a=a.eq(b,d)?c.some([d]):k(a,b,d,d)):a=p(a,b,d,f,g);return a}}});l("12l","b s pq 14y 14z 150".split(" "),function(d,e,c,a,b,f){var g=function(a,d,e,g,n,r,q){a.property().isText(e)&&a.eq(e,n)?(e=c.splitByPair(a,e,g,r),a=f.fracture(a,d,e,e,q)):(n=b.toRight(a,d,n,r),e=b.toLeft(a,d,e,g),a=f.fracture(a,d,e,n,q));return a};return{fractures:function(b,c,e,f,n,r,q){e=a.collect(b,c,e,f,n,r);return d.bind(e,function(a,d){return g(b,c,a.start(),a.soffset(),
a.finish(),a.foffset(),q).toArray()})},fracture:g}});l("zl",["6q","12l"],function(d,e){var c=d();return{fractures:function(a,b,d,g,h,k){return e.fractures(c,a,b,d,g,h,k)},fracture:function(a,b,d,g,h,k){return e.fracture(c,a,b,d,g,h,k)}}});l("v6",["f9","dy","2b"],function(d,e,c){return{makeTo:function(a,b,d){var e=c.owner(a).dom().createRange();e.setStart(a.dom(),b);e.setEndBefore(d.dom());return e},makeFrom:function(a,b,d){var e=c.owner(b).dom().createRange();e.setStartAfter(a.dom());e.setEnd(b.dom(),
d);return e},leftEdge:function(a,b,c,g){return e.after(a,b,c,g)?d.point(c,g):d.point(a,b)},rightEdge:function(a,b,c,g){return e.after(a,b,c,g)?d.point(a,b):d.point(c,g)}}});l("mx","b 1o 7 21 4h m".split(" "),function(d,e,c,a,b,f){var g=function(a,c){var d=e.keys(c).join(",");return(f.is(a,d)?[a]:[]).concat(b.descendants(a,d))};return{cleanse:function(b,e){var f=g(b,e);d.each(f,function(b){var d=a.name(b);(void 0!==e[d]?e[d]:c.noop)(b)})}}});l("v0",["b","v"],function(d,e){return{onlyEphox:function(c){return void 0!==
c&&null!==c&&0<c.trim().length?(c=c.split(/\s+/),d.filter(c,function(a){return e.startsWith(a,"ephox-")}).join(" ")):""}}});l("my","b 6 v0 1a 2o 2r".split(" "),function(d,e,c,a,b,f){var g=function(a){f.unwrap(a)},h=function(c,d){b.remove(c,d);a.hasNone(c)&&g(c)},k=function(a){var b={};d.each(a,function(a){b[a]=m(g)});return b},m=function(b){return function(c){a.has(c,"data-ignore")||b.apply(null,arguments)}};return{cssAndTag:function(a,b,c){a=k(a);c=function(a){h(a,b)};return e.merge(a,{span:m(c),
font:m(c)})},tagList:k,removeStyle:m(h),removeAttribute:m(function(b,c){a.remove(b,c);a.hasNone(b)&&g(b)}),unwrap:m(g),unstyle:m(function(b){var d=a.get(b,"class");a.remove(b,"class");d=c.onlyEphox(d);0<d.length&&a.set(b,"class",d);a.remove(b,"style");a.hasNone(b)&&g(b)}),normal:function(b){a.remove(b,"data-ignore")},ignore:function(b){a.set(b,"data-ignore","true")}}});l("zm","84 b fg 2g 21 2r 2b".split(" "),function(d,e,c,a,b,f,g){var h=function(a,b){var c=g.children(a);e.each(c,function(a){h(a,
b)});b(a)},k=function(e){return b.isElement(e)&&!c.isEmptyTag(e)&&!c.isFrame(e)&&0===a.get(e).replace(d.zeroWidth(),"").length};return{wipeout:h,onEmpty:function(d){h(d,function(d){!b.isElement(d)||c.isFrame(d)||c.isEmptyTag(d)||0!==a.get(d).length?k(d)&&f.unwrap(d):f.remove(d)})},onQuasiEmpty:function(a){h(a,function(a){k(a)&&f.remove(a)})}}});l("uz","b 7 s zl fg v6 mo e9 mx my zm 2n 2p 3d 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t){var s=function(a){return t.parent(a).fold(e.constant([]),
function(a){return b.isBlock(a)?[a]:[a].concat(s(a))})},u=function(a,b){var c=[b].concat(s(b)),c=d.reverse(c),e=d.findIndex(c,a);return-1===e?b:0===e?c[0]:c[e-1]},v=function(a,b){d.each(b,function(b){k.cleanse(b,a);p.onQuasiEmpty(b)})};return{run:function(b,k,s,l){var A=g.left(s).getOrThunk(function(){return f.leftEdge(s.startContainer(),s.startOffset(),s.endContainer(),s.endOffset())}),D=g.right(s).getOrThunk(function(){return f.rightEdge(s.startContainer(),s.startOffset(),s.endContainer(),s.endOffset())}),
B=e.curry(u,l.matches);k=a.fractures(k,A.element(),A.offset(),D.element(),D.offset(),B);k=d.bind(k,function(a){var e;if(0<a.length){e=l.purifiers();var f=(0,l.nu)(b);m.ignore(f);c.from(a[0]).bind(t.prevSibling).each(p.onQuasiEmpty);c.from(a[a.length-1]).bind(t.nextSibling).each(p.onQuasiEmpty);d.each(a,p.onQuasiEmpty);a=d.filter(a,n.inBody);0<a.length?(r.before(a[0],f),q.append(f,a),v(e,a),e=[f]):e=[]}else e=[];return e});d.each(k,m.normal);return h.fussyFromElements(k)}}});l("mw",["b","1b","2b"],
function(d,e,c){var a=function(b,d){return e.eq(b,d)?[]:c.parent(b).fold(function(){return[]},function(e){e=a(e,d);var f=c.findIndex(b).toArray();return e.concat(f)})},b=function(a,b){return a.slice(b+1)},f=function(a,b){return a.slice(0,b)},g=function(a,b,e,f){if(0===f.length)b(e);else{var n=f[0],r=f.slice(1);c.child(e,n).each(function(c){g(a,b,c,r)});e=c.children(e);n=a(e,n);d.each(n,b)}};return{one:function(a,b){a(b)},across:function(e,k,m,p){m=a(m,k);p=a(p,k);k=c.children(k);var n=k.slice(0<m.length?
m[0]+1:0,0<p.length?p[0]:k.length-1);d.each(n,e);0<m.length&&g(b,e,k[m[0]],m.slice(1));0<p.length&&g(f,e,k[p[0]],p.slice(1))}}});l("ht",["6q","pq"],function(d,e){var c=d();return{split:function(a,b){return e.split(c,a,b)},splitByPair:function(a,b,d){return e.splitByPair(c,a,b,d)},range:function(a,b,d,g){return e.range(c,a,b,d,g)},subdivide:function(a,b){return e.subdivide(c,a,b)},position:function(a){return e.position(c,a)}}});l("v5","b ht v6 21 2b 9".split(" "),function(d,e,c,a,b,f){var g=function(c,
e,f){var g=b.children(e),h=0===f,k=f===g.length,m=0<g.length;return void 0!==c.empty&&d.contains(["br","hr","img"],a.name(e))?c.empty:void 0!==c.hasPrevious&&m&&0<f&&f<g.length?c.hasPrevious:void 0!==c.hasNext&&m&&f<g.length-1?c.hasNext:void 0!==c.rightEdge&&m&&k?c.rightEdge:void 0!==c.first&&h?c.first:c.otherwise},h=function(a,b,c){return g(a.before.element,b,c)(b,c)},k=function(a,b,c){return g(a.after.element,b,c)(b,c)},m=function(a,b,c){c=e.split(b,c);var d=function(a){return function(){var c=
f.prototype.slice.call(arguments,0),c=[b].concat(c);return a.apply(null,c)}};return e.position(c).fold(d(a.none),d(a.start),d(a.middle),d(a.end))},p=function(a,b,c){return m(a.before.text,b,c)},n=function(a,b,c){return m(a.after.text,b,c)};return{prefix:function(b,c,d){return(a.isText(c)?p:h)(b,c,d)},postfix:function(b,d,e,f,g){d=c.rightEdge(d,e,f,g);return(a.isText(d.element())?n:k)(b,d.element(),d.offset())}}});l("r1","7 ht v5 v6 1b 21 2b 9".split(" "),function(d,e,c,a,b,f,g,h){var k=function(a,
b){return a.bind(function(a){return b.map(function(b){return{left:d.constant(a),right:d.constant(b)}})})},m=function(a,b,c,d){b=e.splitByPair(b,c,d);return k(a.general.insertBefore(b),a.general.insertAfter(b))},p=function(a,b,c,d){c=g.child(b,c);var e=d<g.children(b).length?g.child(b,d):g.lastChild(b);return c.bind(function(b){return e.bind(function(c){return k(a.general.insertBefore(b),a.general.insertAfter(c))})})};return{both:function(d,e,g,h,s){if(b.eq(e,h)){var u=f.isText(e)?m:p;return g>s?u(d,
e,s,g):u(d,e,g,s)}u=a.leftEdge(e,g,h,s);e=c.postfix(d,e,g,h,s);d=c.prefix(d,u.element(),u.offset());return k(d,e)}}});l("v7","6q b 7 s fg 2v uh zm 1b 4l 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=f.immutable("inside","outside"),r=function(a){return p.parent(a).fold(c.constant(!0),function(a){return b.isBlock(a)||b.isContainer(a)})},q=function(b,f){var g=d(),h=[b].concat(g.up().all(b)),m=[f].concat(g.up().all(f)),g=e.find(h,function(a){return e.exists(m,c.curry(k.eq,a))});return a.from(g)},
t=function(b){return n(b.second(),a.some(b.first()))},s=function(b){return n(a.some(b.first()),b.second())},u=function(b,d){var e=r(b)?b:m.ancestor(b,r).getOr(b);k.eq(b,e)?e=n(a.some(b),a.none()):(e=g.breakPath(b,c.curry(k.eq,e)),e=d(e));return e};return{bridge:function(a,b){var d=u(a,t),e=u(b,s);return d.inside().bind(function(a){return e.inside().bind(function(b){return q(a,b).map(function(f){return{common:c.constant(f),left:c.constant(a),right:c.constant(b),wipeout:function(){d.outside().each(h.onEmpty);
e.outside().each(h.onEmpty)}}})})})}}});l("v8",["7","s","l","2p","2r"],function(d,e,c,a,b){return function(f,g){var h=function(a,f,g){var h=c.fromText(f);a(g,h);return e.some({element:d.constant(h),cleanup:function(){b.remove(h)},splits:d.constant([])})},k=function(b){return{none:e.none,start:d.curry(h,a.before,b),end:d.curry(h,a.after,b),middle:function(c,d,e){return h(a.after,b,d)}}},m=function(b){var c=function(b){return function(c,d){a.appendAt(c,d,b)}};return{prepend:d.curry(h,a.prepend,b),before:d.curry(h,
a.before,b),after:d.curry(h,a.after,b),insertAt:function(a,d){return h(c(d),b,a)},append:d.curry(h,a.append,b)}};return{before:{text:k(f),element:{hasPrevious:m(f).insertAt,first:m(f).prepend,empty:m(f).before,otherwise:m(f).append}},after:{text:k(g),element:{hasNext:m(g).insertAt,rightEdge:m(g).append,empty:m(g).after,otherwise:m(g).append}},general:{insertBefore:m(f).before,insertAfter:m(g).after}}}});l("mz","84 81 87 7 f9 ft 4t jg fg 2v r1 v7 v8".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){var q=
m.immutable("start","soffset","finish","foffset"),t=a.constant(!1),s=function(a){return k.isBlock(a)||k.isContainer(a)},u=function(a,d,k,m,p){var n=e.isCollapsed(d,k,m,p);d=f.toLeaf(d,k);m=f.toLeaf(m,p);var r=g.extractTo(d.element(),d.offset(),s,t),u=g.extractTo(m.element(),m.offset(),s,t),l=function(d){return n||d.offset()!==c.getEnd(d.element())?d:h.after(d.element(),a).map(function(a){return b.point(a,0)}).getOr(d)},F=function(d){return n||0!==d.offset()?d:h.before(d.element(),a).map(function(a){return b.point(a,
c.getEnd(a))}).getOr(d)};return function(){return g.find(r.element(),r.offset(),t).map(l).bind(function(a){return g.find(u.element(),u.offset(),t).map(F).map(function(b){return q(a.element(),a.offset(),b.element(),b.offset())})})}};return{applyTo:function(a,b,c,e,f,g){var h=u(a,c,e,f,g);a=r(d.zeroWidth(),d.zeroWidth());return p.both(a,c,e,f,g).bind(function(a){return n.bridge(a.left().element(),a.right().element()).bind(function(c){b(c.common(),c.left(),c.right());a.left().cleanup();a.right().cleanup();
c.wipeout();return h()})})}}});l("ec","7 mw mx my mz 1b".split(" "),function(d,e,c,a,b,f){return{doRemove:function(a,d,k){var m=function(a){c.cleanse(a,d)};return b.applyTo(a,function(a,b,c){if(f.eq(b,c))e.one(m,b);else e.across(m,a,b,c)},k.startContainer(),k.startOffset(),k.endContainer(),k.endOffset())},allRules:d.constant({b:a.unwrap,strong:a.unwrap,i:a.unwrap,em:a.unwrap,u:a.unwrap,strike:a.unwrap,del:a.unwrap,s:a.unwrap,sup:a.unwrap,sub:a.unwrap,small:d.noop,span:a.unstyle,font:a.unstyle})}});
l("mq","84 b 1o 87 7 s f9 jg mv e7 e9 uw ux uy uz my ec 1y l 2p 21 az".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v,w,l,x,z){return function(A,D,B,C){B=[D].concat(B);var F=b.curry(r.nuTag,D),E=b.curry(q.relatedTags,B),G=s.tagList(B),H=q.queriesTag(D),I={nu:F,matches:E,purifiers:b.constant(G)},K=function(a){var b=w.fromText(d.zeroWidth());k.atStartOf(a.startContainer(),a.startOffset(),b);return p.hare(b,0,b,1)},J=function(a,b,c){return x.isText(b)&&c===z.get(b).length?h.after(b,a).fold(function(){return g.point(b,
c)},function(a){return g.point(a,0)}):g.point(b,c)},L=function(b,c,d){return x.isText(c)&&0===d?h.before(c,b).fold(function(){return g.point(c,d)},function(b){return g.point(b,a.getEnd(b))}):g.point(c,d)},N=function(a,b){return b.map(function(b){var c=J(a,b.start(),b.soffset());b=L(a,b.finish(),b.foffset());return p.fussy(c.element(),c.offset(),b.element(),b.offset())})};B={nu:F,purifiers:b.constant(G),isStyled:b.constant(!0)};var M=["font-size"],O=function(a){return a.getSelection().map(function(a){var b=
c.keys(C),b=e.difference(b,M);return e.forall(b,function(b){return q.queryStyleOn(b,C[b],[D],a)})}).getOr(!1)};return{run:function(a,b){var c=b.doc();return n.detect(b,H.queryOn).fold(function(){return f.none()},function(b){b=K(b);u.doRemove(a,G,b);return f.some(p.fromHare(b))},function(a){a=K(a);var b=w.fromTag(D,c.dom());v.add(b,m.styleSpan());l.wrap(a.startContainer(),b);return f.some(p.fussy(a.startContainer(),1,a.startContainer(),1))},function(b){b=u.doRemove(a,G,b);return N(a,b)},function(c){return t.run(b.doc(),
a,c,I)})},query:function(a){return H.query(a)||O(a)},deferred:b.constant(B),name:b.constant(A)}}});l("zq",["b","s"],function(d,e){var c=function(a,b,c){return{groups:0<a.current.length?a.groups.concat({parent:a.parent,children:a.current}):a.groups,current:[c],parent:b}},a=function(a,b,c){return{groups:a.groups,current:a.current.concat([c]),parent:b}},b=function(b,d,h){return e.from(d.current[d.current.length-1]).bind(b.query().nextSibling).bind(function(c){return b.eq(c,h)?e.some(a):e.none()}).getOr(c)};
return{textnodes:function(a,c){var e=d.foldl(c,function(c,d){return a.property().parent(d).fold(function(){return c},function(e){return b(a,c,d)(c,e,d)})},{groups:[],current:[],parent:null});return 0<e.current.length?e.groups.concat({parent:e.parent,children:e.current}):e.groups}}});l("va","b s f9 pq zq ug".split(" "),function(d,e,c,a,b,f){var g=function(b,c,d,e,f,g){c=a.range(b,c,d,e,f);return h(b,c,g)},h=function(a,b,c){if(0===b.length)return b;b=d.filter(b,function(b){return a.property().isText(b)&&
0<a.property().getText(b).length});return d.map(b,function(b){var d=c();a.insert().before(b,d.element());d.wrap(b);return d.element()})},k=function(a,b){return e.from(b[0]).map(function(d){var e=f.toLower(a,b[b.length-1]);return c.points(c.point(d,0),c.point(e.element(),e.offset()))})};return{wrapWith:g,wrapper:h,leaves:function(a,b,c,d,e,h){b=f.toLeaf(a,b,c);d=f.toLeaf(a,d,e);h=g(a,b.element(),b.offset(),d.element(),d.offset(),h);return k(a,h)},reuse:function(c,e,g,h,k,t,s){e=f.toLeaf(c,e,g);h=f.toLeaf(c,
h,k);h=a.range(c,e.element(),e.offset(),h.element(),h.offset());h=b.textnodes(c,h);var u=function(a){return a.parent},v=function(a){var b=s();c.insert().before(a.children[0],b.element());d.each(a.children,b.wrap);return b.element()};return d.map(h,function(a){return(c.property().children(a.parent).length===a.children.length&&t(a.parent)?u:v)(a)})}}});l("vb",["7"],function(d){return function(e,c){return{element:d.constant(c),wrap:function(a){e.insert().append(c,a)}}}});l("v9","84 7 s f9 uv va vb".split(" "),
function(d,e,c,a,b,f,g){var h=function(b,d,f,g,h,k){b=m(b,d,f,g,h,k);d=b.cursor();d=a.points(a.point(d.element(),d.offset()),a.point(d.element(),d.offset()));return c.some({range:e.constant(d),temporary:b.temporary,wrappers:b.wrappers})},k=function(f,g,h,k,m){k=g.dom().ownerDocument;var p=f.create().nu("span",k);k=f.create().text(d.zeroWidth(),k);f.insert().append(p,k);(f.property().isEmptyTag(g)?f.property().parent(g):c.some(g)).each(function(a){b.atStartOf(f,a,h,p)});return{cursor:e.constant(a.point(k,
1)),wrappers:e.constant([p]),temporary:e.constant(!0)}},m=function(b,f,g,h,m,n){return b.property().parent(f).bind(function(h){var k=a.point(f,g),m;if(m=p(b,n,h))if(m=1===b.property().children(h).length)m=b.property().isText(f)&&b.property().getText(f)===d.zeroWidth();return m?c.some({cursor:e.constant(k),temporary:e.constant(!1),wrappers:e.constant([h])}):c.none()}).getOrThunk(function(){return k(b,f,g,h,m)})},p=function(a,b,c){return"span"===a.property().name(c)&&!1===b(c)},n=function(b,d,h,k,m,
n){var w=d.dom().ownerDocument,l=f.reuse(b,d,h,k,m,e.curry(p,b,n),function(){return g(b,b.create().nu("span",w))});return c.from(l[l.length-1]).map(function(c){var d=b.property().children(c).length;c=a.points(a.point(l[0],0),a.point(c,d));return{wrappers:e.constant(l),temporary:e.constant(!1),range:e.constant(c)}})};return{spans:function(a,b,c,d,f,g){g=void 0!==g?g:e.constant(!1);return(a.eq(b,d)&&c===f?h:n)(a,b,c,d,f,g)}}});l("pr",["v9","va","vb"],function(d,e,c){return{nu:function(a,b){return c(a,
b)},wrapWith:function(a,b,c,d,h,k){return e.wrapWith(a,b,c,d,h,k)},wrapper:function(a,b,c){return e.wrapper(a,b,c)},leaves:function(a,b,c,d,h,k){return e.leaves(a,b,c,d,h,k)},reuse:function(a,b,c,d,h,k,m){return e.reuse(a,b,c,d,h,k,m)},spans:function(a,b,c,e,h,k){return d.spans(a,b,c,e,h,k)}}});l("hu",["6q","pr"],function(d,e){var c=d();return{nu:function(a){return e.nu(c,a)},wrapWith:function(a,b,d,g,h){return e.wrapWith(c,a,b,d,g,h)},wrapper:function(a,b){return e.wrapper(c,a,b)},leaves:function(a,
b,d,g,h){return e.leaves(c,a,b,d,g,h)},reuse:function(a,b,d,g,h,k){return e.reuse(c,a,b,d,g,h,k)},spans:function(a,b,d,g,h){return e.spans(c,a,b,d,g,h)}}});l("n2","b f9 hu mo e7 4e 2o".split(" "),function(d,e,c,a,b,f,g){var h=function(g,h,k){g.getSelection().each(function(r){var q=a.left(r).getOrThunk(function(){return e.point(r.startContainer(),r.startOffset())}),t=a.right(r).getOrThunk(function(){return e.point(r.endContainer(),r.endOffset())});c.spans(q.element(),q.offset(),t.element(),t.offset(),
k).each(function(a){var c=a.temporary()?[b.styleSpan()]:[],e=a.range();d.each(a.wrappers(),function(a){f.add(a,c);h(a)});a=e.begin();e=e.end();g.setSelection(a.element(),a.offset(),e.element(),e.offset())})})},k=function(a,b,c,d){b(a);h(a,d,c)};return{style:function(a,b,c,d){return k(a,c,d,function(a){g.setAll(a,b)})},generic:k}});l("mr","7 s e7 hr n2 uw ux uy uz my ec 1a 1y 1b 2o 21 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u){return function(v,w,l,x,z,A){var D=d.curry(g.nu,x,z,w),
B=d.curry(h.relatedStyle,x,z,l),C=m.cssAndTag(l,x,z),F=h.queriesStyle(x,z,l),E=d.constant(!0),G=function(a,f){b.generic(a,d.noop,E,function(a){r.add(a,c.styleSpan());t.set(a,x,f);n.set(a,c.overrideSpan(),v);t.reflow(a)});return e.none()};w={nu:D,purifiers:d.constant(C),isStyled:function(b){return"span"===s.name(b)&&a.rawState(b,x,z)}};return{run:function(a,b){return f.detect(b,F.queryOn).fold(function(){return e.none()},function(a){return G(b,A)},function(a){return G(b,z)},function(b){return p.doRemove(a,
C,b)},function(c){return k.run(b.doc(),a,c,{nu:D,matches:B,purifiers:d.constant(C)})})},query:function(a){var b="["+c.overrideSpan()+'="'+v+'"]';return a.getSelection().bind(function(a){return u.closest(a.startContainer(),b).bind(function(c){return u.closest(a.endContainer(),b).bind(function(a){return q.eq(c,a)?t.getRaw(c,x).map(function(a){return a===z}):e.none()})})}).getOrThunk(function(){return F.query(a)})},deferred:d.constant(w),name:d.constant(v)}}});l("ms","7 s e7 n2 uw ux uy uz my ec 1a 1y 21 2r 32".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t){return function(s,u){var v=function(a,b){return f.nuAttr(u,a,b)},w=function(a){return"span"===r.name(a)&&p.has(a,u)},l={span:function(a){k.removeAttribute(a,u)}},x=function(a,b){return g.queryAttrIs(u,a,b)},z=function(b,f){a.generic(f,d.noop,void 0,function(a){n.add(a,c.styleSpan());p.set(a,u,b)});return e.none()};return{run:function(a,c,f){return b.detect(c,d.curry(x,f)).fold(function(){return e.none()},function(a){var b=["[",u,'="',f,'"]'].join("");t.closest(a.startContainer(),
b).each(q.unwrap);return e.none()},function(a){return z(f,c)},function(b){return m.doRemove(a,l,b)},function(b){return h.run(c.doc(),a,b,{nu:d.curry(v,f),matches:w,purifiers:d.constant(l)})})},queryValue:function(a){return g.queryAttrSame(u,a)},name:d.constant(s)}}});l("e4",["7","s","mq","mr","ms"],function(d,e,c,a,b){var f=a("bold","strong",["strong","b"],"font-weight","bold","normal"),g=a("italic","em",["em","i"],"font-style","italic","normal"),h=a("underline","span",["u"],"text-decoration","underline",
"none");a=a("strikethrough","span",["s","strike","del"],"text-decoration","line-through","none");b=b("language","lang");var k=c("superscript","sup",["sup","sub"],{"font-size":"smaller","vertical-align":"super"});c=c("subscript","sub",["sub","sup"],{"font-size":"smaller","vertical-align":"sub"});var m={bold:f,italic:g,underline:h,strikethrough:a,language:b,superscript:k,subscript:c};return{bold:d.constant(f),italic:d.constant(g),underline:d.constant(h),strikethrough:d.constant(a),language:d.constant(b),
superscript:d.constant(k),subscript:d.constant(c),search:function(a){return void 0!==m[a]?e.some(m[a]):e.none()}}});l("b2",["7","e4"],function(d,e){var c=function(a,b){return a.query(b)};return{bold:d.curry(c,e.bold()),italic:d.curry(c,e.italic()),underline:d.curry(c,e.underline()),strikethrough:d.curry(c,e.strikethrough()),superscript:d.curry(c,e.superscript()),subscript:d.curry(c,e.subscript()),language:d.curry(function(a,b){return a.queryValue(b)},e.language())}});l("7m",["7j","2v","b2"],function(d,
e,c){var a=e.immutable("bold","italic","underline","strikethrough","superscript","subscript"),b=function(a,b){return a.on(function(a){return b(a)?d.on(!0):d.off()}).getOrThunk(d.off)};return{read:function(d){return a(b(d,c.bold),b(d,c.italic),b(d,c.underline),b(d,c.strikethrough),b(d,c.superscript),b(d,c.subscript))}}});l("151",["2v"],function(d){return d.immutable("startContainer","startOffset","endContainer","endOffset")});l("15p",["2v"],function(d){var e=d.immutable("item","start","finish","text"),
c=d.immutable("items","abort"),a=function(a,b){var c=a.property().getText(b);return e(b,0,c.length,c)},b=function(a,b,d){return c([],!0)},f=function(a,b,d){return c([],!1)},g=function(a,b,d){var f=a.property().getText(b);return d(f).fold(function(){return c([e(b,0,f.length,f)],!1)},function(a){a=a[0]===a[1]?[]:[e(b,a[0],a[1],f.substring(a[0],a[1]))];return c(a,!0)})};return{detail:a,fromItem:function(b,c){return b.property().isText(c)?a(b,c):e(c,0,0,"")},decide:function(a,c,d,e){return(a.property().isBoundary(c)?
b:a.property().isEmptyTag(c)?b:e(a,c)?b:a.property().isText(c)?g:f)(a,c,d)}}});l("ps",["7"],function(d){return{all:function(e,c){for(var a=c.term(),b=[],f=a.exec(e);f;){var g=f.index+c.prefix(f),f=f[0].length-c.prefix(f)-c.suffix(f);b.push({start:d.constant(g),finish:d.constant(g+f)});a.lastIndex=g+f;f=a.exec(e)}return b}}});l("pt",["b","6","ps","9"],function(d,e,c,a){var b=function(b){b=a.prototype.slice.call(b,0);b.sort(function(a,b){return a.start()<b.start()?-1:b.start()<a.start()?1:0});return b};
return{search:function(a,g){var h=d.bind(g,function(b){var g=c.all(a,b.pattern());return d.map(g,function(a){return e.merge(b,{start:a.start,finish:a.finish})})});return b(h)}}});l("hw",["ps","pt"],function(d,e){return{findall:function(c,a){return d.all(c,a)},findmany:function(c,a){return e.search(c,a)}}});l("10b",["7","s","6o","hw","6p"],function(d,e,c,a,b){var f=new b(c.wordbreak()+"+","g"),g=d.constant(0),h=function(b){b=a.findall(b,c.custom(c.wordbreak(),g,g,e.none()));return e.from(b[b.length-
1]).map(function(a){return a.start()})},k=function(a){a=a.search(f);return-1<a?e.some(a):e.none()};return{firstWord:function(a){return k(a).map(function(b){return a.substring(0,b+1)})},lastWord:function(a){return h(a).map(function(b){return a.substring(b)})},leftBreak:h,rightBreak:k,hasBreak:function(a){return k(a).isSome()}}});l("16d",["is","10b"],function(d,e){var c=d.walkers(),a=c.left(),c=c.right();return{left:{sibling:a.sibling,first:a.first,slicer:function(a){return e.leftBreak(a).map(function(c){return[c+
1,a.length]})}},right:{sibling:c.sibling,first:c.first,slicer:function(a){return e.rightBreak(a).map(function(a){return[0,a]})}}}});l("15v",["b","is","15p","16d"],function(d,e,c,a){var b=function(a,g,h,k,m){g=e.walk(a,g,h,k).map(function(d){var e=c.decide(a,d.item(),k.slicer,m);d=e.abort()?[]:b(a,d.item(),d.mode(),k,m);return e.items().concat(d)}).getOr([]);return d.filter(g,function(a){return 0<a.text().trim().length})};return{creepLeft:function(c,d,h){return b(c,d,e.sidestep,a.left,h)},creepRight:function(c,
d,h){return b(c,d,e.sidestep,a.right,h)},flatten:function(a,b){return a.property().isText(b)?[c.detail(a,b)]:d.map(a.down().predicate(b,a.property().isText),function(b){return c.detail(a,b)})},isEmpty:function(a,b){return a.property().isText(b)?!1:0===a.down().predicate(b,a.property().isText).length}}});l("15q",["7","s"],function(d,e){var c=function(a,b){return a.up().closest(b,"[lang]",d.constant(!1)).map(function(b){return a.attrs().get(b,"lang")})};return{nu:function(a){var b=[],c=[],g=[],h=a,
k=function(a){a.each(function(a){b.push(a)})},m=function(a){a.each(function(a){b=b.slice(0,b.length-1)})},p=function(){0<g.length&&c.push({lang:d.constant(h),details:d.constant(g)})},n=function(a){p();g=[];h=a},r=function(c){return c.or(e.from(b[b.length-1])).getOr(a)};return{openInline:function(a,b){var c=r(a);c!==h&&n(c);k(a)},closeInline:function(a,b){m(a)},addDetail:function(a){var b=r(e.none());b!==h&&n(b);g.push(a)},addEmpty:function(a){a=r(e.none());n(a)},openBoundary:function(a,b){k(a);var c=
r(a);n(c)},closeBoundary:function(a,b){m(a);var c=r(a);n(c)},done:function(){p();return c.slice(0)}}},calculate:c,softBounder:function(a){return function(b,d){var g=c(b,d);return!e.equals(a,g)}},strictBounder:function(a,b){return function(d,e){var h=c(d,e).getOr(a);return b!==h}}}});l("152",["b","7","15v","15p","15q"],function(d,e,c,a,b){var f=function(b,d,f,m){var p=c.creepLeft(b,d,m);m=c.creepRight(b,f,m);d=0<p.length?p[p.length-1]:a.fromItem(b,d);b=0<m.length?m[m.length-1]:a.fromItem(b,f);p=0===
p.length&&0===m.length;return{left:e.constant(d),right:e.constant(b),isEmpty:e.constant(p)}};return{byBoundary:function(a,b){var d=e.constant(!1),d=f(a,b,b,d),m=d.isEmpty()&&c.isEmpty(a,b);return{left:d.left,right:d.right,isEmpty:e.constant(m)}},getEdges:f,byLanguage:function(f,h){var k=b.calculate(f,h),m=b.softBounder(k),p=c.creepLeft(f,h,m),m=c.creepRight(f,h,m),n=f.property().isText(h)?[a.detail(f,h)]:[],r=d.reverse(p).concat(n).concat(m);return{all:e.constant(r),left:e.constant(p),middle:e.constant(n),
right:e.constant(m),lang:e.constant(k)}}}});l("12m","84 b 7 s 151 152".split(" "),function(d,e,c,a,b,f){var g=function(a,b,g,p){p=a.property().getText(b);var n=e.filter(p.substring(0,g),function(a){return a!==d.zeroWidth()}).length,r=e.filter(p.substring(g,p.length),function(a){return a===d.zeroWidth()}).length;a=f.byLanguage(a,b);b=0===n&&0===a.left().length;g=g+r===p.length&&0===a.right().length;return{all:a.all,leftEdge:c.constant(b),rightEdge:c.constant(g),text:c.constant(p)}};return{before:function(c,
d,e,f,n){c=g(c,d,e,n);c.rightEdge()?d=a.none():(c=c.all(),0===c.length?d=a.none():(c=c[c.length-1],d=a.some(b(d,f,c.item(),c.finish()))));return d},after:function(c,d,e,f,n){c=g(c,d,e,n);c.leftEdge()?d=a.none():(c=c.all(),0===c.length?d=a.none():(c=c[0],d=a.some(b(c.item(),c.start(),d,f))));return d},both:function(c,d,e,f,g,r){return f===g?a.none():a.some(b(d,f,d,g))},neither:function(c,d,e,f){c=g(c,d,e,f);c.leftEdge()||c.rightEdge()?c=a.none():(d=c.all(),0===d.length?c=a.none():(c=d[0],d=d[d.length-
1],c=a.some(b(c.item(),c.start(),d.item(),d.finish()))));return c}}});l("153",["2v"],function(d){return d.immutable("before","after")});l("12n",["s","153","10b"],function(d,e,c){return{around:function(a,b){var f=a.substring(0,b),g=c.leftBreak(f).map(function(a){return a+1}),f=a.substring(b),f=c.rightBreak(f).map(function(a){return b+a}),h=e(g,f),k=e(d.some(b),d.some(b));return f.bind(function(a){return b===a?d.some(k):d.none()}).getOrThunk(function(){return g.bind(function(a){return b===a?d.some(k):
d.none()}).getOr(h)})}}});l("zr",["s","12m","12n"],function(d,e,c){return{word:function(a,b,f,g){if(!a.property().isText(b))return d.none();var h=a.property().getText(b),k=c.around(h,f);return k.before().fold(function(){return k.after().fold(function(){return e.neither(a,b,f,g)},function(c){return e.after(a,b,f,c,g)})},function(c){return k.after().fold(function(){return e.before(a,b,f,c,g)},function(d){return e.both(a,b,f,c,d,g)})})}}});l("vc",["zr"],function(d){return{word:function(e,c,a,b){return d.word(e,
c,a,b)}}});l("mu",["6q","vc"],function(d,e){var c=d();return{word:function(a,b,d){return e.word(c,a,b,d)}}});l("e8",["81","7","mu"],function(d,e,c){var a=function(a,d,g){c.word(d,g,e.constant(!1)).each(function(c){a.setSelection(c.startContainer(),c.startOffset(),c.endContainer(),c.endOffset())})};return{expand:function(b){b.getSelection().each(function(c){d.isCollapsed(c.startContainer(),c.startOffset(),c.endContainer(),c.endOffset())&&a(b,c.startContainer(),c.startOffset())})},expandWord:a}});l("eb",
"84 87 s e7 e9 e4 ec 1a 2n 1y 1b 2p 3d 21 2r 32 m az 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v,w){var l=function(a,c){var d=b.fussy(c,0,c,w.children(c).length-1);A(a,c,d)},x=function(a){a=w.children(a);return 1===a.length&&q.isText(a[0])&&v.get(a[0])===d.zeroWidth()},z=function(b,c){return s.closest(b,"."+a.styleSpan()).bind(function(b){return s.closest(c,"."+a.styleSpan()).filter(function(a){return p.eq(b,a)})})},A=function(b,d,e){m.remove(d,a.styleSpan());return h.has(d,a.overrideSpan())?
D(b,d,e):c.some(e)},D=function(a,d,e){return B(d).bind(function(f){if(f.isStyled(d)){f=f.nu;var g=w.owner(d),g=f(g);n.before(d,g);r.append(g,w.children(d));t.remove(d);f=p.eq(d,e.start())?g:e.start();g=p.eq(d,e.finish())?g:e.finish();f=c.some(b.fussy(f,e.soffset(),g,e.foffset()))}else f=C(a,d,f.purifiers(),e);return f})},B=function(b){b=h.get(b,a.overrideSpan());return f.search(b).map(function(a){return a.deferred()})},C=function(d,e,f,h){e=w.owner(e);var m=b.fromFussy(h);g.doRemove(d,f,m);d="["+
a.overrideSpan()+"]";return u.one(d,e).bind(function(a){t.unwrap(a);return k.inBody(h.start())&&k.inBody(h.finish())?c.some(h):c.none()})};return{clean:function(a,b){x(b)?t.unwrap(b):l(a,b)},cleanNonEmpty:l,isTransient:x,withinTransient:z,handleOverride:D,apply:function(a,d,f,g,h){var k=b.fussy(d,f,g,h);return z(d,g).bind(function(d){if(x(d)){var f=w.children(d),f=p.eq(d,k.start())?b.fussy(f[0],0,f[0],e.getEnd(f[0])):k;t.unwrap(d);d=c.some(f)}else d=A(a,d,k);return d})}}});l("ea","87 s mv e8 e9 eb ec 2p 2r 2b".split(" "),
function(d,e,c,a,b,f,g,h,k,m){var p=function(a,b){return a.action().run(a.isRoot(),a.environment())};return{override:function(a,c){var g=a.temp();f.handleOverride(a.isRoot(),g,b.fussy(g,0,g,d.getEnd(g)));return e.some(c)},insertAfter:function(a,b){h.after(a.temp(),a.cursor());return e.some(b)},insertBefore:function(a,b){h.before(a.temp(),a.cursor());return e.some(b)},insertAt:function(a,b){var d=a.original();c.atStartOf(d.startContainer(),d.startOffset(),a.cursor());return e.some(b)},apply:p,applyIfOffCursor:function(a,
c){var d=a.action().deferred().isStyled(a.temp()),f=a.cursor(),g=e.some(b.fussy(f,1,f,1));d?d=g:(a.environment().setSelection(f,0,f,0),d=p(a,c));return d},clearCursor:function(a,c){var d=a.cursor(),f=a.action().deferred();g.doRemove(a.isRoot(),f.purifiers(),b.hare(d,0,d,1));return e.some(b.fussy(d,1,d,1))},applyOverCursor:function(a,c){var d=a.cursor();a.environment().setSelection(d,0,d,1);p(a,c);return e.some(b.fussy(d,1,d,1))},regrab:function(c,d){var e=c.environment(),f=c.original();e.setSelection(f.startContainer(),
f.startOffset(),f.endContainer(),f.endOffset());a.expand(e);return e.getSelection().map(b.fromHare)},clearSelection:function(a,c){var d=a.action().deferred();return g.doRemove(a.isRoot(),d.purifiers(),b.fromFussy(c))},applyIfOffRange:function(a,b){var c;a.action().deferred().isStyled(a.temp())?c=e.some(b):(a.environment().setSelection(b.start(),b.soffset(),b.finish(),b.foffset()),c=p(a,b));return c},unwrap:function(a,c){var f=a.temp(),g=m.children(f);k.unwrap(f);return 0===g.length?e.none():e.some(b.fussy(g[0],
0,g[g.length-1],d.getEnd(g[g.length-1])))}}});l("7n","84 b e5 87 7 s 2v e6 e7 e8 e9 e4 ea eb ec 1a 1b l".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v){var w=g.immutable("environment","isRoot","cursor","temp","action","original"),l=function(d,e){return c.lastCursor(d).fold(b.constant(!0),function(b){return u.eq(b,e.startContainer())&&a.getEnd(b)===e.startOffset()})},x=function(a,d){return c.firstCursor(a).fold(b.constant(!0),function(a){return u.eq(a,d.startContainer())&&0===d.startOffset()})},
z=function(a,b,c,g,h){var m=s.get(g,k.overrideSpan()),n=h.collapsed(),t=v.fromText(d.zeroWidth()),u=l(g,h),z=x(g,h),m=a.name()===m,J=w(c,b,t,g,a,h);a=m&&q.isTransient(g)?[r.unwrap]:n&&m&&u?[r.insertAfter,r.override,r.applyIfOffCursor]:n&&m&&z?[r.insertBefore,r.override,r.applyIfOffCursor]:n&&m?[r.insertAt,r.override,r.clearCursor]:n&&u?[r.insertAt,r.override,r.applyOverCursor]:n&&z?[r.insertBefore,r.override,r.applyOverCursor]:n?[r.insertAt,r.override,r.applyOverCursor]:m?[r.override,r.regrab,r.clearSelection,
r.applyIfOffRange]:[r.override,r.regrab,r.apply];return e.foldl(a,function(a,b){return a.bind(function(a){return b(J,a)})},f.some(p.fromHare(h)))};g=function(a,b,c){m.expand(c);var d=c.getSelection().bind(function(d){return q.withinTransient(d.startContainer(),d.endContainer()).filter(function(a){return s.has(a,k.overrideSpan())}).fold(function(){return a.run(b,c)},function(e){return z(a,b,c,e,d)})});return h.inlineFrom(d)};return{bold:b.curry(g,n.bold()),italic:b.curry(g,n.italic()),underline:b.curry(g,
n.underline()),strikethrough:b.curry(g,n.strikethrough()),superscript:b.curry(g,n.superscript()),subscript:b.curry(g,n.subscript()),removeformat:function(a,b){m.expand(b);var c=b.getSelection().bind(function(b){var c=t.allRules();return t.doRemove(a,c,b)});return h.inlineFrom(c)},language:b.curry(function(a,b,c,d){c.getSelection().each(function(a){q.apply(b,a.startContainer(),a.startOffset(),a.endContainer(),a.endOffset()).each(function(a){c.setSelection(a.start(),a.soffset(),a.finish(),a.foffset())})});
m.expand(c);a=a.run(b,c,d);return h.inlineFrom(a)},n.language()),cleanup:q.clean,cleanupNonEmpty:q.cleanNonEmpty,isTransient:q.isTransient,withinTransient:q.withinTransient}});l("5e","7 7k 7l 7b 7m 71 7c 7j 59 4a 7n".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){return function(n){var r=n.content(),q=n.shortcuts(),t=n.undo(),s=m.create({analytics:k(["message","properties"])}),u=function(a,c){var e=b.read(r);(void 0!==e[a]?e[a]():h.unchanged()).fold(c.deselect,d.noop,c.select)},v=function(a){var b=function(b){return a(r.isRoot,
b)};return function(){c.cata(n.selections().get(),d.noop,e.multiple(r,t,b),e.single(r,t,b));r.uiChanged()}},w=v(p.bold),l=v(p.italic),x=v(p.underline),z=v(p.strikethrough),A=v(p.subscript),D=v(p.superscript),v=v(p.removeformat);q.events.bold.bind(w);q.events.italic.bind(l);q.events.underline.bind(x);return{ui:f.ui({"bold.general":{toggle:!0,value:"bold",textkey:a.key("action.bold"),action:w,updateGeneral:d.curry(u,"bold"),icon:!0,tooltip:g.get},"italic.general":{toggle:!0,value:"italic",textkey:a.key("action.italic"),
action:l,updateGeneral:d.curry(u,"italic"),icon:!0,tooltip:g.get},"underline.general":{toggle:!0,value:"underline",textkey:a.key("action.underline"),action:x,updateGeneral:d.curry(u,"underline"),icon:!0,tooltip:g.get},"strikethrough.general":{toggle:!0,value:"strikethrough",textkey:a.key("action.strikethrough"),action:z,updateGeneral:d.curry(u,"strikethrough"),icon:!0,tooltip:g.get},"removeformat.general":{toggle:!1,value:"removeformat",textkey:a.key("action.removeformat"),action:v,updateGeneral:d.identity,
icon:!0,tooltip:g.get},"subscript.general":{toggle:!0,value:"subscript",textkey:a.key("action.subscript"),action:A,updateGeneral:d.curry(u,"subscript"),icon:!0,tooltip:g.get},"superscript.general":{toggle:!0,value:"superscript",textkey:a.key("action.superscript"),action:D,updateGeneral:d.curry(u,"superscript"),icon:!0,tooltip:g.get}}),events:s.registry,destroy:d.noop}}});l("ed",["b","dn"],function(d,e){return{multiple:function(c,a,b,f){return function(g,h){e.runTransaction(c,a,function(){d.each(h,
b)},f)}},single:function(c,a,b,d){return function(g,h){e.runTransaction(c,a,function(){b(h)},d)}}}});l("n0",["mb"],function(d){var e=function(a,b,c){c=a.create().nu(c);var d=a.property().children(b);a.insert().append(b,c);a.insert().appendAll(c,d);return c},c=function(a,b,c){c=a.create().nu(c);var d=a.property().children(b);a.attrs().copyTo(b,c);a.insert().before(b,c);a.insert().appendAll(c,d);a.remove().remove(b);return c};return{blockTransform:function(a,b,f){return(d.isFormatting(a,b)?c:e)(a,b,
f)},nest:e,replace:c}});l("n1",["7"],function(d){return{tags:d.constant("address article aside audio blockquote canvas dd div dl fieldset figcaption figure footer form h1 h2 h3 h4 h5 h6 header hgroup hr li noscript ol output p pre section table tbody td tfoot th thead tr ul video".split(" "))}});l("ep",["b","7","s","n1"],function(d,e,c,a){return function(b){var f=function(a,f,k,m){var p=k.join(",");a=b.up().closest(a,p,m);f=b.up().closest(f,p,m);return a.isSome()&&f.isSome()?(m=a.getOrDie("Just checked it was some."),
f=f.getOrDie("Just checked it was some."),b.eq(m,f)?(k=d.find(k,e.curry(b.is,m)),k=void 0!==k&&null!==k?c.some(k):c.none()):k=c.none(),k):c.none()};return{query:function(b,c,d){c=c.concat(a.tags());return f(b.startContainer(),b.endContainer(),c,d)},queryAll:f}}});l("ee","6q b n0 em mj ep".split(" "),function(d,e,c,a,b,f){var g=d(),h=f(g);return{query:function(a,b,c){return h.query(a,b,c)},apply:function(f,g,h,n,r,q){return a.applyOn(f,b,g,h,n,r,function(a){return e.map(a,function(a){return c.blockTransform(d(),
a,q)})})}}});l("ef",["n2","e8","1a","1y"],function(d,e,c,a){return{background:function(a,c,g){d.style(a,{"background-color":c},e.expand,g)},addClass:function(b,c,g){d.generic(b,e.expand,g,function(b){a.add(b,c)})},foreground:function(a,c,g){d.style(a,{color:c},e.expand,g)},addAttribute:function(a){return function(f,g,h){d.generic(f,e.expand,h,function(d){c.set(d,a,g)})}},face:function(a,c,g){d.style(a,{"font-family":c},e.expand,g)},size:function(a,c,g){d.style(a,{"font-size":c},e.expand,g)}}});l("7o",
"b 7 s dn do ed dq dr 7l 7w ee ef 1a 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q){var t=function(a,d,e,f,m){d=function(b,c,d,f){return a(e.isRoot,b,c,d,f)};var p=b.multiple(e,f,d),n=b.single(e,f,d,h.spot,g.update);return k.cata(m.get(),c.none,function(a,b){return c.some(p(a,b))},function(a,b){return c.some(n(a,b))})};return{transform:function(a,b,c,d,e){return t(function(a,b,c,d,f){return p.apply(a,b,c,d,f,e)},a,b,c,d)},setClass:function(b,c,f,g,h,m){var p=function(b){q.closest(b,h).each(function(b){a.runTransaction(c,
f,function(){r.set(b,"class",m)},c.toEditing)})};k.cata(g.get(),e.noop,function(a,b){d.each(a,p)},function(a,b){p(a.startContainer())})},inline:function(a,b,c,d,g){a=function(a){n.addClass(a,g,m.isAnnotation)};k.cata(d.get(),e.noop,f.multiple(b,c,a,b.toEditing),f.single(b,c,a,b.toEditing))},list:function(a,b,c,d,e){return t(a,b,c,d,e)}}});l("7p","b 6 s 7b 2v 6u".split(" "),function(d,e,c,a,b,f){var g=b.immutable("label","items"),h=function(b,d){return 0<d.length?[g(c.some(a.key(b)),d)]:[]};return{groups:function(a,
b,p){var n=a.divisions(),r=d.map(n.blocks().concat(n.classblocks()),a.toCandidate),q=d.map(n.inlines(),a.toCandidate);a=d.map(n.objects(),a.toCandidate);a=d.foldr(a,function(a,c){var g;f.closest(b,c.base(),p)?(g=c.base(),g=d.contains(["a"],g)?e.merge(a,{link:a.link.concat([c])}):d.contains(["embed","img","object"],g)?e.merge(a,{media:a.media.concat([c])}):d.contains(["hr"],g)?e.merge(a,{line:a.line.concat([c])}):d.contains(["li","ol","ul"],g)?e.merge(a,{list:a.list.concat([c])}):d.contains(["table",
"tr","td","th"],g)?e.merge(a,{table:a.table.concat([c])}):a):g=a;return g},{link:[],media:[],line:[],list:[],table:[]});return d.flatten([[g(c.none(),r)],h("block.label.inline",q),h("block.label.link",a.link),h("block.label.media",a.media),h("block.label.line",a.line),h("block.label.list",a.list),h("block.label.table",a.table)])}}});l("7r",[],function(){var d=function(d,c){return{fold:c}};return{inline:function(e,c,a){return d("inline",function(b,d,g,h){return b(e,c,a)})},object:function(e,c,a,b){return d("object",
function(d,g,h,k){return g(e,c,a,b)})},block:function(e,c,a){return d("block",function(b,d,g,h){return g(e,c,a)})},classblock:function(e,c,a,b){return d("classed block",function(d,g,h,k){return k(e,c,a,b)})},cata:function(d,c,a,b,f){return d.fold(c,a,b,f)}}});l("eg","b 7 s p 7r 7b".split(" "),function(d,e,c,a,b,f){var g="h1 h2 h3 h4 h5 h6 div p pre".split(" "),h="a embed hr img li object ol table td tr ul th".split(" "),k=function(a){var b=a.indexOf("."),d;-1<b?(d=a.substring(0,b),a=a.substring(b+
1),d=-1===a.indexOf(".")?c.some({tag:e.constant(d),clazz:e.constant(a)}):c.none()):d=c.none();return d},m=function(c,e){var f=c.tag(),k=c.clazz(),m=d.contains(g,f),p=d.contains(h,f);return(m?a.value(b.classblock):p?a.value(b.object):a.error("Rule must have object tag or block tag.")).map(function(a){var b=r(e,c,m);return a(f,k,b,e.style)})},p=function(a){return a.text.getOrThunk(function(){return f.key("block."+a.name)})},n=function(a,b){return a.text.getOrThunk(function(){return f.pkey("tag.inline.class",
[b])})},r=function(a,b,c){return a.text.getOrThunk(function(){var a=(c?"block":"tag")+"."+b.tag(),a=(f.has(a)?f.translate(a):b.tag())+" ("+b.clazz()+")";return f.raw(a)})};return{decipher:function(c){return k(c.name).fold(function(){return d.contains(g,c.name)?a.value(b.block(c.name,p(c),c.style)):a.error("Invalid style name: "+c.name)},function(d){return 0<d.tag().length?m(d,c):a.value(b.inline(d.clazz(),n(c,d.clazz()),c.style))})}}});l("7q","b 1o 7 s eg 7r 7b 2v".split(" "),function(d,e,c,a,b,f,
g,h){return function(k){var m=h.immutable("base","value","textkey","icon","styles","tag");k=d.map(k.styles,function(b){return{name:b.rule,text:a.from(b.text).map(g.raw),style:void 0===b.style?{}:b.style}});var p={};d.each(k,function(a){b.decipher(a).each(function(b){p[a.name]=b})});k=c.constant(!0);var n=c.constant(!1),r=function(a,b,c,d){return function(e){return f.cata(e,a,b,c,d)}},q=e.values(p),t=d.filter(q,r(n,n,n,k)),s=d.filter(q,r(n,n,k,n)),u=d.filter(q,r(n,k,n,n)),v=d.filter(q,r(k,n,n,n));
k=function(){var a=t.concat(u).concat(s).concat(v);return d.map(a,function(a){return f.cata(a,function(a,b,c){return"."+a},function(a,b,c,d){return a+"."+b},function(a,b,c){return a},function(a,b,c,d){return a+"."+b})})}();var w=function(b){return void 0!==p[b]?a.some(p[b]):a.none()},l=function(b){return f.cata(b,function(b,c,d){return m("span","."+b,c,a.none(),d,"span")},function(b,c,d,e){return m(b,b+"."+c,d,a.none(),e,"span")},function(b,c,d){return m(b,b,c,a.none(),d,b)},function(b,c,d,e){return m(b,
b+"."+c,d,a.none(),e,b)})},n=function(){var a=e.values(p);return d.map(a,l)}();return{candidateByName:function(a){return w(a).map(l)},toCandidate:l,ruleByName:w,divisions:function(){return{classblocks:c.constant(t),blocks:c.constant(s),objects:c.constant(u),inlines:c.constant(v)}},backup:function(b){return m(b,b,g.key("block."+b),a.none(),{},"span")},selectors:c.constant(k),everything:c.constant(n)}}});l("ei",["7","7b"],function(d,e){return{text:function(c){var a=e.get(c.textkey()),b=e.cata(c.textkey(),
d.constant(!0),d.constant(!1),d.constant(!1));c=b&&void 0===a?c.value():a;return{text:d.constant(c),unknown:d.constant(b)}}}});l("7s","53 eh ei 7b 34 1y 4e 2o l 2p".split(" "),function(d,e,c,a,b,f,g,h,k,m){return{format:function(c){var e=k.fromText(a.get(c.textkey())),g=d.div();f.add(g,b.resolve("format-element-"+c.tag()));h.setAll(g,c.styles());c=d.div();f.add(c,b.resolve("format-element-container"));m.append(g,e);m.append(c,g);return c},face:function(a){var d=c.text(a),f=d.text(),f=e(f).element();
h.setAll(f,{"font-family":a.value()});a=d.unknown()?[b.resolve("font-face-unknown")]:[];g.add(f,a);return f}}});l("n3","8b fh am 53 7 s 7b 34 7j 59 4a 1a 1y 2o 3y l 2p 2r".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v){var w=function(b,c){var e=s.fromTag(b);d.hidden(e,!0);q.set(e,"list-style-type",c);for(var f=h.resolve("list-style-content"),g=0;3>g;g++){var k=s.fromTag("li"),m=a.span();r.add(m,f);u.append(k,m);u.append(e,k)}return e},l=function(b,c){var d=g.translate(c),e=s.fromText(d),
f=a.span();r.add(f,h.resolve("list-style-default"));n.set(b,"data-"+h.resolve("list-style"),"default");n.set(b,"title",d);u.append(f,e);return f};return function(a,q,A){var D=A(void 0===q||"default"===q?f.none():f.some(q)),B=s.fromTag("div");r.add(B,h.resolve("list-style-option"));A=void 0===q||"default"===q?l(B,"ul"===a?"list.unordered.default":"list.ordered.default"):w(a,q);u.append(B,A);a=g.translate(("ul"===a?"list.unordered.":"list.ordered.")+q);n.set(B,"title",a);d.label(B,a);d.menuItemCheckbox(B);
var C=c.describe(B,g.translate("aria.widget.navigation"));u.append(B,C);var F=p.create({action:m(["type","element"])}),E=function(){e.checked(B,!0);r.add(B,h.resolve("list-style-selected"))},G=function(){e.checked(B,!1);r.remove(B,h.resolve("list-style-selected"))},H=t.bind(B,"click",function(a){F.trigger.action(D,f.some(B))});return{element:b.constant(B),instance:D,style:q,update:function(a){(D.query(a)&&D.queryStyle(a)?k.on(!0):k.off()).fold(G,b.noop,E)},select:E,deselect:G,events:F.registry,destroy:function(){H.unbind();
v.remove(B);v.remove(C)}}}});l("ej","b gt 8y 53 7 s n3 34 59 4a 1a 1y 2p 2r 32 1s".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s){var u="data-"+h.resolve("list-style");return function(v,w,l){var x=m.create({action:k(["type"])}),z=a.div();n.add(z,h.resolve("list-style-palette"));var A=d.map(v,function(a){return g("bullist"===w?"ul":"ol",a,l)});d.each(A,function(a){a.events.action.bind(function(a){a.element().each(C);x.trigger.action(a.type())});r.append(z,a.element())});var D=function(){var a=
s.floor(A.length/4)+(0<A.length%4?1:0);return c.grid(z,{cell:b.constant("."+h.resolve("list-style-option"))},a,4,e.grid({trigger:function(a){a.dom().click();return f.some(a)}}))}(),B=function(a){a=d.find(A,a);return f.from(a)},C=function(a){t.sibling(a,"["+u+'="default"]').filter(function(b){return b!==a}).bind(function(b){p.remove(b,u);p.set(a,u,"default")})};return{enter:D.enter,element:b.constant(z),update:function(a){d.each(A,function(b){b.update(a)})},events:x.registry,destroy:function(a){D.isFocused()&&
D.exit();D.destroy();d.each(A,function(a){a.destroy()});q.remove(z)},findDefault:function(){return B(function(a){return p.has(a.element(),u)}).map(function(a){return a.instance})}}}});l("7t","c an 7 dm 7o ej 7c 7j 59 4a 2z 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){return function(r){var q=r.region(),t=r.content(),s=r.undo(),u=r.keyboard(),v=r.listConstructor(),w=r.type(),l=r.styles(),x=r.textkey(),z=r.menuTextkey(),A=v("default"),D=d.detect(),B=u.all();B.swallowKeys([e.ESCAPE()]);var C=m.create({abort:k([]),
done:k([]),close:k([]),analytics:k(["message"])});B.events.escape.bind(function(a){C.trigger.abort()});var F=function(c,d){var e=b.list(function(b,e,f,g,h){return c.apply(b,e,f,g,h,a(q),d)},q,t,s,r.selections());C.trigger.done();t.focus();return e},E=function(){n.descendant(G.element(),'[data-ephox-polish-list-style="default"]').each(function(a){p.focus(a)})},G=f(l,w,v);G.events.action.bind(function(a){F(a.type(),!1)});return{action:function(){var a=G.findDefault().getOr(A);F(a,!0)},element:G.element,
shortcut:!1,textkey:c.constant(x),menuTextkey:c.constant(z),label:c.constant(!1),name:c.constant(w),tooltip:g.get,toggle:!0,value:w,updateWidget:function(a){t.getSelection().each(function(b){var d=A.query(b)?h.on(!0):h.off();d.fold(a.deselect,c.noop,a.select);d.fold(a.release,c.noop,a.press);G.update(b)})},open:function(){D.deviceType.isTouch()||E();B.on()},close:function(){B.off();C.trigger.close()},icon:!0,events:C.registry,enter:G.enter,destroy:function(){B.off();B.destroy();G.destroy()}}}});l("n4",
["6","4q"],function(d,e){var c=e.generate([{mine:["element"]},{other:["element"]},{paragraphs:["elements"]}]);return d.merge(c,{cata:function(a,b,c,d){return a.fold(b,c,d)}})});l("n5","b s fg n4 2o 21 2b".split(" "),function(d,e,c,a,b,f,g){var h=function(a,c,d){var e=f.name(a);return b.getRaw(a,"list-style-type").fold(function(){return e===c&&d.isNone()},function(a){return d.exists(function(b){return e===c&&a===b})})};return{categorise:function(b,e,f){b=d.groupBy(b,function(a){return c.isList(a)?
!0:g.parent(a).map(function(a){return a.dom()}).getOr(!1)});return d.bind(b,function(b){return d.forall(b,c.isList)?d.map(b,function(b){return h(b,e,f)?a.mine(b):a.other(b)}):[a.paragraphs(b)]})}}});l("ek","b e5 87 7 s dw n0 n4 n5 1a 2o l 2p 3d 21 69 4h".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u){return function(v,w,l){var x=function(a){if("p"===t.name(a))return g.replace(v,a,"li");var b=n.fromTag("li");r.before(a,b);r.append(b,a);return b},z=function(a){var c=n.fromTag(w);l.each(function(a){p.set(c,
"list-style-type",a)});r.before(a[0],c);q.append(c,a);b.from(m.get(a[0],"dir")).each(function(a){m.set(c,"dir",a)});return c},A=function(a){var b=s.mutate(a,w);l.fold(function(){p.remove(b,"list-style-type")},function(a){p.set(b,"list-style-type",a)});return b},D=function(b){var c=a.constant(!0),d=a.constant(!1);return b.fold(c,d,d)},B=function(a,d){return function(g){return h.cata(g,function(g){var h=u.descendants(g,"li");return 0<h.length?(g=h[0],h=h[h.length-1],g=e.firstCursor(g).getOr(g),h=e.lastCursor(h).getOr(h),
f.outdent(a,g,0,h,c.getEnd(h),d).map(function(a){return a.all()})):b.none()},b.none,b.none).getOr([])}},C=function(a){return h.cata(a,function(a){return[a]},function(a){return[A(a)]},function(a){a=d.map(a,x);z(a);return a})};return{apply:function(a,b,c){c=k.categorise(c,w,l);a=d.forall(c,D)?B(a,b):C;return d.bind(c,a)}}}});l("el","6q b 7 s fg n6 n7 n8 21 32".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=function(a){return g.cata(a,function(a){return h.wrap(a)},function(a){return[a]},function(a,c){return b.isList(a)?
[a]:e.bind(c,p)},function(a){return h.wrap([a])})};return{isRootContainer:function(a){return function(c){return a(c)||b.isContainer(c)&&"li"!==k.name(c)}},extract:p,isCapable:b.isBlock,canUse:c.constant(!1),quasi:function(){return a.some(f.nu(d()))},ascend:function(a,b){return m.closest(a,"ol,ul",b).getOr(a)}}});l("en","mh n9 na 2o l 21".split(" "),function(d,e,c,a,b,f){var g=function(c,e,f){var g=b.fromTag(e);f.each(function(b){a.set(g,"list-style-type",b)});return d.list(c,g)};return{hasSameType:function(a,
b){return f.name(a)===b},hasSameStyle:function(b,c){var d=a.getRaw(b,"list-style-type");return c.fold(function(){return d.isNone()},function(a){return d.is(a)})},convertOr:function(a,b,c,d,e){return function(f){return d(f.list(),a)&&e(f.list(),b)?c(f):g(f,a,b)}},topContext:function(a,b,d){return c.context(a,b,c.topmost,e.groupWrite,d)},context:function(a,b,d){return c.context(a,b,c.immediate,e.groupWrite,d)},unapply:function(a){return d.level(a,-1*a.level())}}});l("7x","6q b 7 s ek el em en eo ep 2o 21 32".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,r){var q=d(),t=m(q),s=function(b){b=e.map(b,function(a){return r.ancestor(a,"ul,ol")});var c=e.map(b,function(a){return a.fold(function(){return"-"},function(a){return n.name(a)+"-"+p.get(a,"list-style-type")})}),d=c[0];return e.forall(c.slice(1),function(a){return a===d})?b[0]:a.none()};d=function(a,d,e){var m=b(q,a,e),p=function(a,b,c,d,e,h){return g.applyOn(a,f,b,c,d,e,function(b){return m.apply(a,h,b)})},n=function(b,c,d){b=b.selected();return 0<b.length&&s(b).map(function(b){return c(b,
a)&&d(b,e)}).getOr(!1)};return{query:function(b){return t.queryAll(b.startContainer(),b.endContainer(),["ul","ol"],d).exists(function(b){return b===a})},queryStyle:function(a){var b=e.fold(function(){return":not([style])"},function(a){return'[style*="list-style-type: '+a+';"]'});return q.up().closest(a.startContainer(),"ol, ul",d).exists(function(c){return q.up().closest(a.endContainer(),"ol, ul",d).exists(function(a){return c.dom()===a.dom()?q.is(c,b):!1})})},apply:function(b,d,f,g,m,r,q){var s=
q?c.constant(!0):h.hasSameStyle,t=function(){return p(b,d,f,g,m,r)},v=function(b,c){return k.executeUsing(b,d,f,g,m,function(){return h.convertOr(a,e,c,h.hasSameType,s)})},l=function(){return h.topContext(d,g,b).fold(t,function(a){return v(a,h.unapply)})};return h.context(d,g,b).fold(t,function(a){return n(a,h.hasSameType,s)?l():v(a,c.identity)})}}};return{unordered:c.curry(d,"ul"),ordered:c.curry(d,"ol")}});l("7u","7 s dm 7o 7b 7c 7j 7x".split(" "),function(d,e,c,a,b,f,g,h){var k=function(h,k,m,
q){return function(m){var r=q(m.content().isRoot,e.none());return{toggle:!0,value:h,textkey:b.key(k),icon:!0,tooltip:f.get,updateGeneral:function(a){m.content().getSelection().each(function(b){(r.query(b)?g.on(!0):g.off()).fold(a.deselect,d.noop,a.select)})},action:function(){a.list(function(a,b,d,e,f){return r.apply(a,b,d,e,f,c(m.region()))},m.region(),m.content(),m.undo(),m.selections());m.content().focus()}}}},m=k("bullist","action.bullist","ul",h.unordered);return{ol:k("numlist","action.numlist",
"ol",h.ordered),ul:m}});l("7v",["b","7j","2v","ee"],function(d,e,c,a){var b=c.immutable("tag"),f=function(a,b){return d.contains(["label","li","td","th","normal"],b)?e.on(a.backup(b)):e.off()},g=function(b,c,d){return a.query(b,c.selectors(),d).fold(function(){return b.collapsed()?f(c,"normal"):e.off()},function(a){return c.candidateByName(a).map(e.on).getOrThunk(function(){return f(c,a)})})};return{read:function(a,c){var d=a.getSelection().fold(function(){return e.off()},function(b){return g(b,c,
a.isRoot)});return b(d)}}});l("5f","b c 7 s 7o 7l 7p 7q 7r 7f 7s 7t 7u 7b 7v 7w 71 7c 59 4a 2v 7x 1a 2o 32 q 3x".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v,w,l,x,z,A,D,B,C,F){var E=e.detect();return function(e,C){var I=l.create({analytics:w(["message"])}),K=h(C),J=e.region(),L=e.content(),N=e.undo(),M=a.some(p.format),O=L.isRoot,S=function(a){E.deviceType.isiOS()&&d.each(d.groupBy(d.filter(d.map(a,function(a){return B.ancestor(a,"ul,ol",O).getOr(!1)}),c.identity),function(a){return a.dom()}),
function(a){var b=D.get(a[0],"list-style-type");D.set(a[0],"list-style-type","none");F(function(){D.set(a[0],"list-style-type",b)},0)})},P=function(){return f.cata(e.selections().get(),c.constant([]),function(a){return 0<a.length?g.groups(K,a[0]):[]},function(a,b){return g.groups(K,a.startContainer(),O)})},T=function(b){var c=s.hasSelection(L),d=t.read(L,K),e=P();b.populate(e);m.updateMenu(b,d.tag(),c.content(),K.everything(),a.none())},Q=function(a){K.ruleByName(a).each(function(a){k.cata(a,function(a,
c,d){b.inline(J,L,N,e.selections(),a)},function(a,c,d,f){b.setClass(J,L,N,e.selections(),a,c)},function(a,c,f){b.transform(J,L,N,e.selections(),a).each(function(a){d.each(a,function(a){A.remove(a,"class")});S(a)})},function(a,c,f,g){b.transform(J,L,N,e.selections(),a).each(function(a){d.each(a,function(a){A.set(a,"class",c)});S(a)})});L.uiChanged()})},V=x.immutableBag("region content undo selections keyboard listConstructor type styles textkey menuTextkey".split(" "),[]),W=V({region:J,content:L,undo:N,
selections:e.selections(),keyboard:e.keyboard(),listConstructor:c.curry(z.unordered,O),type:"bullist",styles:["default","disc","circle","square"],textkey:q.key("action.bullist"),menuTextkey:q.key("list.unordered.menu")}),V=V({region:J,content:L,undo:N,selections:e.selections(),keyboard:e.keyboard(),listConstructor:c.curry(z.ordered,O),type:"numlist",styles:"default decimal upper-alpha lower-alpha upper-roman lower-roman lower-greek".split(" "),textkey:q.key("action.numlist"),menuTextkey:q.key("list.ordered.menu")}),
$=function(a){return q.translate("block.describe",q.get(a.textkey()))},W=c.curry(n,W),V=c.curry(n,V);return{ui:u.ui({"blocktag.dropdown":function(){return{name:"blocktag",textkey:q.key("block.styles"),menuTextkey:q.key("block.menu"),updateDropdown:T,action:Q,values:K.everything(),render:M,tooltip:v.get,toggle:!1,describe:$}},"bullist.widget":W,"numlist.widget":V,"bullist.general":c.constant(r.ul(e)),"numlist.general":c.constant(r.ol(e))},c.identity),events:I.registry,destroy:c.noop}}});l("nb","b 7 fg mi n7 ov n8 21".split(" "),
function(d,e,c,a,b,f,g,h){var k=["li"],m=function(a,c){return b.cata(a,function(a){return!0===c?[]:g.wrap(a)},function(a){return[a]},function(a,b){return"table"===h.name(a)?[a]:g.handleContainer(k,a,b,m)},function(a){return!0===c?[]:g.wrap([a])})};return{isRootContainer:a.isRootOrContainer,extract:function(a){return m(a,!1)},isCapable:function(a){return f.isBlock(a)||d.contains(k,h.name(a))},canUse:function(a){return c.isFormatting(a)||d.contains(k,h.name(a))},quasi:e.curry(g.handleRoot,k),ascend:e.identity}});
l("nc",["1a"],function(d){return function(e,c){return{is:function(a){return d.get(a,e)===c},remove:function(a){d.remove(a,e)},set:function(a){d.set(a,e,c)}}}});l("eq","b 7 m9 nb em nc 2o bs 32".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(a,b){return k.closest(b,'[dir="rtl"],[dir="ltr"]').filter(a).isSome()},p=function(k,p,n){var s=f(p,n),u=function(a){s.set(a);g.reflow(a)},v=function(a){return h.getDirection(a)===n};return{run:function(c,e,f,g,h){return b.applyOn(c,a,e,f,g,h,function(a){d.each(a,
u);return a})},query:function(a,b){return c.bothMatch(a,b,e.curry(m,v))},name:e.constant(k)}},n=p("DirRtl","dir","rtl"),p=p("DirLtr","dir","ltr");return{dirLtr:e.constant(p),dirRtl:e.constant(n)}});l("7y","7 dp dq dr 7l eq 3x".split(" "),function(d,e,c,a,b,f,g){var h=function(f){return function(h){var p=function(a,b,c,d){return f.run(h.content().isRoot,a,b,c,d)};b.cata(h.selections().get(),d.noop,e.multiple(h.content(),h.undo(),p),e.single(h.content(),h.undo(),p,a.spot,c.update));g(function(){h.content().uiChanged()},
0)}};return{dirRtl:h(f.dirRtl()),dirLtr:h(f.dirLtr())}});l("7z",["7j","2v","eq","32"],function(d,e,c,a){var b=e.immutable("ltrdir","rtldir"),f=function(a,b){return b.query(a.startContainer(),a.endContainer())?d.on(!0):d.off()},g=function(b){return a.closest(b.startContainer(),"[dir]").isSome()||a.closest(b.endContainer(),"[dir]").isSome()};return{readDir:function(a){return a.getSelection().filter(g).map(function(a){return b(f(a,c.dirLtr()),f(a,c.dirRtl()))})}}});l("5g","7 7y 7b 7z 71 7j 59 4a".split(" "),
function(d,e,c,a,b,f,g,h){return function(k){var m=k.content(),p=h.create({analytics:g(["message","properties"])}),n=function(b,c){a.readDir(m).map(function(a){return a[b]}).fold(f.unchanged,d.apply).fold(c.deselect,d.noop,c.select)};return{ui:b.ui({"ltrdir.general":{value:"ltrdir",textkey:c.key("directionality.ltrdir"),action:d.curry(e.dirLtr,k),updateGeneral:d.curry(n,"ltrdir"),toggle:!0},"rtldir.general":{value:"rtldir",textkey:c.key("directionality.rtldir"),action:d.curry(e.dirRtl,k),updateGeneral:d.curry(n,
"rtldir"),toggle:!0}}),events:p.registry,destroy:d.noop}}});l("vd",["e5","7","s","2b"],function(d,e,c,a){var b=function(a,b,c){a=a.createRange();a.selectNode(b.dom());a.collapse(c);return a},f=function(c,f,g){var p=c.createRange();p.selectNode(f.dom());var p=p.getBoundingClientRect(),n=g-p.left<p.right-g;g=n?a.firstChild:a.lastChild;return(n?d.firstCursor:d.lastCursor)(f).orThunk(e.curry(g,f)).map(function(a){return b(c,a,n)})},g=function(a,d,e){var f=d.dom().getBoundingClientRect();return c.some(b(a,
d,e-f.left<f.right-e))};return{search:function(b,c,d){return(0===a.children(c).length?g:f)(b,c,d)}}});l("zs",["1s"],function(d){return{inRect:function(d,c,a){return c>=d.left&&c<=d.right&&a>=d.top&&a<=d.bottom},searchForPoint:function(e,c,a,b,f){if(0===f)return 0;if(c===b)return f-1;for(var g=1;g<f;g++){var h=e(g),k=d.abs(c-h.left);if(!(a>h.bottom)){if(a<h.top||k>b)return g-1;b=k}}return 0}}});l("ve","zs s k 2v 21 az 2b 1s".split(" "),function(d,e,c,a,b,f,g,h){var k=a.immutable("node","doc","x","y",
"fullrect"),m=function(a){var b=function(b){var c=a.doc().createRange();c.setStart(a.node().dom(),b);c.collapse(!0);return c},c=f.get(a.node()).length,e=a.x(),g=a.y(),h=a.fullrect().right,c=d.searchForPoint(function(a){return b(a).getBoundingClientRect()},e,g,h,c);return b(c)},p=function(a,b,f,g){var h=a.createRange();h.selectNode(b.dom());h=h.getClientRects();return c.findMap(h,function(a){return d.inRect(a,f,g)?e.some(a):e.none()}).map(function(c){return k(b,a,f,g,c)})},n=function(a,f,h,k){if(b.isText(f))return p(a,
f,h,k);var m=a.createRange();f=g.children(f);return c.findMap(f,function(b){m.selectNode(b.dom());return d.inRect(m.getBoundingClientRect(),h,k)?n(a,b,h,k):e.none()})};return{search:function(a,b,c,d){var e=a.createRange();e.selectNode(b.dom());e=e.getBoundingClientRect();c=h.max(e.left,h.min(e.right,c));d=h.max(e.top,h.min(e.bottom,d));return n(a,b,c,d).map(m)}}});l("nd","vd ve s l 21 2b".split(" "),function(d,e,c,a,b,f){return{searchForRange:function(g,h,k){return c.from(g.elementFromPoint(h,k)).map(a.fromDom).map(function(c){return"html"===
b.name(c)?a.fromDom(g.body):c}).bind(function(a){var b=function(){return d.search(g,a,h)};return 0===f.children(a).length?b():e.search(g,a,h,k).orThunk(b)})}}});l("er",["es","nd","s","q"],function(d,e,c,a){var b=function(a,b,d){return c.from(a.caretPositionFromPoint(b,d)).bind(function(b){if(null===b.offsetNode)return c.none();var d=a.createRange();d.setStart(b.offsetNode,b.offset);d.collapse();return c.some(d)})},f=function(a,b,d){return c.from(a.caretRangeFromPoint(b,d))},g=a.caretPositionFromPoint?
b:a.caretRangeFromPoint?f:e.searchForRange;return{find:function(a,b,c){return g(a.document,b,c).map(d.writeFromNative)}}});l("80",["er"],function(d){return{find:d.find}});l("gq",["6","4q"],function(d,e){var c=e.generate([{blob:["id","blob","objurl","data"]},{url:["id","url","raw"]}]);return d.merge(c,{cata:function(a,b,c){return a.fold(b,c)}})});l("ne",["2j"],function(d){return function(){return new (d.getOrDie("FileReader"))}});l("h5",["2j"],function(d){return{createObjectURL:function(e){return d.getOrDie("URL").createObjectURL(e)},
revokeObjectURL:function(e){d.getOrDie("URL").revokeObjectURL(e)}}});l("ey","b 30 c gq 3w ne h5 1a".split(" "),function(d,e,c,a,b,f,g,h){c=c.detect();var k=function(a){var b=g.createObjectURL(a);return m(a,b)},m=function(c,d){return b.nu(function(b){var g=f();g.onload=function(f){var g=e.generate("image");f=a.blob(g,c,d,f.target);b(f)};g.readAsDataURL(c)})},p=function(a){return 1===a.length&&d.contains(a,"Files")},n=function(a){return!d.contains(a,"text/_moz_htmlcontext")},r=function(a){return d.contains(a,
"Files")},q=function(a){return!0};return{multiple:function(a){return 0===a.length?b.pure([]):b.mapM(a,k)},toFiles:function(a){return a.raw().target.files||a.raw().dataTransfer.files},isFiles:c.browser.isChrome()||c.browser.isSafari()||c.browser.isOpera()?r:c.browser.isFirefox()?n:c.browser.isIE()?p:q,fromImages:function(c){c=d.map(c,function(b){var c=e.generate("image");return a.url(c,h.get(b,"src"),b)});return b.pure(c)},single:k,singleWithUrl:m}});l("ex","b ey 59 4a 1y 3y".split(" "),function(d,
e,c,a,b,f){return{register:function(g,h,k){var m=a.create({dragover:c(["original"]),dragleave:c(["original"]),drop:c(["original"]),dragndropimages:c(["original","files"]),dragndrophtml:c(["original"])});h.each(function(a){var c=function(b){return function(){b(g,a)}};m.registry.dragover.bind(c(b.add));m.registry.dragleave.bind(c(b.remove));m.registry.drop.bind(c(b.remove))});var p=f.bind(g,"dragover",function(a){!0===k?(a.prevent(),m.trigger.dragover(a)):a.kill()}),n=f.bind(g,"dragleave",m.trigger.dragleave),
r=f.bind(g,"drop",function(a){m.trigger.drop(a);a.kill();if(e.isFiles(a.raw().dataTransfer.types)){var b=e.toFiles(a);m.trigger.dragndropimages(a,b)}else d.contains(a.raw().dataTransfer.types,"text/html")&&m.trigger.dragndrophtml(a)});return{destroy:function(){p.unbind();n.unbind();r.unbind()},events:m.registry}}}});l("82",["ex","ey","59","4a"],function(d,e,c,a){return{forImages:function(b,f,g){b=d.register(b,f,g);var h=a.create({dragover:c(["original"]),dragleave:c(["original"]),drop:c(["original"]),
dragndropimages:c(["assets","x","y"]),dragndrophtml:c(["html","x","y"])});f=function(a,b){a.bind(function(a){b(a.original())})};b.events.dragndropimages.bind(function(a){var b=a.original();e.multiple(a.files()).get(function(a){h.trigger.dragndropimages(a,b.x(),b.y())})});b.events.dragndrophtml.bind(function(a){a=a.original();var b=a.raw().dataTransfer.getData("text/html");h.trigger.dragndrophtml(b,a.x(),a.y())});f(b.events.dragover,h.trigger.dragover);f(b.events.dragleave,h.trigger.dragleave);f(b.events.drop,
h.trigger.drop);return{destroy:b.destroy,events:h.registry}}}});l("nf",["4j"],function(d){return{resolve:d.create("ephox-arcade").resolve}});l("ez",["nf","b","1a","21"],function(d,e,c,a){var b="data-"+d.resolve("no-merge"),f="data-"+d.resolve("atomic");return{doNotMerge:function(d){a.isElement(d)&&c.set(d,b,"true")},shouldMerge:function(d){return a.isElement(d)&&!1===c.has(d,b)},setAtomic:function(b){a.isElement(b)&&c.set(b,f,"true")},isAtomic:function(b){return a.isElement(b)&&"true"===c.get(b,f)},
clear:function(d){a.isElement(d)&&e.each([b,f],function(a){c.remove(d,a)})}}});l("vf",["7","s","l","2p","2b"],function(d,e,c,a,b){return{addAfter:function(f){return function(g,h){var k=h.all(),m=f(g,h);e.from(k[k.length-1]).each(function(e){b.nextSibling(e).fold(function(){var b=c.fromTag("p");a.append(b,c.fromTag("br"));a.after(e,b)},d.noop)});return m}}}});l("r2",["7"],function(d){return function(e,c,a,b){return{context:e,profile:c,action:a,label:d.constant(b)}}});l("zt","b zh ui l 2p 21 2r 4h 2b".split(" "),
function(d,e,c,a,b,f,g,h,k){var m=function(e){var f=k.owner(e);e=h.descendants(e,"td,th");d.each(e,function(d){c.needsCursor(d).each(function(c){b.append(d,a.fromTag("br",f.dom()))})})},p=function(a){c.vacate(a);c.needsCursor(a).each(function(b){g.remove(a)})};return{populate:function(b){c.vacate(b);c.needsCursor(b).each(function(b){var c=a.fromTag("span");e.forceAddBr(b,c)})},purge:function(a){("table"===f.name(a)?m:p)(a)}}});l("vm",["b","fg","zt","2b"],function(d,e,c,a){var b=function(a,b){var e=
f(a),e=d.filter(e,b);d.each(e,c.purge)},f=function(b){var c=function(a){return[a]},d=a.prevSibling(b).map(c).getOr([]),c=a.nextSibling(b).map(c).getOr([]);return d.concat([b]).concat(c)};return{purge:function(a){b(a,e.isBlock)},purgeBy:b}});l("vn","vm b fg 2o 21 6m 4h az 2b".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(a){d.purgeBy(a,function(a){var d=c.isBlock(a)||"li"===b.name(a)||"ol"===b.name(a)||"ul"===b.name(a);if("li"===b.name(a)){var e;if(!(e=0===g.descendants(a,"ul,ol").length)){e=
g.descendants(a,"ul,ol,li");var h=g.descendants(a,"*");a=f.descendants(a,b.isText);e=e.length===h.length&&0===a.length}a=e}else a=!0;return d&&a})};return{purge:m,purgeAll:function(a){var b=g.descendants(a,"ol,ul,li");e.each([a].concat(b),m)},nesting:function(c){c=("li"===b.name(c)?[c]:[]).concat(g.descendants(c,"li"));e.each(c,function(c){var d=k.children(c);e.exists(d,function(a){return b.isText(a)?0<h.get(a).length:!e.contains(["ol","ul"],b.name(a))})||a.set(c,"list-style-type","none")})}}});l("zv",
"84 7 s l 2p 2r 2b".split(" "),function(d,e,c,a,b,f,g){var h=function(b,g){var h=a.fromText(d.zeroWidth());b(g,h);return c.some({element:e.constant(h),cleanup:function(){f.remove(h)},splits:e.constant([])})},k=function(a,b){return a.map(function(a){return{element:e.constant(a),cleanup:e.noop,splits:e.constant(void 0!==b?b:[])}})},m=function(a,c){return h(b.before,a)},p=function(a,c){return h(b.after,a)},n=function(a,c){return h(b.append,a)},r=function(a,c){return h(b.prepend,a)},q=function(a,b){return function(d,
e){return a(d,e).fold(function(){return b(d,e)},c.some)}},t=function(a,b,d){return k(c.some(b),void 0!==b&&void 0!==d?[{first:b.dom(),second:d.dom()}]:[])};return{before:{text:{none:c.none,start:q(function(a,b){return k(g.prevSibling(a))},m),middle:t,end:t},element:{hasPrevious:function(a,b){return k(g.child(a,b-1))},rightEdge:n,first:r,empty:m,otherwise:r}},after:{text:{none:c.none,start:t,middle:function(a,b,d){return k(c.some(d),void 0!==b&&void 0!==d?[{first:b.dom(),second:d.dom()}]:[])},end:q(function(a,
b){return k(g.nextSibling(a))},p)},element:{hasNext:function(a,b){return k(g.child(a,b+1))},rightEdge:n,first:r,empty:p,otherwise:n}}}});l("w9",["7","v5","zv","9"],function(d,e,c,a){return{prefix:d.curry(e.prefix,c),postfix:d.curry(e.postfix,c)}});l("10d","7 s o8 vs 2p 38 2r 69".split(" "),function(d,e,c,a,b,f,g,h){var k=function(b){return!f.descendant(b,function(b){return a.hasCursor(b,["hr","img"])})},m=function(a){var c=h.shallowAs(a,"p");b.before(a,c);g.remove(a);return e.some(c)};return{cleanup:function(a){var b=
a.second(),b=(c.isHeading(b)&&k(b)?m(b):e.none()).getOr(a.second());return{first:a.first,second:d.constant(b),mark:a.mark,splits:a.splits}}}});l("w7","84 b 9o e5 87 7 s mv fg zh w9 uh ui 10d zi o8 1b l 2p 21 az 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,v,w,l,x,z){var A=function(a){return l.isElement(a)&&k.isInline(a)&&0===z.children(a).length},D=function(a){var b=v.fromText(d.zeroWidth());w.append(a,b);return b},B=function(a,b,c){return p.prefix(b,c).bind(function(b){var c=n.breakPath(b.element(),
s.stopAt(a));return c.second().map(function(d){return{first:f.constant(a),second:f.constant(d),mark:f.constant(b),splits:f.constant(c.splits().concat(b.splits()))}})})};return{soft:function(d,e,m){var p=function(a){var c;l.isText(a)?(c=x.get(a),c=-1===c.indexOf("\u00a0")&&0===c.trim().length):c=!1;return c?z.nextSibling(a).forall(p):!b.isStart(d,e)&&k.isBlock(a)},n=v.fromTag("br");h.atStartOf(d,e,n);z.nextSibling(n).fold(function(){return b.getEnd(d)===e&&s.findBlock(d,m).bind(a.lastCursor).fold(f.constant(!1),
function(a){var b="br"===l.name(a)?n:d;return u.eq(b,a)})},p)&&w.after(n,v.fromTag("br"));return g.some({start:f.constant(c.after(n)),finish:f.constant(c.after(n))})},hard:function(a,b,d,g,h){return B(a,b,d).map(q.cleanup).map(function(a){e.each([g.getOr(a.first()),a.second()],function(b){r.postprocess(b,a.mark().element(),h)});s.findValidHardBreak(a.second(),h).orThunk(function(){m.rootBr(a.second(),a.mark().element())});var b=t.plunge(a.second(),f.constant(!1)),b=A(b)?D(b):b;a.mark().cleanup();
return{start:f.constant(c.on(b,0)),finish:f.constant(c.on(b,0))}})},rupture:B}});l("w6",["9o","7","s","l","2p"],function(d,e,c,a,b){var f=function(a,b,d){return c.some({start:e.constant(a(b,d)),finish:e.constant(a(b,d))})};return{doubleBr:function(c){b.after(c,a.fromTag("br"));var e=a.fromTag("br");b.after(c,e);return f(d.after,e,0)},emptyParagraph:function(c){var e=a.fromTag("p"),k=a.fromTag("br");b.append(e,k);b.after(c,e);return f(d.on,k,0)}}});l("12o",[],function(){return{box:function(d){return[d]}}});
l("10e",["7","12o","o8"],function(d,e,c){return{processes:function(a){return{stopper:c.stopAt(a),wrapper:e.box,post:d.noop}}}});l("10f","b s 12o o8 3d 21 2r 2b".split(" "),function(d,e,c,a,b,f,g,h){var k=function(a,c,d){e.from(d[d.length-1]).each(function(a){b.append(a,m(h.children(c)));g.empty(c)})},m=function(b){return d.filter(b,function(b){return!(f.isElement(b)&&a.isList(b)&&0===h.children(b).length)})};return{processes:function(b){return{stopper:a.stopAt(b),wrapper:c.box,post:k}}}});l("10g",
"b 7 fg zh ui o8 1a 2o l 2p 3d 21 38 2r 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t){var s=function(a,b){q.remove(a);return b},u=function(c,d){var e=k.fromTag("p");p.append(e,d);m.before(c,e);q.remove(c);b.needsCursor(e).each(function(b){a.forceAddBr(b,k.fromTag("span"))});return[e]},v=function(a){var b=t.children(a),b=(r.descendant(a,c.isFormatting)?s:u)(a,b);d.each(b,function(b){n.isElement(b)&&(g.transfer(a,b,["dir"]),h.transfer(a,b,["text-align"]))});return b};return{processes:function(a){return{stopper:f.stopAt(a),
wrapper:v,post:e.noop}}}});l("w8","b 9o 7 uh ui 10e 10f 10g 3d 21 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){return{exit:function(n,r){return p.ancestor(n,"ol,ul",r).bind(function(q){var t=p.ancestor(q,"li,ol,ul",r).fold(function(){return h.processes(q)},function(a){return"li"===m.name(a)?g.processes(a):f.processes(q)}),s=a.breakPath(n,t.stopper);return s.second().map(function(a){var f=s.first(),g=t.wrapper(n);k.before(a,g);t.post(f,a,g);d.each([f,a],b.lists);return{start:c.constant(e.on(g[0],
0)),finish:c.constant(e.on(g[0],0))}})})}}});l("o7","s w6 w7 w8 o8 32".split(" "),function(d,e,c,a,b,f){var g=function(e,g,m,p){return f.closest(g,"li",p).fold(function(){return c.hard(e,g,m,d.none(),p)},function(e){e=b.exitList(e)?a.exit(e,p):c.hard(e,g,m,d.some(e),p);return e})};return{hard:function(a,f,m){return b.findValidHardBreak(a,m).fold(function(){return b.findAnchorBreak(a,m).fold(function(){return c.soft(a,f,m)},function(g){return!0===b.isRightEdge(g,a,f)?e.doubleBr(g):c.hard(g,a,f,d.none(),
m)})},function(b){return g(b,a,f,m)})},soft:c.soft,rupture:c.rupture}});l("wa",["2v"],function(d){return d.immutable("cursor","blocks")});l("o9","b 9o 7 s w9 ui w7 o8 wa v6 1b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=function(a,d,f,g){return b.postfix(a,d,f,g).map(function(b){var h=m.leftEdge(a,d,f,g);m.makeTo(h.element(),h.offset(),b.element()).deleteContents();return{start:c.constant(e.before(b.element())),finish:c.constant(e.before(b.element())),mark:b.element}})},r=function(a,b,c,d){return n(a,
b,c,d).bind(function(a){return g.soft(a.mark(),0)})},q=function(b,c,d,e,f){return n(b,c,d,e).bind(function(b){return h.findValidHardBreak(b.mark(),f).bind(function(c){return g.hard(c,b.mark(),0,a.none(),f)})})},t=function(a,b){d.each(a,function(a){f.postprocess(a,b)})};return{soft:r,hard:function(a,b,d,e,f){var g=h.findValidHardBreak(a,f),m=h.findValidHardBreak(d,f),l=g.fold(function(){var c=r(a,b,d,e);return k(c,[])},function(c){return m.fold(function(){var f=r(a,b,d,e);return k(f,[c])},function(g){var h=
p.eq(c,g)?q(a,b,d,e,f):n(a,b,d,e);return k(h,[c,g])})});return l.cursor().map(function(a){var b=l.blocks(),d;d=a.start().fold(c.identity,c.identity,c.identity);t(b,d);return a})},rupture:function(a,b,c,d,e){return n(a,b,c,d).bind(function(a){return h.findValidHardBreak(a.mark(),e).bind(function(b){return g.rupture(b,a.mark(),0)})})}}});l("zu","w9 w7 o7 o8 o9 q".split(" "),function(d,e,c,a,b,f){return{point:function(a,b,d){return c.rupture(a,b,d)},range:function(a,c,d,e,f){return b.rupture(a,c,d,e,
f)},ruptureUntil:function(b,c,k,m,p,n){var r=d.postfix(b,c,k,m);return function(b,c){return a.findValidHardBreak(b,p).map(n).bind(function(a){return e.rupture(a,b,c)})}(b,c).bind(function(a){return r.map(function(b){var c=f.createRange();c.setStartAfter(a.first().dom());c.setEndBefore(b.element().dom());c.deleteContents();b.cleanup();a.mark().cleanup();return a.first()})})}}});l("vg","vm vn b s mv zu 3d 2b".split(" "),function(d,e,c,a,b,f,g,h){var k=function(c,d,e){if(0<c.length){var f=c[0],h=c.slice(1);
b.atStartOf(d,e,f);g.after(f,h);return a.some(c[c.length-1])}return a.none()};return{split:function(b,k,n){var r=void 0===n?d.purge:n;return f.point(b.block(),b.element(),b.offset()).bind(function(b){var d=k.all();g.before(b.second(),d);b.mark().cleanup();r(b.first());r(b.second());c.each([b.first(),b.second()],e.nesting);b=c.reverse(d);b=c.find(b,function(a){return h.parent(a).isSome()});return a.from(b)})},merge:function(a,b){var c=h.children(b.single());return k(c,a.element(),a.offset())},nest:function(a,
b){return k(b.all(),a.element(),a.offset())},insertMany:k,insertChildren:function(a,b){var c=h.children(a);return k(c,b.element(),b.offset())},fallback:function(a,b,c){return k(c,b.startContainer(),b.startOffset())}}});l("vi",["b","7","s","32"],function(d,e,c,a){return{lists:function(b){return d.foldr(b,function(b,c){return b.bind(function(b){return a.closest(c,"ol,ul").map(function(a){return[a].concat(b)})})},c.some([])).map(function(a){return{all:e.constant(a)}})},from:function(a){return{all:e.constant(a)}}}});
l("vj","6 e5 7 s fg 2v 1b 21 4l 32 az 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var r=f.immutable("left","right"),q=function(a){return b.isFormatting(a)||b.isContainer(a)},t=function(a,b,c,d){return k.closest(c,a,b)},s=function(a){return function(b,c,d){return a(b,c.element(),c.offset()).bind(function(c){return a(b,d.element(),d.offset()).map(function(a){return r(c,a)})})}},u=function(a){var b=s(a);return function(a,c,d){return b(a,c,d).filter(function(a){return g.eq(a.left(),a.right())})}};
return{inline:function(b,c,d){return k.closest(c,q,b).fold(function(){return a.some(c)},function(d){return b(d)?a.some(c):a.none()})},formatter:c.curry(t,b.isFormatting),container:function(a,d,e){return k.closest(d,b.isContainer,a).filter(c.not(a))},inListItem:function(a,b,c){return m.closest(b,"li",a)},inList:function(a,b,c){return m.closest(b,"ol,ul",a)},inTableCell:function(a,b,c){return m.closest(b,"td,th",a)},setBlock:function(a,b){return d.deepMerge(a,{block:c.constant(b)})},both:s,shared:u,
sharedPredicate:function(a){a=c.curry(t,a);return u(a)},entireRoot:function(a,b,c){return k.closest(b.element(),a).filter(function(c){var d=function(a){return g.eq(a,b.element())};return a(b.element())&&0===b.offset()||h.isText(b.element())&&0===b.offset()&&e.firstCursor(c).map(d).getOr(!1)}).filter(function(b){var d=function(a){return g.eq(a,c.element())};return a(c.element())&&c.offset()>=n.children(b).length-1||h.isText(c.element())&&c.offset()>=p.get(c.element()).length&&e.lastCursor(b).map(d).getOr(!1)}).map(function(a){return r(a,
a)})}}});l("vh","vn vg vi vj 6u 4h 32".split(" "),function(d,e,c,a,b,f,g){return{insertOne:function(a,g){var m=f.children(g.single(),"li");return 1!==m.length||b.descendant(m[0],"ol,ul")?e.split(a,c.from(m),d.purge):e.insertChildren(m[0],a)},insertMany:function(b,c){return g.ancestor(b.block(),"ol,ul",b.isRoot).bind(function(f){f=a.setBlock(b,f);return e.split(f,c,d.purgeAll)})}}});l("vk",["b","7","s","21"],function(d,e,c,a){var b=function(a){return function(b){return(1===b.length?c.some(b[0]):c.none()).filter(a).map(function(a){return{single:e.constant(a)}})}},
f=function(a){return function(b){var f=d.find(b,a);return(void 0!==f&&null!==f?c.some(b):c.none()).map(function(a){return{all:e.constant(a)}})}};return{oneOf:b,anyOf:f,noneOf:function(a){return function(b){var f=d.find(b,a);return(void 0===f||null===f?c.some(b):c.none()).map(function(a){return{all:e.constant(a)}})}},allOf:function(a){return function(b){return d.forall(b,a)?c.some({all:e.constant(b)}):c.none()}},any:c.some,oneOfTag:function(c){return b(function(b){return a.name(b)===c})},anyOfTag:function(b){return f(function(c){return a.name(c)===
b})},single:function(a){return c.some({single:e.constant(a)})},all:function(a){return c.some({all:e.constant(a)})}}});l("vl","b 7 s fg 21 4h 32".split(" "),function(d,e,c,a,b,f,g){var h=function(a){return 1===a.length?g.closest(a[0],"ol,ul").map(function(a){return{single:e.constant(a)}}):c.none()};return{list:h,listItem:function(a){return h(a).bind(function(a){a=f.descendants(a.single(),"li");return 1===a.length?c.some({single:e.constant(a[0])}):c.none()})},partialList:function(f){if(2!==f.length)return c.none();
var g=f[0],h=f[1];return a.isFormatting(g)||a.isContainer(g)||d.contains(["ol","ul","li"],b.name(g))||!d.contains(["ol","ul"],b.name(h))?c.none():c.some({all:e.constant(f),list:e.constant(h),inline:e.constant(g)})}}});l("ng","vf r2 ez vg vh vi vj vk vl 7 fg".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=g.formatter,r=g.inline,q=g.container,t=function(a){return p.isFormatting(a)&&!1===c.shouldMerge(a)};d=[e(g.inListItem,k.list,b.insertOne,"List"),e(g.inListItem,f.lists,b.insertMany,"Many lists"),
e(r,h.anyOf(t),a.nest,"Copying formatting (NO MERGE) into root"),e(r,h.oneOf(p.isFormatting),a.merge,"Copying formatting into root"),e(n,h.anyOfTag("hr"),a.split,"insert hr into formatter"),e(n,h.anyOf(t),a.split,"Copying one formatting block (NO MERGE) into formatting"),e(n,h.oneOf(p.isFormatting),a.merge,"Copying one formatting block into formatting"),e(n,h.anyOf(p.isFormatting),a.split,"Copying many formatting blocks into formatting"),e(n,h.anyOfTag("table"),d.addAfter(a.split),"Copying tables into formatting"),
e(n,h.anyOf(p.isContainer),a.split,"Copying container blocks into formatting"),e(q,h.all,a.nest,"Fallback pasting into container.")];return{context:function(a,b,c){return b.context(a.isRoot,c.startContainer(),c.startOffset()).map(function(b){return{block:m.constant(b),element:c.startContainer,offset:c.startOffset,isRoot:a.isRoot}})},rules:m.constant(d),fallback:a.fallback}});l("vo",["7","f9","dy"],function(d,e,c){return{force:function(a){var b=c.after(a.startContainer(),a.startOffset(),a.endContainer(),
a.endOffset()),f=b?e.point(a.endContainer(),a.endOffset()):e.point(a.startContainer(),a.startOffset());a=b?e.point(a.startContainer(),a.startOffset()):e.point(a.endContainer(),a.endOffset());return{left:d.constant(f),right:d.constant(a)}}}});l("vp","vm b e5 7 s zu w9 v6 1b l 3d 2r 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){var q=function(a,c){var d=a.original(),e=g.postfix(d.left().element(),d.left().offset(),d.right().element(),d.right().offset()),f=c.all();return e.bind(function(c){h.makeTo(d.left().element(),
d.left().offset(),c.element()).deleteContents();c.cleanup();p.append(a.left(),f);c=r.children(a.right());p.append(a.left(),c);n.remove(a.right());return b.from(f[f.length-1])})},t=function(a,d){if(!k.eq(a.left(),a.right()))throw"replaceContents used in the wrong context";var e=a.left();n.empty(e);var f=d.all();p.append(e,f);return c.lastCursor(e).or(b.from(f[f.length-1]))};return{replace:function(a,c){if(k.eq(a.left(),a.right())){var d=c.all();a.replaceSelection(d);return b.from(d[d.length-1])}return q(a,
c)},replaceContents:t,replaceContentsWrapP:function(b,c){var d=m.fromTag("p");p.append(d,c.all());return t(b,{all:a.constant([d])})},replaceWhole:function(a,c){var d=c.all();p.after(a.left(),d);n.remove(a.left());return b.from(d[d.length-1])},merge:function(a,c){var d=r.children(c.single());a.replaceSelection(d);return b.from(d[d.length-1])},split:function(a,c,g){var h=void 0===g?d.purge:g;g=a.original().left();var k=a.original().right();return f.range(g.element(),g.offset(),k.element(),k.offset(),
a.isRoot).bind(function(a){var d=c.all();p.before(a.second(),d);a.mark().cleanup();e.each([a.first(),a.second()],h);return b.from(d[d.length-1])})},fallback:function(a,c,e){a.replaceSelection(e);b.from(e[0]).each(d.purge);b.from(e[e.length-1]).each(d.purge);return b.from(e[e.length-1])}}});l("vq","s l 2p 3d 21 32 2b".split(" "),function(d,e,c,a,b,f,g){return{insertAll:function(b,c){var e=c.all();a.after(b,e);return d.from(e[e.length-1])},insertChildren:function(b,c){var e=g.children(c.single());a.after(b,
e);return d.some(e[e.length-1])},insertSingle:function(a,b){c.after(a,b.single());return d.some(b.single())},insertFlat:function(b,f){var g=e.fromTag("li");a.append(g,[f.inline(),f.list()]);c.after(b,g);return d.some(f.list())},insertNested:function(g,k){var m=e.fromTag("li");a.append(m,[k.inline(),k.list()]);var p=f.ancestor(g,"ol,ul").fold(function(){var a=e.fromTag(b.name(k.list()));c.append(a,m);return a},function(){return m});c.after(g,p);return d.some(k.list())}}});l("vr","vn b 7 zu 4h 2b".split(" "),
function(d,e,c,a,b,f){var g=function(b,d,e,f){f=void 0!==f?f:c.identity;var g=d.original(),q=g.left(),g=g.right();return a.ruptureUntil(q.element(),q.offset(),g.element(),g.offset(),d.isRoot,f).bind(function(a){var c=b(a,e);h(a);return c},void 0!==f?f:c.identity)},h=function(a){var c=b.ancestors(a,"ol,ul");0<c.length&&e.each([d.purgeAll,d.nesting],function(a){a(c[c.length-1])})};return{postprocess:h,onList:function(a,b,c){return g(a,b,c,function(a){return f.parent(a).getOr(a)})},onItem:function(a,
b,d){return g(a,b,d,c.identity)}}});l("nh","r2 ez vm vn vj vk vo vl vp vq vr b 7 fg vs 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s){var u=b.formatter,v=r.curry(p.onItem,m.insertSingle),l=r.curry(p.onList,m.insertAll),y=r.curry(p.onItem,m.insertChildren),x=r.curry(p.onItem,m.insertFlat);m=r.curry(p.onItem,m.insertNested);d=[d(b.sharedPredicate(e.isAtomic),f.all,k.replaceWhole,"selection: inside something atomic, so just replace the whole thing"),d(b.shared(b.inListItem),h.listItem,function(a,
b){return k.merge(a,b)},"selection: same item, paste: singleton"),d(b.shared(b.inListItem),h.list,function(b,c){return k.split(b,{all:r.constant(s.children(c.single()))},a.purgeAll)},"selection: same item, paste: single list"),d(b.shared(b.inListItem),h.partialList,m,"selection: same item, paste: partial"),d(b.shared(b.inListItem),f.noneOf(q.isBlock),k.replace,"selection: same item, paste: no blocks"),d(b.shared(b.inListItem),f.anyOf(q.isHeading),function(a,b){var d=k.replace(a,b);n.each(b.all(),
function(a){c.purgeBy(a,t.isVacantText)});return d},"selection: same item, paste: heading"),d(b.shared(b.inListItem),f.all,l,"selection: same item, paste: any"),d(b.both(b.inListItem),h.listItem,v,"selection: diff items, paste: singleton"),d(b.both(b.inListItem),h.list,y,"selection: diff items, paste: single list"),d(b.both(b.inListItem),h.partialList,x,"selection: diff items, paste: partial"),d(b.both(b.inListItem),f.all,l,"selection: diff items, paste: any"),d(b.both(u),f.anyOfTag("hr"),k.split,
"selection: inside formatter, paste: split"),d(b.both(u),f.noneOf(q.isBlock),k.replace,"range no blocks"),d(b.both(u),f.anyOf(function(a){return q.isFormatting(a)&&!1===e.shouldMerge(a)}),k.split,"range 1 formatting block"),d(b.both(u),f.oneOf(q.isFormatting),k.merge,"range 1 formatting block"),d(b.both(u),f.all,k.split,"range anything > formatters"),d(b.entireRoot,f.noneOf(q.isBlock),k.replaceContentsWrapP,"complete body, not inserting a block: wrap in P and replace the contents"),d(b.entireRoot,
f.all,k.replaceContents,"complete body: replace the contents")];return{context:function(a,b,c){var d=g.force(c);return b.context(a.isRoot,d.left(),d.right()).map(function(b){return{left:b.left,right:b.right,original:r.constant(d),isRoot:a.isRoot,replaceSelection:a.replaceSelection}})},rules:r.constant(d),fallback:k.fallback}});l("f0","ng nh b 87 7 s f9".split(" "),function(d,e,c,a,b,f,g){var h=function(a,d,e,g,h){return c.foldl(a,function(a,c){return a.orThunk(function(){return g(d,c,e).bind(function(a){return c.profile(h).map(function(d){return{action:c.action,
target:b.constant(d),ctx:b.constant(a)}})})})},f.none())},k=function(b){var c=a.getEnd(b);return g.point(b,c)},m=function(a,b,c,f,g,m){var u={getSelection:a,replaceSelection:b,isRoot:c};return u.getSelection().bind(function(a){var b=a.collapsed()?d:e,c=a.collapsed()?g.concat(b.rules()):m.concat(b.rules());return h(c,u,a,b.context,f).fold(function(){return b.fallback(u,a,f)},function(a){return a.action(a.ctx(),a.target())}).map(k)})};return{insertAtCursor:function(a,b,c,d){return m(a,b,c,d,[],[])},
insertAtCursorWith:m}});l("83","ez f0 b es 9o 81 s k 1a 21 4l".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=function(a){return m.isElement(a)&&"false"===k.get(a,"contenteditable")},r=function(a){return a().map(function(a){a=c.map([a.startContainer(),a.endContainer()],function(a){return p.closest(a,n)});return h.cat(a)}).getOr([])},q=function(a,b,e){c.each(a,b);b=e();c.each(a,d.clear);return b},t=function(a,b){return q(a,d.setAtomic,b)},s=function(a,b,c,d,f,g){var h=r(a);return t(h,function(){return e.insertAtCursorWith(a,
b,c,d,f,g)})},u=function(a,b,c,d){b=s(a.getSelection,a.replaceSelection,a.isRoot,b,c,d);a.domChanged();a.undoChanged();return b},v=function(a,b){return u(a,b,[],[])};return{insertAtCursorWith:u,insertAtCursor:v,insertAtCursorWithInstructions:function(a,b,c){return q(c,a,function(){return v(b,c)})},insertAt:function(c,d,e){e=s(function(){return g.some(d)},function(e){c.win().each(function(c){var g=a.write(b.on(d.startContainer(),d.startOffset()),b.on(d.endContainer(),d.endOffset()));f.replaceRange(c,
g,e)})},c.isRoot,e,[],[]);c.domChanged();c.undoChanged();return e}}});l("5h","80 81 82 s 83 59 4a 3m".split(" "),function(d,e,c,a,b,f,g,h){return function(k){var m=g.create({insertAssets:f(["assets"]),insertHtml:f(["html"])}),p=k.content(),n=a.none(),r=function(a){p.win().each(function(b){d.find(b,a.x(),a.y()).each(function(a){e.set(b,a)})})},q=function(a){r(a);m.trigger.insertAssets(a.assets())},t=function(a){r(a);a=a.html();k.undo().save();a=h.fromHtml(a);b.insertAtCursor(p,a)};p.events.ready.bind(function(b){var d=
a.none();n=a.some(c.forImages(b.api().canvas(),d,!0));n.each(function(a){a.events.dragndropimages.bind(q);a.events.dragndrophtml.bind(t)})});return{events:m.registry,destroy:function(a){n.each(function(a){a.destroy()})}}}});l("86",["3w","7","p"],function(d,e,c){var a=e.compose(d.pure,c.value);d=e.compose(d.pure,c.error);return{pure:a,failed:d,foldSync:function(a,c,d){return a.map(function(a){return a.fold(c,d)})},bindSync:function(a,c){return a.map(function(a){return a.bind(c)})},bindAsync:function(a,
c){return a.bind(function(a){return a.bind(c)})},mapSync:function(a,c){return a.map(function(a){return a.map(c)})},handle:function(a,c,d){return a.get(function(a){return a.fold(c,d)})}}});l("f4",["20"],function(d){return{now:function(){return(new d).getTime()}}});l("f1",["a","1o","f4","s","2v"],function(d,e,c,a,b){return function(f,g){var h=void 0!==g?g:36E5,k=b.immutable("result","timestamp"),m={},p=function(a,b,c){m[a]=k(b,c)},n=function(a){var b=c.now();e.map(a,function(a,c){b-a.timestamp<h&&p(c,
a.result,a.timestamp)})};d.isObject(f)&&n(f);return{set:p,get:function(b,c){return a.from(m[c]).filter(function(a){return b-a.timestamp()<h}).map(function(a){return a.result()})},dump:function(){return e.map(m,function(a){return{result:a.result(),timestamp:a.timestamp()}})}}}});l("qb",["b","6","p"],function(d,e,c){return{consolidateObj:function(a,b){var f=[b],g=[],h=!1;d.each(a,function(a){a.fold(function(a){h=!0;g=g.concat(a)},function(a){f.push(a)})});return h?c.error(g):0===f.length?c.value({}):
c.value(e.deepMerge.apply(void 0,f))},consolidateArr:function(a){var b=[],e=[],g=!1;d.each(a,function(a){a.fold(function(a){g=!0;e=e.concat(a)},function(a){b.push(a)})});return g?c.error(e):c.value(b)}}});l("qc",["b"],function(d){return{narrow:function(e,c){var a={};d.each(c,function(b){void 0!==e[b]&&e.hasOwnProperty(b)&&(a[b]=e[b])});return a},indexOnKey:function(e,c){var a={};d.each(e,function(b){a[b[c]]=b});return a}}});l("qd",["s"],function(d){var e=function(c){return function(a){return a.hasOwnProperty(c)?
d.from(a[c]):d.none()}};return{readOpt:e,readOr:function(c,a){return function(b){return e(c)(b).getOr(a)}},readOptFrom:function(c,a){return e(a)(c)},hasKey:function(c,a){return c.hasOwnProperty(a)&&void 0!==c[a]&&null!==c[a]}}});l("qe",["b"],function(d){return{wrap:function(d,c){var a={};a[d]=c;return a},wrapAll:function(e){var c={};d.each(e,function(a){c[a.key]=a.value});return c}}});l("ih",["qb","qc","qd","qe"],function(d,e,c,a){return{narrow:function(a,c){return e.narrow(a,c)},readOpt:function(a){return c.readOpt(a)},
readOr:function(a,d){return c.readOr(a,d)},readOptFrom:function(a,d){return c.readOptFrom(a,d)},wrap:function(b,c){return a.wrap(b,c)},wrapAll:function(b){return a.wrapAll(b)},indexOnKey:function(a,c){return e.indexOnKey(a,c)},hasKey:function(a,d){return c.hasKey(a,d)},consolidate:function(a,c){return d.consolidateObj(a,c)}}});l("vy",["2j"],function(d){return{parse:function(e){return d.getOrDie("JSON").parse(e)},stringify:function(e,c,a){return d.getOrDie("JSON").stringify(e,c,a)}}});l("vw",["a",
"b","1o","vy"],function(d,e,c,a){return{formatObj:function(b){return d.isObject(b)&&100<c.keys(b).length?" removed due to size":a.stringify(b,null,2)},formatErrors:function(a){a=10<a.length?a.slice(0,10).concat([{path:[],getErrorInfo:function(){return"... (only showing first ten failures)"}}]):a;return e.map(a,function(a){return"Failed path: ("+a.path.join(" > ")+")\n"+a.getErrorInfo()})}}});l("vu",["vw","p"],function(d,e){var c=function(a,b){return e.error([{path:a,getErrorInfo:b}])};return{missingStrict:function(a,
b,e){return c(a,function(){return'Could not find valid *strict* value for "'+b+'" in '+d.formatObj(e)})},missingKey:function(a,b){return c(a,function(){return'Choice schema did not contain choice key: "'+b+'"'})},missingBranch:function(a,b,e){return c(a,function(){return'The chosen schema: "'+e+'" did not exist in branches: '+d.formatObj(b)})},unsupportedFields:function(a,b){return c(a,function(){return"There are unsupported fields: ["+b.join(", ")+"] specified"})},custom:function(a,b){return c(a,
function(){return b})},toString:function(a){return"Failed path: ("+a.path.join(" > ")+")\n"+a.getErrorInfo()}}});l("nl",["7","4q"],function(d,e){var c=e.generate([{strict:[]},{defaultedThunk:["fallbackThunk"]},{asOption:[]},{asDefaultedOptionThunk:["fallbackThunk"]},{mergeWithThunk:["baseThunk"]}]);return{strict:c.strict,asOption:c.asOption,defaulted:function(a){return c.defaultedThunk(d.constant(a))},defaultedThunk:c.defaultedThunk,asDefaultedOption:function(a){return c.asDefaultedOptionThunk(d.constant(a))},
asDefaultedOptionThunk:c.asDefaultedOptionThunk,mergeWith:function(a){return c.mergeWithThunk(d.constant(a))},mergeWithThunk:c.mergeWithThunk}});l("zw",["4q"],function(d){var e=d.generate([{setOf:["validator","valueType"]},{arrOf:["valueType"]},{objOf:["fields"]},{itemOf:["validator"]},{choiceOf:["key","branches"]}]);d=d.generate([{field:["name","presence","type"]},{state:["name"]}]);return{typeAdt:e,fieldAdt:d}});l("vv","nl ih qb qd qe vu zw a b 1o 6 7 s p 4q".split(" "),function(d,e,c,a,b,f,g,h,
k,m,p,n,r,q,t){var s=t.generate([{field:["key","okey","presence","prop"]},{state:["okey","instantiator"]}]),u=function(b,c,d){return a.readOptFrom(c,d).fold(function(){return f.missingStrict(b,d,c)},q.value)},v=function(b,c,d){b=a.readOptFrom(b,c).fold(function(){return d()},n.identity);return q.value(b)},l=function(b,c,d){b=a.readOptFrom(b,c).map(function(a){return!0===a?d:a});return q.value(b)},y=function(c,d,e,f){return e.fold(function(e,g,h,k){var m=function(a){return k.extract(c.concat([e]),
f,a).map(function(a){return b.wrap(g,f(a))})},s=function(a){return a.fold(function(){var a=b.wrap(g,f(r.none()));return q.value(a)},function(a){return k.extract(c.concat([e]),f,a).map(function(a){return b.wrap(g,f(r.some(a)))})})};return function(){return h.fold(function(){return u(c,d,e).bind(m)},function(a){return v(d,e,a).bind(m)},function(){return q.value(a.readOptFrom(d,e)).bind(s)},function(a){return l(d,e,a).bind(s)},function(a){var b=a();return v(d,e,n.constant({})).map(function(a){return p.deepMerge(b,
a)}).bind(m)})}()},function(a,c){var e=c(d);return q.value(b.wrap(a,f(e)))})},x=function(a,b,d,e){d=k.map(d,function(c){return y(a,b,c,e)});return c.consolidateObj(d,{})},z=function(a){return{extract:function(b,c,d){return a(d).fold(function(a){return f.custom(b,a)},q.value)},toString:function(){return"val"},toDsl:function(){return g.typeAdt.itemOf(a)}}},A=function(a){return{extract:function(b,c,d){return x(b,d,a,c)},toString:function(){return"obj{\n"+k.map(a,function(a){return a.fold(function(a,
b,c,d){return a+" -> "+d.toString()},function(a,b){return"state("+a+")"})}).join("\n")+"}"},toDsl:function(){return g.typeAdt.objOf(k.map(a,function(a){return a.fold(function(a,b,c,d){return g.fieldAdt.field(a,c,d)},function(a,b){return g.fieldAdt.state(a)})}))}}},D=function(a){return{extract:function(b,d,e){e=k.map(e,function(c,e){return a.extract(b.concat(["["+e+"]"]),d,c)});return c.consolidateArr(e)},toString:function(){return"array("+a.toString()+")"},toDsl:function(){return g.typeAdt.arrOf(a)}}};
t=z(q.value);var B=n.compose(D,A);return{anyValue:n.constant(t),value:z,obj:A,objOnly:function(a){var b=A(a),c=k.foldr(a,function(a,b){return b.fold(function(b){return p.deepMerge(a,e.wrap(b,!0))},n.constant(a))},{});return{extract:function(a,d,g){var p=h.isBoolean(g)?[]:m.keys(g),p=k.filter(p,function(a){return!e.hasKey(c,a)});return 0===p.length?b.extract(a,d,g):f.unsupportedFields(a,p)},toString:b.toString,toDsl:b.toDsl}},arr:D,setOf:function(a,b){var c=function(b,c){return D(z(a)).extract(b,n.identity,
c)};return{extract:function(a,e,f){var g=m.keys(f);return c(a,g).bind(function(c){c=k.map(c,function(a){return s.field(a,a,d.strict(),b)});return A(c).extract(a,e,f)})},toString:function(){return"setOf("+b.toString()+")"},toDsl:function(){return g.typeAdt.setOf(a,b)}}},arrOfObj:B,state:s.state,field:s.field,output:function(a,b){return s.state(a,n.constant(b))},snapshot:function(a){return s.state(a,n.identity)}}});l("vt","ih vu vv zw 1o p".split(" "),function(d,e,c,a,b,f){var g=function(a,b,f,g,n){return d.readOptFrom(g,
n).fold(function(){return e.missingBranch(a,g,n)},function(d){return c.obj(d).extract(a.concat(["branch: "+n]),b,f)})};return{choose:function(c,f){return{extract:function(a,b,n){return d.readOptFrom(n,c).fold(function(){return e.missingKey(a,c)},function(c){return g(a,b,n,f,c)})},toString:function(){return"chooseOn("+c+"). Possible values: "+b.keys(f)},toDsl:function(){return a.typeAdt.choiceOf(c,f)}}}}});l("ni","vt vu vv vw a b 1o 7 p n".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=c.value(k.value);
e=c.arr;b=c.obj;f=c.objOnly;g=c.setOf;var n=function(a,b,c,d){return b.extract([a],c,d).fold(function(a){return k.error({input:d,errors:a})},k.value)},r=function(a,b,c){return n(a,b,h.constant,c)},q=function(a,b,c){return n(a,b,h.identity,c)},t=function(a){return a.fold(function(a){throw new m(s(a));},h.identity)},s=function(b){return"Errors: \n"+a.formatErrors(b.errors)+"\n\nInput object: "+a.formatObj(b.input)};return{anyValue:h.constant(p),arrOfObj:function(a){return c.arrOfObj(a)},arrOf:e,arrOfVal:function(){return c.arr(p)},
valueOf:function(a){return c.value(a)},setOf:g,objOf:b,objOfOnly:f,asStruct:r,asRaw:q,asStructOrDie:function(a,b,c){return t(r(a,b,c))},asRawOrDie:function(a,b,c){return t(q(a,b,c))},getOrDie:t,formatError:s,choose:function(a,b){return d.choose(a,b)}}});l("zx",["3w","ne"],function(d,e){return function(c){return d.nu(function(a){var b=e();b.onload=function(b){a(b.target.result)};b.readAsText(c)})}});l("zy",["2j"],function(d){return function(){return new (d.getOrDie("XMLHttpRequest"))}});l("vx","a 1o 6 zx 3w zy s p v o".split(" "),
function(d,e,c,a,b,f,g,h,k,m){var p={"*":"*/*",text:"text/plain",html:"text/html",xml:"application/xml, text/xml",json:"application/json, text/javascript"};return{ajax:function(n,r,q,t){var s=c.merge({url:n,contentType:"application/json",processData:!1,type:"GET"},t),u=f();u.open(s.type.toUpperCase(),s.url,!0);"blob"===s.responseType&&(u.responseType=s.responseType);d.isString(s.contentType)&&u.setRequestHeader("Content-Type",s.contentType);var v=s.dataType;t=d.isString(v)&&"*"!==v?p[v]+", "+p["*"]+
"; q=0.01":p["*"];u.setRequestHeader("Accept",t);void 0!==s.xhrFields&&!0===s.xhrFields.withCredentials&&(u.withCredentials=!0);d.isObject(s.headers)&&e.each(s.headers,function(a,b){d.isString(b)||d.isString(a)?u.setRequestHeader(b,a):m.error("Request header data was not a string: ",b," -> ",a)});var l=function(){var c;c="blob"===s.responseType?g.from(u.response).map(a).getOr(b.pure("no response content")):b.pure(u.responseText);c.get(function(a){0===u.status?q("Unknown HTTP error (possible cross-domain request)",
u.status,a):q('Could not load url "'+n+'": '+u.statusText,u.status,a)})},y=function(){var a;if("json"===v)try{a=h.value(JSON.parse(u.response))}catch(b){a=h.error({status:u.status,statusText:"Response was not JSON",responseText:u.responseText})}else a=h.value(u.response);a.fold(l,function(a){r(a)})};u.onerror=l;u.onload=function(){0===u.status?k.startsWith(s.url,"file:")?y():l():100>u.status||400<=u.status?l():y()};void 0===s.data?u.send():u.send(s.data)}}});l("nj",["6","vx","vy"],function(d,e,c){var a=
function(a){return function(b,d,e){var m;try{m=void 0===e||""===e?e:c.parse(e)}catch(p){m={contents:e}}a(b,d,m)}},b=function(b,c,h,k,m){e.ajax(b,h,a(k),d.merge({dataType:"json",type:c},m))};return{get:function(a,c,d,e){b(a,"GET",c,d,e)},post:function(a,e,h,k,m){b(a,"POST",h,k,d.merge({data:c.stringify(e)},m))},ajax:b}});l("f2","ni a 1o nj 3w p v w".split(" "),function(d,e,c,a,b,f,g,h){return{get:function(k,m,p,n){var r={headers:n};return{execute:function(n){n=d.asRawOrDie(k+".ajax.service.get",m,
n);n=c.map(n,function(a){return e.isBoolean(a)?h(a):a});var t=g.supplant(p,n);return b.nu(function(b){a.get(t,function(a){b(f.value(a))},function(a,c,d){a=e.isObject(d)?d:a;b(f.error(a))},r)})}}},post:function(c,g,h,n){var r={headers:n};return{execute:function(n){var t=d.asRawOrDie(c+".ajax.service.post",g,n);return b.nu(function(b){a.post(h,t,function(a){b(f.value(a))},function(a,c,d){a=e.isObject(d)?d:a;b(f.error(a))},r)})}}}}});l("nk",["ih","b","6"],function(d,e,c){return{partition:function(a,
b,f,g,h){return!0===h?{known:{},unknown:f}:e.foldl(f,function(e,f){var h=g(f);return a(b,h).fold(function(){return{known:e.known,unknown:e.unknown.concat([f])}},function(a){a=d.wrap(h,a);return{known:c.merge(e.known,a),unknown:e.unknown}})},{known:{},unknown:[]})}}});l("f3",["1o","6","86","nk","s"],function(d,e,c,a,b){var f=function(a,b,f,m,p,n,r){a=a(m,r);return c.mapSync(a,function(a){a=p(a);d.each(a,function(a,c){b.set(c,a,n)});return e.deepMerge(f,a)})};return{single:function(a,d,e,f,p){return(!0===
p?b.none():d.get(f,e)).fold(function(){return a(e,p).map(function(a){return a.map(function(a){d.set(e,a,f);return a})})},function(a){return c.pure(a)})},multiple:function(b,d,e,m,p,n,r){e=a.partition(d.get,n,e,p,r);return 0===e.unknown.length?c.pure(e.known):f(b,d,e.known,e.unknown,m,n,r)}}});l("nm",["nl","vv","a","p"],function(d,e,c,a){var b=function(a,b){return e.field(a,a,d.strict(),b)};return{strict:function(a){return e.field(a,a,d.strict(),e.anyValue())},strictOf:b,strictObjOf:function(a,b){return e.field(a,
a,d.strict(),e.obj(b))},strictArrayOf:function(a,c){return b(a,c)},strictArrayOfObj:function(a,b){return e.field(a,a,d.strict(),e.arrOfObj(b))},strictFunction:function(b){return e.field(b,b,d.strict(),e.value(function(b){return c.isFunction(b)?a.value(b):a.error("Not a function")}))},forbid:function(b,c){return e.field(b,b,d.asOption(),e.value(function(d){return a.error("The field: "+b+" is forbidden. "+c)}))},option:function(a){return e.field(a,a,d.asOption(),e.anyValue())},optionOf:function(a,b){return e.field(a,
a,d.asOption(),b)},optionObjOf:function(a,b){return e.field(a,a,d.asOption(),e.obj(b))},optionObjOfOnly:function(a,b){return e.field(a,a,d.asOption(),e.objOnly(b))},defaulted:function(a,b){return e.field(a,a,d.defaulted(b),e.anyValue())},defaultedOf:function(a,b,c){return e.field(a,a,d.defaulted(b),c)},defaultedObjOf:function(a,b,c){return e.field(a,a,d.defaulted(b),e.obj(c))},field:function(a,b,c,d){return e.field(a,b,c,d)},state:function(a,b){return e.state(a,b)}}});l("nn",["b","7","p"],function(d,
e,c){var a=function(a){return"["+a.join(", ")+"]"},b=["iframely","oembed","fallback"],f=function(e,f,k){return d.exists(f,function(a){return d.contains(e,a)})?c.error("Embed response source: "+a(e)+" contains more than one of "+a(b)):c.value(k)};return{iframely:e.constant("iframely"),oembed:e.constant("oembed"),fallback:e.constant("fallback"),identify:function(e){return d.contains(e,"iframely")?f(e,["oembed","fallback"],"iframely"):d.contains(e,"oembed")?f(e,["iframely","fallback"],"oembed"):d.contains(e,
"fallback")?f(e,["iframely","oembed"],"fallback"):c.error("Embed response source: "+a(e)+" did not contain any of: "+a(b))}}});l("f6","nl nm ni a nn 7 p".split(" "),function(d,e,c,a,b,f,g){var h=c.objOf([e.strict("url"),e.strict("maxWidth"),e.defaulted("fresh",!1)]),k=c.objOf([e.strict("status_code"),e.strict("sub_code"),e.strict("msg")]);d=c.objOf([e.strict("html"),e.strictObjOf("rels",[e.field("source","source",d.strict(),c.valueOf(function(c){return a.isArray(c)?b.identify(c):g.error("Sources was not an array: "+
c)}))])]);return{requestOne:f.constant(h),responseFailed:f.constant(k),responseSucceeded:f.constant(d)}});l("f5",["ni","f6","7","p"],function(d,e,c,a){return{failed:function(b){return d.asStruct("EmbedResponse.failure",e.responseFailed(),b).fold(function(b){return a.error({code:c.constant(600),subcode:c.constant(0),msg:c.constant(d.formatError(b))})},function(b){return a.error({code:b.status_code,subcode:b.sub_code,msg:b.msg})})},success:function(b){return d.asStruct("EmbedResponse.success",e.responseSucceeded(),
b).fold(function(b){return a.error({code:c.constant(601),subcode:c.constant(0),msg:c.constant(d.formatError(b))})},function(b){return a.value({recommended:c.constant({html:b.html,source:b.rels().source})})})}}});aa("f7",encodeURIComponent);l("85","86 f1 f2 f3 f4 f5 f6 f7".split(" "),function(d,e,c,a,b,f,g,h){return function(k,m,p){var n=e(p),r=c.get("ephox.media.service.one",g.requestOne(),k+"/1/embed?url=${url}&maxWidth=${maxWidth}",m);return{checkOne:function(c,e,g){var k=b.now();g=a.single(function(a,
b){return r.execute({url:h(c),maxWidth:e,fresh:b})},n,e+"&"+c,k,void 0!==g?g:!1);return d.foldSync(g,f.failed,f.success)},dumpCache:n.dump}}});l("88",["7","34","cw"],function(d,e,c){var a=e.resolve("embed-checking");return{configure:function(b){b.add(b.input(),a,c.removeClass(a));b.add(b.output(),a,c.removeClass(a));b.add(b.history(),a,c.removeClass(a));b.add(b.internal(),a,c.removeClass(a))},embedChecking:d.constant(a)}});l("89",["7","7b","1s"],function(d,e,c){var a=function(){return e.translate("link.anchor.top")},
b=function(){return e.translate("link.anchor.bottom")},f=function(){var c={};c[a().toLowerCase()]="top";c[b().toLowerCase()]="bottom";return c};return{bookmarkDataAttr:d.constant("data-textbox-bookmark"),bookmarkAnchorDataAttr:d.constant("data-textbox-bookmark-anchor"),topAnchorUrl:a,bottomAnchorUrl:b,top:d.constant("top"),bottom:d.constant("bottom"),reservedUrls:f,isReservedUrl:function(a){return f().hasOwnProperty(a.toLowerCase())},getReservedUrl:function(c){var d={};d.top=a();d.bottom=b();return d[c.toLowerCase()]}}});
l("vz",["2p"],function(d){return{setCss:function(e,c,a){e.dom().styleSheet?e.dom().styleSheet.cssText=c:d.append(e,a)}}});l("zz",[],function(){return{escape:function(d){return d.replace(/[-[\]{}()*+?.,\\^$|#\s]/g,"\\$&")}}});l("w0",["1o","zz","6p"],function(d,e,c){var a=function(a,d,g){d=new c("url\\(\\s*['\"]?"+e.escape(d)+"(.*?)['\"]?\\s*\\)","g");return a.replace(d,'url("'+g+'$1")')};return{replace:a,replaceMany:function(b,c){var e=b;d.each(c,function(b,c){e=a(e,c,b)});return e}}});l("no","1a l 2p 32 vz w0 9".split(" "),
function(d,e,c,a,b,f,g){return{stylesheets:function(a){a=a.dom().styleSheets;return g.prototype.slice.call(a)},inject:function(g,k,m){var p=e.fromTag("style",m.dom());d.set(p,"type","text/css");g=void 0===k?g:f.replaceMany(g,k);b.setCss(p,g,e.fromText(g,m.dom()));m=a.descendant(m,"head").getOrDie();c.append(m,p)}}});aa("w1",CSSRule);l("np",["b","2v","w1"],function(d,e,c){var a=e.immutable("selector","style","raw"),b=function(e){return d.bind(e.cssRules,function(d){if(d.type===c.IMPORT_RULE)return b(d.styleSheet);
if(d.type===c.STYLE_RULE){var e=d.selectorText,f=d.style.cssText;if(void 0===f)throw"WARNING: Browser does not support cssText property";return[a(e,f,d.style)]}return[]})};return{extract:b,extractAll:function(a){return d.bind(a,b)}}});(function(d,e,c){d("nq",[],function(){var a=function(){var a;a=function(a){var b=a,c,d={a:0,b:0,c:0},e=[];c=function(c,h){var r,q,t,s,u,v;if(c.test(b))for(r=b.match(c),q=0,t=r.length;q<t;q+=1)d[h]+=1,s=r[q],u=b.indexOf(s),v=s.length,e.push({selector:a.substr(u,v),type:h,
index:u,length:v}),b=b.replace(s,Array(v+1).join(" "))};(function(){var a=function(a){var c,d,e;if(a.test(b))for(a=b.match(a),c=0,d=a.length;c<d;c+=1)e=a[c],b=b.replace(e,Array(e.length+1).join("A"))};a(/\\[0-9A-Fa-f]{6}\s?/g);a(/\\[0-9A-Fa-f]{1,5}\s/g);a(/\\./g)})();(function(){var a=/:not\(([^\)]*)\)/g;a.test(b)&&(b=b.replace(a,"     $1 "))})();(function(){var a=RegExp("{[^]*","gm"),c,d,e;if(a.test(b))for(a=b.match(a),c=0,d=a.length;c<d;c+=1)e=a[c],b=b.replace(e,Array(e.length+1).join(" "))})();
c(/(\[[^\]]+\])/g,"b");c(/(#[^\s\+>~\.\[:]+)/g,"a");c(/(\.[^\s\+>~\.\[:]+)/g,"b");c(/(::[^\s\+>~\.\[:]+|:first-line|:first-letter|:before|:after)/gi,"c");c(/(:[\w-]+\([^\)]*\))/gi,"b");c(/(:[^\s\+>~\.\[:]+)/g,"b");b=b.replace(/[\*\s\+>~]/g," ");b=b.replace(/[#\.]/g," ");c(/([^\s\+>~\.\[:]+)/g,"c");e.sort(function(a,b){return a.index-b.index});return{selector:a,specificity:"0,"+d.a.toString()+","+d.b.toString()+","+d.c.toString(),specificityArray:[0,d.a,d.b,d.c],parts:e}};return{calculate:function(c){var d,
e,k,m=[];c=c.split(",");e=0;for(k=c.length;e<k;e+=1)d=c[e],0<d.length&&m.push(a(d));return m},compare:function(c,d){var e,k,m;if("string"===typeof c){if(-1!==c.indexOf(","))throw"Invalid CSS selector";e=a(c).specificityArray}else if(Array.isArray(c)){if(4!==c.filter(function(a){return"number"===typeof a}).length)throw"Invalid specificity array";e=c}else throw"Invalid CSS selector or specificity array";if("string"===typeof d){if(-1!==d.indexOf(","))throw"Invalid CSS selector";k=a(d).specificityArray}else if(Array.isArray(d)){if(4!==
d.filter(function(a){return"number"===typeof a}).length)throw"Invalid specificity array";k=d}else throw"Invalid CSS selector or specificity array";for(m=0;4>m;m+=1){if(e[m]<k[m])return-1;if(e[m]>k[m])return 1}return 0}}}();"undefined"!==typeof exports&&(exports.calculate=a.calculate,exports.compare=a.compare);return a})})(na.define,na.require,na.demand);l("f8","b 2v 1a 2o 4h v no np nq".split(" "),function(d,e,c,a,b,f,g,h,k){var m=e.immutable("selector","raw"),p=function(a,b){var c={};d.each(a,function(e){if(void 0!==
a[e]){var f=b.dom().style;d.contains(f,e)||(c[e]=a[e])}});return c},n=function(e,f){var g=d.bind(f,function(c){var f=b.descendants(e,c.selector());d.each(f,function(b){var d=p(c.raw(),b);a.setAll(b,d)});return f});d.each(g,function(a){c.remove(a,"class")})},r=function(a,b){var c=function(a){return-1!==a.selector().indexOf(",")},e=d.bind(d.filter(a,c),function(a){var b=a.selector().split(",");return d.map(b,function(b){b=b.trim();return m(b,a.raw())})}),e=d.filter(a,function(a){return!c(a)}).concat(e);
e.sort(function(a,b){return k.compare(a.selector(),b.selector())}).reverse();n(b,e)};return{inlineStyles:function(a,b,c){a=g.stylesheets(a);a=h.extractAll(a).map(function(a){var b=a.selector(),b=c.hasOwnProperty(b)?c[b]:b;return m(b,a.raw())});r(a,b)},inlinePrefixedStyles:function(a,b,c){a=g.stylesheets(a);a=h.extractAll(a);a=d.filter(a,function(a){return f.startsWith(a.selector(),c)});r(a,b)}}});l("8a",["f8"],function(d){return{inlineStyles:function(e,c,a){d.inlineStyles(e,c,a)},inlinePrefixedStyles:function(e,
c,a){d.inlinePrefixedStyles(e,c,a)}}});l("5i","84 b 85 86 2c 87 88 89 1a 1y 1b l 2p 21 2r 3n 2b 8a".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,l){return function(w,y,x){var z=g.embedChecking(),A=w.internalevents(),D=w.communication(),B=c(x.url,D.mediatorHeaders(),y.cache),C=w.undo(),F=w.content();w=w.filter();g.configure(w);var E=["img","video","audio"],G=function(a,b){r.after(a,b);t.remove(a)},H=function(b,c){m.add(b,z);var d=B.checkOne(c,400);a.handle(d,function(a){m.remove(b,z)},function(a){m.remove(b,
z);C.save();var d=n.fromHtml(a.recommended().html().trim());e.contains(E,q.name(d))||k.set(d,"data-ephox-embed-iri",c);var g=n.fromTag("div");r.append(g,d);x.inlineStyles&&F.doc().each(function(a){l.inlinePrefixedStyles(a,g,".ephox-summary-card")});F.getSelection().fold(function(){G(b,d)},function(a){G(b,d);var c=u.nextSibling(d).filter(f.isCursorPosition).getOrThunk(function(){var a=n.fromTag("br");r.after(d,a);return a});u.parent(d).each(function(b){a.collapsed()&&(p.eq(a.startContainer(),b)||p.contains(b,
a.startContainer()))&&F.setSelection(c,0,c,0)})})})},I=function(a){var c=a.command(),f=a.data();k.has(f,h.bookmarkAnchorDataAttr())||"insertLink"!==c&&"updateLink"!==c||u.parent(f).each(function(a){var c=s.get(a).replace(d.zeroWidth(),""),g=k.get(f,"href");if(c===g||"http://"+c===g)H(f,g);else{var c=u.children(a),h=e.find(e.reverse(c),function(a){return"br"===q.name(a)&&b.documentPositionPreceding(f.dom(),a.dom())});a=e.find(c,function(a){return"br"===q.name(a)&&b.documentPositionPreceding(a.dom(),
f.dom())});c=void 0!==h?c.slice(e.indexOf(c,h)+1,c.length):c;a=void 0!==a?c.slice(0,e.indexOf(c,a)):c;a=e.foldl(a,function(a,b){return a+s.get(b)},"");a!==g&&"http://"+a!==g||H(f,g)}})};A.events.internal.bind(I);return{destroy:function(){A.events.internal.unbind(I)},state:function(){return{cache:B.dumpCache()}}}}});l("8c",["3y"],function(d){return{handle:function(e,c){return d.bind(e,"click",c)}}});l("8d",["7","7b"],function(d,e){return{editor:function(c,a){var b=d.curry(e.translate,a?"aria.label.fullscreen":
"aria.label.editor");return c.fold(d.identity,b)}}});l("6b",["6","7","s"],function(d,e,c){return function(a){var b=function(){return d.merge(null===a.project.apiKey?{}:{headers:{"textbox-api-key":a.project.apiKey}},{xhrFields:{withCredentials:!0}})},f=function(a){var b=a+(-1===a.indexOf("?")?"?":"&")+"url=";return function(a){return c.some(b+encodeURIComponent(a))}},f=void 0===a.imageEdit.proxy?c.none:f(a.imageEdit.proxy);return{headers:b,mediatorHeaders:function(){var a=b().headers;return void 0===
a?{}:a},proxy:f,destroy:e.noop}}});l("4d",["7"],function(d){return{styleSpan:d.constant("ephox-hare-style-span"),base:d.constant("ephox-candy-mountain"),active:d.constant("ephox-candy-mountain-active")}});l("100","b c 4d 3w 7 p 59 4a 1a 1y 1b 3y l 2z 2g 4l ld q 37".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,l,w){var y=e.detect();return function(e){var z="true"===k.get(e,"contenteditable");k.set(e,"contenteditable","true");var A=n.bind(e,"keydown",function(a){Q.trigger.keydown(a)}),D=n.bind(e,
"keyup",function(a){Q.trigger.keyup(a)}),B=n.bind(e,"keypress",function(a){Q.trigger.keypress(a)}),C=n.bind(e,"mousedown",function(a){Q.trigger.mousedown(a)}),F=n.bind(e,"mouseout",function(a){Q.trigger.mouseout(a)}),E=n.bind(e,"mouseup",function(a){Q.trigger.mouseup(a)}),G=n.bind(e,"contextmenu",function(a){Q.trigger.contextmenu(a)}),H=n.bind(e,"cut",function(a){Q.trigger.cut(a)}),I=n.bind(e,"copy",function(a){Q.trigger.copy(a)}),K=n.bind(e,"paste",function(a){Q.trigger.paste(a)}),J=n.bind(r.fromDom(l),
"selectionchange",function(a){Q.trigger.selectionchange(a)}),L=function(){Q.trigger.paint()},N=n.capture(e,"load",L);u.bind(e,L);var M=y.browser.isFirefox()?"focus":"focusin",O=n.bind(e,M,function(a){Q.trigger.focus(a)}),S=n.bind(e,"focusout",function(a){Q.trigger.focusOut(a)}),P=n.bind(e,"dblclick",function(a){Q.trigger.dblclick(a)}),T=function(a){return p.eq(e,a)},M={loaded:a.pure(f.error("no iframe in inline mode"))},Q=h.create({keydown:g(["original"]),keyup:g(["original"]),keypress:g(["original"]),
mousedown:g(["original"]),mouseup:g(["original"]),mouseout:g(["original"]),contextmenu:g(["original"]),cut:g(["original"]),copy:g(["original"]),paste:g(["original"]),focus:g(["original"]),dblclick:g(["original"]),focusOut:g(["original"]),selectionchange:g(["original"]),paint:g([])});return{win:b.constant(w),doc:b.constant(r.fromDom(l)),body:b.constant(e),get:function(){return t.get(e)},set:function(a){t.set(e,a)},focus:function(){y.browser.isIE()?e.dom().setActive(!0):q.focus(e)},focused:function(){return l.activeElement===
e.dom()},blur:function(){e.dom().blur()},destroy:function(){z||k.remove(e,"contenteditable");d.each([A,D,B,C,E,F,G,H,I,K,O,S,P,J,N],function(a){a.unbind()});u.unbind(e,L)},events:Q.registry,futures:M,background:b.noop,foreground:b.noop,hasRange:function(a){return s.closest(a.startContainer(),T).isSome()&&s.closest(a.endContainer(),T).isSome()},isActive:function(){return m.has(e,c.active())}}}});l("12p","c 80 es 9o 81 7 ft 4q l 2z 2p 21 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){var q=f.constant(!1),
t=d.detect(),s=t.browser.isIE()||t.browser.isSpartan()?2:5,u=h.generate([{above:["element"]},{below:["element"]}]),l=function(a,c,d){return function(c){return b.bounds(a,c).fold(q,d)}},w=function(a,b){return l(a,b,function(a){return b>a.top+a.height-s})},y=function(a,b){return l(a,b,function(a){return b<a.top+s})};return function(d,f,h){var q=function(a){var b=g.freefallRtl(f).element();return r.ancestor(b,"table").filter(w(d,a)).map(u.above)},s=function(a,c){a.kill();b.set(d,c);h()};return function(b){var h=
b.y();q(h).orThunk(function(){var a=g.freefallLtr(f).element();return r.ancestor(a,"table").filter(y(d,h)).map(u.below)}).fold(function(){if("html"===n.name(b.target())){var a=b.x(),c=b.y();e.find(d,a,c).each(function(a){var c=function(a){return r.closest(a,'[contenteditable="false"]').isSome()},d=a.start().fold(c,c,c),c=a.finish().fold(c,c,c);(d||c)&&t.browser.isIE()||m.focus(f);s(b,a)})}},function(d){var e=k.fromHtml("<p><br /></p>");d.fold(function(a){p.after(a,e)},function(a){p.before(a,e)});
s(b,c.write(a.on(e,0),a.on(e,0)))})}}});l("12v",["es","81","jt"],function(d,e,c){return{clearAll:function(a){e.clearAll(a)},get:function(a){return e.get(a).map(function(a){return c(a.start(),a.soffset(),a.finish(),a.foffset())})},set:function(a,b){e.setExact(a,b.startContainer(),b.startOffset(),b.endContainer(),b.endOffset())},setExact:function(a,b,c,d,h){e.setExact(a,b,c,d,h)},setRelative:function(a,b,c){b=d.write(b,c);e.set(a,b)},replace:function(a,b){e.replace(a,b)}}});l("12q",["12v","59","4a",
"6e","3x"],function(d,e,c,a,b){return function(f){var g=null,h=function(){g=null;d.get(f.win()).each(function(a){a.collapsed()&&f.focused()&&k.trigger.loiter(a.startContainer(),a.startOffset())})},k=c.create({loiter:e(["node","offset"])});return{reset:function(){null!==g&&(a(g),g=null);g=b(h,1E3)},destroy:function(){null!==g&&(a(g),g=null)},events:k.registry}}});l("12r","7 s k br 59 4a 2n 1b 21 4l m".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=function(a,b){var e=d.curry(h.eq,g.body()),f=b.join(", ");
return c.findMap(a,function(a){return m.ancestor(a,function(a){return p.is(a,f)},e)}).isSome()};return function(c,d){var g=e.none(),m=a.tap(function(){m.control.block();var a=c();a.each(function(a){var b=function(){p.trigger.nodeChanged(a.startContainer(),a.startOffset(),g.map(function(a){return a.startContainer()}))};g.fold(b,function(c){var e=h.eq,f=a.startContainer(),g=a.endContainer(),m=c.startContainer(),p=c.endContainer(),r=c.startOffset()!==a.startOffset();c=c.endOffset()!==a.endOffset();e(m,
f)&&e(p,g)&&!(!k.isText(f)&&r||!k.isText(g)&&c)||!1!==n([a.startContainer()],d)||b()})});g=a;m.control.unblock()}),p=f.create({nodeChanged:b(["node","offset","prev"])});return{update:function(){m.instance()},clear:function(){g=e.none()},destroy:function(){g=e.none();m.control.block()},events:p.registry}}});l("12s",["7","1b","l","2z"],function(d,e,c,a){var b=function(b,c){return{toEditor:b,toOld:d.curry(a.focus,c),isSet:function(){return a.active().exists(function(a){return e.eq(a,c)})}}},f=function(a,
e,f,m){m=m.dom().activeElement;return a()?{toEditor:e,toOld:d.noop,isSet:d.constant(!0)}:void 0===m||null===m?{toEditor:f,toOld:d.noop,isSet:d.constant(!1)}:b(f,c.fromDom(m))};return{build:f,toEditor:function(a,b,c,d){f(a,b,c,d).toEditor()}}});l("12t",["s"],function(d){return function(){var e=d.none();return{get:function(){return e},restore:function(c){e.each(c)},update:function(c){e=c.or(e)},clear:function(){e=d.none()}}}});l("12u",["9o","12v","6u","32"],function(d,e,c,a){var b=function(a){return c.closest(a.startContainer(),
'[contenteditable="false"]')&&c.closest(a.endContainer(),'[contenteditable="false"]')};return{focus:function(c,g,h){g=g().filter(b);g.each(function(b){a.closest(b.endContainer(),'[contenteditable="false"]').each(function(a){e.setRelative(c.win(),d.after(a),d.after(a))})});c.focus();g.each(function(a){h(a.startContainer(),a.startOffset(),a.endContainer(),a.endOffset())})}}});l("101","c 12p 12q 12r 12s 12t 12u 12v 7 ft 59 4a 4b 3o 3y l o q 37".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,l,
w){var y=d.detect();return function(d,z){var A=function(){return L().orThunk(C.get)},D=t.bind(d.body(),"click",e(d.win(),d.body(),k.noop)),B=a(A,z),C=f(),F=function(){B.update();J()},E=function(){C.restore(function(a){N(a.startContainer(),a.startOffset(),a.endContainer(),a.endOffset())})};B.events.nodeChanged.bind(function(a){W.trigger.nodeChanged(a.node(),a.offset(),a.prev());W.trigger.uiStale()});d.events.keyup.bind(function(a){W.trigger.keyup(a.original());F();G.reset();W.trigger.interaction()});
d.events.mouseout.bind(function(a){J()});d.events.mouseup.bind(function(a){W.trigger.mouseup(a.original());F();G.reset();W.trigger.interaction()});var G=c(d);G.events.loiter.bind(function(a){W.trigger.loiter(a.node(),a.offset())});var H=function(){L().isNone()?E():J()},I=function(){d.isActive()&&(H(),g.focus(d,A,O))},K=function(){W.trigger.domChanged()},J=function(){var a=L();C.update(a)},L=function(){return h.get(w).filter(d.hasRange)},N=function(a,b,c,d){try{h.setExact(w,a,b,c,d)}catch(e){u.log("Skipping restoring invalid cursor position")}},
M=function(a){P(function(b){d.isActive()&&a();F()},b.build(d.focused,H,I,s.fromDom(l)))},O=function(a,b,c,d){M(function(){N(a,b,c,d)})},S=function(a,b){var c=h.get(w);E();var d=a(b);b.toOld();c.each(function(a){N(a.startContainer(),a.startOffset(),a.endContainer(),a.endOffset());y.browser.isSpartan()&&(b.isSet()||b.toOld())});return d},P=function(a,b){var c=a(b);b.toOld();return c},T=function(a){var c=b.build(d.focused,H,I,s.fromDom(l));return(L().isSome()?P:S)(a,c)},Q=function(a){return function(){var b=
arguments;return T(function(c){c.toEditor();return a(b)})}}(function(a){l.execCommand.apply(l,a);J()}),V=function(a,b){return q(a,b)},W=n.create({nodeChanged:p(["node","offset","prev"]),loiter:p(["node","offset"]),uiStale:p([]),domChanged:p([]),interaction:p([]),keyup:p(["original"]),mouseup:p(["original"]),keydown:r(["original"],d.events.keydown),keypress:r(["original"],d.events.keypress),mousedown:r(["original"],d.events.mousedown),contextmenu:r(["original"],d.events.contextmenu),cut:r(["original"],
d.events.cut),copy:r(["original"],d.events.copy),paste:r(["original"],d.events.paste),focus:r(["original"],d.events.focus),focusOut:r(["original"],d.events.focusOut),dblclick:r(["original"],d.events.dblclick),selectionchange:p(["original"]),paint:r([],d.events.paint)});d.events.selectionchange.bind(function(a){L().each(function(){W.trigger.selectionchange(a.original())})});return{win:d.win,doc:d.doc,body:d.body,canvas:d.body,getContent:d.get,setContent:d.set,resetContent:function(a){d.set(a);C.clear();
B.clear();a=m.freefallLtr(d.body());O(a.element(),a.offset(),a.element(),a.offset());K()},blur:d.blur,focus:function(){b.toEditor(d.focused,H,I,s.fromDom(l))},uiChanged:function(){T(function(){W.trigger.uiStale()})},domChanged:K,clearSelection:function(){h.clearAll(w)},getSelection:A,setSelection:O,setRelativeSelection:function(a,b){M(function(){h.setRelative(w,a,b)})},backupSelection:J,replaceSelection:function(a){L().fold(function(){E();L().each(function(){h.replace(w,a);F()})},function(b){h.replace(w,
a);F()})},execCommand:Q,destroy:function(){d.destroy();G.destroy();D.unbind();B.destroy()},events:W.registry,futures:d.futures,background:d.background,foreground:d.foreground,translateScreen:V,translateLocation:V}}});l("102",["b","2v","1b","52"],function(d,e,c,a){var b=e.immutable("doc","href");return function(){var e=[],g=function(a,b){return function(d){return c.eq(a,d.doc())&&b===d.href()}};return{addLinkIfMissing:function(c,k){d.find(e,g(c,k))||(e.push(b(c,k)),a.addStylesheet(k,c))}}}});l("103",
["b","9"],function(d,e){return function(){var c=null,a=[],b=function(){return null!==c},f=function(){d.each(a,function(a){g(a)})},g=function(a){setTimeout(function(){a.apply(null,c)},0)};return{get:function(c){b()?g(c):a.push(c)},set:function(){c=e.prototype.slice.call(arguments);f();a=[]},isSet:b}}});l("w2","b 8b 100 101 102 103 7 1a 2o l 2g 21 2r 2b 6p".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t){var s=b();return function(b,n,t){var l=m.fromTag("div");e.presentation(l);k.set(l,"display",
"none");var x=p.get(b);(function(a){var c=q.owner(b);d.each(a,function(a){s.addLinkIfMissing(c,a)})})(n);n=f();var z=c(b),A=a(z,t);n.set(A);return{element:function(){return b},onCanvas:function(a){a(A.canvas())},initial:g.constant(x),placeholder:function(){return l},tabindex:function(a){h.set(b,"tabindex",a)},destroy:function(){r.remove(l);A.destroy()},loaded:n.get,isInline:g.constant(!0)}}});l("12w",["7"],function(d){return function(e,c){var a=e.doc();return{execCommand:function(b){var e=arguments,
g=b.toLowerCase(),h=d.die("This should not be in hare."),h={fontsize:h,forecolor:h,fontname:h,bgcolor:h,inserthtml:h,blockquote:h};(void 0!==h[g]?h[g]:function(){a.dom().execCommand.apply(a.dom(),e)})();c.update()}}}});l("12x",["12u","jt","12v","7","6u"],function(d,e,c,a,b){return function(b){var g=function(){return c.get(b.win())},h=function(a,d,g,h){a=e(a,d,g,h);c.set(b.win(),a)};return{clearSelection:function(){c.clearAll(b.win())},getSelection:g,replaceSelection:function(a){c.replace(b.win(),
a)},setSelection:h,setRelativeSelection:function(a,d){c.setRelative(b.win(),a,d)},restore:a.noop,backup:a.noop,nativeCall:a.apply,focus:function(){d.focus(b,g,h)},destroy:a.noop,clear:a.noop}}});l("12y","jt 12v 7 s 3y 2z o q".split(" "),function(d,e,c,a,b,f,g,h){var k=function(){g.log("The previous selection could not be restored. Defaulting to the current selection.")};return function(g,p){var n=a.none(),r=b.bind(p,"blur",function(a){t()}),q=function(){n=a.none()},t=function(){e.get(g.win()).fold(c.noop,
function(b){n=a.some(b)})},s=function(b,c){try{c(g.win(),b),n=a.some(b)}catch(d){k()}},u=function(a){s(a,e.set)},l=function(){n.each(u)},w=function(a){var b=h.activeElement;a=a();null!==b&&void 0!==b&&b!==h.activeElement&&void 0!==b.focus&&b.focus();return a};return{clearSelection:function(){f.hasFocus(p)&&e.clearAll(g.win())},getSelection:function(){return f.hasFocus(p)?e.get(g.win()):n},replaceSelection:function(a){f.hasFocus(p)||l();e.replace(g.win(),a)},setSelection:function(a,b,e,g){w(function(){var h=
d(a,b,e,g);f.hasFocus(p)?u(h):s(h,c.noop)})},setRelativeSelection:function(a,b){w(function(){q();try{e.setRelative(g.win(),a,b)}catch(c){k()}t()})},restore:l,backup:t,nativeCall:function(a){return w(function(){f.hasFocus(p)||l();return a()})},focus:function(){if(h.activeElement!==p.dom()){var a=n;g.focus();a.each(u)}else e.get(g.win()).fold(l,c.noop)},destroy:function(){r.unbind()},clear:q}}});l("104","c 12p 12q 12r 12w 12x 12y aa ft 59 4a 4b 3y 3p 2a".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,
r,q,t){return function(s,u,l){var w=d.detect(),y=w.browser.isIE()||w.browser.isSpartan()?g(s,u):f(s),x=r.bind(s.doc(),"click",e(s.win(),s.body(),y.backup)),z=function(){return y.getSelection()},A=a(z,l),D=b(s,A);(w.browser.isChrome()||w.browser.isSafari())&&D.execCommand("defaultParagraphSeparator",!1,"p");A.events.nodeChanged.bind(function(a){H.trigger.nodeChanged(a.node(),a.offset(),a.prev());H.trigger.uiStale()});s.events.keyup.bind(function(a){y.backup();A.update(a)});var B=h(A.update,300);s.events.mouseup.bind(function(a){y.backup();
B.throttle(a)});var C=c(s);C.events.loiter.bind(function(a){H.trigger.loiter(a.node(),a.offset())});l=function(){C.reset();H.trigger.interaction()};s.events.keyup.bind(l);s.events.mouseup.bind(l);var F=function(){H.trigger.domChanged()},E=function(a,b,c,d){y.setSelection(a,b,c,d);A.update()},G=function(a,b){return q.absolute(u).translate(a,b)},H=p.create({nodeChanged:m(["node","offset","prev"]),loiter:m(["node","offset"]),uiStale:m([]),domChanged:m([]),interaction:m([]),keydown:n(["original"],s.events.keydown),
keyup:n(["original"],s.events.keyup),keypress:n(["original"],s.events.keypress),mousedown:n(["original"],s.events.mousedown),mouseup:n(["original"],s.events.mouseup),contextmenu:n(["original"],s.events.contextmenu),cut:n(["original"],s.events.cut),copy:n(["original"],s.events.copy),paste:n(["original"],s.events.paste),focus:n(["original"],s.events.focus),focusOut:n(["original"],s.events.focusOut),dblclick:n(["original"],s.events.dblclick),selectionchange:n(["original"],s.events.selectionchange),paint:n([],
s.events.paint)});return{win:s.win,doc:s.doc,body:s.body,canvas:s.doc,getContent:s.get,setContent:s.set,resetContent:function(a){s.set(a);y.clear();A.clear();a=k.freefallLtr(s.body());E(a.element(),a.offset(),a.element(),a.offset());F()},blur:s.blur,focus:function(){y.focus()},uiChanged:function(){H.trigger.uiStale()},domChanged:F,clearSelection:function(){y.clearSelection()},getSelection:z,setSelection:E,setRelativeSelection:function(a,b){y.setRelativeSelection(a,b);A.update()},backupSelection:function(){y.backup()},
replaceSelection:function(a){y.replaceSelection(a);A.update()},execCommand:function(){var a=arguments;y.nativeCall(function(){D.execCommand.apply(null,a);H.trigger.uiStale()})},destroy:function(){y.destroy();s.destroy();C.destroy();x.unbind();A.destroy()},events:H.registry,futures:s.futures,background:s.background,foreground:s.foreground,translateScreen:G,translateLocation:function(a,b){var c=t.get(s.doc());return G(a,b).translate(-c.left(),-c.top())}}}});l("15w",["7","aa","s"],function(d,e,c){return function(a){return{background:d.noop,
foreground:d.noop,focus:d.noop,keydown:d.noop,mousedown:c.some,mouseup:c.some,selectionchange:function(a){return e(a,300).throttle}}}});l("16e",["7","2a"],function(d,e){return{unbound:function(){return{unbind:d.noop}},saveScroll:function(c,a){var b=e.get(c);a();var d=e.get(c);b.top()===d.top()&&b.left()===d.left()||c.dom().defaultView.scrollTo(b.left(),b.top())}}});l("15x","16e 7 s l 2b q 37".split(" "),function(d,e,c,a,b,f,g){return function(h,k){return{background:e.noop,foreground:e.noop,focus:function(c,
e,h){d.saveScroll(a.fromDom(f),function(){d.saveScroll(b.owner(h),function(){k.browser.isSpartan()&&g.getSelection().removeAllRanges();h.dom().focus()})})},keydown:e.noop,mousedown:c.some,mouseup:c.some,selectionchange:e.constant(e.noop)}}});l("15y",["16e","7","s","21","2b"],function(d,e,c,a,b){return function(d){var g=function(b){return"body"===a.name(b.target())||"html"===a.name(b.target())?c.none():c.some(b)};return{background:function(a,c,d){b.owner(c).dom().defaultView.focus()},foreground:function(a,
b,c){void 0!==a.focus&&a.focus()},focus:e.noop,keydown:function(a){void 0!==a.focus&&a.focus()},mousedown:function(a){return g(a)},mouseup:function(a){return g(a)},selectionchange:e.constant(e.noop)}}});l("154",["c","15w","15x","15y"],function(d,e,c,a){var b=d.detect(),f=b.deviceType.isiOS()?a:b.deviceType.isAndroid()?e:c;return{get:function(a){return f(a,b)}}});l("155",["s","l"],function(d,e){var c=function(a){a=a.dom();try{var b=a.contentWindow?a.contentWindow.document:a.contentDocument;return void 0!==
b&&null!==b?d.some(e.fromDom(b)):d.none()}catch(c){return console.log("Error reading iframe: ",a),console.log("Error was: "+c),d.none()}};return{doc:function(a){return c(a).fold(function(){return a},function(a){return a})}}});l("14l",["155","2n"],function(d,e){return{write:function(c,a){if(!e.inBody(c))throw"Internal error: attempted to write to an iframe that is not in the DOM";var b=d.doc(c).dom();b.open();b.writeln(a);b.close()}}});l("i5","2m 3w p 3y 6e 3x".split(" "),function(d,e,c,a,b,f){var g=
function(d,e,g,p){return d(function(d){var h=a.bind(e,g,function(a){b(q);h.unbind();d(c.value(a))}),q=f(function(){h.unbind();d(c.error("Event "+g+" did not fire within "+p+"ms"))},p)})};return{cWaitFor:function(a,b,c){return g(d.nu,a,b,c)},waitFor:function(a,b,c){return g(e.nu,a,b,c)}}});l("12z","b c 4d 154 7 aa 155 14l 59 4a 4e 3y i5 2g 32 q".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s){var u=e.detect(),l=function(a){var c=a.base.fold(b.constant(""),function(a){return'<base href="'+a+'" />'}),
e=a.editorStyles.concat(a.stylesheets),e=d.map(e,function(a){return'<link rel="stylesheet" type="text/css" href="'+a+'" />'});a=0===a.documentStyles.length?"":'<style type="text/css">'+a.documentStyles+"</style>";return"<!doctype html><html><head>"+c+e.join("")+a+'</head><body contenteditable="true" spellcheck="false"></body></html>'};return function(e,f){h.write(e,l(f));var x=e.dom().contentWindow,z=g.doc(e),A=t.descendant(z,"body").getOrDie();p.add(A,[c.base(),c.active()]);var D=u.browser.isFirefox(),
B=m.create({keydown:k(["original"]),keyup:k(["original"]),keypress:k(["original"]),mousedown:k(["original"]),mouseup:k(["original"]),contextmenu:k(["original"]),cut:k(["original"]),copy:k(["original"]),paste:k(["original"]),focus:k(["original"]),dblclick:k(["original"]),focusOut:k(["original"]),paint:k([]),selectionchange:k(["original"])}),C=a.get(B),F={loaded:r.cWaitFor(e,"load",1E3)},E=n.bind(z,"keydown",function(a){C.keydown(x);B.trigger.keydown(a)}),G=n.bind(z,"keyup",function(a){B.trigger.keyup(a)}),
H=n.bind(z,"keypress",function(a){B.trigger.keypress(a)}),I=n.bind(z,"mousedown",function(a){C.mousedown(a).fold(function(){a.kill()},B.trigger.mousedown)}),K=n.bind(z,"mouseup",function(a){C.mouseup(a).fold(function(){a.kill()},B.trigger.mouseup)}),J=n.bind(z,"contextmenu",function(a){B.trigger.contextmenu(a)}),L=n.bind(z,"cut",function(a){B.trigger.cut(a)}),N=n.bind(z,"copy",function(a){B.trigger.copy(a)}),M=n.bind(z,"paste",function(a){B.trigger.paste(a)}),O=n.bind(z,D?"focus":"focusin",function(a){B.trigger.focus(a)}),
S=n.bind(z,"focusout",function(a){B.trigger.focusOut(a)}),P=n.bind(z,"dblclick",function(a){B.trigger.dblclick(a)}),T=C.selectionchange(function(a){B.trigger.mouseup(a)}),Q=n.bind(z,"selectionchange",function(a){T(a);B.trigger.selectionchange(a)}),V=n.bind(z,"touchstart",function(a){B.trigger.mousedown(a)}),W=n.bind(z,"touchend",function(a){B.trigger.mouseup(a);da()}),$=function(){B.trigger.paint()},X=n.capture(A,"load",$),Y=function(){x.addEventListener("resize",$,!1);return{unbind:function(){x.removeEventListener&&
x.removeEventListener("resize",$,!1)}}}(),da=function(){C.foreground(x,e,A)};return{win:b.constant(x),doc:b.constant(z),body:b.constant(A),get:function(){return q.get(A)},set:function(a){q.set(A,a)},focus:function(){C.focus(x,e,A)},focused:function(){return s.activeElement===e.dom()},blur:function(){A.dom().blur()},destroy:function(){d.each([E,G,H,I,K,J,L,N,M,O,S,Q,P,V,W,X,Y],function(a){a.unbind()})},events:B.registry,futures:F,background:function(){C.background(x,e,A)},foreground:da}}});l("130",
["4j"],function(d){return{resolve:d.create("ephox-hare").resolve}});l("105","12z 130 103 7 s 1a 2n 1y 3y l 2r th".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){return function(r){var q=m.fromTag("iframe");h.add(q,e.resolve("content-iframe"));var t=b.none(),s=c(),u=k.bind(q,"load",function(){u.unbind();var c=n.onShow(q,function(){t.each(a.apply);t=b.none();g.inBody(q)&&s.set(d(q,r))});t=b.some(c)});return{element:function(){return q},tabindex:function(a){f.set(q,"tabindex",a)},destroy:function(){p.remove(q);
u.unbind();t.each(a.apply)},loaded:s.get}}});l("w3",["104","105","103","7","3x"],function(d,e,c,a,b){return function(f,g){var h=e(f),k=c(),m=a.noop;h.loaded(function(a){var c=d(a,h.element(),g);b(function(){k.set(c);m=c.destroy},0)});return{element:h.element,onCanvas:function(a){k.get(function(b){a(b.canvas())})},initial:a.constant(""),placeholder:h.element,tabindex:h.tabindex,destroy:function(){m();h.destroy()},loaded:k.get,isInline:a.constant(!1)}}});l("nr","c w2 w3 7 s br 59 4a 3o".split(" "),
function(d,e,c,a,b,f,g,h,k){var m=function(c){var e=b.none(),m=f.tap(function(a,b,c){z.trigger.nodeChanged(a,b,c)});c.loaded(function(a){if(void 0===a.win().window)a.destroy();else{e=b.some(a);if(d.detect().browser.isFirefox()){try{a.execCommand("enableObjectResizing",!1,!1)}catch(c){}try{a.execCommand("enableInlineTableEditing",!1,!1)}catch(f){}}a.events.nodeChanged.bind(function(a){m.instance(a.node(),a.offset(),a.prev())});a.events.loiter.bind(function(a){z.trigger.loiter(a.node(),a.offset())});
a.events.uiStale.bind(function(){z.trigger.uiStale()});a.events.domChanged.bind(function(){z.trigger.domChanged()});a.events.interaction.bind(function(){z.trigger.interaction()});a.events.keyup.bind(function(a){z.trigger.keyup(a.original())});a.events.keydown.bind(function(a){z.trigger.keydown(a.original())});a.events.keypress.bind(function(a){z.trigger.keypress(a.original())});a.events.mousedown.bind(function(a){z.trigger.mousedown(a.original())});a.events.mouseup.bind(function(a){z.trigger.mouseup(a.original())});
a.events.contextmenu.bind(function(a){z.trigger.contextmenu(a.original())});a.events.cut.bind(function(a){z.trigger.cut(a.original())});a.events.copy.bind(function(a){z.trigger.copy(a.original())});a.events.paste.bind(function(a){z.trigger.paste(a.original())});a.events.focus.bind(function(a){z.trigger.focus(a.original())});a.events.focusOut.bind(function(a){z.trigger.focusOut(a.original())});a.events.dblclick.bind(function(a){z.trigger.dblclick(a.original())});a.events.selectionchange.bind(function(a){z.trigger.selectionchange(a.original())});
a.futures.loaded.get(function(){void 0!==a.win().window&&z.trigger.loaded()});a.events.paint.bind(function(){z.trigger.paint()});a.resetContent(s);z.trigger.ready(a);a.uiChanged()}});var q=function(){return e.map(function(a){return a.win()})},t=function(){return e.map(function(a){return a.doc()})},s=c.initial(),u=function(){e.each(function(a){a.focus()})},l=function(){return e.bind(function(a){return a.getSelection()})},w=function(a,b,c,d){e.each(function(e){e.setSelection(a,b,c,d)})},y=function(a,
b){e.each(function(c){c.setRelativeSelection(a,b)})},x=function(){var a=arguments;e.each(function(b){b.execCommand.apply(null,a)})},z=h.create({nodeChanged:g(["node","offset","prev"]),loiter:g(["node","offset"]),uiStale:g([]),domChanged:g([]),interaction:g([]),keydown:g(["original"]),keyup:g(["original"]),keypress:g(["original"]),mousedown:g(["original"]),mouseup:g(["original"]),contextmenu:g(["original"]),cut:g(["original"]),copy:g(["original"]),paste:g(["original"]),focus:g(["original"]),focusOut:g(["original"]),
dblclick:g(["original"]),selectionchange:g(["original"]),paint:g([]),ready:g(["api"]),loaded:g([])});return{element:c.element,tabindex:c.tabindex,onCanvas:c.onCanvas,win:q,doc:t,body:function(){return e.map(function(a){return a.body()})},getContent:function(){return e.fold(function(){return s},function(a){return a.getContent()})},setContent:function(a){e.fold(function(){s=a},function(b){b.setContent(a)})},resetContent:function(a){e.fold(function(){s=a},function(b){b.resetContent(a)})},blur:function(){e.each(function(a){a.blur()})},
focus:u,uiChanged:function(){e.each(function(a){a.uiChanged()})},domChanged:function(){e.each(function(a){a.domChanged()})},clearSelection:function(){e.each(function(a){a.clearSelection()})},getSelection:l,setSelection:w,setRelativeSelection:y,backupSelection:function(){e.each(function(a){a.backupSelection()})},replaceSelection:function(a){e.each(function(b){b.replaceSelection(a)})},execCommand:x,lockdown:function(a){var b=m.control.isBlocked();m.control.block();a();b||m.control.unblock()},destroy:function(){c.destroy();
e=b.none()},events:z.registry,background:function(){e.fold(a.identity,function(a){a.background()})},foreground:function(){e.fold(a.identity,function(a){a.foreground()})},on:function(b){return q().bind(function(c){return t().map(function(d){return b({win:a.constant(c),doc:a.constant(d),execCommand:x,getSelection:l,setSelection:w,setRelativeSelection:y,focus:u})})})},translateScreen:function(a,b){return e.fold(function(){return k(a,b)},function(c){return c.translateScreen(a,b)})},translateLocation:function(a,
b){return e.fold(function(){return k(a,b)},function(c){return c.translateLocation(a,b)})},placeholder:c.placeholder,isInline:c.isInline}};return{frame:function(a,b){var d=c(a,b);return m(d)},detached:function(a,b,c){a=e(a,b,c);return m(a)}}});l("j1","a 1o 81 7 57 2o l 2g 2p 2r 3x".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=function(a,b){if(void 0!==a&&d.isFunction(a.setData))try{return e.each(b,function(b,c){a.setData(c,b())}),!0}catch(c){return!1}else return!1},r=function(a,b,d){var e=g.fromTag("div",
a.doc().dom());f.setAll(e,{position:"absolute",top:"-1000px"});b=b["text/html"]();h.set(e,b);k.append(a.body(),e);var n=a.getSelection();c.selectElementContents(a.win(),e);p(function(){m.remove(e);n.each(function(b){a.setSelection(b.startContainer(),b.startOffset(),b.endContainer(),b.endOffset())});p(d,0)},0)},q=function(a){return function(b,c,e){var f=b.raw();if(!d.isString(f.type)||"copy"!==f.type.toLowerCase()&&"cut"!==f.type.toLowerCase())throw"Can only set the clipboard with a cut or copy event";
if(!d.isFunction(c["text/html"]))throw"Must provide at least text/html data function when setting clipboard contents";n(f.clipboardData,c)?(b.kill(),p(e,0)):a(c,e)}},t=b.exactly(["doc","win","body","getSelection","setSelection"]);return{register:function(b){t(b);b=a.curry(r,b);return{setClipboard:q(b)}},textMime:a.constant("text/plain"),htmlMime:a.constant("text/html")}});l("ns",["21","c6"],function(d,e){var c=e(d.isComment,"comment");return{get:function(a){return c.get(a)},getOption:function(a){return c.getOption(a)},
set:function(a,b){c.set(a,b)}}});l("j0","b 7 r s k j1 ns 21 v".split(" "),function(d,e,c,a,b,f,g,h,k){var m={clipboardType:e.constant("x-textbox/html"),findClipboardTags:function(c){c=b.cat(d.map(c,function(b){if(h.isComment(b)){var c=g.get(b);if(k.contains(c,"x-textbox/html"))return a.some(b)}return a.none()}));return 0===c.length?a.none():a.some(c)}};return{intraFlag:e.constant(m),buildClipboardContents:function(a,b){var d={};d["x-textbox/html"]=e.constant("true");d[f.textMime()]=c.cached(a);d[f.htmlMime()]=
c.cached(function(){return"\x3c!-- x-textbox/html --\x3e"+b()});return d},ignoreSelectors:e.constant([".ephox-sloth-bin"])}});l("fa","nr 7 j0 34 4e 2o 2p 32 o".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(a,b){return{editable:e.constant(a),connect:b}},p=function(a,b){var e=d.frame(b,c.ignoreSelectors());e.events.ready.bind(function(b){b=b.api().body();a.updateUi(b)});return m(e,function(a){g.append(a,e.element())})},n=function(p,n){0!==n.stylesheets.length&&k.log("You have attempted to declare the following stylesheets for use in textbox.io: ["+
n.stylesheets.join(", ")+"]. User stylesheets are not used in inline editing mode and have been ignored.");0!==n.documentStyles.length&&k.log('You have attempted to declare the following document styles for use in textbox.io: "'+n.documentStyles+'". Document styles are not used in inline editing mode and have been ignored.');n.base.fold(e.noop,function(a){k.log('You have attempted to declare the following content base URL for use in textbox.io: "'+a+'". Content base URL is not used in inline editing mode and has been ignored.')});
var t=d.detached(n.inline,n.editorStyles,c.ignoreSelectors());return m(t,function(c){g.append(c,t.placeholder());c=h.ancestor(c,".ephox-polish-editor-container").getOr(c);f.set(t.placeholder(),"display","none");b.add(c,[a.resolve("inline-editor-container"),a.resolve("layer-editor")])})};return{build:function(a,b){return(void 0!==b.inline?n:p)(a,b)}}});l("fb",["s","2a"],function(d,e){return function(c){var a=d.none(),b=d.none(),f=function(){a.each(function(a){c.setSelection(a.startContainer(),a.startOffset(),
a.endContainer(),a.endOffset())});b.each(function(a){c.win().each(function(b){b.scrollTo(a.left(),a.top())})})},g=function(){a=d.none();b=d.none()};return{restore:function(){f();g()},save:function(){a=c.getSelection();b=c.doc().map(e.get)},get:function(){return a},clear:g,attempt:function(b){a=b.or(a)}}}});l("nt","84 b c l 2p 2b".split(" "),function(d,e,c,a,b,f){var g=c.detect().browser.isFirefox(),h=function(c){e.each(c,function(c){f.nextSibling(c).isNone()&&b.after(c,a.fromText(d.zeroWidth()))})};
return{configure:function(a){g&&a.addSelector(a.input(),"a",h)}}});l("fc","b 87 7 ft nt 34 fg cw e7 7n 1a 1y l 2p 2r 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s){var u=f.resolve("content-eph-wrapper"),l=f.resolve("content-eph-extra"),w=f.resolve("content-eph-general"),y=function(a){d.each(a,function(a){n.remove(a,k.styleSpan());p.remove(a,k.overrideSpan());(p.hasNone(a)||m.isTransient(a))&&t.unwrap(a)})},x=function(a){d.each(a,function(a){n.remove(a,k.quasiBlock())})},z=function(a){d.each(a,
function(a){var b=p.get(a,"style");p.set(a,"style",b.replace(/"/g,"'"))})},A=function(b){return e.isCursorPosition(b)||g.isBlock(b)||e.isCursorPosition(a.freefallLtr(b).element())},D=function(a){d.each(a,function(a){if(0===d.filter(s.children(a),A).length){var b=r.fromTag("br");q.append(a,b)}})};return{configure:function(a){a.add(a.internal(),u,h.unwrap);a.add(a.internal(),l,h.remove);a.add(a.internal(),w,h.remove);a.add(a.internal(),k.quasiBlock(),x);a.add(a.output(),u,h.unwrap);a.add(a.output(),
l,h.remove);a.add(a.output(),w,h.remove);a.add(a.output(),k.styleSpan(),y);a.add(a.output(),k.quasiBlock(),x);a.addExcludedContext(["."+u,"."+l,"."+w,"."+k.styleSpan()]);a.addSelector(a.input(),"[style]",z);a.addSelector(a.input(),"td,th",D);a.addSelector(a.paste(),"[style]",z);a.addSelector(a.paste(),"td,th",D);b.configure(a)},markerWrapper:c.constant(u),markerExtra:c.constant(l),markerGeneral:c.constant(w)}});l("131",["4j"],function(d){return{resolve:d.create("ephox-cereal").resolve}});l("106",
"131 b 7 1a 1y 4e 32 e2".split(" "),function(d,e,c,a,b,f,g,h){var k=d.resolve("start-cursor"),m=d.resolve("finish-cursor"),p="data-"+d.resolve("start-offset"),n="data-"+d.resolve("finish-offset"),r=function(b){a.remove(b,p);a.remove(b,n);f.remove(b,[k,m]);""===a.get(b,"class")&&a.remove(b,"class")},q=function(b,c){var d=a.get(b,c);return h(d,10)};return{setInfo:function(c,d,f,g){e.each([c,d],r);b.add(c,k);b.add(d,m);a.set(c,p,f);a.set(d,n,g)},clearInfo:r,findStart:function(a){return g.descendant(a,
"."+k).map(function(a){return{token:c.constant(a),offset:c.constant(q(a,p))}})},findFinish:function(a){return g.descendant(a,"."+m).map(function(a){return{token:c.constant(a),offset:c.constant(q(a,n))}})}}});l("132",["2v"],function(d){return d.immutable("token","remove","extra")});l("107",["106","132","7"],function(d,e,c){return{use:function(a,b){return e(b,c.noop,[])},extract:function(a){return{remove:c.curry(d.clearInfo,a),element:c.constant(a)}}}});l("108","132 131 7 s 1y 2o l 2p 2r 2b".split(" "),
function(d,e,c,a,b,f,g,h,k,m){var p=e.resolve("pre-cursor-token"),n=e.resolve("post-cursor-token"),r=e.resolve("first-cursor-token"),q=function(){var a=g.fromTag("span");f.set(a,"display","none");return a},t=function(a){var b=c.curry(k.remove,a);return d(a,b,[a])},s=function(c){return b.has(c,p)?m.nextSibling(c):b.has(c,n)?m.prevSibling(c):b.has(c,r)?m.parent(c):a.none()};return{pre:function(a,c){var d=q();h.before(c,d);b.add(d,p);return t(d)},post:function(a,c){var d=q();h.after(c,d);b.add(d,n);
return t(d)},first:function(a,c){var d=q();h.prepend(a,d);b.add(d,r);return t(d)},extract:function(a){return s(a).map(function(b){return{remove:c.curry(k.remove,a),element:c.constant(b)}})}}});l("133",["2v"],function(d){var e=d.immutable("element","offset");d=d.immutable("startContainer","startOffset","endContainer","endOffset");return{point:e,range:d}});l("134","131 7 1y l 2p 4h 2b".split(" "),function(d,e,c,a,b,f,g){var h=d.resolve("text-node-wrapper"),k=function(a){return c.has(a,h)};return{create:function(){var b=
a.fromTag("span");c.add(b,h);return b},findIn:function(a){return f.children(a,"."+h)},isWrap:k,inWrap:function(a){return g.parent(a).fold(e.constant(!1),function(a){return k(a)})},child:function(c){return g.child(c,0).fold(function(){var d=a.fromText("");b.append(c,d);return d},e.identity)}}});l("135","134 b l 2p 2r 2b".split(" "),function(d,e,c,a,b,f){var g=function(g){g=d.findIn(g);e.each(g,function(d){0===f.children(d).length&&a.before(d,c.fromText(""));b.unwrap(d)})},h=function(a){f.parent(a).each(b.unwrap)};
return{unwrap:function(a){(d.inWrap(a)?h:g)(a)}}});l("109","106 133 134 135 107 108 7 1b dy 21 2r".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=function(a,c,d,e){return h.eq(a,c)?f.first(a,c):m.isElement(c)&&!e(c)?b.use(a,c):d(a,c)};return{extractFrom:function(b,d){b.remove();d.remove();var f=function(b){var d=c.isWrap(b)?p.unwrap:a.unwrap,e=c.isWrap(b)?c.child(b):b;return{target:g.constant(e),unwrap:g.curry(d,b)}},h=f(b.element()),k=f(d.element()),m=e.range(h.target(),b.offset(),k.target(),d.offset());
return{remove:function(){h.unwrap();k.unwrap()},getSelection:function(){return m}}},same:function(a,b,c,e,g){a=n(a,b,f.pre,g);d.setInfo(a.token(),a.token(),c,e);return[a]},diff:function(a,b,c,e,g,h){var m=k.after(b,c,e,g),p=m?f.pre:f.post;b=n(a,b,m?f.post:f.pre,h);a=n(a,e,p,h);d.setInfo(b.token(),a.token(),c,g);return[b,a]}}});l("136","134 b 7 2p 21 2b".split(" "),function(d,e,c,a,b,f){var g=function(a){return f.parent(a).fold(c.constant(!1),function(a){return d.isWrap(a)})},h=function(c){return e.foldr(c,
function(c,e){if(b.isText(e)&&!g(e)){var f=d.create();a.wrap(e,f);return[f].concat(c)}return c},[])};return{wrap:function(a){var b=f.children(a),b=0<b.length?b:[a];return d.isWrap(a)?[]:h(b)}}});l("10a",["106","135","136","b","7"],function(d,e,c,a,b){var f=function(a){a.remove()};return{combine:function(g,h){var k=a.bind(g,c.wrap),m=a.bind(h,function(a){return a.extra()});return{extra:b.constant(m),wrappers:b.constant(k),remove:function(){a.each(h,function(a){d.clearInfo(a.token())});a.each(g,e.unwrap);
a.each(h,f)}}}}});l("w4","106 107 108 109 10a 7 1b".split(" "),function(d,e,c,a,b,f,g){var h=function(c,d,e,f,g,h){var k=[d,f];c=a.diff(c,d,e,f,g,h);return b.combine(k,c)},k=function(c,d,e,f,g,h){f=[d];c=a.same(c,d,e,g,h);return b.combine(f,c)},m=function(a,b){return b(a).map(function(a){var b=c.extract(a.token()).getOrThunk(function(){return e.extract(a.token())});return{remove:b.remove,offset:a.offset,element:b.element}})},p=function(a){return m(a,d.findStart).bind(function(b){return m(a,d.findFinish).map(function(a){return{startMarker:f.constant(b),
finishMarker:f.constant(a)}})})};return{insertAt:function(a,b,c,d,e,f){return(g.eq(b,d)?k:h)(a,b,c,d,e,f)},extract:function(b){return p(b).map(function(b){return a.extractFrom(b.startMarker(),b.finishMarker())})}}});l("nu",["w4"],function(d){return{insert:function(e,c,a){e=d.insertAt(e,c.startContainer(),c.startOffset(),c.endContainer(),c.endOffset(),a);return{extra:e.extra,wrappers:e.wrappers,remove:e.remove}},extract:function(e){return d.extract(e).map(function(c){return{remove:c.remove,getSelection:c.getSelection}})}}});
l("bo",["1q","a","b","1o","19"],function(d,e,c,a,b){var f=function(c){var d=b.create(null);a.each(c,function(a,b){d[b]=a});return d},g=f({img:!0,br:!0,hr:!0,input:!0}),h=f({script:!0,style:!0,noscript:!0}),k={'"':"&quot;","&":"&amp;"},m=/["&]/g,p=/[<>&\u00A0]/g,n={"<":"&lt;",">":"&gt;","&":"&amp;","\u00a0":"&nbsp;"},r=function(a,b,c){return a.replace(b,function(a){return c[a]||a})},q=function(a,b){for(var c="<"+a,d="",e=0;e<b.length;e++){var f=b[e];f.specified&&"_moz_dirty"!==f.name&&(d+=" "+f.name+
'="'+r(f.value,m,k)+'"')}return c+d},t=function(a){var b="";c.each(a,function(a){b+=u(a)});return b},s=function(a){var b="";c.each(a,function(a){b+=a.textContent});return b},u=function(a){var b=a.nodeType;if(b===d.ELEMENT){var b=a.nodeName.toLowerCase(),c=a.childNodes;a=a.attributes;0===c.length&&g[b]?b=q(b,a)+" />":(c=h[b]?s(c):t(c),b=q(b,a)+">"+c+"</"+b+">");return b}if(b===d.TEXT)return r(a.textContent,p,n);if(b==d.COMMENT)return"\x3c!--"+a.data+"--\x3e";throw"unsupported node type "+a.nodeType;
};return{writeNode:function(a){if(!e.isObject(a))throw"sugarNode parameter must be an object";return u(a.dom())},writeChildren:function(a){if(!e.isObject(a))throw"sugarNode parameter must be an object";return t(a.dom().childNodes)}}});l("fd","nu b es 9o 87 7 fc 1a 1y nv 2g 69 2b bo 1s".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t){var s=function(a,b){e.each(a,function(a){k.add(a,b)})},u=function(a){var b=function(){return r.parent(a).map(function(a){return"false"===h.get(a,"contenteditable")}).getOr(!1)};
return"false"===h.get(a,"contenteditable")||b()};return{extract:function(a){return d.extract(a)},getSelection:function(d){var e=d.getSelection();d=e.startContainer();var f=e.startOffset(),g=e.endContainer(),e=e.endOffset(),h=b.getEnd(d),k=b.getEnd(g);return 0<=f&&f<=h&&0<=e&&e<=k?c.write(a.on(d,f),a.on(g,e)):c.write(a.before(d),a.before(d))},remove:function(a){a.remove()},serialise:function(a,b){return m.path(a,b.startContainer()).bind(function(c){return m.path(a,b.endContainer()).bind(function(e){var h=
n.deep(a);return m.follow(h,c).bind(function(a){return m.follow(h,e).map(function(c){c={startContainer:f.constant(a),startOffset:f.constant(b.startOffset()),endContainer:f.constant(c),endOffset:f.constant(b.endOffset())};c=d.insert(h,c,u);s(c.wrappers(),g.markerWrapper());s(c.extra(),g.markerExtra());return q.writeChildren(h)})})})})}}});l("137",["2v"],function(d){return d.immutable("word","left","right")});l("138",["b","s","137"],function(d,e,c){var a=["'","\u2018","\u2019"],b=d.bind(a,function(a){return d.map(["twas"],
function(b){return a+b})}),f=function(a){var b=a.word();return c(b.substring(1),e.some(b.charAt(0)),a.right())},g=function(b){return d.contains(a,b)},h=function(a){var c=a.word(),e=d.exists(b,function(a){return-1<c.indexOf(a)})?2:1,h=c.substring(0,e);return d.forall(h,g)&&!g(c.charAt(e))?f(a):a},k=function(a){var b=a.word();2<=b.length&&g(b.charAt(b.length-1))&&!g(b.charAt(b.length-2))&&(b=a.word(),a=c(b.substring(0,b.length-1),a.left(),e.some(b.charAt(b.length-1))));return h(a)};return{scope:k,text:function(a){a=
c(a,e.none(),e.none());return k(a).word()}}});l("10c","b s 6o hw 137 138 6p".split(" "),function(d,e,c,a,b,f,g){return{words:function(g){var k=c.unsafetoken(c.wordchar()+"+"),k=a.findall(g,k),m=g.length;return d.map(k,function(a){var c=a.start(),d=a.finish();a=g.substring(c,d);c=0<c?e.some(g.charAt(c-1)):e.none();d=d<m?e.some(g.charAt(d)):e.none();a=b(a,c,d);return f.scope(a)})}}});l("w5",["10b","10c"],function(d,e){return{identify:function(c){return e.words(c)},isWord:function(c,a){return!d.hasBreak(a)}}});
l("nw",["6q","w5"],function(d,e){var c=d();return{identify:function(a){return e.identify(a)},isWord:function(a){return e.isWord(c,a)}}});l("fe","c s f9 nw e8 21 2b".split(" "),function(d,e,c,a,b,f,g){var h=d.detect(),k=function(a,b){return f.isText(a)?e.some(c.point(a,b)):0===g.children(a).length?e.none():g.child(a,b).bind(function(a){return k(a,0)})},m=function(a,c,d){a.on(function(a){b.expandWord(a,c,d)})},p=function(b,c){var d=b.dom().createRange();d.setStart(c.startContainer().dom(),c.startOffset());
d.setEnd(c.endContainer().dom(),c.endOffset());return a.isWord(d.cloneContents().textContent)};return{correct:function(a){a.getSelection().each(function(b){a.doc().each(function(c){p(c,b)&&k(b.startContainer(),b.startOffset()).each(function(c){(!b.collapsed()||a.isInline()&&h.browser.isIE())&&m(a,c.element(),c.offset())})})})},expand:function(a){a.on(b.expand);a.backupSelection()}}});l("66",["84","bo","6p"],function(d,e,c){return{output:function(a,b){a.filterDom(a.output(),b);var f=e.writeChildren(b),
g=new c(d.zeroWidth(),"g");return f.replace(g,"")}}});aa("ny",Image);l("nx","59 4a 1a 3y l ny".split(" "),function(d,e,c,a,b,f){return function(){var a=e.create({fail:d(["url","image"]),success:d(["url","image"]),start:d(["url"])}),h=function(a,b,c){var d=a.dom();d.addEventListener(b,c,!1);return{unbind:function(){d.removeEventListener(b,c,!1)}}},k=function(b){var d=c.get(b,"src"),e=h(b,"load",function(){e.unbind();f.unbind();(!0===b.dom().complete?a.trigger.success:a.trigger.fail)(d,b)}),f=h(b,"error",
function(){e.unbind();f.unbind();a.trigger.fail(d,b)})};return{go:function(c){a.trigger.start(c);var d=new f;d.src=c;k(b.fromDom(d))},monitor:k,events:a.registry}}});l("h6",["b","3w","7","p"],function(d,e,c,a){var b=function(a,b){return a.bind(function(a){return a.fold(function(){return e.pure(a)},function(a){return b(a)})})},f=function(b){return e.pure(a.value(b))},g=function(b){return e.nu(function(c){b.then(function(b){c(a.value(b))},function(b){c(a.error(b))})})},h=function(b){return b.map(a.value)};
return{fromPromise:g,error:function(b){return e.pure(a.error(b))},map:function(a,b){return a.map(function(a){return a.map(b)})},bind:b,pure:f,fromChain:function(a){return function(c){return d.foldl(a,function(a,c){return b(a,function(a){return c(a)})},f(c))}},fromFuture:h,pToFR:function(a){return c.compose(g,a)},fToFR:function(a){return c.compose(h,a)},effect:function(a){return function(b){b.each(function(){a()});return b}}}});l("ff","nx 3w p h6 1a ny".split(" "),function(d,e,c,a,b,f){var g=function(a){return e.nu(function(b){if(!0===
a.dom().complete)b(c.value(a));else{var e=d();h(e,b);e.monitor(a)}})},h=function(a,b){a.events.success.bind(function(a){b(c.value(a.image()))});a.events.fail.bind(function(a){b(c.error("Unable to download image "+a.url()))})};return{load:function(a){return e.nu(function(b){var c=d();h(c,b);c.go(a)})},loadIfNeeded:function(c){return!0===c.dom().complete||void 0===b.get(c,"src")?a.pure(c):g(c)}}});l("8e","ez 84 c 9o 81 3w 7 s f9 br 83 3l fa fb fc fd fe 66 ff cn 59 4a 4b fg 1a 1y 1b 3y l 3m 2p 21 4l 2r 69 4h m az 2b".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,l,w,y,x,z,A,D,B,C,F,E,G,H,I,K,J,L,N,M,O,S,P){var T=c.detect();return function(c,V,W,$,X){t.configure(c);var Y=h.none(),da={inline:W.inline,base:h.from(W.base),editorStyles:[W.css+"/content.css"],stylesheets:W.stylesheets,documentStyles:W.documentStyles};$=r.build($,da);var R=$.editable();null!==W.tabindex&&R.tabindex(W.tabindex);void 0!==X.raw&&R.setContent(X.raw);R.events.ready.bind(function(){if(void 0!==X.raw){var a=R.getContent();X.raw===a&&ea(X.marked,
!1)}a=R.body().getOrDie();Y=h.some(E.bind(a,"dblclick",function(a){u.correct(R)}))});R.events.ready.bind(function(a){y.addClasses(a.api().body())});var ca=function(){return R.getSelection().bind(function(a){var b=R.body().getOrDie("content should not return a selection if body is not yet available");return s.serialise(b,a)}).getOr(R.getContent())},ea=function(a,b){R.body().each(function(c){R.setContent(a);s.extract(c).fold(function(){R.setSelection(c,0,c,0)},function(a){var b=s.getSelection(a);s.remove(a);
R.setRelativeSelection(b.start(),b.finish())});if(!T.deviceType.isiOS()){var d=M.descendants(c,"img");b?f.mapM(d,w.loadIfNeeded).get(function(){Z()}):Z()}})},fa=z.create({nodeChanged:x(["node","offset","prev"]),undoChanged:x([]),loiter:A(["node","offset"],R.events.loiter),uiStale:A([],R.events.uiStale),domChanged:A([],R.events.domChanged),interaction:A([],R.events.interaction),keydown:A(["original"],R.events.keydown),keyup:A(["original"],R.events.keyup),keypress:A(["original"],R.events.keypress),
mousedown:A(["original"],R.events.mousedown),mouseup:A(["original"],R.events.mouseup),contextmenu:A(["original"],R.events.contextmenu),copy:A(["original"],R.events.copy),paste:A(["original"],R.events.paste),focus:A(["original"],R.events.focus),focusOut:A(["original"],R.events.focusOut),dblclick:A(["original"],R.events.dblclick),selectionchange:A(["original"],R.events.selectionchange),paint:A([],R.events.paint),ready:A(["api"],R.events.ready),loaded:A([],R.events.loaded),background:x([]),foreground:x([]),
scrollToCursor:x([]),scrollToElement:x(["element"]),toEditing:x([]),toReading:x([])});R.events.nodeChanged.bind(function(a){fa.trigger.nodeChanged(a.node(),a.offset(),a.prev());ia()});var ga=m.tap(function(){fa.trigger.undoChanged()}),ia=function(){ga.instance()},ha=function(a){ga.instance();var b=ga.control.isBlocked();ga.control.block();a=a();b||ga.control.unblock();ga.instance();return a},Z=function(){fa.trigger.scrollToCursor()},aa=m.tap(function(){R.focus()});W=function(a){return function(){var b=
arguments;P.parent(R.element()).fold(function(){a.apply(null,b)},function(c){var d=c.dom().scrollTop;a.apply(null,b);c.dom().scrollTop=d})}}(R.execCommand);var ja=function(a){return K.isText(a)&&(T.browser.isSafari()||0===S.get(a).length)||K.isElement(a)&&!D.isEmptyTag(a)&&!D.isBlock(a)},ba=function(a){var b=G.fromText(e.zeroWidth());I.after(a,b);return b},U=function(a,b){var c=P.children(a);if(b>=c.length)return k.point(a,b);var d=c[b];return K.isElement(d)&&!D.isEmptyTag(d)?U(c[b],0):k.point(a,
b)},ka=function(b){b=ja(b)?ba(b):b;R.setRelativeSelection(a.after(b),a.after(b));R.getSelection().each(function(a){a=U(a.startContainer(),a.startOffset());R.setSelection(a.element(),a.offset(),a.element(),a.offset())})},pa=function(){return la.getSelection().bind(function(a){if(a.collapsed())return h.none();a=b.cloneFragment(la.win().getOrDie(),a.startContainer(),a.startOffset(),a.endContainer(),a.endOffset());return h.some(a)})},ma=function(a){return l.output(c,a)},la={onCanvas:R.onCanvas,element:R.element,
isInline:R.isInline,win:R.win,doc:R.doc,body:R.body,getContent:R.getContent,setContent:R.setContent,resetContent:R.resetContent,focus:function(){aa.instance()},blur:R.blur,uiChanged:R.uiChanged,domChanged:R.domChanged,undoChanged:ia,clearSelection:R.clearSelection,getSelection:R.getSelection,getSelectionStart:function(){return R.getSelection().map(function(a){return a.startContainer()})},setSelection:R.setSelection,setRelativeSelection:R.setRelativeSelection,backupSelection:R.backupSelection,replaceSelection:R.replaceSelection,
replaceElement:function(a,b){var c=la.getSelection().filter(function(b){var c=g.curry(F.eq,a);return J.closest(b.startContainer(),c)||J.closest(b.endContainer(),c)}).isSome();I.before(a,b);L.remove(a);c&&ka(b);la.domChanged();ia()},findTagAtCursor:function(a){var b=function(a,b,d){a=P.child(a,b).getOr(a);return J.closest(a,function(a){return O.is(a,d)&&c.includeContext(a)})};return la.getSelection().bind(function(c){return b(c.startContainer(),c.startOffset(),a).orThunk(function(){return b(c.endContainer(),
c.endOffset(),a)})})},getFilteredAttributes:function(a){a=N.shallow(a);var b=G.fromTag("div");I.append(b,a);c.filterDom(c.output(),b);return B.clone(a)},execCommand:W,insertHtmlAtCursor:function(a){var b=H.fromHtml(a);ha(function(){p.insertAtCursorWithInstructions(d.doNotMerge,la,b).each(function(a){var c=a.element();P.parent(c).each(function(a){ka(c);V.input(b)})})})},on:R.on,destroy:function(){Y.each(function(a){a.unbind()});R.destroy()},events:fa.registry,state:function(){return{raw:R.getContent(),
marked:ca()}},serialize:ca,deserialize:function(a){ea(a,!0)},background:function(){R.background();fa.trigger.background()},foreground:function(){R.foreground();fa.trigger.foreground()},isRoot:function(a){return R.body().fold(g.constant(!1),function(b){return F.eq(b,a)})},selectWord:function(){u.expand(R)},cursor:function(){return q(R)},activate:function(){aa.control.unblock()},deactivate:function(){aa.control.block()},cursorIntoView:Z,elementIntoView:function(a){fa.trigger.scrollToElement(a)},placeholder:R.placeholder,
connect:$.connect,translateScreen:R.translateScreen,translateLocation:R.translateLocation,runOrOnLoaded:function(a){R.body().fold(function(){R.events.ready.bind(function(b){a(b.api().body())})},function(b){a(b)})},getSelectedText:function(){return pa().map(function(a){a=P.children(a);return n.toText(a)})},getSelectedHtml:function(){return pa().map(function(a){var b=G.fromTag("div");I.append(b,a);return ma(b)})},getFilteredContents:ma,toEditing:function(){fa.trigger.toEditing()},toReading:function(){fa.trigger.toReading()},
undoOperation:ha,markAsEphemeral:function(a){C.add(a,t.markerGeneral())},hideInlineSelection:function(){R.isInline()&&(R.backupSelection(),R.clearSelection())}};return la}});l("fj",["7"],function(d){return{get:d.constant({onShortcut:function(d,c){d.bind(c)}})}});l("nz",["gr","34","1a"],function(d,e,c){var a="data-"+e.resolve("context-type");return{nu:function(b,e,g){b=d.item(b,g.value(),g.text());c.set(b,a,e);c.setAll(b,g.attrs());return b},type:function(b){return c.get(b,a)}}});l("o0","7d b 8b gr kq s nz 4e".split(" "),
function(d,e,c,a,b,f,g,h){return{derive:function(k,m,p){m=e.map(m,function(a){var b=p[a],m=b.primary(),t=b.submenus();return e.map(m,function(b){var e=g.nu(k,a,b),m=t.hasOwnProperty(b.value())&&void 0!==t[b.value()]?[d.resolve("menu-more")]:[],p=void 0!==t[b.value()];c.menuItem(e,f.some(b.text()),f.some(p));h.add(e,m);return e})});m=e.filter(m,function(a){return 0<a.length});return e.flatten(b.intersperseThunk(m,function(){return[a.separator(k)]}))}}});l("o1","b 8b gr s nz 7b 3d".split(" "),function(d,
e,c,a,b,f,g){return{derive:function(h,k,m){return d.bind(k,function(k){var n=m[k].secondary();return d.map(n,function(m){var n=c.submenu(h,m.value(),[]);e.menu(n,f.get(m.textkey()));m=d.map(m.items(),function(c){var d=b.nu(h,k,c);e.menuItem(d,a.some(c.text()),a.none());return d});g.append(n,m);return n})})}}});l("fk","b 1o 8b gr 6 s nz o0 o1 7b 34 4p 1y 3d 2r".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t){return function(s){var u=n({}),l=n([]),w={},y=f.none();return{structure:u.get,all:l.get,
main:function(){return l.get()[0]},update:function(g){d.each(l.get(),function(a){t.remove(a)});y=f.some(g);var n=e.keys(w);e.each(w,function(a){a.assign(y)});var A=e.tupleMap(w,function(a,b){return{k:b,v:a.situation(g)}}),D=h.derive(s,n,A),B=k.derive(s,n,A),n=d.foldr(n,function(a,c){return b.merge(a,A[c].submenus())},{});if(0===D.length)l.set([]);else{var C=a.mainmenu(s,p.resolve("main-context-menu"),[]);q.append(C,D);c.menu(C,m.translate("aria.context.menu.generic"));D=[C].concat(B);d.each(D,function(a){r.add(a,
p.resolve("layer-menus"))});l.set(D);u.set(n)}},handle:function(a){var b=g.type(a),b=w[b];void 0!==b&&b.handle(a)},register:function(a,b){w[a]=b}}}});l("o2",["ku"],function(d){return{mainmenu:function(e,c,a,b,f,g){return d.main(e,c,a,b,f,g)},submenu:function(e,c,a,b,f){return d.submenu(e,c,a,b,f)}}});l("fl","o2 7 o3 75 o4 o5 o6 3o l q".split(" "),function(d,e,c,a,b,f,g,h,k,m){return{makeshift:function(d,n,r,q,t,s,u,l,w){return{recalculate:e.noop,isAnchored:e.constant(!1),place:function(e){var n=d.doc().getOr(k.fromDom(m)),
n=d.isInline()?h(r,q):f.translate(c.fixedOrigin(),n,r,q),z=a(n.left(),n.top(),t,s),n=u.isRtl()?b.allRtl():b.all(),z=c.box(z);e=e.panel();g.fixed(z,e,l,n,void 0===w?{}:w)}}},mainmenu:function(a,b,c,e){return d.mainmenu(a.uiContainer,a.bounds,b,c,e)},submenu:function(a,b,c){return d.submenu(a.uiContainer,a.bounds,b,c)}}});l("8f","ak al b fh c 53 7 s fi fj fk 7i fl ay fm 2v 3o 2o 3p 21 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,u,l,w,y,x){var z=s.immutable("target","x","y"),A=b.detect().browser,
D=function(b,s,D,E,G,H){D=s.doc().getOrDie();var I=p(D),K=u(0,0);D=m.get();var J=k.fromUnsafe(s),L=d.menuSystem(G.uiContainer,g.constant("context"),e.menu({focusActive:!0})),N=d.popup(L.sandbox,G.bounds,b,[],q.editorContainer());H=f.div();var M=N.initMenu(H),O=function(a){I.update(a.target());var b=V(),c=[L.sandbox()];if(0<b.all.length){var d=a.x(),e=a.y();K=u(d,e);M.setContent(b.main);T(M);M.open();L.open(c,b.main);return h.some(a)}return h.none()},S=function(a){return s.getSelection().bind(function(a){return function(){return n.selectionContains(a).fold(function(){return y.isText(a.startContainer())?
x.parent(a.startContainer()):h.some(a.startContainer())},function(a){return h.some(a)})}().map(function(a){var b=w.viewport(a),b=s.translateScreen(b.left(),b.top());return z(a,b.left(),b.top())})})},P=function(a){var b;b=a.original();b=A.isIE()&&10>=A.version.major?u(b.raw().clientX,b.raw().clientY):u(b.x(),b.y());b=s.translateScreen(b.left(),b.top());return z(a.original().target(),b.left(),b.top())},T=function(a){var c;c=t(14,10);c=r.makeshift(s,G,K.left(),K.top(),0,0,b.uiDirection(),c);G.show(a,
c)},Q=function(){M.close();var a=V();c.each(a.all,function(a){l.set(a,"display","none")});J.end()};M.events.close.bind(function(){L.close()});var V=function(){var a=I.all();return{all:a,main:a[0],submenus:a.slice(1)}};s.events.contextmenu.bind(function(a){var b=P(a);O(b).orThunk(function(){return S().bind(O)}).each(function(b){a.original().raw().preventDefault()})});D.onShortcut(E.events.context,function(){S().each(O)});L.events.open.bind(function(){var a=I.structure(),b=V();L.update(a);N.registerMenus(b.submenus);
T(M);L.setActiveMenu(b.main)});L.events.itemAction.bind(function(a){I.handle(a.item())});L.events.itemHover.bind(function(a){J.begin()});L.events.reveal.bind(function(b){a.expanded(b.trigger());N.expandMenu(b.menu(),b.trigger(),M);T(M)});L.events.collapse.bind(function(b){N.hideMenu(b.menu());b.item().each(a.collapsed)});L.events.itemAction.bind(Q);L.events.escaped.bind(function(){Q();s.focus()});s.events.mousedown.bind(Q);return{register:I.register,destroy:function(){M.destroy();L.destroy()}}};return function(a,
b,d,e,f){var h=[],k={register:function(a,b){h=h.concat([{name:a,feature:b}])},destroy:g.noop};b.events.ready.bind(function(g){k=D(a,b,d,e,f);c.each(h,function(a){k.register(a.name,a.feature)})});return{register:function(a,b){k.register(a,b)},destroy:function(){k.destroy()}}}});l("fn","c 7 s 1a l 2p 21 2r 2b 3x".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=d.detect().browser,n=function(a){var d=b.fromHtml("<p><br></p>");f.append(a,d);return c.some(d)},r=function(a){var b=k.children(a);return 0===
b.length?n(a):1===b.length&&"br"===g.name(b[0])?(h.empty(a),n(a)):c.none()},q=function(b){return 1===b.dom().childNodes.length?k.firstChild(b).fold(e.constant(!1),function(b){return"br"===g.name(b)&&a.has(b,"_moz_editor_bogus_node")}):!1},t=function(a){return r(a).orThunk(function(){var b;p.isFirefox()&&q(a)?(h.empty(a),b=n(a)):b=c.none();return b})};return{listen:function(a){a.events.nodeChanged.bind(function(b){b=b.node();a.isRoot(b)&&t(b).each(function(b){a.setSelection(b,0,b,0)})})}}});l("fo",
[],function(){return function(){var d=!0;return{isHandled:function(){return d},handle:function(){d=!1}}}});l("8m",["7","7n","2b"],function(d,e,c){return{onNodeChange:function(a,b){a.events.nodeChanged.bind(function(c){c.prev().each(function(c){e.withinTransient(c,c).each(function(c){b.atomic(function(){e.cleanup(a.isRoot,c)})})})});return{destroy:d.noop}},preLinebreak:function(a){a.getSelection().each(function(b){c.parent(b.startContainer()).each(function(b){e.withinTransient(b,b).each(function(b){e.cleanupNonEmpty(a.isRoot,
b)})})})}}});l("ag",["b","an","7"],function(d,e,c){var a=function(a,b){var c=b.original(),c=c.raw().which||c.raw().keycode;return d.contains(a,c)},b=c.curry(a,e.ENTER()),f=c.curry(a,e.SPACE()),g=c.curry(a,e.BACKSPACE()),h=c.curry(a,e.DEL()),k=c.curry(a,e.LEFT().concat(e.UP())),m=c.curry(a,e.RIGHT().concat(e.DOWN())),p=c.curry(a,e.TAB());e=c.curry(a,e.ESCAPE());return{isEnter:b,isSpace:f,isBackspace:g,isDel:h,isTab:p,isLeftOrUp:k,isRightOrDown:m,isEscape:e}});l("fp",["o7","o8","o9"],function(d,e,c){var a=
function(a,c,d,h){return e.isCollapsed(a)?c(a.startContainer(),a.startOffset(),h):d(a.startContainer(),a.startOffset(),a.endContainer(),a.endOffset(),h)};return{soft:function(b,e){return a(b,d.soft,c.soft,e)},hard:function(b,e){return a(b,d.hard,c.hard,e)}}});l("8g","7 fn fo 8m ag 59 4a fp".split(" "),function(d,e,c,a,b,f,g,h){return function(k,m){var p=g.create({preLinebreak:f(["handler"]),postLinebreak:f([])});e.listen(k);var n=function(b){m.save();k.getSelection().each(function(d){var e=c();p.trigger.preLinebreak(e);
k.getSelection().each(function(c){e.isHandled()&&(a.preLinebreak(k),(b?h.soft:h.hard)(c,k.isRoot).each(function(a){k.setRelativeSelection(a.start(),a.finish());k.domChanged();k.cursorIntoView()}));p.trigger.postLinebreak()})})};k.events.keydown.bind(function(a){b.isEnter(a)&&(a.original().raw().preventDefault(),n(a.original().raw().shiftKey))});return{linebreak:n,destroy:d.noop,events:p.registry}}});l("fq",["4h"],function(d){return function(e,c){return{find:function(a){return d.descendants(a,e)},
cleaner:c}}});l("hx",["b","l","bo"],function(d,e,c){var a=function(a,c){d.each(c,function(c){var d=c.find(a);c.cleaner(d,a)})};return{filterHtml:function(b,d){var g=e.fromTag("div");g.dom().innerHTML=b;a(g,d);return c.writeChildren(g)},filterDom:a}});l("oa",[],function(){return function(){var d=[];return{add:function(e){d.push(e)},get:function(){return d.slice(0)}}}});l("fr",["s","hx","oa"],function(d,e,c){return function(){var a={},b=function(b){return d.from(a[b])};return{get:b,getOrInit:function(b){var d=
a[b];void 0===d&&(a[b]=c(),d=a[b]);return d},filterDom:function(a,c){b(a).each(function(a){e.filterDom(c,a.get())})},filterHtml:function(a,c){return b(a).fold(function(){return c},function(a){return e.filterHtml(c,a.get())})}}}});l("fs",["6m"],function(d){return function(e,c){return{find:function(a){return d.descendants(a,e)},cleaner:c}}});l("8h","b 7 6x fq fr fs m".split(" "),function(d,e,c,a,b,f,g){return function(h){var k=b(),m=e.constant("output"),p=e.constant("input"),n=e.constant("history"),
r=e.constant("internal"),q=e.constant("paste"),t=[],s=function(b,c,d){b=k.getOrInit(b);c=a(c,d);b.add(c)},u=function(a,b,c){a=k.getOrInit(a);b=f(b,c);a.add(b)};h=c(h,s,u);return{add:function(a,b,c){s(a,"."+b,c)},addSelector:s,addPredicate:u,filterHtml:k.filterHtml,filterDom:k.filterDom,internal:r,output:m,input:p,paste:q,history:n,customFilters:e.constant(h),state:h.state,destroy:e.noop,addExcludedContext:function(a){t=t.concat(a)},includeContext:function(a){return!d.exists(t,e.curry(g.is,a))}}}});
l("8i","7 7b 71 7c 59 4a".split(" "),function(d,e,c,a,b,f){return function(g,h,k){var m=!1,p=f.create({maximize:b(["layout"]),restore:b(["layout"]),analytics:b(["message"]),select:b([]),deselect:b([])}),n=function(){p.trigger.maximize(k.alternate)},r=function(){p.trigger.restore(k.alternate)},q=function(a){m?a.select():a.deselect()},t=function(){p.trigger.analytics("fullscreen_"+(m?"off":"on"));g.focus();(m?r:n)()},s=function(b,c){var d=e.key(m?"action.toggle.fullscreen":"action.fullscreen");return a.get(d,
c)};h.events.fullscreen.bind(t);h=c.ui({"fullscreen.general":function(){return{toggle:!0,value:"fullscreen",textkey:e.key("action.fullscreen"),tooltip:s,action:t,updateGeneral:q,icon:!0,shortcut:!0,selected:m}}},d.identity);var u=c.actions({maximize:n,restore:r});return{ui:h,actions:u,select:function(){m=!0},deselect:function(){m=!1},destroy:d.noop,events:p.registry}}});l("wb",["84","b","s","2v","6p"],function(d,e,c,a,b){var f=a.immutable("ch","offset"),g=function(a,b){return f(a.charAt(b),b)};return{previous:function(a,
b){for(var e=b.getOr(a.length)-1;0<=e;e--)if(a.charAt(e)!==d.zeroWidth())return c.some(g(a,e));return c.none()},next:function(a,b){for(var e=b.getOr(0)+1;e<a.length;e++)if(a.charAt(e)!==d.zeroWidth())return c.some(g(a,e));return c.none()},rfind:function(a,b){b.lastIndex=-1;var d=e.reverse(a).join(""),f=d.match(b);return void 0!==f&&null!==f&&0<=f.index?c.some(d.length-1-f.index):c.none()},lfind:function(a,b){b.lastIndex=-1;var d=a.match(b);return void 0!==d&&null!==d&&0<=d.index?c.some(d.index):c.none()}}});
l("wc","7 s f9 m4 is oj mb 4q".split(" "),function(d,e,c,a,b,f,g,h){var k=b.walkers().left(),m=b.walkers().right(),p=h.generate([{abort:[]},{kontinue:[]},{finish:["info"]}]),n=h.generate([{aborted:[]},{edge:["element"]},{success:["info"]}]),r=function(a,b){return g.isEmptyTag(a,b)||a.property().isBoundary(b)},q=function(a,c,d,f,g,h,k){var m=function(){return k.fold(n.aborted,n.edge)},s=function(f){return b.walk(a,c,d,h).fold(m,function(b){return q(a,b.item(),b.mode(),e.none(),g,h,f)})};if(r(a,c))return m();
if(a.property().isText(c)){var t=a.property().getText(c);return g(a,p,c,t,f).fold(m,function(){return s(e.some(c))},n.success)}return s(k)},t=function(b,d,g,h){g=a.toLeaf(b,d,g);return b.property().isText(d)?e.none():f.left(b,g.element(),b.property().isText,h).map(function(a){return c.point(a,b.property().getText(a).length)})},s=function(b,d,g,h){g=a.toLeaf(b,d,g);return b.property().isText(d)?e.none():f.right(b,g.element(),b.property().isText,h).map(function(a){return c.point(a,0)})},u=function(a,
b,e){var f=d.curry(r,a);return t(a,b,e,f).orThunk(function(){return s(a,b,e,f)}).getOr(c.point(b,e))};return{repeatLeft:function(a,c,d,f){c=u(a,c,d);return q(a,c.element(),b.sidestep,e.some(c.offset()),f,k,e.none())},repeatRight:function(a,c,d,f){c=u(a,c,d);return q(a,c.element(),b.sidestep,e.some(c.offset()),f,m,e.none())}}});l("ob","7 s f9 is wb wc 57".split(" "),function(d,e,c,a,b,f,g){var h=g.exactly(["regex","attempt"]),k=function(a,b,c,d){return f.repeatLeft(a,b,c,d)},m=function(a,b,c,d){return f.repeatRight(a,
b,c,d)},p=function(b,f,g){var h=d.constant(!1);if(!b.property().isText(f))return e.none();var k=b.property().getText(f);return g<=k.length?e.some(c.point(f,g)):a.seekRight(b,f,b.property().isText,h).bind(function(a){return p(b,a,g-k.length)})};return{previousChar:function(a,c){return b.previous(a,c)},nextChar:function(a,c){return b.next(a,c)},repeatLeft:k,repeatRight:m,expandLeft:function(a,c,d,e){var f=h(e);return k(a,c,d,function(a,c,d,e,g){a=g.getOr(e.length);return b.rfind(e.substring(0,a),f.regex()).fold(function(){return c.kontinue()},
function(a){return f.attempt(c,d,e,a)})})},expandRight:function(a,c,d,e){var f=h(e);return m(a,c,d,function(a,c,d,e,g){var h=g.getOr(0);return b.lfind(e.substring(h),f.regex()).fold(function(){return c.kontinue()},function(a){return f.attempt(c,d,e,h+a)})})},scanRight:p}});l("it",["6q","ob"],function(d,e){var c=d();return{previousChar:function(a,b){return e.previousChar(a,b)},nextChar:function(a,b){return e.nextChar(a,b)},repeatLeft:function(a,b,d){return e.repeatLeft(c,a,b,d)},repeatRight:function(a,
b,d){return e.repeatRight(c,a,b,d)},expandLeft:function(a,b,d){return e.expandLeft(c,a,b,d)},expandRight:function(a,b,d){return e.expandRight(c,a,b,d)},scanRight:function(a,b){return e.scanRight(c,a,b)}}});l("fu","81 7 s f9 ft 6o it 2v 1b 21 2b 6p".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var r=h.immutable("before","after"),q=function(a,b,c,d,e){return x(c).fold(function(){var c=B(a,b,d);return r(c,e)},function(f){var g=C(c,f);return g.length>a?r(d,e):z(b).fold(function(){var b=D(a-g.length,f,
e+g);return r(d,b)},function(c){var h=C(c,b);return h.length>a-g.length?r(d,e+g):q(a-g.length-h.length,c,f,h+d,e+g)})})};h=function(b,c,d,e){return b.finish(a.point(c,e))};var t={regex:function(){return new n(f.wordchar(),"i")},attempt:h},s={regex:function(){return new n(f.wordbreak(),"i")},attempt:h},u=function(a,b){return a.offset()===b.offset()&&k.eq(a.element(),b.element())},l=function(b){return a.point(b,m.value(b).length)},w=function(b){return a.point(b,0)},y=function(a,b,d){var e=function(b){b=
d(b);return u(a,b)?c.none():c.some(b)};return b(a.element(),a.offset(),t).fold(c.none,e,function(a){return b(a.element(),a.offset(),s).fold(c.none,e,function(a){return c.some(a)})})},x=function(a){return y(a,g.expandRight,l)},z=function(a){return y(a,g.expandLeft,w)},A=function(a,b,c,d,f,g){return a(c).fold(e.constant(d),function(e){var h=f(c,e);return h.length+d.length>b||0===h.length?d:A(a,b,e,g(d,h),f,g)})},D=function(a,b,c){return A(x,a,b,c,C,function(a,b){return a+b})},B=function(a,b,c){return A(z,
a,b,c,function(a,b){return C(b,a)},function(a,b){return b+a})},C=function(a,b){var c=p.defaultView(a.element()).dom();return d.stringAt(c,a.element(),a.offset(),b.element(),b.offset())};return{beforeAfter:r,anchorText:function(a,c){var d=b.freefallLtr(c);return x(d).map(function(b){var c=C(d,b);return c+D(a-c.length,b,"")}).getOr("")},flankingText:function(a,c){if(0===a)return r("","");var d=b.freefallLtr(c),e=b.freefallRtl(c);return q(a,d,e,"","")},extendRightAndLeft:q,extendWordsSearch:A,extendWordsRight:D,
extendWordsLeft:B,wordSearch:y,wordLeft:z,wordRight:x,pointEq:u,boundaryPointRight:l,boundaryPointLeft:w,textBetweenPoints:C,wordSeeker:t,wordBreakSeeker:s}});l("a7","b s ft fu 7i fg 2v 1a 1b l 69 32 m 3n 2b 1s".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s){var u=function(a,b){try{return a()}catch(c){if(12===c.code)return b();throw c;}},l=function(a){return n.closest(a,"a[href]")},w=function(a,b){return l(a).bind(function(a){return l(b).filter(function(b){return k.eq(a,b)})})},y=g.immutable("element",
"innerText","before","after"),x=function(a){return r.is(a,"a[href]")?[a]:r.all("a[href]",a)};return{contentLink:function(a){return a.getSelection().bind(function(a){return b.detect(a).fold(function(){return w(a.startContainer(),a.endContainer())},function(a){return e.some(a.image()).bind(l)})})},sharedLink:w,sharedLinkOrClosest:function(a,b){var d=c.toLeaf(a.startContainer(),a.startOffset()),e=c.toLeaf(a.endContainer(),a.endOffset());return w(d.element(),e.element()).orThunk(function(){return n.closest(d.element(),
"a[href]",b)})},findLinkTargets:function(a){return r.all("h1,h2,h3,h4,h5,h6,div[id],p[id],span[id],a[id],a[name]",a)},linkTargetText:function(b,c){var d=q.get(c).length,e=p.deep(c),d=a.anchorText(d,e);if(f.isBlock(c))return y(c,d,"","");e=a.flankingText(s.max(0,b-d.length),c);return y(c,d,e.before(),e.after())},linkTargetFastText:function(a,b){var c=q.get(b),c=50<c.length?c.substr(0,50):c;return y(b,c,"","")},all:x,many:function(a){return d.bind(a,x)},hrefUrl:function(a,b){return u(function(){return r.all('a[href="'+
b+'"]',a)},function(){var c=x(a);return d.filter(c,function(a){return h.get(a,"href")===b})})},anchorTarget:function(a,b){return u(function(){return r.one("#"+b+',a[name="'+b+'"]',a)},function(){var c=t.owner(a).dom();return e.from(c.getElementById(b)).map(m.fromDom).orThunk(function(){var c=r.all("[name]",a);return e.from(d.find(c,function(a){return h.get(a,"id")===b||h.get(a,"name")===b}))})})}}});l("8j","b 7 s a7 59 4a n".split(" "),function(d,e,c,a,b,f,g){return function(){var h={inputLinks:"insertLink"},
k=f.create({internal:b(["command","data"])}),m=function(a,b){c.from(h[a]).fold(function(){throw new g("invalid internal event:",a);},function(a){d.each(b,function(b){k.trigger.internal(a,b)})})};return{input:function(b){b=a.many(b);m("inputLinks",b)},destroy:e.noop,events:k.registry}}});l("fv",["oc","3y","q"],function(d,e,c){return function(a,b){var c=d(),g=e.bind(b,"keydown",c.keydown),h=e.bind(b,"keypress",c.keypress),k=function(a){c.keydown(a.original())},m=function(a){c.keypress(a.original())};
a.events.keydown.bind(k);a.events.keypress.bind(m);return{off:c.off,on:c.on,swallowShortcuts:c.swallowShortcuts,yieldShortcuts:c.yieldShortcuts,swallowChars:c.swallowChars,yieldChars:c.yieldChars,swallowKeys:c.swallowKeys,yieldKeys:c.yieldKeys,destroy:function(){g.unbind();h.unbind();a.events.keydown.unbind(k);a.events.keypress.unbind(m)},events:c.events}}});l("fw",["oc"],function(d){return function(e){var c=d(),a=function(a){c.keydown(a.original())},b=function(a){c.keypress(a.original())};e.events.keydown.bind(a);
e.events.keypress.bind(b);return{off:c.off,on:c.on,swallowShortcuts:c.swallowShortcuts,yieldShortcuts:c.yieldShortcuts,swallowChars:c.swallowChars,yieldChars:c.yieldChars,swallowKeys:c.swallowKeys,yieldKeys:c.yieldKeys,events:c.events,destroy:function(){e.events.keydown.unbind(a);e.events.keypress.unbind(b)}}}});l("fx",["oc","3y"],function(d,e){return function(c){var a=d(),b=e.bind(c,"keydown",a.keydown),f=e.bind(c,"keypress",a.keypress);return{off:a.off,on:a.on,swallowShortcuts:a.swallowShortcuts,
yieldShortcuts:a.yieldShortcuts,swallowChars:a.swallowChars,yieldChars:a.yieldChars,swallowKeys:a.swallowKeys,yieldKeys:a.yieldKeys,destroy:function(){b.unbind();f.unbind()},events:a.events}}});l("8k",["7","fv","fw","fx"],function(d,e,c,a){return function(b,f){return{all:function(){return e(b,f.element())},container:function(b){return a(b)},editor:function(){return c(b)},destroy:d.noop}}});l("fz",["jt","f9","it","21"],function(d,e,c,a){var b=function(b,d){var h=e.point(b,d);return a.isText(b)?c.scanRight(b,
d).getOr(h):h};return{handle:function(a){var c=b(a.startContainer(),a.startOffset());a=b(a.endContainer(),a.endOffset());return d(c.element(),c.offset(),a.element(),a.offset())}}});l("139",["87","4q","21","2b"],function(d,e,c,a){var b=e.generate([{onText:["element","offset"]},{firstText:["parent","child","offset"]},{beforeText:["parent","child","offset"]},{afterText:["parent","child"," offset"]},{lastText:["parent","child","offset"]},{onElement:["element","offset"]}]);return{detect:function(e,g){if(c.isText(e))return b.onText(e,
g);var h=a.children(e);return 0===h.length?b.onElement(e,g):0===g&&c.isText(h[0])?(0,b.firstText)(e,h[0],0):g===h.length&&c.isText(h[h.length-1])?(h=h[g-1],(0,b.lastText)(e,h,d.getEnd(h))):g<h.length&&c.isText(h[g])?(0,b.beforeText)(e,h[g],0):0<g&&c.isText(h[g-1])?(h=h[g],(0,b.afterText)(e,h,d.getEnd(h))):b.onElement(e,g)},cata:function(a,b,c,d,e,p,n){return a.fold(b,c,d,e,p,n)}}});l("156",["7","s"],function(d,e){return function(c){return{backup:d.identity,restore:d.constant(e.none()),element:d.constant(c)}}});
l("157",["2v"],function(d){return d.immutable("startContainer","startOffset","endContainer","endOffset")});l("13d",["4j"],function(d){return{resolve:d.create("ephox-newt").resolve}});l("10i",["13d","1y","2o","l"],function(d,e,c,a){var b=d.resolve("cursor-marker");return{generator:function(d){var g=null;return{getOrInit:function(){var h;null===g?(h=a.fromTag("span",d.dom()),e.add(h,b),c.set(h,"display","none")):h=g;return g=h}}},isCursor:function(a){return e.has(a,b)}}});l("13a","b 156 157 10i 7 s 1b 2p 2r 2b".split(" "),
function(d,e,c,a,b,f,g,h,k,m){var p=function(a,d){return{element:b.constant(d),backup:b.identity,restore:function(){var b=c(a,0,a,0);return f.some(b)}}},n=function(c){c=m.children(c);return d.filter(c,b.not(a.isCursor))},r=function(a,d){return{element:b.constant(d),backup:b.identity,restore:function(){var b=n(a).length,b=c(a,b,a,b);return f.some(b)}}},q=function(a){return m.parent(a).bind(function(b){var e=n(b),e=d.findIndex(e,function(b){return g.eq(a,b)});return-1<e?f.some(c(b,e,b,e)):f.none()})},
t=function(a,d){return{backup:function(){h.before(a,d)},restore:function(){var a=m.nextSibling(d);k.remove(d);return a.map(function(a){return q(a).getOrThunk(function(){return c(a,0,a,0)})})},element:b.constant(d)}};return{place:function(a,b,c){var d=m.children(a);return 0===d.length?p(a,c):d.length===b?r(a,c):0===b?p(a,c):b>d.length?e(c):t(d[b],c)}}});l("13b",["157","10i","7","s"],function(d,e,c,a){var b=function(a,b){return b().fold(function(){return e.generator(a).getOrInit()},function(a){return a.element()})},
f=function(b){b=b();b.backup();return a.some(b)},g=function(a,b){var c=a.or(b),e=b.or(a);return c.bind(function(a){return e.map(function(b){return d(a.startContainer(),a.startOffset(),b.startContainer(),b.startOffset())})})};return{ltr:function(d,e,m){var p=a.none(),n=a.none();return{backup:function(){n=f(e);p=f(m)},restore:function(){return p.bind(function(a){return n.bind(function(b){var c=a.restore();b=b.restore();return g(c,b)})})},element:c.curry(b,d,function(){return n})}},rtl:function(d,e,
m){var p=a.none(),n=a.none();return{backup:function(){p=f(m);n=f(e)},restore:function(){return n.bind(function(a){return p.bind(function(b){var c=a.restore();b=b.restore();return g(b,c)})})},element:c.curry(b,d,function(){return p})}}}});l("13c","156 157 87 7 jg ht 2p 2r".split(" "),function(d,e,c,a,b,f,g,h){var k=function(c,d,f){return{backup:function(){g.before(d,f)},restore:function(){var a=b.after(f,c).map(function(a){return e(a,0,a,0)});h.remove(f);return a},element:a.constant(f)}},m=function(d,
f,k){return{backup:function(){g.after(f,k)},restore:function(){var a=b.before(k,d).map(function(a){var b=c.getEnd(a);return e(a,b,a,b)});h.remove(k);return a},element:a.constant(k)}};return{place:function(a,b,c,e){b=f.split(b,c);return f.position(b).fold(function(){return d(e)},function(b){return k(a,b,e)},function(b,c){return m(a,b,e)},function(b){return m(a,b,e)})}}});l("q4",["2v"],function(d){return d.immutable("result","cursor")});l("10h","139 13a 13b 13c q4 10i dy 2b".split(" "),function(d,e,
c,a,b,f,g,h){var k=function(b,c,f){var g=function(c,d,e){return a.place(b,d,e,f)};return d.cata(c,function(c,d){return a.place(b,c,d,f)},g,g,g,g,function(a,b){return e.place(a,b,f)})},m=function(a,b,c,e){e=e.getOrInit();b=d.detect(b,c);return k(a,b,e)},p=function(a,c){a.backup();var d=c(a.element());return b(d,a.restore())};return{inspect:m,runOnRange:function(a,b,d,e,k,l){var v=h.owner(b),w=(g.after(b,d,e,k)?c.rtl:c.ltr)(v,function(){return m(a,e,k,f.generator(v))},function(){return m(a,b,d,f.generator(v))});
return p(w,l)},runOnCursor:p}});l("wi",["10h","10i","1b","2b"],function(d,e,c,a){var b=function(a,b,c,e,f,n){return d.runOnRange(a,b,f>c?c:f,b,f>c?f:c,n)},f=d.runOnRange;return{point:function(b,c,f,m){var p=a.owner(c),p=e.generator(p);b=d.inspect(b,c,f,p);return d.runOnCursor(b,m)},range:function(a,d,e){return(c.eq(d.startContainer(),d.endContainer())?b:f)(a,d.startContainer(),d.startOffset(),d.endContainer(),d.endOffset(),e)}}});l("od","wi q4 s 2n 1y 2z 2b".split(" "),function(d,e,c,a,b,f,g){var h=
function(a,b){return function(a,d){var f=d(b);return e(f,c.none())}},k=function(a,b){return function(c,e){return d.point(a,b.startContainer(),b.startOffset(),p(c,e))}},m=function(a,b){return function(c,e){return d.range(a,b,p(c,e))}},p=function(a,c){return function(d){b.add(d,a);return c(d)}};return{diagnose:function(b,c){var d=c.startContainer(),e=c.endContainer(),p=g.owner(d);return a.inBody(d)&&a.inBody(e)&&f.active(p).forall(a.inBody)?c.collapsed()?k(b,c):m(b,c):h(b,c.startContainer())}}});l("g0",
["7","od","34","cw","2n"],function(d,e,c,a,b){return function(f,g){var h=c.resolve("ops-eph-cursor");f.add(f.internal(),h,a.remove);f.add(f.output(),h,a.remove);f.addExcludedContext(["."+h]);var k=function(a){var c=function(c){c=e.diagnose(g.isRoot,c)(h,a);c.cursor().each(function(a){b.inBody(a.startContainer())&&b.inBody(a.endContainer())&&g.getSelection().each(function(b){g.setSelection(a.startContainer(),a.startOffset(),a.endContainer(),a.endOffset())})});return c.result()};return function(){return g.getSelection().fold(a,
c)}};return{destroy:d.noop,run:function(a){return k(a)()}}}});l("8l","fy fz g0 7i 1b 21".split(" "),function(d,e,c,a,b,f){return function(g,h){var k=c(g,h),m=function(a,c){var d=a(),f=e.handle(c);h.getSelection().forall(function(a){return!b.eq(a.startContainer(),f.startContainer())||!b.eq(a.endContainer(),f.endContainer())||a.startOffset()!==f.startOffset()||a.endOffset()!==f.endOffset()})&&h.setSelection(f.startContainer(),f.startOffset(),f.endContainer(),f.endOffset());return d},p=function(a){return f.isText(a)||
"br"===f.name(a)};return{destroy:function(){},run:k.run,preserve:function(a){h.getSelection().each(function(b){var c=d.descend(b.startContainer(),b.startOffset());b=d.descend(b.endContainer(),b.endOffset());a(c.element(),b.element());h.setSelection(c.element(),c.offset(),b.element(),b.offset())})},lightweightWith:function(b,c){return p(c.startContainer())&&p(c.endContainer())||a.detect(c).isSome()?m(b,c):k.run(b)},adapt:function(a){h.getSelection().each(function(b){k.run(function(){a(b.startContainer(),
b.endContainer())})})},pure:function(a){h.getSelection().each(function(b){a(b.startContainer(),b.endContainer())})},atomic:function(a){return k.run(a)}}}});l("oe",["7","7b","71","59","4a"],function(d,e,c,a,b){return function(){var f=b.create({back:a([]),abort:a([])});return{ui:c.ui({"back.general":{toggle:!1,value:"mobile-back",textkey:e.key("toolbar.backbutton"),action:function(){f.trigger.back()},updateGeneral:d.noop,icon:!0,label:!0}}),events:f.registry,destroy:d.noop}}});l("10j",["7","p"],function(d,
e){return function(c,a){return e.error({small:d.constant(c),big:d.constant(a)})}});l("10k",["b","p"],function(d,e){return{fold:function(c,a){return d.foldr(c,function(b,c){return b.bind(function(b){return a(c).map(function(a){return[a].concat(b)})})},e.value([]))}}});l("10l",["a","1o","10j","10k","p"],function(d,e,c,a,b){var f=function(a,d){var f=d.groups(),g=f[a];return void 0===g?c("Unknown group: "+a,["No binding for group: "+a+". Known groups: "+e.keys(f)]):b.value(g)},g=function(a,c){var e=d.isArray(a)?
{label:"",items:a}:a;return b.value(e)},h=function(b,c,d,e,f){return a.fold(c,function(a){return f.item(a,d,e,f)}).map(function(a){return{category:b,items:a}})};return{build:function(a,b,c,e){return(d.isString(a)?f:g)(a,b).bind(function(a){return h(a.label,a.items,b,c,e)})}}});l("10m",["a","1o","10j","p"],function(d,e,c,a){var b=function(b,d,f,g){d=d.commands();f=d[b];return void 0===f?c("Unknown command: "+b,["No binding for command: "+b+". Known commands: "+e.keys(d)]):a.value(f)},f=function(a,
b,c,d){return(void 0===a.items?g:d.menu)(a,b,c,d)},g=function(a,b,d,e){return void 0===d?c("You need a custom action factory to use this",[]):d(a)};return{build:function(a,c,e,g){return(d.isString(a)?b:f)(a,c,e,g)}}});l("10n","a b 10j 10k p vy".split(" "),function(d,e,c,a,b,f){var g=function(a){return e.forall(a,d.isArray)?b.value(a):e.exists(a,d.isArray)?c("Menu items must be a single array or an array where every element is an array",["Menu items must be a single array or an array where every element is an array.",
"Contents of menu: "+f.stringify(a)]):b.value([a])};return{build:function(b,d,e,p){if(void 0===b.label||void 0===b.items||0===b.items.length)return c("Invalid toolbar configuration for menu",["Invalid menu. Must be an object containing label and items.","Contents of menu: "+f.stringify(b)]);var n=b.menuLabel?b.menuLabel:b.label;return g(b.items).bind(function(b){return a.fold(b,function(a){return p.group(a,d,e,p)})}).map(function(a){return{name:b.id,textkey:b.label,menuTextkey:n,type:"submenu",contentFocus:!1,
enabled:!0,icon:b.icon,commands:a}})}}});l("wj","a b 1o 10j 10k 10l 10m 10n p vy".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=c.map({group:f.build,item:g.build,menu:h.build},function(a,b){return function(){if(4!==arguments.length)throw"Incorrect usage of builder ["+b+"]. Only given: "+arguments.length;return a.apply(null,arguments)}}),n=function(b){if(void 0===b.items)return a("Invalid group, no items specified",["Invalid group, no items specified: "+b.label]);var c=b.items;return d.isArray(c)?
(b=e.bind(c,function(a,b){return d.isString(a)||d.isArray(a)||void 0!==a.label&&d.isArray(a.items)?[]:["Invalid group at index: "+b+". Must be either a string, an array or an object containing label and items. Was: "+m.stringify(a)]}),0===b.length?k.value(c):a("Invalid toolbar configuration for groups",b)):a("Invalid toolbar, items is not an array",["Invalid toolbar, items is not an array: "+m.stringify(b)])};return{build:function(a,c,d){return n(a).bind(function(a){return b.fold(a,function(a){return p.group(a,
c,d,p)})})}}});l("wn",["b","7","ip"],function(d,e,c){var a=function(){return c.isSmallTouch()},b=function(a,b){return{feature:a.feature,command:a.command,type:"pre_flatmenu",items:b}};return{shouldFlatten:a,never:e.constant("never_flatten"),streamline:function(a){var b=function(a){return d.bind(a,function(a){return"never_flatten"===a.flatten?[a]:"submenu"===a.type?d.bind(a.commands,function(a){return b(a.items)}):"pre_flatmenu"===a.type?d.map(a.items,function(b){return{feature:a.feature,type:"general",
command:b}}):[a]})};return d.map(a,function(a){var c=b(a.items);return{category:a.category,items:c}})},setup:function(d,g){var h=b(d,g);return c.choice([{predicate:a,value:e.constant(h)}],d)},make:b}});l("wk",["7","s","7b","wn","ip"],function(d,e,c,a,b){var f=function(a,b){return{predicate:a,value:d.constant(b)}};return function(d,h,k,m,p){var n=function(a,b){return a()?b:{feature:e.none()}};k=n(function(){return!d&&b.isLargeDesktop()},{feature:k.ui(),command:"fullscreen",type:"general",unsupported:"Fullscreen is not supported in inline mode"});
p=b.choice([f(b.isLargeDesktop,{feature:m.fileupload().ui(),command:"fileupload",type:"general"}),f(b.isLargeTouch,{feature:m.fileupload().ui(),command:"fileupload",type:"menu"})],a.make({feature:m.fileupload().ui(),command:"fileupload"},p.allowLocalImages?["camera"]:[]));var r=n(b.isLargeDesktop,{feature:m.accessibility().ui(),command:"a11ycheck",type:"general"}),n=n(b.isLarge,{feature:m.specialchar().ui(),command:"specialchar",type:"general"}),q=b.choice([f(b.isLarge,{feature:m.blocktag().ui(),
command:"bullist",type:"split-widget"})],{feature:m.blocktag().ui(),command:"bullist",type:"general"}),t=b.choice([f(b.isLarge,{feature:m.blocktag().ui(),command:"numlist",type:"split-widget"})],{feature:m.blocktag().ui(),command:"numlist",type:"general"}),s={feature:m.formatting().ui(),command:"superscript",type:"general"},l={feature:m.formatting().ui(),command:"subscript",type:"general"},v={feature:m.formatting().ui(),command:"strikethrough",type:"general"},w={feature:m.font().ui(),command:"fontface",
type:"dropdown"},y=b.choice([f(b.isTouch,{feature:m.font().ui(),command:"fontsize",type:"general"})],{feature:m.font().ui(),command:"fontsize",type:"inline-widget"}),x={feature:m.font().ui(),command:"fontcolor",type:"widget"},z={feature:m.spelling().hasAutocorrect()?m.macros().ui():e.none(),command:"autocorrect",type:"general"},A={feature:m.spelling().ui(),command:"spelling",type:m.spelling().hasDropdown()?"dropdown":"general"},D={feature:m.macros().ui(),command:"capitalisation",type:"general"},B=
{feature:m.help().ui(),command:"help",type:"general"},C={feature:m.wordcount().ui(),command:"wordcount",type:"general"};return{link:{feature:m.link().ui(),command:"link",type:"general"},wordcount:C,media:{feature:m.media().ui(),command:"media",type:"general"},hr:{feature:m.horizontalrule().ui(),command:"horizontalrule",type:"general"},specialchar:n,fileupload:p,table:{feature:m.table().ui(),command:"table",type:"widget"},undo:{feature:h.ui(),command:"undo",type:"general"},redo:{feature:h.ui(),command:"redo",
type:"general"},styles:{feature:m.blocktag().ui(),command:"blocktag",type:"dropdown"},language:{feature:m.parlance().ui(),command:"parlance",type:"dropdown"},ltrdir:{feature:m.directionality().ui(),command:"ltrdir",type:"general"},rtldir:{feature:m.directionality().ui(),command:"rtldir",type:"general"},bold:{feature:m.formatting().ui(),command:"bold",type:"general"},italic:{feature:m.formatting().ui(),command:"italic",type:"general"},underline:{feature:m.formatting().ui(),command:"underline",type:"general"},
strikethrough:v,superscript:s,subscript:l,ul:q,ol:t,removeformat:{feature:m.formatting().ui(),command:"removeformat",type:"general"},alignment:{feature:m.alignindent().ui(),command:"alignment",type:"dropdown"},outdent:{feature:m.alignindent().ui(),command:"outdent",type:"general"},indent:{feature:m.alignindent().ui(),command:"indent",type:"general"},blockquote:{feature:m.alignindent().ui(),command:"blockquote",type:"general"},"font-menu":{name:"font",textkey:c.key("font.menu-button"),menuTextkey:c.key("font.menu"),
type:"submenu",contentFocus:!0,commands:[{category:"Font-menu",items:[w,y,x,s,l,v]}]},"font-face":w,"font-size":y,"font-color":x,fullscreen:k,find:{feature:m.findreplace().ui(),command:"find",type:"general"},accessibility:r,usersettings:{name:"usersettings",textkey:c.key("cog.menu-button"),menuTextkey:c.key("cog.menu"),type:"submenu",flatten:a.never(),contentFocus:!0,commands:[{category:"a",items:[C]},{category:"b",items:[A,z,D]},{caetgory:"",items:[B]}]}}}});l("wl","a 1o 10j vy 7 s p kr 7b".split(" "),
function(d,e,c,a,b,f,g,h,k){return function(){return{make:function(m){var p=function(b){return c(k.translate("errors.toolbar.missing.custom.string",b),['The required property "'+b+'" for a custom command must be a string. It was: '+a.stringify(m[b]),"Properties specified in custom command: "+e.keys(m).join(", "),"Definition specified for custom command: "+a.stringify(m)])};if(!d.isString(m.id))return p("id");if(!d.isString(m.text))return p("text");p={};p[m.id]=b.constant({general:function(){return{toggle:!1,
value:h.cssSanitise(m.id),textkey:k.raw(m.text),action:m.action,updateGeneral:b.identity,icon:void 0!==m.icon?m.icon:!1}}});return g.value({feature:f.some(p),command:m.id,type:"general"})}}}});l("wm",["7b"],function(d){return function(){var e={id:"insert",label:d.key("insert.menu-button"),menuLabel:d.key("insert.menu"),items:[["link","fileupload","media","table"],["specialchar","hr"]]};return{undo:{label:d.key("category.undo"),items:["undo","redo"]},insert:{label:d.key("category.insert"),items:[e]},
style:{label:d.key("category.style"),items:["styles"]},language:{label:d.key("category.language"),items:["language","ltrdir","rtldir"]},emphasis:{label:d.key("category.emphasis"),items:["bold","italic","underline"]},align:{label:d.key("category.align"),items:["alignment"]},listindent:{label:d.key("category.listindent"),items:["ul","ol","outdent","indent","blockquote"]},format:{label:d.key("category.format"),items:["font-menu","removeformat"]},tools:{label:d.key("category.tools"),items:["find","accessibility",
"fullscreen","usersettings"]},"table-tools":{label:d.key("category.table"),items:["table-tools"]},"image-tools":{label:d.key("category.image"),items:["image-tools","crop-tools"]}}}});l("of","wj c 6 7 wk wl wm wn".split(" "),function(d,e,c,a,b,f,g,h){var k=f(),m=function(a,b){return a.bind(function(a){return b.map(function(b){return a.concat(b)})})};return{config:function(f,n,r){return function(q,t,s,l){q=b(q,t,s,l,r);q=c.deepMerge(q,n);l={"table-tools":{feature:l.table().ui(),command:"cell",type:"palette"},
"image-tools":{feature:l.imageEdit().ui(),command:"edit",type:"palette"},"crop-tools":{feature:l.imageEdit().ui(),command:"crop",type:"palette"}};q={forItems:a.constant({commands:a.constant(q),groups:g}),forContextual:a.constant({commands:a.constant(l),groups:g})};l=d.build({items:f.items},q.forItems(),k.make);q=d.build({items:f.contextual},q.forContextual(),k.make);t=e.detect().deviceType.isTouch()?h.streamline:a.identity;return m(l,q).map(t)}}}});l("13e","b 7 l 2z 21 3x".split(" "),function(d,e,
c,a,b,f){var g=function(a){return function(a){f(function(){a()},0)}};return{resume:function(f){f.focus();var k=c.fromDom(f.document.body);(a.active().exists(function(a){return d.contains(["input","textarea"],b.name(a))})?g(k):e.apply)(function(){a.active().each(a.blur);a.focus(k)})}}});l("13f",["1a","1u","e2"],function(d,e,c){return{safeParse:function(a,b){var f=c(d.get(a,b),10);return e(f)?0:f}}});l("13g",["b","81","87","l","2b"],function(d,e,c,a,b){var f=function(a){return{left:a.left,top:a.top,
width:2,height:a.height}},g=function(g){if(g.collapsed){var k=a.fromDom(g.startContainer);return b.parent(k).bind(function(a){return e.rectangleAt(g.startContainer.ownerDocument.defaultView,k,g.startOffset,a,c.getEnd(a)).map(f).map(d.pure)}).getOr([])}return g.getClientRects()};return{getRectangles:function(a){a=a.getSelection();return void 0!==a&&0<a.rangeCount?g(a.getRangeAt(0)):[]}}});l("13h",["4j"],function(d){return{resolve:d.create("ephox-nomad").resolve}});l("10o","13e 13f 13g 13h 7 s 1a 3y l 1s 37".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p){var n="data-"+a.resolve("last-outer-height"),r=function(a){return{top:b.constant(a.top),bottom:b.constant(a.top+a.height)}},q=function(a){a=c.getRectangles(a);return 0<a.length?f.some(a[0]).map(r):f.none()},t=function(a){a=e.safeParse(a,n);var b=p.innerHeight;return a>b?f.some(a-b):f.none()};return{setup:function(a,b){var c=k.fromDom(b.document.body),e=h.bind(k.fromDom(a),"resize",function(){t(c).each(function(a){q(b).each(function(c){c=c.top()>b.innerHeight||c.bottom()>
b.innerHeight?m.min(a,c.bottom()-b.innerHeight+50):0;0!==c&&b.scrollTo(b.pageXOffset,b.pageYOffset+c)})});g.set(c,n,p.innerHeight)});g.set(c,n,p.innerHeight);return{toEditing:function(){d.resume(b)},destroy:function(){e.unbind()}}}}});l("p0",["2j"],function(d){return function(e){return new (d.getOrDie("Event"))(e)}});l("gs",["p0"],function(d){var e=function(c){var a=d("Event");a.initEvent(c,!0,!0);return a};return{event:function(c,a){var b=e(a);c.target().dom().dispatchEvent(b)},target:function(c,
a){var b=e(a);c.dom().dispatchEvent(b)}}});l("hp",["gs"],function(d){return function(e){return{closeMenus:function(c){c=c?c.target():e;d.target(c,"mousedown")}}}});l("10p","7 s 59 4a 3y l 1s 2t 2u 37".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=function(){var a=m.matchMedia("(orientation: portrait)").matches;return{isPortrait:d.constant(a)}};return{get:p,onChange:function(){var d=a.create({ready:c(["orientation"]),change:c(["orientation"])}),g=f.fromDom(m),q=null,t=b.bind(g,"orientationchange",
function(){h(q);var a=p();d.trigger.change(a);s(function(){d.trigger.ready(a)})}),s=function(a){h(q);var b=m.innerHeight,c=0;q=k(function(){b!==m.innerHeight?(h(q),a(e.some(m.innerHeight))):20<c&&(h(q),a(e.none()));c++},50)};return{onAdjustment:s,events:d.registry,destroy:function(){t.unbind()}}}}});l("10q",["1a","l","2p","32"],function(d,e,c,a){return{tag:function(){var b=a.first("head").getOrDie(),f=a.first('meta[name="viewport"]').getOrThunk(function(){var a=e.fromTag("meta");d.set(a,"name","viewport");
c.append(b,a);return a}),g=d.get(f,"content");return{maximize:function(){d.set(f,"content","width=device-width, initial-scale=1.0, user-scalable=no, maximum-scale=1.0")},restore:function(){void 0!==g&&null!==g&&0<g.length?d.set(f,"content",g):d.remove(f,"content")}}}}});l("10r",["7","3y"],function(d,e){return function(c){return function(a,b){var f=e.bind(c,"touchmove",a.move),g=e.bind(c,"touchend",a.drop);return{element:d.constant(c),start:d.noop,stop:d.noop,destroy:function(){f.unbind();g.unbind()}}}}});
l("13i","7 s 2o 32 2s 1s".split(" "),function(d,e,c,a,b,f){var g=function(a,c){var d=b.get(a);return f.floor(c/100*d)},h=function(b,c){return a.ancestor(c,"td,th").fold(function(){return g(b,98)},function(a){return g(a,94)})},k=function(a,b,c){var d=b.dom().width;a=h(a,b);return f.max(0,f.min(a,d+c))},m=function(a,b,c){return b.dom().height+c};return{compare:function(a,b){var c=b.deltaX()-a.deltaX(),e=b.deltaY()-a.deltaY(),f=b.deltaDistance()-a.deltaDistance();return{deltaX:d.constant(c),deltaY:d.constant(e),
deltaDistance:d.constant(f)}},extract:function(a){var b=a.raw().touches;if(2>b.length)return e.none();a=f.abs(b[0].clientX-b[1].clientX);var b=f.abs(b[0].clientY-b[1].clientY),c=f.sqrt(f.pow(a,2)+f.pow(b,2));return e.some({deltaX:d.constant(a),deltaY:d.constant(b),deltaDistance:d.constant(c)})},resize:function(a,d,e){var g=c.getRaw(d,"height"),t=c.getRaw(d,"width"),s=0<e.deltaDistance()?1:-1,l=s*f.abs(e.deltaX()),v=s*f.abs(e.deltaY());e=k(a,d,l);s=m(a,d,v);l=f.abs(l)>f.abs(v);c.setAll(d,{height:l?
"auto":s+"px",width:l?e+"px":"auto",transform:"translate3d(0, 0, 0)"});b.get(d)>h(a,d)&&(g.each(function(a){c.set(d,"height",a)}),t.each(function(a){c.set(d,"width",a)}))}}});l("10s","xk iw s 13i 4p 2o 3y 21".split(" "),function(d,e,c,a,b,f,g,h){return function(k,m,p,n){var r=b(c.none());p=d.mode({compare:a.compare,extract:a.extract,sink:p,mutate:function(b,c){r.get().each(function(b){a.resize(m,b,c)})}});var q=e.transform({},{mode:p}),t=g.bind(k,"touchstart",function(a){"img"===h.name(a.target())&&
2===a.raw().touches.length&&(r.set(c.some(a.target())),q.on(),q.go(m))});q.events.stop.bind(function(){r.get().each(function(a){f.remove(a,"transform")});n()});return{destroy:function(){t.unbind();q.destroy()}}}});l("wo","b c 10o hp 10p 10q 7 s 79 10r 10s 1y 2o 3y l 2z q 37".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,l,v){var w=6<=e.detect().os.version.major;return function(e,x,z){var A=z.toolbar.element(),D=f.tag(),B=[],C=t.fromDom(l),F=a(A),E=null,G=k.api(),H=h.none(),I=function(){G.run(function(a){a.toEditing()})},
K=function(){F.closeMenus()},J=function(){e.getSelection().each(function(a){a=a.collapsed()?"0px":"23px";r.set(A,"margin-top",a)})},L=function(a){r.set(A,"margin-top","0px")},N=function(){var a=[q.bind(A,"touchmove",F.closeMenus)];B=e.doc().map(function(a){return x||!0===w?[]:[q.bind(a,"selectionchange",J),q.bind(C,"focusin",L)]}).getOr([]).concat(a)},M=function(){d.each(B,function(a){a.unbind()})};return{enter:function(){e.body().each(function(a){e.doc().each(function(d){e.win().each(function(f){s.focus(a);
E=b.onChange();var k=m(d),k=p(d,a,k,g.noop);H=h.some(k);f=c.setup(v,f);G.set(f);e.events.toEditing.bind(I);E.events.change.bind(K)})})});n.add(A,"ephox-polish-mobile-show");z.toolbar.refresh();D.maximize();N()},exit:function(){G.clear();e.events.toEditing.unbind(I);E.events.change.unbind(K);null!==E&&E.destroy();D.restore();M()},destroy:function(){H.each(function(a){a.destroy()});M()}}}});l("wp","b 8b 53 7 7b 34 59 4a 1y 2o 3y l 2p 2r 3x".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t){return function(){var t=
n.fromTag("div");k.add(t,f.resolve("disabled-mask"));var l=!1,v=c.div();k.add(v,f.resolve("content-container"));var w=c.div();e.hidden(w,!0);k.add(w,f.resolve("tap-icon"));r.append(v,w);var y=c.div();k.add(y,f.resolve("disclosure"));r.append(y,n.fromText(b.translate("taptoedit")));r.append(v,y);r.append(t,v);e.textButton(t,v);var x=h.create({fullscreen:g([])}),z=function(a){var b=t.dom().getClientRects()[0];return d.forall(a,function(a){return a.pageY>=b.top&&a.pageY<=b.top+b.height&&a.pageX>=b.left&&
a.pageX<=b.left+b.width})},A=[p.bind(t,"touchmove",function(a){l=!0}),p.bind(t,"touchend",function(a){var b=a.raw().changedTouches;z(b)&&!l&&(a.kill(),x.trigger.fullscreen())}),p.bind(t,"touchstart",function(a){l=!1}),p.bind(t,"click",function(a){a.kill();x.trigger.fullscreen()})];return{element:a.constant(t),events:x.registry,destroy:function(){d.each(A,function(a){a.unbind()});q.remove(w);q.remove(y);q.remove(v);q.remove(t)},show:function(){m.remove(t,"display")},hide:function(){m.set(t,"display",
"none")}}}});l("og","cx 34 wo wp 1y 2z 2p".split(" "),function(d,e,c,a,b,f,g){return function(h,k,m,p,n,r){var q=r.element(),t=c(h,n.fillscreen,r),s=function(){t.enter();p.actions().maximize()},l=function(){var b=a();g.append(r.element(),b.element());b.events.fullscreen.bind(function(a){p.actions().maximize()})};return{init:function(){r.socket(h);h.events.scrollToCursor.bind(function(){d.cursorIntoView(h)})},loaded:function(){var a=!0===n.fillscreen;(b.has(q,e.resolve("fullscreen-maximized"))||a?
s:l)()},restoreEditor:function(){p.actions().restore();t.exit()},destroy:function(){h.body().each(f.blur)}}}});l("g1",["7","oe","of","og"],function(d,e,c,a){return function(b,f,g,h,k){var m=h.toolbar.items,p=function(d){var p=a(b,f,g,k,h,d),q=e();d=c.config({items:[["back"]].concat(m),contextual:[]},{back:{feature:q.ui(),command:"back",type:"general"}},{allowLocalImages:h.allowLocalImages});q.events.back.bind(function(){p.restoreEditor()});return{init:p.init,loaded:p.loaded,config:d,destroy:function(){p.destroy();
q.destroy()}}};return{tabbed:p,full:p,destroy:d.noop}}});l("g2",["7","of","og"],function(d,e,c){return function(a,b,f,g,h){var k=g.toolbar.items,m=function(d){var m=c(a,b,f,h,g,d);d=e.config({items:k,contextual:[]},{},{allowLocalImages:g.allowLocalImages});return{init:m.init,loaded:m.loaded,config:d,destroy:function(){m.destroy()}}};return{tabbed:m,full:m,destroy:d.noop}}});l("g3",["7","cx","of"],function(d,e,c){return function(a,b,f,g){b=function(b){return{init:function(){b.socket(a);a.events.scrollToCursor.bind(function(){e.cursorIntoView(a)});
a.events.toEditing.bind(a.focus)},loaded:d.noop,config:c.config(g.toolbar,{},{allowLocalImages:g.allowLocalImages}),destroy:d.noop}};return{tabbed:b,full:b,destroy:d.noop}}});l("10t",["b","1a","2o","4h"],function(d,e,c,a){var b=function(a){return a.body().map(function(a){a=c.get(a,"background-color");return void 0!==a&&""!==a?"background-color:"+a+"!important":"background-color:rgb(255,255,255)!important;"}).getOr("background-color:rgb(255,255,255)!important;")};return{clobberStyles:function(c,g){var h=
function(a){return function(b){var c=e.get(b,"style"),c=void 0===c?"no-styles":c.trim();c!==a&&(e.set(b,"data-ephox-mobile-fullscreen-style",c),e.set(b,"style",a))}},k=a.ancestors(c,"*"),m=d.bind(k,function(b){return a.siblings(b,"*")}),p=b(g);d.each(m,h("display:none!important;"));d.each(k,h("position:absolute!important;top:0!important;left:0!important;margin:0!important;padding:0!important;width:100%!important;height:100%!important;overflow:visible!important;"+p))},restoreStyles:function(){var b=
a.all("[data-ephox-mobile-fullscreen-style]");d.each(b,function(a){var b=e.get(a,"data-ephox-mobile-fullscreen-style");"no-styles"!==b?e.set(a,"style",b):e.remove(a,"style");e.remove(a,"data-ephox-mobile-fullscreen-style")})}}});l("wq","10q 7 s 34 wp 10t 1y 2o q".split(" "),function(d,e,c,a,b,f,g,h,k){return function(m,p){var n=d.tag(),r=c.none(),q=b();return{maximize:function(){r=c.some(k.body.scrollTop);h.set(q.element(),"display","none");g.add(m,a.resolve("fullscreen-maximized"));f.clobberStyles(m,
p);n.maximize()},restore:function(){f.restoreStyles();g.remove(m,a.resolve("fullscreen-maximized"));n.restore();h.remove(q.element(),"display");r=r.bind(function(a){k.body.scrollTop=a;return c.none()})},destroy:function(){q.destroy()},mask:e.constant(q)}}});l("13j",["2o","l","2z","2p","2r"],function(d,e,c,a,b){return{input:function(f,g){var h=e.fromTag("input");d.setAll(h,{opacity:"0",position:"absolute",top:"-1000px",left:"-1000px"});a.append(f,h);c.focus(h);g(h);b.remove(h)}}});l("hf",["2z","3x"],
function(d,e){return{refreshInput:function(c){var a=c.dom().selectionStart,b=c.dom().selectionEnd,f=c.dom().selectionDirection;e(function(){c.dom().setSelectionRange(a,b,f);d.focus(c)},50)},refresh:function(c){var a=c.getSelection();if(0<a.rangeCount){var b=a.getRangeAt(0);c=c.document.createRange();c.setStart(b.startContainer,b.startOffset);c.setEnd(b.endContainer,b.endOffset);a.removeAllRanges();a.addRange(c)}}}});l("13k",["hf","1b","l","2z"],function(d,e,c,a){return{resume:function(b,f){a.active().each(function(b){e.eq(b,
f)||a.blur(b)});b.focus();a.focus(c.fromDom(b.document.body));d.refresh(b)}}});l("10u","b hp 13j 13k 7 2n 3y 2z 21".split(" "),function(d,e,c,a,b,f,g,h,k){return{stubborn:function(b,p,n,r,q){var t=e(q),s=function(){a.resume(b,n)},l=g.bind(p,"keydown",function(a){d.contains(["input","textarea"],k.name(a.target()))||(t.closeMenus(void 0),s())});return{toReading:function(){c.input(f.body(),h.blur)},toEditing:s,onToolbarTouch:function(a){},destroy:function(){l.unbind()}}},timid:function(c,d,e,f,g){return{toReading:function(){h.blur(e)},
toEditing:function(){a.resume(c,e)},onToolbarTouch:function(){h.blur(e)},destroy:b.noop}}}});l("13l",["s","59","4a","3y"],function(d,e,c,a){return{touch:function(b){var f=c.create({touchstart:e(["raw"]),touchend:e(["raw"])}),g=!1,h=d.none(),k=a.capture(b,"touchstart",function(c){g=!0;h=d.some(a.capture(b,"touchend",function(a){g=!1;f.trigger.touchend(a.raw());m()}));f.trigger.touchstart(c.raw())}),m=function(){h.each(function(a){a.unbind()})};return{isTouching:function(){return g},events:f.registry,
destroy:function(){k.unbind();m()}}}}});l("158","81 13j 13h 2n 3p 32 2b".split(" "),function(d,e,c,a,b,f,g){var h=function(a){a=g.documentElement(a);var d=c.resolve("unfocused-selection");return f.descendant(a,"."+d).bind(function(a){return b.absolute(a).top})};return{switchSelection:function(b,c,f){var g=f.isActive,h=!1;return{on:function(){g()||(h=!1,f.update(),c.save(),d.clearAll(b))},off:function(){g()&&!h&&(f.clear(),c.restore())},fakeOut:function(){h=!0;e.input(a.body(),c.restore)}}},inView:function(a,
b,c){return function(){return h(b).map(function(b){var c=a.dom().scrollTop;return 0<b()-c})}}}});l("159",[],function(){return{onScroll:function(d,e,c,a){var b=function(){d()||f()},f=function(){a.events.touchend.unbind(b);a.isTouching()?a.events.touchend.bind(b):(c().getOr(!0)?e.off:e.fakeOut)()};return{start:function(){a.events.touchend.unbind(b);e.on()},stop:f,destroy:function(){a.events.touchend.unbind(b)}}}}});l("13m",["158","159"],function(d,e){return{toFake:d.switchSelection,inView:d.inView,
onScroll:e.onScroll}});l("15z",["s","k"],function(d,e){return{findDevice:function(c,a){return e.findMap([{width:320,height:480,keyboard:{portrait:300,landscape:240}},{width:320,height:568,keyboard:{portrait:300,landscape:240}},{width:375,height:667,keyboard:{portrait:305,landscape:240}},{width:414,height:736,keyboard:{portrait:320,landscape:240}},{width:768,height:1024,keyboard:{portrait:320,landscape:400}},{width:1024,height:1366,keyboard:{portrait:380,landscape:460}}],function(b){return c<=b.width&&
a<=b.height?d.some(b.keyboard):d.none()}).getOr({portrait:a/5,landscape:c/4})}}});l("15a",["10p","15z","2o","68","37"],function(d,e,c,a,b){var f=e.findDevice(b.screen.width,b.screen.height),g=function(c){c=a.get(c);var e=d.get().isPortrait(),g=e?f.portrait:f.landscape;return c-((e?b.screen.height:b.screen.width)-b.innerHeight>g?0:g)};return{getGreenzone:g,updatePadding:function(b,d){var e=g(d),e=a.get(d)-e;c.set(b,"padding-bottom",e+"px")}}});l("13q","b 3q 13f 15a 13h 7 4q 1a 2o 68 4h 1u e2 37".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,r,q){var t=g.generate([{fixed:["element","offsetY"]},{scroller:["element","offsetY"]}]),s="data-"+b.resolve("position-y-fixed"),l="data-"+b.resolve("scrolling"),v="data-"+b.resolve("last-window-height"),w=function(a){return c.safeParse(a,s)},y=function(a){var b=w(a);return("true"===h.get(a,l)?t.scroller:t.fixed)(a,b)},x=function(a){var b=h.get(a,"style");k.setAll(a,{position:"absolute",top:"0px"});h.set(a,s,"0px");return{restore:function(){h.set(a,"style",b||"");h.remove(a,
s)}}},z=function(a,b,c){var d=h.get(c,"style");e.register(c);k.setAll(c,{position:"absolute",height:b+"px",width:"100%",top:a+"px"});h.set(c,s,a+"px");h.set(c,l,"true");return{restore:function(){e.deregister(c);h.set(c,"style",d||"");h.remove(c,s);h.remove(c,l)}}},A=function(a,b){var c=q.innerHeight;h.set(a,v,c+"px");return c-b};return{findFixtures:function(a){a=p.descendants(a,"["+s+"]");return d.map(a,y)},takeover:function(b,d,e){var g=x(e),p=m.get(e),n=A(b,p),r=z(p,n,b),p=function(){var a=q.innerHeight,
d=c.safeParse(b,v);return a>d},t=function(){var c=m.get(e),f=A(b,c);h.set(b,s,c+"px");k.set(b,"height",f+"px");a.updatePadding(d,b)};a.updatePadding(d,b);return{setViewportOffset:function(a){h.set(b,s,a+"px");t()},isExpanding:p,isShrinking:f.not(p),refresh:t,restore:function(){g.restore();r.restore()}}},getYFixedData:w}});l("15b",["s","1s","2t","2u"],function(d,e,c,a){var b=function(a,b,c){return e.abs(a-b)<=c?d.none():a<b?d.some(a+c):d.some(a-c)};return{create:function(){var d=null;return{animate:function(g,
h,k,m,p,n){c(d);var r=function(a){c(d);p(a)};d=a(function(){var a=g();b(a,h,k).fold(function(){c(d);p(h)},function(b){m(b,r);var k=g();if(k!==b||e.abs(k-h)>e.abs(a-h))c(d),p(h)})},n)}}},adjust:b}});l("13o","3w 13f 13q 15b 13h 7 1a 2o 1s e2 37".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=a.create(),r="data-"+b.resolve("last-scroll-top"),q=function(a){a=h.getRaw(a,"top").getOr(0);return m(a,10)},t=function(a){return m(a.dom().scrollTop,10)},s=function(a,b){var d=b+c.getYFixedData(a)+"px";h.set(a,
"top",d)};return{moveScrollAndTop:function(a,b,c){return d.nu(function(d){var e=f.curry(t,a);n.animate(e,b,15,function(b){a.dom().scrollTop=b;h.set(a,"top",q(a)+15+"px")},function(e){a.dom().scrollTop=b;h.set(a,"top",c+"px");d(b)},10)})},moveOnlyScroll:function(a,b){return d.nu(function(c){var d=f.curry(t,a);g.set(a,r,d());var h=k.abs(b-d()),h=k.ceil(h/10);n.animate(d,b,h,function(b,c){e.safeParse(a,r)!==a.dom().scrollTop?c(a.dom().scrollTop):(a.dom().scrollTop=b,g.set(a,r,b))},function(d){a.dom().scrollTop=
b;g.set(a,r,b);c(b)},10)})},moveOnlyTop:function(a,b){return d.nu(function(c){var d=f.curry(q,a),e=function(b){h.set(a,"top",b+"px")},g=k.abs(b-d()),g=k.ceil(g/10);n.animate(d,b,g,e,function(a){e(b);c(b)},10)})},moveWindowScroll:function(a,b,c){return d.nu(function(d){var e=function(c){s(a,c);s(b,c);p.scrollTo(0,c)};n.animate(function(){return p.pageYOffset},c,15,e,function(a){e(a);d(a)},10)})}}});l("13n",["hf","15a","13o","7","e2"],function(d,e,c,a,b){return{scrollIntoView:function(b,g,h,k){var m=
e.getGreenzone(g);b=a.curry(d.refresh,b);h>m||k>m?c.moveOnlyScroll(g,g.dom().scrollTop-m+k).get(b):0>h&&c.moveOnlyScroll(g,g.dom().scrollTop+h).get(b)}}});l("13p","b 3w 13o 13q 2o e2".split(" "),function(d,e,c,a,b,f){var g=function(a,d){return a.fold(function(a,c){b.set(a,"top",d+c+"px");return e.pure(c)},function(a,e){var g=d+e,h=b.getRaw(a,"top").getOr(e),h=g-f(h,10),h=a.dom().scrollTop+h;return c.moveScrollAndTop(a,h,g)})};return{updatePositions:function(b,c){var f=a.findFixtures(b),f=d.map(f,
function(a){return g(a,c)});return e.par(f)}}});l("13r","b 13g 13k 13h 1y 4e 2o 3y l 2p 3d 2r 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){return function(q,t){var s=q.document,l=k.fromTag("div");b.add(l,a.resolve("unfocused-selections"));m.append(k.fromDom(s.documentElement),l);var v=h.bind(l,"touchstart",function(a){a.prevent();c.resume(q,t);y()}),w=function(b){var c=k.fromTag("span");f.add(c,[a.resolve("layer-editor"),a.resolve("unfocused-selection")]);g.setAll(c,{left:b.left+"px",top:b.top+
"px",width:b.width+"px",height:b.height+"px"});return c},y=function(){n.empty(l)};return{update:function(){y();var a=e.getRectangles(q),a=d.map(a,w);p.append(l,a)},isActive:function(){return 0<r.children(l).length},destroy:function(){v.unbind();n.remove(l)},clear:y}}});l("13s",["2m","7","4p"],function(d,e,c){return function(a){var b=c(d.pure({}));return{start:function(c){var g=d.nu(function(b){return a(c).get(b)});g.get(e.identity);b.set(g)},idle:function(a){b.get().get(function(){a()})}}}});l("10v",
"13l 10p 13m 13g 13n 13o 13p 13q 13r 13s 7 aa s 2n 2o 3y l 1s 2t 6e o e2 2u 3x 37".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,l,v,w,y,x,z,A,D,B){var C=function(b,c,d,e,h,k){var q=m(function(a){return f.moveWindowScroll(b,c,a)}),t=function(){var b=a.getRectangles(k);return r.from(b[0]).bind(function(a){var b=a.top-c.dom().scrollTop;return b>B.innerHeight+5||-5>b?r.some({top:p.constant(b),bottom:p.constant(b+a.height)}):r.none()})},v=n(function(){q.idle(function(){g.updatePositions(d,e.pageYOffset).get(function(a){t().each(function(a){c.dom().scrollTop=
c.dom().scrollTop+a.top()});q.start(0);h.refresh()})})},1E3),w=s.bind(l.fromDom(e),"scroll",function(){0>e.pageYOffset||v.throttle()});g.updatePositions(d,e.pageYOffset).get(p.identity);return{unbind:w.unbind}};return{setup:function(a){var g=a.cWin(),m=a.ceBody(),n=a.socket(),r=a.toolstrip(),v=a.toolbar(),w=a.contentElement(),y=a.cursor(),x=a.keyboardType();a=a.isScrolling();var z=h.takeover(n,m,r),A=x(g,q.body(),w,r,v),D=e.onChange();D.events.ready.bind(z.refresh);D.onAdjustment(function(){z.refresh()});
var P=s.bind(l.fromDom(B),"resize",function(){z.isExpanding()&&z.refresh()}),T=C(r,n,q.body(),B,z,g),Q=k(g,w),V=function(){Q.clear()},r=c.toFake(g,y,Q),m=c.inView(n,m,v),W=d.touch(l.fromDom(g)),$=c.onScroll(a,r,m,W);return{toEditing:function(){A.toEditing();V()},toReading:function(){A.toReading()},onToolbarTouch:function(a){A.onToolbarTouch(a)},refreshSelection:function(){Q.isActive()&&Q.update()},clearSelection:V,highlightSelection:function(){Q.update()},scrollIntoView:function(a,c){b.scrollIntoView(g,
n,a,c)},updateToolbarPadding:p.noop,setViewportOffset:function(a){z.setViewportOffset(a);f.moveOnlyTop(n,a).get(p.identity)},syncHeight:function(){t.set(w,"height",w.dom().contentWindow.document.body.scrollHeight+"px")},selectionScrollStarted:function(){$.start()},selectionScrollStopped:function(){$.stop()},destroy:function(){z.restore();D.destroy();T.unbind();P.unbind();A.destroy();$.destroy();W.destroy();Q.destroy()}}}}});l("13t",["13h","1a"],function(d,e){var c="data-"+d.resolve("horizontal-scroll"),
a=function(a){var b;(b=0<a.dom().scrollTop)||(a.dom().scrollTop=1,b=0!==a.dom().scrollTop,a.dom().scrollTop=0);return b},b=function(a){var b;(b=0<a.dom().scrollLeft)||(a.dom().scrollLeft=1,b=0!==a.dom().scrollLeft,a.dom().scrollLeft=0);return b};return{markAsHorizontal:function(a){e.set(a,c,"true")},hasScroll:function(d){return"true"===e.get(d,c)?b:a}}});l("10w",["13t","7","s","3y","32"],function(d,e,c,a,b){var f=function(a){var b=a.dom().scrollTop,d=a.dom().scrollHeight;a=a.dom().offsetHeight;return 0>=
b?c.some(1):b+a>=d?c.some(d-a-1):c.none()},g=function(a){f(a).each(function(b){a.dom().scrollTop=b})},h=function(b,c){return a.bind(b,"touchstart",function(a){c(a.target()).each(g)})};return{fixEdges:g,exclusive:function(c,f){return a.bind(c,"touchmove",function(a){b.closest(a.target(),f).filter(d.hasScroll).fold(function(){a.raw().preventDefault()},e.noop)})},link:function(a,b){return h(a,e.constant(b))},ancestor:function(a,c){return h(a,function(a){return b.closest(a,c)})},indirect:h,markAsHorizontal:function(a){d.markAsHorizontal(a)}}});
l("q5",["84","l","2p","2r","2b"],function(d,e,c,a,b){var f=function(a){return e.fromText(d.zeroWidth(),a.dom())};return{runAndRemove:function(d,h){var k=b.owner(d),m=e.fromTag("span",k.dom());c.append(m,f(k));c.prepend(d,m);k=h(m);a.remove(m);return k},enrichAndRemove:function(d,e){var k=f(b.owner(d));c.append(d,k);var m=e(d);a.remove(k);return m}}});l("i9","q4 7 s ct q5 od 2v 3o 2n 2o 68 3p 21 2b b0 2s e2".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,l){var v=g.immutable("left","top","width",
"height","direction","absolute"),w=function(b){return{position:e.constant(a.find(b)),width:e.constant(s.getOuter(b)),height:e.constant(p.getOuter(b))}},y=function(a){var b=m.get(a,"display");return{backup:function(){m.set(a,"display","inline-block")},restore:function(){m.set(a,"display",b)}}},x={backup:e.noop,restore:e.noop},z=function(a){return r.isElement(a.startContainer())?c.some(a.startContainer()):r.isElement(a.endContainer())?c.some(a.endContainer()):q.parent(a.startContainer()).filter(r.isElement).orThunk(function(){return q.parent(a.endContainer()).filter(r.isElement)})},
A=function(b,c){return z(c).fold(function(){return v(0,0,0,b.uiDirection(),h(0,0))},function(c){var d=a.find(c),e=s.get(c),f=p.get(c),g=n.absolute(c);return v(d.left(),d.top(),e,f,b.directionAt(c),g)})},D=function(a,c,d,e){return f.diagnose(a,d)(e,function(a){var e=t.isVisible(a)||"br"===r.name(a)?x:y(a);e.backup();var f;if(k.inBody(a)){var g=b.enrichAndRemove(a,w);f=g.position();var h=g.width(),g=g.height(),m=c.directionAt(a);a=n.absolute(a);f=v(f.left(),f.top(),h,g,m,a)}else f=A(c,d);e.restore();
return f})},B=function(a,e,f,g){var h=f.startContainer(),k=f.startOffset();if("body"===r.name(h)&&0===k){var p=f.startContainer();a=l(m.get(p,"padding-top"),10);g=l(m.get(p,"padding-left"),10);var q=b.runAndRemove(p,w),h=q.position(),k=q.width(),q=q.height();e=e.directionAt(p);p=n.absolute(p);f=d(v(h.left()+g,h.top()+a,k,q,e,p),c.some(f))}else f=D(a,e,f,g);return f},C=function(a,b,c,d,e){b.focus();a=B(b.isRoot,a,c,e);a.cursor().each(function(a){b.setSelection(a.startContainer(),a.startOffset(),a.endContainer(),
a.endOffset())});a=a.result();d(a)};return{insertAt:C,insertAtCursor:function(a,b,c,d){b.getSelection().each(function(e){C(a,b,e,c,d)})}}});l("10x",["7","3y","21"],function(d,e,c){return function(a){return function(b,f){var g=e.bind(a,"touchmove",b.move),h=e.bind(a,"touchend",b.drop),k=e.bind(a,"gesturestart",function(a){"img"===c.name(a.target())&&a.prevent()});return{element:d.constant(a),start:d.noop,stop:d.noop,destroy:function(){g.unbind();h.unbind();k.unbind()}}}}});l("wr","b 3q 80 81 10u 10v hp 10p 10w aa s 8c 79 i9 34 10s 10x 2v 1y 1b 2o 3y l 2z 68 3p 32 2t 6e q 2u 3x 37".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,t,s,l,v,w,y,x,z,A,D,B,C,F,E,G,H,I,K,J){return function(G,K,M,O,S,P,T,Q){var V=[],W=P.toolbar.element(),$=P.banners(),X=P.viewport(),Y=p.none(),da=g(W),R=null,ca=r.api(),ea=p.none(),fa=e.event(X),ga=v.immutableBag("cWin ceBody socket toolstrip toolbar contentElement cursor keyboardType isScrolling".split(" "),[]),ia=function(){ca.run(function(a){a.highlightSelection()})},ha=function(){ca.run(function(a){a.refreshSelection()})},Z=function(a){var b=C.absolute(a).top()-
X.dom().scrollTop;ca.run(function(c){c.scrollIntoView(b,b+B.get(a))})},aa=function(){q.insertAtCursor(O,G,function(a){var b=a.absolute().top()-X.dom().scrollTop;ca.run(function(c){c.scrollIntoView(b,b+a.height())})})},ja=function(a){aa();ca.run(function(a){a.syncHeight()})},ba=function(a){var b=B.get(W);ca.run(function(a){a.setViewportOffset(b)});ha();ja()},U=function(a){Z(a.element())},ka=m(ja,300),pa=function(){da.closeMenus()},ma=function(){qa();var a=I(function(){0===J.pageYOffset&&(E(a),ja())},
100)},la=function(){ca.run(function(a){a.clearSelection()})},Ca=function(){la();ka.throttle()},Da=function(){ca.run(function(a){a.toEditing()})},Ea=function(){ca.run(function(a){a.toReading()})},na=function(a){ca.run(function(b){b.onToolbarTouch(a)})},qa=function(){(h.get().isPortrait()?w.remove:w.add)(P.element(),t.resolve("mobile-landscape"))},oa=function(a){var b=x.get(a,"background-color");void 0!==b&&""!==b&&x.set(a,"-webkit-tap-highlight-color",b)},sa=function(b){var d=G.win().getOrDie(),e=
function(e){D.focus(b);e=e.raw().changedTouches[0];c.find(d,e.pageX,e.pageY).each(function(b){a.set(d,b)})},f=G.doc().map(function(a){var c=l(a),c=s(a,b,c,ja);ea=p.some(c);var d=A.fromDom(a.dom().documentElement);return[z.bind(a,"touchend",function(a){(y.eq(d,a.target())||y.eq(b,a.target()))&&e(a)})]}).getOr([]),g=[z.capture(W,"touchstart",function(a){ia();na(a)}),z.bind(b,"touchstart",la),n.handle(b,za),z.bind(W,"touchmove",da.closeMenus)];V=f.concat(g)},za=function(a){a.kill()};return{exit:function(){G.body().each(function(a){x.remove($,
"display");x.set(P.viewport(),"overflow","hidden");Y=Y.bind(function(a){a.unbind();return p.none()});w.remove(W,t.resolve("mobile-show"));ca.clear();D.blur(a);x.remove(a,"padding-top");d.each(V,function(a){a.unbind()});T.restore();G.events.keyup.unbind(Ca);G.events.domChanged.unbind(ka.throttle);G.events.scrollToCursor.unbind(ka.throttle);G.events.scrollToElement.unbind(U);G.events.domChanged.unbind(ha);G.events.nodeChanged.unbind(ha);G.events.toEditing.unbind(Da);G.events.toReading.unbind(Ea);R.events.change.unbind(pa);
R.events.ready.unbind(ma);P.toolbar.events.transitionend.unbind(ba);null!==R&&R.destroy()})},enter:function(a){G.body().each(function(a){G.win().each(function(c){R=h.onChange();T.maximize();sa(a);D.focus(a);Y=p.some(k.exclusive(M,"."+e.scrollable()));x.getRaw(W,"overflow-x").is("auto")&&F.descendant(W,".ephox-chameleon-toolbar").each(function(a){k.markAsHorizontal(a);e.register(a)});oa(a);qa();H.body.scrollTop=0;w.add(W,t.resolve("mobile-show"));P.toolbar.refresh();x.set($,"display","block");F.descendant(W,
".ephox-chameleon-toolbar").each(function(d){ca.set(f.setup(ga({cWin:c,ceBody:a,socket:X,toolstrip:W,toolbar:d,contentElement:G.element(),cursor:G.cursor(),keyboardType:b.stubborn,isScrolling:fa.isScrolling})))});G.events.keyup.bind(Ca);G.events.domChanged.bind(ka.throttle);G.events.scrollToCursor.bind(ka.throttle);G.events.scrollToElement.bind(U);G.events.domChanged.bind(ha);G.events.nodeChanged.bind(ha);G.events.toEditing.bind(Da);G.events.toReading.bind(Ea);R.events.change.bind(pa);R.events.ready.bind(ma);
P.toolbar.events.transitionend.bind(ba);ja()})})},destroy:function(){ea.each(function(a){a.destroy()});Y.each(function(a){a.unbind()});fa.destroy()}}}});l("oh","7 wq wr l 2z 2g 2p 2b q".split(" "),function(d,e,c,a,b,f,g,h,k){return function(m,p,n,r,q){var t=e(q.element(),m),s=a.fromDom(k),l=m.element(),v=d.constant(!0===r.fillscreen),w=c(m,p,s,n,l,q,t,v),y=function(b){var c=h.children(b),d;if(!(d=0===c.length)){if(c=1===c.length)c=f.get(b),c=10===c.charCodeAt(0)&&10===c.charCodeAt(1);d=c}d&&(c=a.fromHtml("<p><br></p>"),
g.append(b,c));w.enter()},x=function(a){g.append(q.element(),t.mask().element());t.mask().events.fullscreen.bind(function(a){w.enter()})},z=function(a){(v()?y:x)(a)};return{init:function(){q.socket(m)},loaded:function(){m.body().each(z)},restoreEditor:function(){m.body().each(b.blur);m.element().dom().focus();m.element().dom().blur();w.exit();b.focus(t.mask().element())},destroy:function(){m.body().each(b.blur);w.destroy();t.destroy()}}}});l("g4",["7","oe","of","oh"],function(d,e,c,a){return function(b,
f,g,h){var k=h.toolbar.items;return{tabbed:function(d){var p=a(b,f,g,h,d),n=e();d=c.config({items:[["back"]].concat(k),contextual:[]},{back:{feature:n.ui(),command:"back",type:"general"}},{allowLocalImages:h.allowLocalImages});n.events.back.bind(function(){p.restoreEditor()});return{init:p.init,loaded:p.loaded,config:d,destroy:function(){p.destroy();n.destroy()}}},full:d.die("mobile does not support fullscreen layout"),destroy:d.noop}}});l("g5",["7","of","oh"],function(d,e,c){return function(a,b,
f,g){var h=g.toolbar.items;return{tabbed:function(d){var m=c(a,b,f,g,d);d=e.config({items:h,contextual:[]},{},{allowLocalImages:g.allowLocalImages});return{init:m.init,loaded:m.loaded,config:d,destroy:function(){m.restoreEditor();m.destroy()}}},full:d.die("mobile does not support fullscreen layout"),destroy:d.noop}}});l("8n","c g1 g2 g3 g4 g5".split(" "),function(d,e,c,a,b,f){var g=d.detect();return function(d,k,m,p,n){return(g.deviceType.isiOS()?!0===n.fillscreen?f:b:g.deviceType.isAndroid()?!0===
n.fillscreen?c:e:a)(d,k,m,n,p)}});l("oi",["1","vy","7","s","o"],function(d,e,c,a,b){var f=function(){try{var b=d.localStorage;b.setItem("__storage_test__","__storage_test__");b.removeItem("__storage_test__");return a.some(b)}catch(c){return a.none()}}().fold(function(){var a={};return{getItem:function(b){return a[b]},setItem:function(b,c){a[b]=c}}},function(a){return{getItem:function(b){return a.getItem("ephox.textboxio."+b)},setItem:function(b,c){a.setItem("ephox.textboxio."+b,c)}}}),g=function(b,
c){return a.from(f.getItem(b)).map(e.parse).getOr(c)},h=function(a){return g(a,{})},k=function(a,b){var c=e.stringify(b);f.setItem(a,c)};return{read:h,readOr:g,write:k,access:function(a){return{read:c.curry(h,a),write:c.curry(k,a)}}}});l("g6",["oi","4p"],function(d,e){return function(c,a){var b=d.readOr(c,a),f=e(b),g=function(a){f.set(a)};return{setAndCache:function(a){g(a);d.write(c,a)},set:g,get:function(){return f.get()}}}});l("8o",["7","g6"],function(d,e){return function(c){var a=e("native.spelling",
c.nativeSpelling),b=e("spelling",c.spelling),f=e("autocorrect",c.autocorrect),g=e("linkpreviews",c.linkpreviews),h=e("capitalisation",c.capitalisation);return{spelling:d.constant(b),nativeSpelling:d.constant(a),autocorrect:d.constant(f),linkpreviews:d.constant(g),capitalisation:d.constant(h),state:function(){return{nativeSpelling:a.get(),spelling:b.get(),autocorrect:f.get(),linkpreviews:g.get(),capitalisation:h.get()}},destroy:d.noop}}});l("g7",["84","9o","7","l","2p"],function(d,e,c,a,b){var f=function(b,
c,e){c.body().each(function(f){e.save();var p=a.fromHtml(d.zeroWidth());b(f,p);c.setSelection(p,0,p,0)})};return{upOrLeft:function(a,d,k){a.setRelativeSelection(e.before(k),e.before(k));a.getSelection().fold(function(){f(b.prepend,a,d)},c.noop)},right:function(a,d,k){a.setRelativeSelection(e.after(k),e.after(k));a.getSelection().fold(function(){f(b.append,a,d)},c.noop)}}});l("g8","87 s jg 1b 6u 2b".split(" "),function(d,e,c,a,b,f){return{left:function(a,h,k){return a(h)&&d.isStart(h,k)?e.none():d.isStart(h,
k)?c.before(h,a).filter(function(a){return!b.ancestor(a,"head")}):a(h)&&0<k?f.child(h,k-1):e.none()},right:function(a,h,k){return a(h)&&d.isEnd(h,k)?e.none():d.isEnd(h,k)?c.after(h,a).filter(function(c){return a(c)||b.ancestor(c,"body")}):a(h)&&k<d.getEnd(h)?f.child(h,k+1):e.none()},isFirstInContent:function(b,c){return b.body().map(function(b){b=f.children(b);return a.eq(b[0],c)}).getOr(!1)},isLastInContent:function(b,c){return b.body().map(function(b){b=f.children(b);return 0<b.length&&a.eq(b[b.length-
1],c)}).getOr(!1)}}});l("g9",["b","s"],function(d,e){var c=function(a,c){return a.getSelection().bind(function(d){return d.collapsed()?c(a.isRoot,d.startContainer(),d.startOffset()):e.none()})},a=function(a,c){return d.foldr(a,function(a,b){return b(c).or(a)},e.none())};return{get:function(b,d,e){return c(b,e).bind(function(b){return a(d,b)})}}});l("8p",["g7","g8","g9","2r"],function(d,e,c,a){return function(b,f,g){var h=f.all();h.on();var k=[];h.events.backspace.bind(function(){c.get(b,k,e.left).each(a.remove)});
f=function(a){var f=a.stopper();c.get(b,k,e.left).each(function(a){f();d.upOrLeft(b,g,a)})};h.events.right.bind(function(a){var f=a.stopper();c.get(b,k,e.right).each(function(a){f();d.right(b,g,a)})});h.events.left.bind(f);h.events.up.bind(f);return{registerSkip:function(a){k.push(a)},destroy:function(){h.destroy()}}}});l("8q",["7","s","cf","96"],function(d,e,c,a){return function(b,f){(f.error?e.some(f.error):e.none()).map(function(b){return c(a.get(b.name,[b]))}).each(b.displayBanner);return{destroy:d.noop}}});
l("om",["2v"],function(d){return{response:d.immutable("selection","kill")}});l("gb",[],function(){var d=function(a){return function(b){return b===a}},e=d(38),c=d(40);return{ltr:{isBackward:d(37),isForward:d(39)},rtl:{isBackward:d(39),isForward:d(37)},isUp:e,isDown:c,isNavigation:function(a){return 37<=a&&40>=a}}});l("on",["80","es","81"],function(d,e,c){return function(a){return{getRect:function(a){return a.dom().getBoundingClientRect()},getRangedRect:function(b,d,e,h){return c.rectangleAt(a,b,d,
e,h)},getSelection:function(){return c.get(a)},fromSitus:function(b){return c.deriveExact(a,b)},situsFromPoint:function(b,c){return d.find(a,b,c)},clearSelection:function(){c.clearAll(a)},setSelection:function(b){c.setExact(a,b.start(),b.soffset(),b.finish(),b.foffset())},setRelativeSelection:function(b,d){c.set(a,e.write(b,d))},selectContents:function(b){c.selectElementContents(a,b)},getInnerHeight:function(){return a.innerHeight},getScrollY:function(){return a.scrollY},scrollBy:function(b,c){a.scrollBy(b,
c)}}}});l("ou",["4j"],function(d){return{resolve:d.create("ephox-darwin").resolve}});l("iz",["ou","7"],function(d,e){var c=d.resolve("selected"),a=d.resolve("last-selected"),b=d.resolve("first-selected");return{selectedClass:e.constant(c),lastSelectedClass:e.constant(a),firstSelectedClass:e.constant(b)}});l("10y",["7","s","qy"],function(d,e,c){var a=function(a,c){return c.column()>=a.startCol()&&c.column()+c.colspan()-1<=a.finishCol()&&c.row()>=a.startRow()&&c.row()+c.rowspan()-1<=a.finishRow()};
return{inSelection:function(a,c){var d=c.column(),e=c.column()+c.colspan()-1,k=c.row(),m=c.row()+c.rowspan()-1;return d<=a.finishCol()&&e>=a.startCol()&&k<=a.finishRow()&&m>=a.startRow()},isWithin:a,isRectangular:function(b,f){for(var g=!0,h=d.curry(a,f),k=f.startRow();k<=f.finishRow();k++)for(var m=f.startCol();m<=f.finishCol();m++)g=g&&c.getAt(b,k,m).exists(h);return g?e.some(f):e.none()}}});l("wt",["gg","qy","10y","1b","1s"],function(d,e,c,a,b){var f=function(c,f,k){f=e.findItem(c,f,a.eq);var m=
e.findItem(c,k,a.eq);return f.bind(function(a){return m.map(function(c){return d.bounds({startCol:b.min(a.column(),c.column()),finishCol:b.max(a.column()+a.colspan()-1,c.column()+c.colspan()-1),startRow:b.min(a.row(),c.row()),finishRow:b.max(a.row()+a.rowspan()-1,c.row()+c.rowspan()-1)})})})};return{getAnyBox:f,getBox:function(a,b,d){return f(a,b,d).bind(function(b){return c.isRectangular(a,b)})}}});l("ws","b 7 qy 10y wt 1b".split(" "),function(d,e,c,a,b,f){return{moveBy:function(a,b,d,e){return c.findItem(a,
b,f.eq).bind(function(b){var f=0<d?b.row()+b.rowspan()-1:b.row();b=0<e?b.column()+b.colspan()-1:b.column();return c.getAt(a,f+d,b+e).map(function(a){return a.element()})})},intercepts:function(f,h,k){return b.getAnyBox(f,h,k).map(function(b){b=c.filterItems(f,e.curry(a.inSelection,b));return d.map(b,function(a){return a.element()})})},parentCell:function(a,b){return c.findItem(a,b,function(a,b){return f.contains(b,a)}).bind(function(a){return a.element()})}}});l("ot","bl qx qy ws wt 1b".split(" "),
function(d,e,c,a,b,f){var g=function(a){a=e.fromTable(a);return c.generate(a)};return{moveBy:function(b,c,e){return d.table(b).bind(function(d){d=g(d);return a.moveBy(d,b,c,e)})},intercepts:function(b,c,d){b=g(b);return a.intercepts(b,c,d)},nestedIntercepts:function(b,c,d,e,n){var r=g(b);c=f.eq(b,d)?c:a.parentCell(r,c);b=f.eq(b,n)?e:a.parentCell(r,e);return a.intercepts(r,c,b)},getBox:function(a,c,d){a=g(a);return b.getBox(a,c,d)}}});l("os","b iz 7 s gf ot 1y 1b 6s 4h 32".split(" "),function(d,e,
c,a,b,f,g,h,k,m,p){var n="."+e.selectedClass(),r=k.addClass(e.selectedClass()),q=k.removeClasses([e.selectedClass(),e.lastSelectedClass(),e.firstSelectedClass()]),t=function(a){a=m.descendants(a,n);d.each(a,q)},s=function(a,b){return p.ancestor(a,"table")},l=function(c,d,e){return h.eq(c,d)?a.some([c]):s(c,e).bind(function(a){return s(d,e).bind(function(g){return h.eq(a,g)?f.intercepts(a,c,d):h.contains(a,g)?f.nestedIntercepts(a,c,a,d,g):h.contains(g,a)?f.nestedIntercepts(g,c,a,d,g):b.ancestors(c,
d).shared().bind(function(b){return p.closest(b,"table",e).bind(function(b){return f.nestedIntercepts(b,c,a,d,g)})})})})},v=function(b){b=d.find(b,k.hasClass(e.lastSelectedClass()));return a.from(b)},w=function(a){return p.ancestor(a,"table").bind(function(b){return p.descendant(b,"."+e.firstSelectedClass()).bind(function(b){return l(b,a).map(function(d){return{boxes:c.constant(d),start:c.constant(b),finish:c.constant(a)}})})})};return{clear:t,identify:l,retrieve:function(b){b=m.descendants(b,n);
return 0<b.length?a.some(b):a.none()},shiftSelection:function(a,b,c){return v(a).bind(function(a){return f.moveBy(a,b,c).bind(w)})},isSelected:function(a){return g.has(a,e.selectedClass())},selectRange:function(a,b,c,f){t(a);d.each(b,r);g.add(c,e.firstSelectedClass());g.add(f,e.lastSelectedClass())},getEdges:function(a){return p.descendant(a,"."+e.firstSelectedClass()).bind(function(d){return p.descendant(a,"."+e.lastSelectedClass()).bind(function(a){return b.sharedOne(s,[d,a]).map(function(b){return{first:c.constant(d),
last:c.constant(a),table:c.constant(b)}})})})}}});l("oo","om os es 9o 81 87 s 1b 32".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(b,k,m,q){return!h.eq(m,q)&&(k=e.identify(m,q,k).getOr([]),0<k.length)?(e.selectRange(b,k,m,q),g.some(d.response(g.some(c.write(a.on(m,0),a.on(m,f.getEnd(m)))),!0))):g.none()};return{sync:function(a,c,d,e,f,h){return b.isCollapsed(d,e,f,h)?g.none():k.closest(d,"td,th",c).bind(function(b){return k.closest(f,"td,th",c).bind(function(d){return m(a,c,b,d)})})},detect:m,
update:function(a,b,c,d){return e.shiftSelection(d,a,b).map(function(a){e.clear(c);e.selectRange(c,a.boxes(),a.start(),a.finish());return a.boxes()})}}});l("10z",["2v"],function(d){var e=d.immutableBag(["left","top","right","bottom"],[]);return{nu:e,moveUp:function(c,a){return e({left:c.left(),top:c.top()-a,right:c.right(),bottom:c.bottom()-a})},moveDown:function(c,a){return e({left:c.left(),top:c.top()+a,right:c.right(),bottom:c.bottom()+a})},moveBottomTo:function(c,a){var b=c.bottom()-c.top();return e({left:c.left(),
top:a-b,right:c.right(),bottom:a})},moveTopTo:function(c,a){var b=c.bottom()-c.top();return e({left:c.left(),top:a,right:c.right(),bottom:a+b})},getTop:function(c){return c.top()},getBottom:function(c){return c.bottom()},translate:function(c,a,b){return e({left:c.left()+a,top:c.top()+b,right:c.right()+a,bottom:c.bottom()+b})},toString:function(c){return"("+c.left()+", "+c.top()+") -> ("+c.right()+", "+c.bottom()+")"}}});l("110",["10z","87","s","21"],function(d,e,c,a){var b=function(a){return d.nu({left:a.left,
top:a.top,right:a.right,bottom:a.bottom})};return{getBoxAt:function(d,g,h){return a.isElement(g)?c.some(d.getRect(g)).map(b):a.isText(g)?(d=0<=h&&h<e.getEnd(g)?d.getRangedRect(g,h,g,h+1):0<h?d.getRangedRect(g,h-1,g,h):c.none(),d.map(b)):c.none()},getEntireBox:function(d,g){return a.isElement(g)?c.some(d.getRect(g)).map(b):a.isText(g)?d.getRangedRect(g,0,g,e.getEnd(g)).map(b):c.none()}}});l("wv","10z 110 7 s jg fg 4q 4l 1s".split(" "),function(d,e,c,a,b,f,g,h,k){var m=g.generate([{none:[]},{retry:["caret"]}]),
p=function(a,b,d){return h.closest(b,f.isBlock).fold(c.constant(!1),function(b){return e.getEntireBox(a,b).exists(function(a){return d.left()<a.left()||1>k.abs(a.right()-d.left())||d.left()>a.right()})})};g={point:d.getBottom,adjuster:function(a,b,c,e,f){var g=d.moveDown(f,5);return 1>k.abs(c.bottom()-e.bottom())?m.retry(g):c.top()>f.bottom()?m.retry(g):c.top()===f.bottom()?m.retry(d.moveDown(f,1)):p(a,b,f)?m.retry(d.translate(g,5,0)):m.none()},move:d.moveDown,gather:b.after};var n=function(b,c,d,
f,g){return 0===g?a.some(f):b.situsFromPoint(f.left(),c.point(f)).bind(function(h){return h.start().fold(a.none,function(h,k){return e.getEntireBox(b,h,k).bind(function(e){return c.adjuster(b,h,e,d,f).fold(a.none,function(a){return n(b,c,d,a,g-1)})}).orThunk(function(){return a.some(f)})},a.none)})},r=function(b,c,d){return b.point(c)>d.getInnerHeight()?a.some(b.point(c)-d.getInnerHeight()):0>b.point(c)?a.some(-b.point(c)):a.none()},q=function(a,b,c){var d=a.move(c,5),e=n(b,a,c,d,100).getOr(d);return r(a,
e,b).fold(function(){return b.situsFromPoint(e.left(),a.point(e))},function(c){b.scrollBy(0,c);return b.situsFromPoint(e.left(),a.point(e)-c)})};return{tryUp:c.curry(q,{point:d.getTop,adjuster:function(a,b,c,e,f){var g=d.moveUp(f,5);return 1>k.abs(c.top()-e.top())?m.retry(g):c.bottom()<f.top()?m.retry(g):c.bottom()===f.top()?m.retry(d.moveUp(f,1)):p(a,b,f)?m.retry(d.translate(g,5,0)):m.none()},move:d.moveUp,gather:b.before}),tryDown:c.curry(q,g),ieTryUp:function(a,b){return a.situsFromPoint(b.left(),
b.top()-5)},ieTryDown:function(a,b){return a.situsFromPoint(b.left(),b.bottom()+5)},getJumpSize:c.constant(5)}});l("ww",["87","gf","4q","1b","32"],function(d,e,c,a,b){var f=c.generate([{none:["message"]},{success:[]},{failedUp:["cell"]},{failedDown:["cell"]}]),g=function(a){return b.closest(a,"tr")};return{verify:function(c,k,m,p,n,r,q){return b.closest(p,"td,th",q).bind(function(m){return b.closest(k,"td,th",q).map(function(b){return a.eq(m,b)?a.eq(p,m)&&d.getEnd(m)===n?r(b):f.none("in same cell"):
e.sharedOne(g,[m,b]).fold(function(){var a=c.getRect(b),d=c.getRect(m);return d.right>a.left&&d.left<a.right?f.success():r(b)},function(a){return r(b)})})}).getOr(f.none("default"))},cata:function(a,b,c,d,e){return a.fold(b,c,d,e)},adt:f}});l("13u","b 7 s 2v 1b 4l 4h 32 2b".split(" "),function(d,e,c,a,b,f,g,h,k){var m=a.immutable("ancestor","descendants","element","index"),p=a.immutable("parent","children","element","index"),n=function(a,f){var g=d.findIndex(a,e.curry(b.eq,f));return-1<g?c.some(g):
c.none()};return{childOf:function(a,c){return f.closest(a,function(a){return k.parent(a).exists(function(a){return b.eq(a,c)})})},indexOf:n,indexInParent:function(a){return k.parent(a).bind(function(b){var c=k.children(b);return n(c,a).map(function(d){return p(b,c,a,d)})})},selectorsInParent:function(a,b){return k.parent(a).bind(function(c){var d=g.children(c,b);return n(d,a).map(function(b){return p(c,d,a,b)})})},descendantsInAncestor:function(a,b,c){return h.closest(a,b).bind(function(b){var d=
g.descendants(b,c);return n(d,a).map(function(c){return m(b,d,a,c)})})}}});l("111","ww es 9o 87 s f9 13u 21 az 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=function(a){return"br"===h.name(a)},n=function(a,c,d){return c(a,d).bind(function(a){return h.isText(a)&&0===k.get(a).trim().length?n(a,c,d):b.some(a)})},r=function(a,b,c){return c.traverse(b).orThunk(function(){return n(b,c.gather,a)}).map(c.relative)},q=function(a,b){return m.child(a,b).filter(p).orThunk(function(){return m.child(a,b-1).filter(p)})},
t=function(a,b,d,e){return q(b,d).bind(function(b){return e.traverse(b).fold(function(){return n(b,e.gather,a).map(e.relative)},function(a){return g.indexInParent(a).map(function(a){return c.on(a.parent(),a.index())})})})};return{tryBr:function(a,b,c,d){return(p(b)?r(a,b,d):t(a,b,c,d)).map(function(a){return e.write(a,a)})},process:function(c){return d.cata(c,function(a){return b.none("BR ADT: none")},function(){return b.none()},function(a){return b.some(f.point(a,0))},function(c){return b.some(f.point(c,
a.getEnd(c)))})}}});l("wu","10z 110 wv ww 111 c 87 s f9 1b 21".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=f.detect(),r=function(c,d,e){return c.getSelection().bind(function(f){return b.tryBr(d,f.finish(),f.foffset(),e).fold(function(){return h.some(k.point(f.finish(),f.foffset()))},function(g){g=c.fromSitus(g);g=a.verify(c,f.finish(),f.foffset(),g.finish(),g.foffset(),e.failure,d);return b.process(g)})})},q=function(b,c,e,f,k,p){return 0===p?h.none():u(b,c,e,f,k).bind(function(n){var r=b.fromSitus(n),
r=a.verify(b,e,f,r.finish(),r.foffset(),k.failure,c);return a.cata(r,function(){return h.none()},function(){return h.some(n)},function(a){return m.eq(e,a)&&0===f?t(b,e,f,d.moveUp,k):q(b,c,a,0,k,p-1)},function(a){return m.eq(e,a)&&f===g.getEnd(a)?t(b,e,f,d.moveDown,k):q(b,c,a,g.getEnd(a),k,p-1)})})},t=function(a,b,d,f,g){return e.getBoxAt(a,b,d).bind(function(b){return l(a,g,f(b,c.getJumpSize()))})},l=function(a,b,c){return n.browser.isChrome()||n.browser.isSafari()||n.browser.isFirefox()||n.browser.isSpartan()?
b.otherRetry(a,c):n.browser.isIE()?b.ieRetry(a,c):h.none()},u=function(a,b,c,d,f){return e.getBoxAt(a,c,d).bind(function(b){return l(a,f,b)})};return{handle:function(a,b,c){return r(a,b,c).bind(function(d){return q(a,b,d.element(),d.offset(),c,20).map(a.fromSitus)})}}});l("op","om oo wu c es 9o 7 s 1b 38 32 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var r=a.detect(),q=function(a,b){return m.ancestor(a,function(a){return n.parent(a).exists(function(a){return k.eq(a,b)})})},t=function(a,b,d,e,
f){return p.closest(e,"td,th",b).bind(function(e){return p.closest(e,"table",b).bind(function(k){return q(f,k)?c.handle(a,b,d).bind(function(a){return p.closest(a.finish(),"td,th",b).map(function(b){return{start:g.constant(e),finish:g.constant(b),range:g.constant(a)}})}):h.none()})})};return{navigate:function(a,c,e,g,k){return r.browser.isIE()?h.none():t(a,c,e,g,k).map(function(a){a=a.range();return d.response(h.some(b.write(f.on(a.start(),a.soffset()),f.on(a.finish(),a.foffset()))),!0)})},select:function(a,
b,c,d,f,g){return t(a,c,d,f,g).bind(function(a){return e.detect(b,c,a.start(),a.finish())})}}});l("oq",["os","7","s","1b","32"],function(d,e,c,a,b){var f=function(a,c){return b.closest(a,"td,th",c)};return function(b,e,k){var m=c.none(),p=function(){m=c.none()};return{mousedown:function(a){d.clear(e);m=f(a.target(),k)},mouseover:function(c){m.each(function(m){d.clear(e);f(c.target(),k).each(function(c){var f=d.identify(m,c,k).getOr([]);if(1<f.length||1===f.length&&!a.eq(m,c))d.selectRange(e,f,m,c),
b.selectContents(c)})})},mouseup:function(){m.each(p)}}}});l("or",["wv","ww","9o","jg","2b"],function(d,e,c,a,b){return{down:{traverse:b.nextSibling,gather:a.after,relative:c.before,otherRetry:d.tryDown,ieRetry:d.ieTryDown,failure:e.adt.failedDown},up:{traverse:b.prevSibling,gather:a.before,relative:c.before,otherRetry:d.tryUp,ieRetry:d.ieTryUp,failure:e.adt.failedUp}}});l("ga","om gb on oo op oq or os 9o 7 s k 2v".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){var q=r.immutable("rows","cols");return{mouse:function(a,
b,d){a=c(a);b=f(a,b,d);return{mousedown:b.mousedown,mouseover:b.mouseover,mouseup:b.mouseup}},keyboard:function(f,r,l){var v=c(f),w=function(){h.clear(r);return p.none()};return{keydown:function(c,f,t,A,D,B){var C=c.raw().which,F=!0===c.raw().shiftKey;return h.retrieve(r).fold(function(){return e.isDown(C)&&F?m.curry(b.select,v,r,l,g.down,A,f):e.isUp(C)&&F?m.curry(b.select,v,r,l,g.up,A,f):e.isDown(C)?m.curry(b.navigate,v,l,g.down,A,f):e.isUp(C)?m.curry(b.navigate,v,l,g.up,A,f):p.none},function(b){var c=
function(c){return function(){return n.findMap(c,function(c){return a.update(c.rows(),c.cols(),r,b)}).fold(function(){return h.getEdges(r).map(function(a){var b=e.isDown(C)||B.isForward(C)?k.after:k.before;v.setRelativeSelection(k.on(a.first(),0),b(a.table()));h.clear(r);return d.response(p.none(),!0)})},function(a){return p.some(d.response(p.none(),!0))})}};return e.isDown(C)&&F?c([q(1,0)]):e.isUp(C)&&F?c([q(-1,0)]):B.isBackward(C)&&F?c([q(0,-1),q(-1,0)]):B.isForward(C)&&F?c([q(0,1),q(1,0)]):e.isNavigation(C)&&
!1===F?w:p.none})()},keyup:function(b,c,d,f,g){return h.retrieve(r).fold(function(){var h=b.raw().which;return!0===b.raw().shiftKey===!1?p.none():e.isNavigation(h)?a.sync(r,l,c,d,f,g):p.none()},p.none)}}}}});l("gc",["os","ot"],function(d,e){return{retrieve:function(c){return d.retrieve(c)},retrieveBox:function(c){return d.getEdges(c).bind(function(a){return e.getBox(a.table(),a.first(),a.last())})},clear:function(c){d.clear(c)}}});l("gd",["b","iz","4e","6s"],function(d,e,c,a){return{configure:function(b){d.each([b.output(),
b.internal()],function(c){var g=[e.lastSelectedClass(),e.firstSelectedClass(),e.selectedClass()],h=d.map(g,function(a){return"."+a}).join(",");b.addSelector(c,h,function(b){d.each(b,a.removeClasses(g))})})}}});l("ge","jt 87 je s f9 ft jg fg ov 1b dy 21 4l az 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,l){return function(s){var u=function(a){return!s.isRoot(a)&&(k.isBlock(a)||"li"===n.name(a))},v=function(a){return n.isText(a)&&0===q.get(a).trim().length},w=function(a,c,d,e){return r.closest(a,
function(a){return l.parent(a).exists(s.isRoot)},s.isRoot).fold(function(){return b.point(a,c)},function(f){return d(f,a,c)?e(f):b.point(a,c)})},y=function(a,d){var f=function(c){return g.before(c,s.isRoot).fold(function(){return b.point(a,d)},function(a){return v(a)?f(a):b.point(a,e.getEnd(a))})};return r.closest(a,function(a){return u(a)&&l.prevSibling(a).isSome()},s.isRoot).fold(function(){return w(a,d,c.isAtLeftEdge,f)},function(e){return u(a)||c.isAtLeftEdge(e,a,d)?f(e):b.point(a,d)})},x=function(a,
d){var e=function(c){return g.after(c,s.isRoot).fold(function(){return b.point(a,d)},function(a){return v(a)?e(a):b.point(a,0)})};return r.closest(a,function(a){return u(a)&&l.nextSibling(a).isSome()},s.isRoot).fold(function(){return w(a,d,c.isAtRightEdge,e)},function(f){return u(a)||c.isAtRightEdge(f,a,d)?e(f):b.point(a,d)})};return{getSelection:function(c){return c.getSelection().bind(function(c){var g;g=c.startContainer();var k=c.endContainer();m.eq(g,k)?(k=l.child(g,c.startOffset()),g=l.child(g,
c.endOffset()),g=k.filter(h.isList).isSome()||g.filter(h.isList).isSome()):g=!0;if(g){if(p.after(c.startContainer(),c.startOffset(),c.endContainer(),c.endOffset()))return g=f.toLeaf(c.startContainer(),c.startOffset()),c=f.toLeaf(c.endContainer(),c.endOffset()),g=e.isStart(g.element(),g.offset())?y(g.element(),g.offset()):b.point(g.element(),g.offset()),c=e.isEnd(c.element(),c.offset())?x(c.element(),c.offset()):b.point(c.element(),c.offset()),a.some(d(g.element(),g.offset(),c.element(),c.offset()));
g=f.toLeaf(c.startContainer(),c.startOffset());c=f.toLeaf(c.endContainer(),c.endOffset());g=e.isEnd(g.element(),g.offset())?x(g.element(),g.offset()):b.point(g.element(),g.offset());c=e.isStart(c.element(),c.offset())?y(c.element(),c.offset()):b.point(c.element(),c.offset());return a.some(d(g.element(),g.offset(),c.element(),c.offset()))}return a.some(c)})}}}});l("gi",["51"],function(d){var e=function(a){return 0===a.button},c=function(a,b){return{bind:function(c,e){return d.bind(c,a,b,e)}}};return{realClick:c("click",
function(a){return 6===a.mozInputSource||0===a.mozInputSource?!1:void 0!==a.isTrusted&&!0!==a.isTrusted?!1:!0}),leftDown:c("mousedown",e),leftPressedOver:c("mouseover",function(a){return void 0===a.buttons?!0:0!==(a.buttons&1)}),leftUp:c("mouseup",e)}});l("8r","b ga gb gc c 87 7 s 7l gd ge 59 4a gf 4p bl 3y gi 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,l,s,u,v,w){var y=b.detect();return function(b,z,A){m.configure(z);var D=p(A),B=r.create({beforeScan:n([]),afterScan:n([])});z=function(){A.body().each(function(b){A.getSelection().each(function(c){q.sharedOne(s.table,
[c.startContainer(),c.endContainer()]).fold(function(){a.clear(b)},g.noop)})})};(y.browser.isChrome()||y.browser.isSafari())&&A.events.contextmenu.bind(z);A.events.nodeChanged.bind(z);var C=l([]);A.runOrOnLoaded(function(a){var d=w.defaultView(a).dom(),f=e.mouse(d,a,A.isRoot),h=e.keyboard(d,a,A.isRoot);C.set([v.leftDown.bind(a,f.mousedown),v.leftPressedOver.bind(a,f.mouseover),v.leftUp.bind(a,f.mouseup),u.bind(a,"keyup",function(a){a.raw().shiftKey&&c.isNavigation(a.raw().which)&&A.getSelection().each(function(b){h.keyup(a,
b.startContainer(),b.startOffset(),b.endContainer(),b.endOffset()).each(function(b){k(a,b)})},g.noop)}),u.bind(a,"keydown",function(a){A.getSelection().each(function(d){B.trigger.beforeScan();var e=b.directionAt(d.endContainer()).isRtl()?c.rtl:c.ltr;h.keydown(a,d.startContainer(),d.startOffset(),d.endContainer(),d.endOffset(),e).each(function(b){k(a,b)});B.trigger.afterScan()})})]);var k=function(a,b){b.kill()&&a.kill();b.selection().each(function(a){A.setRelativeSelection(a.start(),a.finish())})}});
var F=function(a){return{win:a.win,doc:a.doc,execCommand:a.execCommand,getSelection:function(){return D.getSelection(a)},setSelection:a.setSelection,setRelativeSelection:a.setRelativeSelection,focus:a.focus}},E=function(a,b){return{doc:b.doc,win:b.win,execCommand:b.execCommand,focus:b.focus,setSelection:g.noop,setRelativeSelection:g.noop,getSelection:function(){return h.some(G(a))}}},G=function(a){return{startContainer:g.constant(a),startOffset:g.constant(0),endContainer:g.constant(a),endOffset:g.constant(f.getEnd(a))}};
return{get:function(){return A.on(function(b){return A.body().fold(k.none,function(c){return a.retrieve(c).fold(function(){return A.getSelection().fold(k.none,function(a){return k.single(a,F(b))})},function(a){var c=d.map(a,function(a){return E(a,b)});return k.multiple(a,c)})})}).getOrThunk(k.none)},surround:G,events:B.registry,destroy:function(){var a=C.get();d.each(a,function(a){a.unbind()})}}}});l("gj","b 6 oc 7 3y l".split(" "),function(d,e,c,a,b,f){return function(g){g=e.merge({scopes:[f.fromDom(document)],
shortcuts:[],swallow:!1},g);var h=c(g),k=[],m=[];d.each(g.scopes,function(a){k.push(b.bind(a,"keydown",h.keydown).unbind);m.push(b.bind(a,"keypress",h.keypress).unbind)});return{off:h.off,on:h.on,destroy:function(){d.each(k,a.apply);d.each(m,a.apply)},events:h.events,swallowShortcuts:h.swallowShortcuts,yieldShortcuts:h.yieldShortcuts,swallowChars:h.swallowChars,yieldChars:h.yieldChars,swallowKeys:h.swallowKeys,yieldKeys:h.yieldKeys}}});l("8s","b c gj an 7 s k 59 4a 2v".split(" "),function(d,e,c,a,
b,f,g,h,k,m){var p=function(b){var c=e.detect(),d=c.os.isOSX(),f=c.os.isLinux(),g=d?a.META():a.CTRL(),c=[[g,"Z"]],h=d?[[a.META(),a.SHIFT(),"Z"]]:f?[[a.CTRL(),"Y"],[a.CTRL(),a.SHIFT(),"Z"]]:[[a.CTRL(),"Y"]],k=[[a.SHIFT(),121]],p=d?[[a.ALT(),121]]:[[121]],n=[[g,a.SHIFT(),"F"]],f=d?[[a.META(),a.ALT(),"U"]]:f?[[a.CTRL(),a.ALT(),"U"]]:[[a.CTRL(),a.SHIFT(),"U"]],d=d?[[a.CTRL(),a.ALT(),"H"]]:[[a.CTRL(),a.SHIFT(),"H"]],l=[[g,"B"]],A=[[g,"I"]],D=[[g,"U"]],B=[[g,221],[g,"M"]],C=[[g,219],[g,a.SHIFT(),"M"]],
F=[[g,a.SHIFT(),"9"]],E=[[g,"K"]],g=[[g,"F"]],G=m.immutable("keys","trigger");return{undo:G(c,b.trigger.undo),redo:G(h,b.trigger.redo),context:G(k,b.trigger.context),toolbar:G(p,b.trigger.toolbar),bold:G(l,b.trigger.bold),italic:G(A,b.trigger.italic),underline:G(D,b.trigger.underline),indent:G(B,b.trigger.indent),outdent:G(C,b.trigger.outdent),link:G(E,b.trigger.link),search:G(g,b.trigger.search),blockquote:G(F,b.trigger.blockquote),help:G(d,b.trigger.help),fullscreen:G(n,b.trigger.fullscreen),plaincode:G(f,
b.trigger.plaincode)}},n=function(a,b){return function(c){return d.contains(a,c)?f.some(b):f.none()}};return function(a,e){var m=k.create({undo:h([]),redo:h([]),context:h([]),toolbar:h([]),plaincode:h([]),bold:h([]),italic:h([]),underline:h([]),indent:h([]),outdent:h([]),link:h([]),blockquote:h([]),search:h([]),help:h([]),fullscreen:h([])}),l=p(m),u=[l.undo,l.redo,l.context,l.toolbar],v=[l.plaincode,l.bold,l.italic,l.underline,l.indent,l.outdent,l.link,l.search,l.blockquote,l.help,l.fullscreen],u=
(l=!0===e.features)?u.concat(v):u,w=d.bind(u,function(a){return a.keys()}),y=d.map(u,function(a){return n(a.keys(),a.trigger())}),x=f.none();a.onCanvas(function(a){a=c({scopes:[a],shortcuts:w});x=f.some(a);a.swallowShortcuts(w);a.events.command.bind(function(a){var c=a.command();g.findMap(y,function(a){return a(c)}).each(b.apply)});a.on()});return{isHelpShortcutEnabled:b.constant(l),events:m.registry,destroy:function(){x.each(function(a){a.destroy()})}}}});l("ow",["b","s","2v"],function(d,e,c){var a=
function(a){return function(b){return b.key()===a}},b=c.immutable("key","value");return{put:function(c,e,h,k,m){var p=void 0!==k?k:b,n=void 0!==m?m:a(e);c=d.foldl(c,function(a,b){var c=n(b)?p(e,h):b;return{updated:n(b)||a.updated,acc:a.acc.concat([c])}},{updated:!1,acc:[]});return c.updated?c.acc:c.acc.concat([p(e,h)])},get:function(b,c,h){c=void 0!==h?h:a(c);b=d.find(b,c);return e.from(b)}}});l("ox",["2v"],function(d){return d.immutable("popup","anchor")});l("gk",["b","ow","ox","b0"],function(d,
e,c,a){return function(){var b=[],f=function(){b=d.filter(b,function(b){return a.isVisible(b.popup().panel())})};return{recalculate:function(){f();d.map(b,function(a){a.anchor().recalculate(a.popup())})},dismiss:function(){f();d.map(b,function(a){a.anchor().isAnchored()||a.popup().close()})},update:function(a,d){b=e.put(b,a,d,c,function(b){return b.popup()===a})},destroy:function(){}}}});l("gl",["7","3y","2a"],function(d,e,c){return{bind:function(a,b){var d=c.get(a);return{unbind:e.bind(a,"scroll",
function(e){e=c.get(a);e.top()===d.top()&&e.left()===d.left()||b(e);d=e}).unbind}}}});l("8t","b an 53 7 r gk 34 1y 3y 2p gl 32 m 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q){return function(l,s,u){var v=f(),w=l.isInline()?a.noop:b.cached(function(){y=p.bind(l.doc().getOrDie(),function(a){v.dismiss();l.focus()})}),y=null,x=c.div();h.add(x,g.resolve("ui-container"));u.updateUi(x);l.events.ready.bind(function(){var a=l.placeholder(),a=n.ancestor(a,"."+g.resolve("socket")).bind(q.parent).getOr(a);
m.prepend(a,x)});var z=k.bind(x,"keydown",function(b){var c;if(c=d.contains(e.BACKSPACE(),b.raw().which))c=b.target(),c=a.curry(r.is,c),c=!d.exists(["textarea","input",'[contenteditable="true"]'],c);c&&b.kill()});return{uiContainer:a.constant(x),refresh:v.recalculate,bounds:s,show:function(a,b){w();v.update(a,b);b.place(a)},destroy:function(){null!==y&&y.unbind();v.destroy();z.unbind()}}}});l("gm","7 kd 59 4a 6e 3x".split(" "),function(d,e,c,a,b,f){return function(g,h,k){g=e(k,g);k=function(){var a=
f(function(){b(a);m.trigger.expired()},h);return{clear:function(){b(a)}}};var m=a.create({expired:c([]),close:c([])}),p=0<h?k():{clear:d.noop};g.events.close.bind(function(){p.clear();m.trigger.close()});return{element:g.element,action:g.action,destroy:g.destroy,events:m.registry}}});l("8u","7 gm 7z 34 1y 3y 6u".split(" "),function(d,e,c,a,b,f,g){return function(h,k,m,p,n,r,q,l){var s=q.layout.build(h,k,m,p,n,r,q,l),u=f.bind(s.element(),"mousedown",function(a){g.closest(a.target(),'input,div[contenteditable="true"],textarea,.ephox-polish-dialog.ephox-polish-help-modal,select,.ephox-polish-bottom-bar,.ephox-polish-side-bar')||
a.prevent()});(function(){var e=b.toggler(s.element(),a.resolve("content-ltr")),f=b.toggler(s.element(),a.resolve("content-rtl")),g=function(){var a=r.uiDirection().isRtl(),b=a?f.on:f.off;(a?e.off:e.on)();b()};h.events.uiStale.bind(function(){c.readDir(h).fold(g,function(a){a.ltrdir().fold(e.off,d.noop,e.on);a.rtldir().fold(f.off,d.noop,f.on);e.isOn()===f.isOn()&&g()})})})();return{element:s.element,connect:s.connect,viewport:s.viewport,socket:s.socket,showMessage:function(a,b,c){a=e(a,b,c);b=d.curry(s.hideBanner,
a);a.events.expired.bind(b);s.displayBanner(a);return b},displayBanner:s.displayBanner,hideBanner:s.hideBanner,init:s.init,refocus:s.tabstrip.refocus,tabstrip:s.tabstrip,refresh:s.refresh,position:s.position,state:s.state,destroy:function(){s.destroy();u.unbind()}}}});l("gn",[],function(){return{isDefaultEmpty:function(d){return/^\s*<p>\s*<br\s?\/?>\s*<\/p>\s*$/.test(d)}}});l("wx",["s"],function(d){return function(e){var c=void 0!==e?e.slice(0):[];return{pop:function(){return d.from(c.pop())},push:function(a){c.push(a)},
peek:function(){return d.from(c[c.length-1])},pushAll:function(a){c=c.concat(a)},clear:function(){c=[]},isEmpty:function(){return 0===c.length},size:function(){return c.length},state:function(){return c.slice(0)}}}});l("oy",["b","wx","59","4a"],function(d,e,c,a){return function(b){var f=a.create({changed:c([])}),g=b.initial,h=e(b.undo),k=e(b.redo),m=function(a){h.isEmpty()&&h.push(g);h.push(a);f.trigger.changed()},p=function(a,b){b(h.peek().getOr(g),a)?(h.pop(),h.push(a)):(m(a),k.clear())};return{save:p,
checkChanged:function(a,b){return!b(h.peek().getOr(g),a)},undo:function(a,b){p(a,b);return h.pop().bind(function(a){h.isEmpty()||(k.push(a),f.trigger.changed());return h.peek()})},redo:function(a,b){b(h.peek().getOr(g),a)||k.clear();return k.pop().bind(function(a){m(a);return h.peek()})},reset:function(a){g=a;h.clear();k.clear()},state:function(){return{initial:g,undo:h.state(),redo:k.state()}},rewrite:function(a){var b=a(g),c=d.map(h.state(),a);a=d.map(k.state(),a);g=b;h=e(c);k=e(a)},events:f.registry}}});
l("go",["oy"],function(d){return{fromInitial:function(e){return d({initial:e,undo:[],redo:[]})},fromState:function(e){return d(e)}}});l("8v","b 7 br 7b gn 71 7c 59 4a 4b 2v 2n go".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){var q=p.immutable("raw","marked"),l=function(a){return q(a.raw,a.marked)},s=function(a,b){return{initial:b(a.initial),undo:d.map(a.undo,b),redo:d.map(a.redo,b)}},u=function(a){return{raw:a.raw(),marked:a.marked()}};return function(d,p,y,x,z){var A=r.fromState(s(z,l)),D=k.create({changed:m([],
A.events.changed),undo:h([]),redo:h([])}),B=function(a,c){var e;if(!(e=""===a.raw()&&b.isDefaultEmpty(c.raw()))){e=d.filterHtml(d.internal(),a.raw());var f=d.filterHtml(d.internal(),c.raw());e=e===f}return e},C=function(){var a=d.filterHtml(d.history(),p.getContent()),b=d.filterHtml(d.history(),p.serialize());return q(a,b)},F=function(a){return p.deserialize(a.marked())};z=function(){var a=C();A.undo(a,B).each(F);p.domChanged();p.toEditing();D.trigger.undo()};var E=function(){var a=C();A.redo(a,B).each(F);
p.domChanged();p.toEditing();D.trigger.redo()},G=c.tap(function(a,b){if(a()){var c=C();A.save(c,b)}}),H=function(){G.instance(function(){return p.getSelectionStart().exists(n.inBody)},B)},I=function(a){var b=G.control.isBlocked();G.control.block();a=a();b||G.control.unblock();return a};y.editor().events.space.bind(H);y.editor().events.enter.bind(H);x.events.undo.bind(z);x.events.redo.bind(E);p.events.undoChanged.bind(H);p.events.loiter.bind(H);y=f.ui({"undo.general":{toggle:!1,value:"undo",textkey:a.key("action.undo"),
action:z,shortcut:!0,updateGeneral:e.identity,tooltip:g.get},"redo.general":{toggle:!1,value:"redo",textkey:a.key("action.redo"),action:E,shortcut:!0,updateGeneral:e.identity,tooltip:g.get}});return{undo:z,redo:E,save:H,checkChanged:function(){var a=C();return A.checkChanged(a,B)},reset:function(a){A.reset(q(a,a))},destroy:e.noop,state:function(){return s(A.state(),u)},rewrite:function(a,b){var c=function(c){return c.replace(a,b)};A.rewrite(function(a){return q(c(a.raw()),c(a.marked()))})},transaction:function(a){H();
a=I(a);H();return a},disable:I,replaceTop:function(){G.instance(e.constant(!0),e.constant(!0))},ui:y,events:D.registry}}});l("ae",["4q"],function(d){d=d.generate([{aboveView:["item"]},{inView:["item"]},{belowView:["item"]}]);return{aboveView:d.aboveView,inView:d.inView,belowView:d.belowView,cata:function(d,c,a,b){return d.fold(c,a,b)}}});l("8w","b 79 59 4a ae 3y 21 2b 6e 3x".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=function(a,b){var c=null;return{throttle:function(){var d=arguments;null!==c&&
k(c);c=m(function(){a.apply(null,d);d=c=null},b)},destroy:function(){null!==c&&(k(c),c=null)}}};return function(k){var m=e.unbindable(),q=a.create({onChange:c([])}),l=p(function(){q.trigger.onChange()},1E3),s=function(){k.runOrOnLoaded(function(a){k.doc().each(function(a){m.set(f.bind(a,"scroll",function(a){l.throttle()}));l.throttle()})})};k.isInline()||s();var u=function(){return k.body().bind(function(a){return k.win().map(function(b){var c=b.innerHeight;b=h.children(a);var e=d.findIndex(b,function(a){if(!g.isElement(a))return!1;
a=a.dom().getBoundingClientRect();return a.top<c&&0<a.bottom});if(-1===e)return[a];var f=d.findIndex(b.slice(e+1),function(a){if(!g.isElement(a))return!1;a=a.dom().getBoundingClientRect();return!(a.top<c&&0<a.bottom)});return b.slice(e,-1<f?e+1+f:b.length)})}).getOr([])};return{sections:function(){return u()},setOn:s,setOff:function(){m.clear()},viewport:function(){return{assess:function(a){if(!g.isElement(a))return b.inView(a);var c=k.win().map(function(a){return a.innerHeight}).getOr(0),d=a.dom().getBoundingClientRect();
c=0>d.bottom?b.aboveView:d.top>c?b.belowView:b.inView;return c(a)}}},destroy:function(){m.clear();l.destroy()},events:q.registry}}});l("5j","b 8b c 7 s 8c 8d 6b 8e 8f 8g 8h 8i 8j 8k 6w 8l 8m 8n 8o 8p 8q 8r 8s 8t 8u 8v 8w 58 7b 3y 32 o".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,l,s,u,v,w,y,x,z,A,D,B,C,F,E,G,H,I,K,J){return function(I,N,M){var O=h(I),S=y(M.profile),P=n(M.filters),T=q(),Q=k(P,T,I.content,N,M.content),V=A(N,P,Q),W=D(Q,I.shortcuts),$=I.ui.layout.bounds(I.ui),X=B(Q,$,N),Y=!1!==I.fullscreen.bundled?
r(Q,W,I.fullscreen):G.fullscreen(),da=w(Q,X,N,Y,I.platform),R=C(Q,W,X,da,Y,N,I.ui,M.ui),ca=l(Q,R),ea=F(P,Q,ca,W,M.undo),fa=x(Q,ca,ea),ga=u(P,Q),ia=p(Q,ea,I.editorcontext),ha=E(Q),Z=z(R,I.registration),aa=m(N,Q,ca,W,X,I.contextmenu),ja=v.onNodeChange(Q,ga),ba=s(M.laundry);ea.events.changed.bind(function(){ba.setDirty(!0)});ba.events.clean.bind(function(){Q.undoChanged()});Q.events.interaction.bind(function(a){!ba.isDirty()&&ea.checkChanged()&&ba.setDirty(!0)});var U=c.detect(),ka=U.deviceType.isTouch(),
$=W.isHelpShortcutEnabled();M=!Q.isInline()&&!ka&&I.ui.showHelpHint;I=g.editor(I.ui.editorName,I.ui.isFullScreen);var U=H.translate(U.os.isOSX()?"aria.help.mac":"aria.help.ctrl"),$=$?b.some(U):b.none(),pa=(Q.isInline()?e.inline:e.editor)(R.element(),Q.element(),I,$,M),ma=b.none();Q.runOrOnLoaded(function(a){var c=f.handle(a,function(a){K.closest(a.target(),"a").each(function(b){K.closest(b,'[contenteditable="false"]').each(a.kill)})});ma=b.some(c);ka&&(e.label(a,H.translate("aria.label.content")),
e.region(R.viewport()),e.region(R.tabstrip.element()))});return{region:a.constant(N),communication:a.constant(O),profile:a.constant(S),filter:a.constant(P),internalevents:a.constant(T),content:a.constant(Q),keyboard:a.constant(ca),shortcuts:a.constant(W),smartview:a.constant(X),undo:a.constant(ea),proximity:a.constant(fa),operations:a.constant(ga),context:a.constant(ia),fullscreen:a.constant(Y),platform:a.constant(da),registration:a.constant(Z),contextmenu:a.constant(aa),ui:a.constant(R),selections:a.constant(V),
insertFilteredHtmlAtCursor:function(a){a=P.filterHtml(P.input(),a);Q.insertHtmlAtCursor(a)},viewablearea:a.constant(ha),laundry:a.constant(ba),state:function(){return{ui:R.state(),undo:ea.state(),content:Q.state(),profile:S.state(),laundry:ba.state()}},destroy:function(){ma.each(function(a){a.unbind()});d.each([Q,ha,ja,aa,Z,da,Y,ia,ga,fa,ea,X,W,ca,V,P,S,O,R],function(a){a.destroy?a.destroy():J.log("Feature missing destroy method: ",a)});pa.destroy()}}}});l("oz",["4j"],function(d){return{resolve:d.create("ephox-hermes").resolve}});
l("gp","oz ey 7 59 4a 1a 1y 3y l 33".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=function(){var p=b.create({upload:a(["files"])}),r=k.fromTag("input");g.add(r,d.resolve("hidden"));g.add(r,d.resolve("file-selector-input"));f.setAll(r,{type:"file",accept:"image/*"});var q=h.bind(r,"change",function(a){a=e.toFiles(a);p.trigger.upload(a)});return{element:c.constant(r),open:function(){m.set(r,"");r.dom().click()},destroy:function(){q.unbind()},events:p.registry}};return{single:p,multiple:function(){var a=
p();f.set(a.element(),"multiple","multiple");return{element:a.element,open:a.open,destroy:a.destroy,events:a.events}}}});l("8x",["gp","ey","59","4a"],function(d,e,c,a){return function(){var b=d.single(),f=a.create({upload:c(["assets"])});b.events.upload.bind(function(a){e.multiple(a.files()).get(function(a){f.trigger.upload(a)})});return{element:b.element,open:b.open,destroy:b.destroy,events:f.registry}}});l("8z",["s","cf","96"],function(d,e,c){return function(a){var b=d.none(),f=function(c){g();
c=e(c);c.events.close.bind(function(){b=d.none()});b=d.some(c);a().displayBanner(c)},g=function(){b.each(a().hideBanner);b=d.none()};return{show:f,showKey:function(a){var b=c.get.apply(void 0,arguments);f(b)},hide:g,reset:function(){b=d.none()}}}});l("90","b gq 83 1a 3y l".split(" "),function(d,e,c,a,b,f){var g=function(c,g){return d.map(g,function(d){var g=f.fromTag("img"),k=b.bind(g,"load",function(){k.unbind();c.domChanged()});d=e.cata(d,function(a,b,c,d){return c},function(a,b,c){return b});a.set(g,
"src",d);return g})};return{insertMobileAssets:function(a,b,d,e){var f=g(a,e);return a.undoOperation(function(){var g=c.insertAt(a,b,f);d.uploadAssets(e);return g})},insertAssets:function(a,b,d){var e=g(a,d);a.focus();a.undoOperation(function(){c.insertAtCursor(a,e).each(function(b){a.setSelection(b.element(),b.offset(),b.element(),b.offset())});b.uploadAssets(d)})}}});l("wy",["4j"],function(d){return{resolve:d.create("ephox-gel").resolve}});l("s8","8b wy 6 59 4a 1y 2o l 2p 2r 32".split(" "),function(d,
e,c,a,b,f,g,h,k,m,p){return function(n,r){var q=c.merge({layerClass:void 0,zindex:void 0,padding:"0px"},n),l=b.create({exiting:a([])}),s=h.fromTag("div");d.presentation(s);f.add(s,e.resolve("modal"));f.add(s,e.resolve("modal-hidden"));g.setAll(s,{position:"fixed",left:q.padding,top:q.padding,right:q.padding,bottom:q.padding});void 0!==q.background&&g.set(s,"background",q.background);void 0!==q.zindex&&g.set(s,"z-index",q.zindex);void 0!==q.layerClass&&f.add(s,q.layerClass);var u=void 0!==r?r:p.first("body").getOrDie();
k.append(u,s);return{element:function(){return s},content:function(a){m.empty(s);k.append(s,a)},show:function(){f.add(u,e.resolve("modal-active"));f.remove(s,e.resolve("modal-hidden"));f.add(s,e.resolve("modal-show"))},hide:function(){f.remove(u,e.resolve("modal-active"));f.add(s,e.resolve("modal-hidden"));f.remove(s,e.resolve("modal-show"))},destroy:function(){m.remove(s);f.remove(u,e.resolve("modal-active"))},events:l.registry}}});l("wz","8b wy 6 10p 7 59 4a 1y 2o 3y l 2p 2r 32 37".split(" "),function(d,
e,c,a,b,f,g,h,k,m,p,n,r,q,l){return function(s,u){var v=a.onChange(),w=g.create({exiting:f([])}),y=c.merge({layerClass:null,zindex:null,padding:"0px",background:"rgba(0, 0, 0, 0.5)"},s),x=p.fromTag("div");d.presentation(x);h.add(x,e.resolve("moodal"));h.add(x,e.resolve("moodal-hidden"));k.setAll(x,{left:y.padding,top:y.padding,right:y.padding,bottom:y.padding});y.background&&k.set(x,"background",y.background);y.zindex&&k.set(x,"z-index",y.zindex);y.layerClass&&h.add(x,y.layerClass);var z=void 0!==
u?u:q.first("body").getOrDie();n.append(z,x);var A=p.fromTag("div");d.presentation(A);h.add(A,e.resolve("moodal-flexor"));n.append(x,A);var D=function(){k.setAll(A,{top:l.scrollY+"px",height:l.innerHeight+"px"})},B=function(){C.unbind();v.destroy();r.remove(x);h.remove(z,e.resolve("modal-active"))},C=m.bind(x,"click",function(){w.trigger.exiting();B()});v.events.ready.bind(function(){D()});return{element:b.constant(x),content:function(a){r.empty(A);n.append(A,a)},show:function(){h.add(z,e.resolve("moodal-active"));
h.remove(x,e.resolve("moodal-hidden"));h.add(x,e.resolve("moodal-show"));D()},hide:function(){h.remove(z,e.resolve("moodal-active"));h.add(x,e.resolve("moodal-hidden"));h.remove(x,e.resolve("moodal-show"))},destroy:B,events:w.registry}}});l("p1","c s8 wz wy 6 4a 4b 1y 2o 2p 2r 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){return function(r){var q=b.deepMerge({layerClass:void 0,zindex:void 0,modal:{}},r);r=void 0!==r.container?r.container:n.first("body").getOrDie();var l=(d.detect().os.isiOS()?
c:e)(q.modal,r),s=l.element(),u=f.create({exiting:g([],l.events.exiting)});void 0!==q.zindex&&k.set(s,"z-index",q.zindex);void 0!==q.layerClass&&h.add(s,q.layerClass);h.add(s,a.resolve("centered-dialog"));m.append(r,s);return{content:l.content,show:function(){l.show()},hide:function(){l.hide()},destroy:function(){p.remove(s);l.destroy()},events:u.registry}}});l("p2","8b 30 c 53 7b 34 59 4a 1a 1y 3y l 2z 2p 3d 2r".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,l,s){var u=c.detect().deviceType.isiOS();
return function(){var c=function(a,b){m.add(a,f.resolve(b));return a},w=c(a.div(),"dialog"),y=c(a.div(),"top"),x=c(a.span(),"dialog-title"),z=c(a.span(),"dialog-close"),A=c(a.div(),"dialog-content"),D=c(a.div(),"dialog-controls");k.set(w,"tabindex",-1);k.set(z,"tabindex",-1);d.button(z,b.translate("button.close"));var B=p.bind(z,"click",function(){C.trigger.close()});l.append(w,[y,A,D]);l.append(y,[x,z]);var C=h.create({close:g([])});return{element:function(){return w},focus:function(){r.focus(w)},
setTitle:function(a){s.empty(x);q.append(x,n.fromText(a));u||(d.dialog(w,a),a=e.generate("ephox-aria"),k.set(x,"id",a),d.labelledBy(w,a))},setContent:function(a){s.empty(A);q.append(A,a);a=e.generate("ephox-aria");k.set(A,"id",a);d.describedBy(w,a)},setControls:function(a){s.empty(D);q.append(D,a)},close:function(){C.trigger.close()},destroy:function(){s.remove(w);B.unbind()},events:C.registry}}});l("gu","c p1 s p2 3q 34 2n 3y".split(" "),function(d,e,c,a,b,f,g,h){var k=d.detect();return function(d){var p=
a(),n=c.none(),r=e({container:d,layerClass:f.resolve("layer-dialog"),modal:{layerClass:f.resolve("layer-below-dialog")}});r.content(p.element());r.events.exiting.bind(function(){b.unlock([g.body()]);p.close()});var q=function(){r.hide();b.unlock([g.body()])};return{element:p.element,destroy:function(){p.destroy();n.each(function(a){a.unbind()});q();r.destroy()},setTitle:p.setTitle,setContent:p.setContent,setControls:p.setControls,show:function(){r.content(p.element());r.show();p.focus();k.deviceType.isTouch()&&
(n=c.some(h.bind(p.element(),"click",function(a){a.stop()})));b.lock([g.body()])},hide:q,events:p.events}}});l("gv","gt 8y 7 s 32 m".split(" "),function(d,e,c,a,b,f){var g=function(b){b.dom().click();return a.some(b)};return{setup:function(a,b,c){b=d.dialog({execute:function(a){a.dom().click()},ok:b.ok().element(),cancel:b.cancel().element()});a=e.dialog(a.element(),c,b);return{enter:a.enter,exit:a.exit,destroy:a.destroy}},button:function(c){return(f.is(c,".ephox-pastry-button")?a.some(c):b.descendant(c,
".ephox-pastry-button")).bind(g)},click:g,radio:function(a,b,f){b={item:c.constant(b),selected:c.constant(f)};return e.radio(a,b,d.radio({one:function(a,b){b.dom().click()}}))}}});l("92","8b c gt gu gv 7b gw 34 59 4a 1y 3y l 3x 37".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,l){return function(s,u,v,w,y,x){var z=g.okCancel("file-upload"),A=w(y),D=null,B=e.detect(),C=m.create({close:k([]),analytics:k(["message"]),escaped:k([]),insertAssets:k(["assets"]),opened:k([])}),F=function(){D.unbind();G.hide();
C.trigger.close();C.trigger.analytics("insert_image_closed");E()},E=function(){A.reset();z.ok().disable()},G=a(v);G.setTitle(f.translate("fileupload.title"));G.setContent(A.element());G.setControls(z.element());G.events.close.bind(F);p.add(G.element(),h.resolve("imageupload-dialog"));var H=x(G.element(),A.keylayouts(),c.dialog({cancel:z.cancel().element(),ok:z.ok().element(),execute:b.click,index:0}));A.events.upload.bind(function(a){C.trigger.insertAssets(a.assets());F()});A.events.dragndrop.bind(function(a){C.trigger.insertAssets(a.assets());
F()});A.events.success.bind(function(a){z.ok().enable()});A.events.lookup.bind(function(a){z.ok().disable()});A.events.setActive.bind(function(a){E()});z.events.ok.bind(function(){A.selected().each(function(a){C.trigger.insertAssets([a]);F()})});z.events.cancel.bind(F);E();return{show:function(){B.deviceType.isiOS()&&(d.hidden(u.element(),!0),q(function(){A.focus();d.hidden(u.element(),!1)},250));G.show();H.enter();C.trigger.analytics("insert_image_opened");C.trigger.opened();var a=r.fromDom(l);D=
n.bind(a,"orientationchange",function(){s.foreground()})},element:G.element,events:C.registry,destroy:function(){H.exit();H.destroy();G.hide();G.destroy();A.destroy();z.destroy()}}}});l("p3","gq oz 7 1a 1y 1s".split(" "),function(d,e,c,a,b,f){return{previewAsset:function(f,h){d.cata(f,c.die("asset should not be a file type"),function(c,d,f){b.add(h,e.resolve("fluid-image"));a.set(h,"src",d)})}}});l("p4","8b 30 c nx oz ey 53 7 aa s 59 4a 1a 1y 3y l 2z 2p 3d 33 ny".split(" "),function(d,e,c,a,b,f,g,
h,k,m,p,n,r,q,l,s,u,v,w,y,x){var z=c.detect();return function(c){var x=n.create({success:p(["assets"]),invalidUrl:p(["url"]),empty:p([]),lookup:p([])}),B=[],C=g.div(),F=q.toggler(C,b.resolve("url-indicator-loading")),E=a();E.events.start.bind(function(){F.on()});E.events.fail.bind(function(a){F.off();x.trigger.invalidUrl(a.url());B=[]});E.events.success.bind(function(a){F.off();var b=y.get(K);a.url()===b?f.fromImages([a.image()]).get(function(a){B=a;x.trigger.success(B)}):E.go(b)});var G=g.div();
q.add(G,b.resolve("url-selector"));var H=s.fromTag("label");c=s.fromText(c("fileupload.web.url"));var I=e.generate(b.resolve("input-id"));r.set(H,"for",I);q.add(H,b.resolve("url-input-label"));v.append(H,c);var K=s.fromTag("input");r.setAll(K,{id:I,type:"url",placeholder:"http://www.example.com/image.jpg"});q.add(K,b.resolve("url-input"));z.os.isAndroid()&&r.set(K,"autofocus","true");d.required(K);c=s.fromHtml("<span role=presentation>*</span>");q.add(c,b.resolve("url-input-required"));v.append(H,
c);w.append(G,[H,K,C]);var J=k(function(a){""!==a&&E.go(a)},1E3),L=l.bind(K,"input",function(){var a=y.get(K);""===a.trim()?(x.trigger.empty(),J.throttle("")):(x.trigger.lookup(),J.throttle(a))});return{element:h.constant(G),input:h.constant(K),events:x.registry,reset:function(){F.off();y.set(K,"")},focus:function(){u.focus(K)},selected:function(){return m.from(B[0])},destroy:function(){L.unbind()}}}});l("gz","b 8b 30 oz p3 p4 53 7 59 4a 1a 1y l 2p 3d 2r ny".split(" "),function(d,e,c,a,b,f,g,h,k,
m,p,n,r,q,l,s,u){return function(u){var w=m.create({lookup:k([]),success:k([])}),y=g.span(),x=r.fromHtml('<div role=presentation><span role=presentation class="'+a.resolve("url-input-required")+'">*</span> '+u("fileupload.weburlhelp")+"</div>"),z=c.generate(a.resolve("help-message"));p.set(x,"id",z);n.add(x,a.resolve("fileupload-weburl-help"));var A=r.fromHtml("<div role=presentation><div role=presentation>"+u("fileupload.invalid1")+"</div><div role=presentation>"+u("fileupload.invalid2")+"</div><div role=presentation>"+
u("fileupload.invalid3")+"</div></div>");n.add(A,a.resolve("fileupload-weburl-help"));n.add(A,a.resolve("fileupload-weburl-help-invalid"));var D=function(a){s.empty(E);q.append(E,a)},B=function(a){var c=r.fromTag("img");q.append(E,c);b.previewAsset(a,c)},C=g.div();n.add(C,a.resolve("web-url-container"));var F=f(u),E=g.div();n.add(E,a.resolve("image-preview-container"));u=c.generate("ephox-hermes-url-state");e.live(E,u,"polite");e.controls(F.input(),u);e.describedBy(F.input(),z);z=g.div();n.add(z,
a.resolve("hbox"));l.append(z,[F.element(),E,x]);q.append(C,z);F.events.lookup.bind(function(a){w.trigger.lookup();s.empty(E)});F.events.success.bind(function(a){d.each(a.assets(),B);w.trigger.success()});F.events.invalidUrl.bind(function(){D(A)});F.events.empty.bind(function(){D(y)});D(y);return{element:h.constant(C),selected:F.selected,input:F.input,events:w.registry,focus:F.focus,reset:function(){D(y);F.reset()},destroy:function(){F.destroy()}}}});l("gx","gz gt 8y 53 7 7b 59 4a 4b 2p".split(" "),
function(d,e,c,a,b,f,g,h,k,m){return function(p){p=a.div();var n=d(f.translate),r=h.create({upload:g(["assets"]),dragndrop:g(["assets"]),dragover:g([]),dragleave:g([]),drop:g([]),setActive:g(["item"]),lookup:k([],n.events.lookup),success:k([],n.events.success)}),q=[function(){var a=n.input();return c.input(a,e.input({}))}()];m.append(p,n.element());return{element:b.constant(p),events:r.registry,keylayouts:b.constant(q),reset:function(){n.reset()},focus:n.focus,selected:n.selected,destroy:function(){n.destroy()}}}});
l("91","ak al b 8b gr 8x 8y 6 gs 7 s 92 gx 7b 7c 59 4a l 3d q".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,l,s,u,v,w,y){return function(x,z,A,D,B){var C=u.create({insertAsset:s(["asset"]),open:s([]),done:s([]),abort:s([])}),F=v.fromDom(y);D=b.mainmenu(F,"file-upload-menu",[]);var E=function(c,d){var e=b.item(F,c,q.get(d)+"...");a.menuItem(e,p.some(q.get(d)),p.none());return e},G=E("from-url",q.key("image.from-url")),E=E("from-camera",q.key("image.from-camera")),G=!0===B.allowLocalImages?[G,E]:
[G],H=f();H.events.upload.bind(function(a){p.from(a.assets()[0]).each(function(a){K();C.trigger.insertAsset(a)})});var I=function(a){a=a.assets();c.each(a,function(a){C.trigger.insertAsset(a)})},K=function(){k.target(A.uiContainer(),"mousedown")};w.append(D,G);D={name:"image",textkey:q.key("image.menu-button"),menuTextkey:q.key("image.menu"),icon:p.none,tooltip:l.get,contentFocus:!1,toggle:!1};G=[[{handlers:m.constant({"from-url":function(a){C.trigger.open();var b=n(x,z,A.uiContainer(),r,B,g.dialog);
b.events.insertAssets.bind(I);a=function(){x.focus();b.destroy()};b.events.opened.bind(K);b.events.close.bind(a);b.events.escaped.bind(a);b.show()},"from-camera":function(){C.trigger.open();H.open()}}),destroyer:m.noop,refreshMenu:m.noop,structure:m.constant({}),submenus:m.constant([]),items:m.constant(G),events:C.registry}]];D=d.menu(D,G,q.get,e.menu({focusActive:!0}));G={label:m.constant(!1),hasDialog:!0};return h.merge(D,G)}});l("x0","ln lo s 1a 1y l".split(" "),function(d,e,c,a,b,f){return function(g){var h=
f.fromTag("button");a.set(h,"type","button");b.add(h,e.resolve("independent-button"));return d(h,c.none(),g)}});l("p5","fh ex gp oz 53 x0 eh 7 s 1y l 2z 2p 3d".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q){return function(l){var s=c.multiple(),u=b.div();m.add(u,a.resolve("drop-container"));var v=e.register(u,k.some(a.resolve("drop-active")),!1),w=f();w.content(g(l("fileupload.chooseimage")));m.add(w.element(),a.resolve("default-action"));m.add(w.element(),a.resolve("file-selector-trigger"));var y=
p.fromTag("p");m.add(y,a.resolve("help-text-drop-icon"));var x=p.fromTag("p");m.add(x,a.resolve("help-text-drop"));d.disable(x);r.append(x,p.fromText(l("fileupload.dropimages")));q.append(u,[y,x,w.element(),s.element()]);return{container:h.constant(u),dropper:h.constant(v),picker:h.constant(s),button:h.constant(w),focus:function(){n.focus(w.element())},destroy:function(){s.destroy();v.destroy();w.destroy()}}}});l("gy","p5 ey 7 59 4a 4b".split(" "),function(d,e,c,a,b,f){return function(g){var h=d(g);
g=h.picker();var k=h.container(),m=h.dropper(),p=h.button(),n=b.create({upload:a(["assets"]),dragndrop:a(["assets"]),dragover:f([],m.events.dragover),dragleave:f([],m.events.dragleave),drop:f([],m.events.drop)}),r=function(a){return function(b){e.multiple(b.files()).get(function(b){a(b)})}};g.events.upload.bind(r(n.trigger.upload));m.events.dragndropimages.bind(r(n.trigger.dragndrop));p.events.click.bind(g.open);return{element:c.constant(k),button:c.constant(p),input:g.element,focus:h.focus,events:n.registry,
destroy:function(){h.destroy()}}}});l("h0","b 53 p6 eh lo 7 59 4a 2v 1a 1y l 2p 3d".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q){return function(l,s,u){var v=[],w=k.immutable("view","item","container"),y=h.create({setActive:g(["item"])}),x=e.div();p.add(x,b.resolve("tablayout-wrapper"));p.add(x,b.resolve("tablayout-wrapper-"+l));void 0!==u&&p.add(x,u);var z=e.div();p.add(z,b.resolve("tablayout-body"));var A=n.fromTag("div");p.add(A,b.resolve("tablayout-menu"));q.append(x,[A,z]);var D=function(d){var e=
c(d);e.content(a(d));p.add(e.element(),b.resolve("tablayout-item"));return e},B=[],C=d.map(s,function(a){var c=D(a.heading());m.set(c.element(),"data-ephox-pastry-tablayout-tab",a.heading());r.append(A,c.element());var d=n.fromTag("div");p.add(d,b.resolve("tablayout-content"));m.set(d,"data-ephox-pastry-tablayout-view",a.heading());r.append(z,d);B.push(d);var e=w(a,c,d);v.push(e);c.events.click.bind(function(){F(e)});return c}),F=function(a){d.each(v,function(c){var d=c.view(),e=c.item(),f=c.container();
c===a?(p.add(f,b.resolve("tablayout-active")),e.select(),d.renderer().render(f),y.trigger.setActive(e)):(p.remove(f,b.resolve("tablayout-active")),e.deselect())})};F(v[0]);return{element:function(){return x},tabs:f.constant(C),body:f.constant(z),menu:f.constant(A),tabContent:f.constant(B),destroy:function(){d.each(C,function(a){a.destroy()})},events:y.registry}}});l("h1",["2p","2r"],function(d,e){return function(c){return{render:function(a){e.empty(a);d.append(a,c)}}}});l("h2",["2v"],function(d){return d.immutable("heading",
"renderer")});l("h3",["7"],function(d){return{left:d.constant("left"),top:d.constant("top")}});l("93","b 8b 30 c gy gz gt 8y 6 53 h0 h1 h2 h3 7 gv 7b 34 4a 4b 1a 1y 2p".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,q,l,s,u,v,w,y,x,z,A){return function(D){var B=m.div(),C=b(u.translate),F=f(u.translate),E=function(a,b){var c=u.translate(a),d=n(b);return r(c,d)},G=E("fileupload.tabweburl",F.element());D=(D.allowLocalImages?[E("fileupload.tablocal",C.element())]:[]).concat(G);var H=p(q.top(),D,"file-upload");
e.hidden(C.input(),!0);E=function(){var b=C.button();z.add(b.element(),v.resolve("dialog-button-default"));var c=a.detect().browser.isFirefox(),d={execute:s.button},c=c?k.merge(d,{process:l.noop}):d,c=g.button(c);return h.button(b.element(),c)}();e.tabList(H.menu());var G=function(){var a=F.input();return h.input(a,g.input({}))}(),I=h.flow(H.menu(),{item:l.constant(".ephox-pastry-statebutton")},g.flow({trigger:s.button,executeOnArrow:!0})),E=[I].concat(E).concat(G),K=H.tabs();d.each(H.tabContent(),
function(a){e.tabPanel(a)});d.each(D,function(a,b){var c=K[b];e.tabButton(c.element(),a.heading());z.add(c.element(),v.resolve("tab-button"));c.events.click.bind(function(){I.clickFocus(c.element())})});d.each(H.tabContent(),function(a,b){var d=K[b],f=c.generate("ephox-aria");x.set(d.element(),"id",f);e.labelledBy(a,f)});D=w.create({upload:y(["assets"],C.events.upload),dragndrop:y(["assets"],C.events.dragndrop),dragover:y([],C.events.dragover),dragleave:y([],C.events.dragleave),drop:y([],C.events.drop),
lookup:y([],F.events.lookup),success:y([],F.events.success),setActive:y(["item"],H.events.setActive)});H.events.setActive.bind(function(a){a=x.get(a.item().element(),"data-ephox-pastry-tablayout-tab");a===u.translate("fileupload.tablocal")?C.focus():a===u.translate("fileupload.tabweburl")&&F.focus()});A.append(B,H.element());return{element:l.constant(B),events:D.registry,focus:F.focus,keylayouts:l.constant(E),reset:function(){F.reset()},selected:F.selected,destroy:function(){H.destroy();C.destroy();
F.destroy()}}}});l("94",["a","b","gq","7"],function(d,e,c,a){var b=["image"],f=function(a,c,f,m){return e.exists(b,function(a){return d.isString(c.type)&&-1<c.type.indexOf(a)})};return{validate:function(b){b=e.foldl(b,function(b,d){return!1===c.cata(d,f,a.constant(!0))?{assets:b.assets,failure:!0}:{assets:b.assets.concat([d]),failure:b.failure}},{assets:[],failure:!1});return{assets:a.constant(b.assets),failure:a.constant(b.failure)}}}});l("h4",["ey"],function(d){return{multiple:function(e){return d.multiple(e)},
single:function(e){return d.single(e)},singleWithUrl:function(e,c){return d.singleWithUrl(e,c)}}});l("x1",[],function(){function d(d,c,a){d.width=c;d.height=a;return d}return{create:function(e,c){return d(document.createElement("canvas"),e,c)},resize:d,get2dContext:function(d){return d.getContext("2d")},get3dContext:function(d){var c=null;try{c=d.getContext("webgl")||d.getContext("experimental-webgl")}catch(a){}c||(c=null);return c}}});l("x2",[],function(){return{getWidth:function(d){return d.naturalWidth||
d.width},getHeight:function(d){return d.naturalHeight||d.height}}});l("x3",[],function(){function d(a,b){return function(){a.apply(b,arguments)}}function e(c){if("object"!==typeof this)throw new TypeError("Promises must be constructed via new");if("function"!==typeof c)throw new TypeError("not a function");this._value=this._state=null;this._deferreds=[];h(c,d(a,this),d(b,this))}function c(a){var b=this;null===this._state?this._deferreds.push(a):k(function(){var c=b._state?a.onFulfilled:a.onRejected;
if(null===c)(b._state?a.resolve:a.reject)(b._value);else{var d;try{d=c(b._value)}catch(e){a.reject(e);return}a.resolve(d)}})}function a(c){try{if(c===this)throw new TypeError("A promise cannot be resolved with itself.");if(c&&("object"===typeof c||"function"===typeof c)){var e=c.then;if("function"===typeof e){h(d(e,c),d(a,this),d(b,this));return}}this._state=!0;this._value=c;f.call(this)}catch(g){b.call(this,g)}}function b(a){this._state=!1;this._value=a;f.call(this)}function f(){for(var a=0,b=this._deferreds.length;a<
b;a++)c.call(this,this._deferreds[a]);this._deferreds=null}function g(a,b,c,d){this.onFulfilled="function"===typeof a?a:null;this.onRejected="function"===typeof b?b:null;this.resolve=c;this.reject=d}function h(a,b,c){var d=!1;try{a(function(a){d||(d=!0,b(a))},function(a){d||(d=!0,c(a))})}catch(e){d||(d=!0,c(e))}}if(window.Promise)return window.Promise;var k=e.immediateFn||"function"===typeof setImmediate&&setImmediate||function(a){setTimeout(a,1)},m=Array.isArray||function(a){return"[object Array]"===
Object.prototype.toString.call(a)};e.prototype["catch"]=function(a){return this.then(null,a)};e.prototype.then=function(a,b){var d=this;return new e(function(e,f){c.call(d,new g(a,b,e,f))})};e.all=function(){var a=Array.prototype.slice.call(1===arguments.length&&m(arguments[0])?arguments[0]:arguments);return new e(function(b,c){function d(f,g){try{if(g&&("object"===typeof g||"function"===typeof g)){var h=g.then;if("function"===typeof h){h.call(g,function(a){d(f,a)},c);return}}a[f]=g;0===--e&&b(a)}catch(k){c(k)}}
if(0===a.length)return b([]);for(var e=a.length,f=0;f<a.length;f++)d(f,a[f])})};e.resolve=function(a){return a&&"object"===typeof a&&a.constructor===e?a:new e(function(b){b(a)})};e.reject=function(a){return new e(function(b,c){c(a)})};e.race=function(a){return new e(function(b,c){for(var d=0,e=a.length;d<e;d++)a[d].then(b,c)})};return e});l("x4",[],function(){return{guessMimeType:function(d){var e=document.createElement("a");e.href=d;d=e.pathname.split(".");(d=d[d.length-1])&&(d=d.toLowerCase());
return{jpg:"image/jpeg",jpeg:"image/jpeg",png:"image/png"}[d]}}});l("py",["x3","x1","x4","x2"],function(d,e,c,a){function b(a){return new d(function(b){function c(){a.removeEventListener("load",c);b(a)}a.complete?b(a):a.addEventListener("load",c)})}function f(c){return b(c).then(function(b){var c;c=e.create(a.getWidth(b),a.getHeight(b));e.get2dContext(c).drawImage(b,0,0);return c})}function g(a){return new d(function(b){var c=new XMLHttpRequest;c.open("GET",a,!0);c.responseType="blob";c.onload=function(){200==
this.status&&b(this.response)};c.send()})}function h(a){return new d(function(b){var c,d,e,f,g;a=a.split(",");(c=/data:([^;]+)/.exec(a[0]))&&(f=c[1]);c=atob(a[1]);if(window.WebKitBlobBuilder){g=new WebKitBlobBuilder;d=new ArrayBuffer(c.length);for(e=0;e<d.length;e++)d[e]=c.charCodeAt(e);g.append(d);b(g.getBlob(f))}else{d=new Uint8Array(c.length);for(e=0;e<d.length;e++)d[e]=c.charCodeAt(e);b(new Blob([d],{type:f}))}})}function k(a){return new d(function(b){var c=new FileReader;c.onloadend=function(){b(c.result)};
c.readAsDataURL(a)})}return{blobToImage:function(a){return new d(function(b){function c(){d.removeEventListener("load",c);b(d)}var d=new Image;d.addEventListener("load",c);d.src=URL.createObjectURL(a);d.complete&&c()})},imageToBlob:function(a){return b(a).then(function(a){var b=a.src;return 0===b.indexOf("blob:")?g(b):0===b.indexOf("data:")?h(b):f(a).then(function(a){return h(a.toDataURL(c.guessMimeType(b)))})})},blobToDataUri:k,blobToBase64:function(a){return k(a).then(function(a){return a.split(",")[1]})},
imageToCanvas:f,canvasToBlob:function(a,b){return h(a.toDataURL(b))},revokeImageUrl:function(a){URL.revokeObjectURL(a.src)},uriToBlob:function(a){return 0===a.indexOf("blob:")?g(a):0===a.indexOf("data:")?h(a):null}}});l("x5",[],function(){function d(a,c,d){a=parseFloat(a);a>d?a=d:a<c&&(a=c);return a}function e(a,c){var d,e,k,m,p=[],n=Array(10);for(d=0;5>d;d++){for(e=0;5>e;e++)p[e]=c[e+5*d];for(e=0;5>e;e++){for(k=m=0;5>k;k++)m+=a[e+5*k]*p[k];n[e+5*d]=m}}return n}function c(a,c){c=d(c,0,1);return a.map(function(a,
b){a=0===b%6?1-(1-a)*c:a*c;return d(a,0,1)})}var a=[0,0.01,0.02,0.04,0.05,0.06,0.07,0.08,0.1,0.11,0.12,0.14,0.15,0.16,0.17,0.18,0.2,0.21,0.22,0.24,0.25,0.27,0.28,0.3,0.32,0.34,0.36,0.38,0.4,0.42,0.44,0.46,0.48,0.5,0.53,0.56,0.59,0.62,0.65,0.68,0.71,0.74,0.77,0.8,0.83,0.86,0.89,0.92,0.95,0.98,1,1.06,1.12,1.18,1.24,1.3,1.36,1.42,1.48,1.54,1.6,1.66,1.72,1.78,1.84,1.9,1.96,2,2.12,2.25,2.37,2.5,2.62,2.75,2.87,3,3.2,3.4,3.6,3.8,4,4.3,4.7,4.9,5,5.5,6,6.5,6.8,7,7.3,7.5,7.8,8,8.4,8.7,9,9.4,9.6,9.8,10];return{identity:function(){return[1,
0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1]},adjust:c,multiply:e,adjustContrast:function(b,c){var g;c=d(c,-1,1);c*=100;0>c?g=127+c/100*127:(g=c%1,g=0===g?a[c]:a[Math.floor(c)]*(1-g)+a[Math.floor(c)+1]*g,g=127*g+127);return e(b,[g/127,0,0,0,0.5*(127-g),0,g/127,0,0,0.5*(127-g),0,0,g/127,0,0.5*(127-g),0,0,0,1,0,0,0,0,0,1])},adjustBrightness:function(a,c){c=d(255*c,-255,255);return e(a,[1,0,0,0,c,0,1,0,0,c,0,0,1,0,c,0,0,0,1,0,0,0,0,0,1])},adjustSaturation:function(a,c){var g;c=d(c,-1,1);g=1+(0<c?
3*c:c);return e(a,[0.3086*(1-g)+g,0.6094*(1-g),0.082*(1-g),0,0,0.3086*(1-g),0.6094*(1-g)+g,0.082*(1-g),0,0,0.3086*(1-g),0.6094*(1-g),0.082*(1-g)+g,0,0,0,0,0,1,0,0,0,0,0,1])},adjustHue:function(a,c){var g,h;c=d(c,-180,180)/180*Math.PI;g=Math.cos(c);h=Math.sin(c);return e(a,[0.213+0.787*g+-0.213*h,0.715+-0.715*g+-0.715*h,0.072+-0.072*g+0.928*h,0,0,0.213+-0.213*g+0.143*h,0.715+g*(1-0.715)+0.14*h,0.072+-0.072*g+-0.283*h,0,0,0.213+-0.213*g+-0.787*h,0.715+-0.715*g+0.715*h,0.072+0.928*g+0.072*h,0,0,0,0,
0,1,0,0,0,0,0,1])},adjustColors:function(a,c,g,h){c=d(c,0,2);g=d(g,0,2);h=d(h,0,2);return e(a,[c,0,0,0,0,0,g,0,0,0,0,0,h,0,0,0,0,0,1,0,0,0,0,0,1])},adjustSepia:function(a,f){f=d(f,0,1);return e(a,c([0.393,0.769,0.189,0,0,0.349,0.686,0.168,0,0,0.272,0.534,0.131,0,0,0,0,0,1,0,0,0,0,0,1],f))},adjustGrayscale:function(a,f){f=d(f,0,1);return e(a,c([0.33,0.34,0.33,0,0,0.33,0.34,0.33,0,0,0.33,0.34,0.33,0,0,0,0,0,1,0,0,0,0,0,1],f))}}});l("p7",["x1","x2","py","x5"],function(d,e,c,a){function b(a,b){return c.blobToImage(a).then(function(a){var f=
d.create(e.getWidth(a),e.getHeight(a)),g=d.get2dContext(f);g.drawImage(a,0,0);m(a);a=g.getImageData(0,0,f.width,f.height);var h=a.data,k,p,l,y,x,z=b[0],A=b[1],D=b[2],B=b[3],C=b[4],F=b[5],E=b[6],G=b[7],H=b[8],I=b[9],K=b[10],J=b[11],L=b[12],N=b[13],M=b[14],O=b[15],S=b[16],P=b[17],T=b[18],Q=b[19];for(x=0;x<h.length;x+=4)k=h[x],p=h[x+1],l=h[x+2],y=h[x+3],h[x]=k*z+p*A+l*D+y*B+C,h[x+1]=k*F+p*E+l*G+y*H+I,h[x+2]=k*K+p*J+l*L+y*N+M,h[x+3]=k*O+p*S+l*P+y*T+Q;g.putImageData(a,0,0);return c.canvasToBlob(f)})}function f(a,
b){return c.blobToImage(a).then(function(a){var f=d.create(e.getWidth(a),e.getHeight(a)),g=d.get2dContext(f),h;g.drawImage(a,0,0);m(a);a=g.getImageData(0,0,f.width,f.height);h=g.getImageData(0,0,f.width,f.height);h=function(a,b,c){function d(a,b,c){a>c?a=c:a<b&&(a=b);return a}var e,f,g,h,k,m,p,n,r,l,q,t,s,L;g=Math.round(Math.sqrt(c.length));h=Math.floor(g/2);e=a.data;f=b.data;s=a.width;L=a.height;for(k=0;k<L;k++)for(a=0;a<s;a++){for(l=m=p=n=0;l<g;l++)for(r=0;r<g;r++)q=d(a+r-h,0,s-1),t=d(k+l-h,0,L-
1),q=4*(t*s+q),t=c[l*g+r],m+=e[q]*t,p+=e[q+1]*t,n+=e[q+2]*t;q=4*(k*s+a);f[q]=d(m,0,255);f[q+1]=d(p,0,255);f[q+2]=d(n,0,255)}return b}(a,h,b);g.putImageData(h,0,0);return c.canvasToBlob(f)})}function g(a){return function(b,f){return c.blobToImage(b).then(function(b){var g=d.create(e.getWidth(b),e.getHeight(b)),h=d.get2dContext(g),k,n=Array(256);for(k=0;k<n.length;k++)n[k]=a(k,f);h.drawImage(b,0,0);m(b);b=h.getImageData(0,0,g.width,g.height);k=b.data;var l;for(l=0;l<k.length;l+=4)k[l]=n[k[l]],k[l+1]=
n[k[l+1]],k[l+2]=n[k[l+2]];h.putImageData(b,0,0);return c.canvasToBlob(g)})}}function h(c){return function(d,e){return b(d,c(a.identity(),e))}}function k(a){return function(b){return f(b,a)}}var m=c.revokeImageUrl;return{invert:function(a){return function(c){return b(c,a)}}([-1,0,0,0,255,0,-1,0,0,255,0,0,-1,0,255,0,0,0,1,0]),brightness:h(a.adjustBrightness),hue:h(a.adjustHue),saturate:h(a.adjustSaturation),contrast:h(a.adjustContrast),grayscale:h(a.adjustGrayscale),sepia:h(a.adjustSepia),colorize:function(c,
d,e,f){return b(c,a.adjustColors(a.identity(),d,e,f))},sharpen:k([0,-1,0,-1,5,-1,0,-1,0]),emboss:k([-2,-1,0,-1,1,1,0,1,2]),gamma:g(function(a,b){return 255*Math.pow(a/255,1-b)}),exposure:g(function(a,b){return 255*(1-Math.exp(-(a/255)*b))}),colorFilter:b,convoluteFilter:f}});l("x6",["x3","py","x1","x2"],function(d,e,c,a){function b(c,d,e){var m=a.getWidth(c),p=a.getHeight(c),m=d/m,n=e/p,p=!1;if(0.5>m||2<m)m=0.5>m?0.5:2,p=!0;if(0.5>n||2<n)n=0.5>n?0.5:2,p=!0;c=f(c,m,n);return p?c.then(function(a){return b(a,
d,e)}):c}function f(b,e,f){return new d(function(d){var p=a.getWidth(b),n=a.getHeight(b),r=Math.floor(p*e),l=Math.floor(n*f),t=c.create(r,l);c.get2dContext(t).drawImage(b,0,0,p,n,0,0,r,l);d(t)})}return{scale:b}});l("p8",["py","x1","x2","x6"],function(d,e,c,a){var b=d.revokeImageUrl,f=function(a){return function(c){b(a);return c}};return{rotate:function(a,f){return d.blobToImage(a).then(function(k){var m=e.create(c.getWidth(k),c.getHeight(k)),p=e.get2dContext(m),n=0,r=0;f=0>f?360+f:f;90!=f&&270!=f||
e.resize(m,m.height,m.width);if(90==f||180==f)n=m.width;if(270==f||180==f)r=m.height;p.translate(n,r);p.rotate(f*Math.PI/180);p.drawImage(k,0,0);b(k);return d.canvasToBlob(m,a.type)})},flip:function(a,f){return d.blobToImage(a).then(function(a){var g=e.create(c.getWidth(a),c.getHeight(a)),p=e.get2dContext(g);"v"==f?(p.scale(1,-1),p.drawImage(a,0,-g.height)):(p.scale(-1,1),p.drawImage(a,-g.width,0));b(a);return d.canvasToBlob(g)})},crop:function(a,c,f,m,p){return d.blobToImage(a).then(function(a){var g=
e.create(m,p);e.get2dContext(g).drawImage(a,-c,-f);b(a);return d.canvasToBlob(g)})},resize:function(b,c,e){return d.blobToImage(b).then(function(m){var p=f(m);return a.scale(m,c,e).then(function(a){return d.canvasToBlob(a,b.type)}).then(p,p)})}}});l("h7",["p7","p8"],function(d,e){return{invert:function(c){return d.invert(c)},sharpen:function(c){return d.sharpen(c)},emboss:function(c){return d.emboss(c)},brightness:function(c,a){return d.brightness(c,a)},hue:function(c,a){return d.hue(c,a)},saturate:function(c,
a){return d.saturate(c,a)},contrast:function(c,a){return d.contrast(c,a)},grayscale:function(c,a){return d.grayscale(c,a)},sepia:function(c,a){return d.sepia(c,a)},colorize:function(c,a,b,e){return d.colorize(c,a,b,e)},gamma:function(c,a){return d.gamma(c,a)},exposure:function(c,a){return d.exposure(c,a)},flip:function(c,a){return e.flip(c,a)},crop:function(c,a,b,d,g){return e.crop(c,a,b,d,g)},resize:function(c,a,b){return e.resize(c,a,b)},rotate:function(c,a){return e.rotate(c,a)}}});l("9t",["h6",
"h7"],function(d,e){var c=function(a){return function(b){return e.rotate(b,a)}},a=function(a){return function(b){return e.flip(b,a)}},b=function(a){return function(b){return e.resize(b,a.width(),a.height())}},f=d.pToFR(e.sharpen),g=d.pToFR(c(-90)),c=d.pToFR(c(90)),h=d.pToFR(a("v")),a=d.pToFR(a("h"));return{rotateLeft:g,rotateRight:c,flipVertical:h,flipHorizontal:a,sharpen:f,crop:function(a,b,c,f){return d.pToFR(function(d){return e.crop(d,a,b,c,f)})},resizeTo:function(a){return d.pToFR(b(a))}}});
l("h8",["h6"],function(d){return{mapIfSet:function(e,c){return d.map(e,function(a){return a.map(c)})},applyIfSet:function(e){return function(c){return d.bind(e,function(a){return a.fold(function(){return d.pure(c)},function(a){return a(c)})})}}}});l("ab",["b"],function(d){return{partition:function(e){var c=[],a=[];d.each(e,function(b){b.fold(function(a){c.push(a)},function(b){a.push(b)})});return{errors:c,values:a}}}});l("p9",["2v"],function(d){return d.immutable("width","height")});l("x7",["4q",
"pi"],function(d,e){var c=d.generate([{special:["size"]},{regular:["value","size","unit"]}]);return{identify:function(a){a=a.match(/(\d*\.?\d*)(.*)/);return""!==a[1]?c.regular(a[0],e(a[1]),a[2]):c.special(a[0])}}});l("pa","s p9 x7 2v 1a 2o 68 2s e2".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(a,e){return f.getRaw(a,e).orThunk(function(){return b.has(a,e)?d.some(b.get(a,e)):d.none()}).bind(function(a){return c.identify(a).fold(function(a){return d.none()},function(a,b,c){switch(c){case "":case "px":return d.some(k(b,
10));default:return d.none()}})})},p=function(a,b,c){b=b(a);return 0<b?d.some(b):m(a,c)};return{get:function(a){return p(a,h.get,"width").bind(function(b){return p(a,g.get,"height").map(function(a){return e(b,a)})})},measure:p}});l("pb",[],function(){var d=function(a,b){var c=b/a;return 1>c?c:1},e=function(a,b){var c=d(a.height,b.height);return 1===c?a:{width:a.width*c,height:b.height}},c=function(a,b){var c=d(a.width,b.width);return 1===c?a:{width:b.width,height:a.height*c}};return{max:function(a,
b){var d=0<b.height?b.height:0,g=0<b.width?b.width:0;if(!(a.height>d||a.width>g)||d===g&&0===d)return a;var d={width:g,height:d},g=a.width>a.height,h=0<d.height,k=(h?a.height/d.height:0)>(0<d.width?a.width/d.width:0);return(d.width===d.height&&g||!h||!k?c:e)(a,d)}}});l("h9","h5 s p9 h6 pa ff pb".split(" "),function(d,e,c,a,b,f,g){var h=function(b){var c=d.createObjectURL(b);return a.map(f.load(c),function(a){a=k(a);d.revokeObjectURL(c);return a})},k=function(a){return c(a.dom().naturalWidth,a.dom().naturalHeight)},
m=function(a){var c=k(a);return b.get(a).filter(function(a){return a.width()!==c.width()||a.height()!==c.height()})};return{restrain:function(b){var d=b.width(),f=b.height(),k=function(a){var b=g.max({width:a.width(),height:a.height()},{width:d,height:f});return a.height()>f||a.width()>d?e.some(c(b.width,b.height)):e.none()};return function(b){b=h(b);return a.map(b,k)}},changedBounds:function(b){return a.map(f.loadIfNeeded(b),m)}}});l("95","gq h4 h5 9t h6 h8 ab h9 o".split(" "),function(d,e,c,a,b,
f,g,h,k){var m=function(b){b=f.mapIfSet(b,a.resizeTo);return f.applyIfSet(b)},p=function(a,c,d){return b.fromChain([m(a),d])(c)};return{instance:function(a){var f=h.restrain(a);return function(a){return d.cata(a,function(d,g,h,k){d=f(g);return p(d,g,function(d){if(d===g)return b.pure(a);c.revokeObjectURL(h);return b.fromFuture(e.single(d))})},function(){return b.pure(a)})}},processResults:function(a){return function(b){b=g.partition(b);0<b.errors.length&&(a("imageedit.generic"),k.error("Image resample errors: ",
b.errors));return b.values}},resampleAction:p}});l("5k","8x 8y 7 8z 90 91 92 93 94 7b 95 96 71 59 4a".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,l,t){return function(s,u,v,w,y){var x=s.content(),z=s.smartview(),A=s.ui().tabstrip,D=a(s.ui),B=p.processResults(D.showKey),C=function(a){s.undo().save();a=k.validate(a);(a.failure()?c.curry(D.showKey,"fileupload.invalidimages"):D.hide)();v.assets(a.assets()).map(B).get(function(a){b.insertAssets(x,u,a)})},F=function(a){C(a.assets())};w.events.insertAssets.bind(function(a){y.allowLocalImages?
C(a.assets()):n.getOrLog("errors.dragdrop.images.disallowed")});var E=x.cursor();w=t.create({analytics:l(["message"])});return{ui:r.ui({"fileupload.general":c.constant({value:"image",textkey:m.key("insert.image"),icon:!0,updateGeneral:c.identity,action:function(){var a=g(x,A,z.uiContainer(),h,y,e.dialog);a.events.insertAssets.bind(F);a.events.close.bind(function(){x.focus();a.destroy()});a.events.escaped.bind(function(){x.focus();a.destroy()});s.content().hideInlineSelection();a.show()},hasDialog:!0}),
"fileupload.menu":function(){var a=f(x,A,z,s.ui(),y);a.events.insertAsset.bind(function(a){E.get().bind(function(c){b.insertMobileAssets(x,c,u,[a.asset()])})});a.events.open.bind(function(a){x.getSelection().each(E.save)});return a},"camera.general":function(){var a=d();a.events.upload.bind(function(a){E.get().bind(function(c){b.insertMobileAssets(x,c,u,a.assets())})});return{value:"image",textkey:m.key("image.from-camera"),icon:!0,updateGeneral:c.identity,action:function(){x.getSelection().each(E.save);
x.toReading();a.open()},hasDialog:!0}}},c.identity),events:w.registry,destroy:function(){}}}});l("97",["7","34","cw"],function(d,e,c){var a=e.resolve("find-match");e=e.resolve("find-mark");var b="."+a+", ."+e;return{configure:function(a){a.addSelector(a.output(),b,c.unwrap);a.addSelector(a.history(),b,c.unwrap);a.addSelector(a.internal(),b,c.unwrap)},matchClass:d.constant(a),markClass:d.constant(e),findIdAttr:d.constant("data-ephox-find-id"),shiftKeyState:function(a){return{isShift:d.constant(a)}}}});
l("x8",[],function(){var d=function(d){return{fold:d}};return{created:function(e){return d(function(c,a){return a(e)})},preserved:function(e){return d(function(c,a){return c(e)})}}});l("112",["2v"],function(d){return d.immutable("id","match","current")});l("13v",["4j"],function(d){return{resolve:d.create("data.ephox.cram").resolve}});l("13w",["4j"],function(d){return{resolve:d.create("ephox-cram").resolve}});l("113","13v 13w 7 s 1a 1y 4h 32 2b".split(" "),function(d,e,c,a,b,f,g,h,k){var m=d.resolve("highlight-id"),
p=e.resolve("highlight-wrap"),n=function(a,b){return h.closest(a,"."+b)},r=function(c){return a.from(b.get(c,m))};return{marker:n,idMarker:function(a){return n(a,p)},id:r,set:function(a,c){b.set(a,m,c);f.add(a,c)},all:function(a){return r(a).fold(c.constant([a]),function(b){var c=k.owner(a);return g.descendants(c,"."+b)})}}});l("pd",["2v"],function(d){return d.immutable("word","pattern")});l("160",["b","7","v1","hv"],function(d,e,c,a){return{separate:function(b,f,g){var h=d.bind(g,function(a){return[a.start(),
a.finish()]}),k=a.splits(f,h,function(a,d){return c.subdivide(b,a.element(),d)});return d.map(g,function(c){var f=a.sublist(k,c.start(),c.finish()),f=d.map(f,function(a){return a.element()}),g=d.map(f,b.property().getText).join("");return{elements:e.constant(f),word:c.word,exact:e.constant(g)}})}}});l("15c","b s pd f9 zo k5 160 6o hv hw".split(" "),function(d,e,c,a,b,f,g,h,k,m){var p=function(b,c){return k.generate(c,function(c,d){var f=d+b.property().getText(c).length;return e.from(a.range(c,d,f))})},
n=function(a,c,e,h){c=b.group(a,c,h);return d.bind(c,function(b){b=f.justText(b);var c=d.map(b,a.property().getText).join(""),c=m.findmany(c,e);b=p(a,b);return g.separate(a,b,c)})};return{safeWords:function(a,b,e,f){e=d.map(e,function(a){var b=h.safeword(a);return c(a,b)});return n(a,b,e,f)},safeToken:function(a,b,d,e){d=c(d,h.safetoken(d));return n(a,b,[d],e)},run:n}});l("13x",["15c"],function(d){return{safeWords:function(e,c,a,b){return d.safeWords(e,c,a,b)},safeToken:function(e,c,a,b){return d.safeToken(e,
c,a,b)},run:function(e,c,a,b){return d.run(e,c,a,b)}}});l("114",["6q","13x"],function(d,e){var c=d();return{safeWords:function(a,b,d){return e.safeWords(c,a,b,d)},safeToken:function(a,b,d){return e.safeToken(c,a,b,d)},run:function(a,b,d){return e.run(c,a,b,d)}}});l("x9","b 112 113 30 7 s 114".split(" "),function(d,e,c,a,b,f,g){var h=function(g,h){var p=d.bind(g.elements(),function(a){return c.marker(a,h).fold(b.constant([]),function(a){return[a]})}),n=a.generate("ephox-cram");return e(n,g,f.from(p[0]))};
return{matchWords:function(a,b,c){return g.safeWords(a,b,c)},matchToken:function(a,b,c){return g.safeToken(a,b,c)},matchPattern:function(a,b,c){return g.run(a,[b],c)},annotates:function(a,b){return d.map(a,function(a){return h(a,b)})}}});l("pc",["b","x8","x9","7","hu"],function(d,e,c,a,b){var f=function(f,h,k,m){h=c.annotates(m,k.label());return d.bind(h,function(c){return c.current().fold(function(){var h=c.match();if(f.ignore(h))return[];h=b.wrapper(h.elements(),k.nu)||[];d.each(h,a.curry(k.tag,
c));return[e.created(h)]},function(a){return[e.preserved(a)]})})};return{highlight:function(a,b,d,e){d=c.matchToken(b,d,a.optimise);return f(a,b,e,d)},highlightPattern:function(a,b,d,e){d=c.matchPattern(b,d,a.optimise);return f(a,b,e,d)}}});l("ha","b pc 7 s pd 6o 97 fg 1a 1y l 2p 21 2r 4h 3n 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,l,t,s,u){var v=function(a,b){return r.isElement(b)&&h.isBlock(b)?0>s.get(b).toLowerCase().indexOf(a):!1},w=function(a){return{ignore:c.constant(!1),optimise:c.curry(v,
a.toLowerCase())}},y=c.constant("."+g.matchClass()),x={label:g.matchClass,tag:function(a,b){m.add(b,g.matchClass());k.set(b,g.findIdAttr(),a.id())},nu:function(){var a=p.fromTag("span");return{element:c.constant(a),wrap:c.curry(n.append,a)}}},z=function(a){d.each(a,function(a){m.add(a,g.markClass())})},A=function(a){d.each(a,function(a){m.remove(a,g.markClass())})},D=function(b,c){var e=d.groupBy(t.descendants(b,c),function(a){return k.get(a,g.findIdAttr())});return 0===e.length?a.none():a.some(e)},
B=function(a,d){var e=f.custom(f.sanitise(a),c.constant(0),c.constant(0),d);return b(a,e)},C=function(a,b,c){return D(a,y()).map(function(e){var f=d.filter(e,function(a){return m.has(a[0],g.markClass())}),h=d.findIndex(e,function(a){return d.contains(f,a)});return{pos:c(e,d.flatten(f),h,b(h,e.length)),all:D(a,y())}})},F=function(a,b,c,d){A(b);z(a[d]);return d},E=function(a,b){return a===b-1?0:a+1},G=function(a,b){return 0===a?b-1:a-1},H=function(a,b){return C(a,E,function(a,c,e,f){F(a,c,e,f);n.before(c[0],
p.fromText(b));d.each(c,l.remove);return 0===f?f:e})};return{search:function(b,c,d){if(0===c.length)return a.none();var f=w(c),g=u.children(b);c=!0===d?B(c,a.none()):B(c,a.some("gi"));e.highlightPattern(f,g,c,x);return D(b,y()).map(function(b){z(b[0]);return{all:a.some(b),pos:0}})},clear:function(b){b=t.descendants(b,y());d.each(b,l.unwrap);return a.none()},next:function(a){return C(a,E,F)},prev:function(a){return C(a,G,F)},replace:H,replaceAll:function(b,c){for(;H(b,c).isSome(););return a.none()}}});
l("hb",["7","s","ha","2b"],function(d,e,c,a){return function(a,f,g){var h=function(){f.counter.update(0,0)},k=function(c){c.all.fold(h,function(d){f.counter.update(c.pos+1,d.length);d=d[c.pos][0];a.setSelection(d,0,d,0);g.element(d)})},m=function(){g.cursor();h()},p=function(a,b,d){c.clear(a);c.search(a,b,d).fold(m,k);return e.some(b)},n=function(a,b){var d=(!0===b?c.prev:c.next)(a);d.fold(m,k);return d},r=function(d){a.body().each(function(e){c.replace(e,d).fold(m,k);a.domChanged();a.undoChanged()})},
l=e.none(),t=function(){l=e.none()};f.events.search.bind(function(c){a.body().each(function(a){p(a,c.term(),c.matchcase())})});f.events.next.bind(function(){a.body().each(function(a){n(a,!1)})});f.events.prev.bind(function(){a.body().each(function(a){n(a,!0)})});f.events.replace.bind(function(a){r(a.value())});f.events.replaceAll.bind(function(d){a.body().each(function(e){c.replaceAll(e,d.value()).fold(m,k);a.undoChanged()})});f.events.interactive.bind(function(c){a.body().each(function(a){l=p(a,
c.term(),c.matchcase())})});f.events.encase.bind(function(c){a.body().each(function(a){l.each(function(b){p(a,b,c.matchcase())})})});f.events.clear.bind(function(d){a.body().each(function(a){c.clear(a);t()})});return{zeroCount:h,updateMatch:k,enterSearchAction:function(c,e){a.body().each(function(a){var b=f.getCase();l=l.filter(function(a){return c===a}).fold(function(){return p(a,c,b)},function(f){return n(a,e.isShift()).fold(function(){return p(a,c,b)},d.constant(l))})});(0===c.length?f.counter.hide:
f.counter.show)()},enterReplaceAction:r,clearLastSearch:t}}});l("hc",["c","7","cx"],function(d,e,c){var a=d.detect().deviceType.isiOS();return function(b){var d=b.content();b=function(a){d.elementIntoView(a)};var g=function(){d.cursorIntoView()};b={element:a?b:e.curry(c.elementIntoView,d),cursor:a?g:e.curry(c.cursorIntoView,d)};return{get:e.constant(b)}}});l("pf","8b am 53 hg eh lp 7 7b 34 59 4a 4b 1a 2n 1y 4e 2o 3y l 2z 2p 3d ip 2r b0".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,l,t,s,u,v,w,y,
x,z,A,D,B){var C=function(a,b,c){a=a();var e=a.element();s.add(e,b);d.button(e,c);r.set(e,"tabindex","-1");a.events.click.bind(function(){y.focus(e)});return a},F=function(b,c){var d=C(a,b,c);r.set(d.element(),"title",c);return d},E=function(c,d){var e=k.resolve("inline-main-button"),e=c.concat([e]),e=C(a,e,d);e.content(b(d));return e},G=function(a,b,c){var d=k.resolve("inline-main-button-toggle");a=a.concat([d]);c=C(f,a,c);r.set(c.element(),"title",b);return c},H=function(a,b,c){var e=w.fromTag("input");
s.add(e,a);r.set(e,"placeholder",b);d.label(e,c);return{element:g.constant(e),destroy:g.curry(D.remove,e)}};return{counter:function(a){var b=c.div(),d=c.span();t.add(b,k.resolve("search-widget-counter"));t.add(d,k.resolve("search-widget-counter-text"));x.append(b,d);return{element:g.constant(b),update:function(a,b){var c=h.translate("units.amount-of-total",a,b);D.empty(d);x.append(d,w.fromText(c));B.isVisible(d)&&e.speak(l.body(),c)},hide:function(){u.set(b,"display","none")},show:function(){u.remove(b,
"display")},destroy:function(){D.remove(d);D.remove(b)}}},dummyCounter:function(a){a=c.div();t.add(a,k.resolve("search-widget-counter"));return{element:g.constant(a),update:g.noop,hide:g.noop,show:g.noop,destroy:g.curry(D.remove,a)}},searchField:function(){var a=c.span(),b=F([k.resolve("stepper-button"),k.resolve("search-widget-previous")],h.translate("search.previous")),d=F([k.resolve("stepper-button"),k.resolve("search-widget-next")],h.translate("search.next")),e=G([k.resolve("search-widget-more")],
h.translate("aria.label.more"),h.translate("aria.label.more"));t.add(a,k.resolve("search-widget-searchField"));var f=H([k.resolve("search-widget-input"),k.resolve("search-widget-input-search")].concat(A.isSmallTouch()?[k.resolve("search-widget-small-touch")]:[]),h.translate("search.search"),h.translate("search.field.search")),r=p.create({next:n([],d.events.click),previous:n([],b.events.click),more:n([],e.events.click),input:m(["raw"])}),l=v.bind(f.element(),"input",r.trigger.input);z.append(a,[f.element(),
b.element(),d.element(),e.element()]);return{events:r.registry,element:g.constant(a),input:f.element,focus:function(){y.focus(f.element())},previous:b.element,next:d.element,moreToggle:e,destroy:function(){l.unbind();f.destroy();b.destroy();d.destroy();e.destroy()}}},replaceDrawer:function(){var a=H([k.resolve("search-widget-input"),k.resolve("search-widget-input-replace")],h.translate("search.replace"),h.translate("search.field.replace")),b=G([k.resolve("search-widget-matchcase")],h.translate("search.matchcase"),
h.translate("search.matchcase")),e=E([k.resolve("search-widget-replace")],h.translate("search.replace")),f=E([k.resolve("search-widget-replace-all")],h.translate("search.replace-all")),m=w.fromTag("div");d.group(m);var p=c.div();t.add(m,k.resolve("search-widget-replace-drawer"));t.add(p,k.resolve("search-widget-replace-drawer-tools"));z.append(p,[b.element(),e.element(),f.element()]);z.append(m,[a.element(),p]);return{element:g.constant(m),replace:e,replaceAll:f,input:a,matchcase:b,destroy:function(){b.destroy();
e.destroy();f.destroy();D.remove(p);D.remove(m)}}},button:F,input:H}});l("hd","pe 8b fh 53 7 aa pf 34 59 4a 4b 1y 2o 3y 68 3d ip 2r 33".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,l,t,s,u,v,w){var y=function(a,b,d){a?(c.expanded(b),e.hidden(d,!1)):(c.collapsed(b),e.hidden(d,!0))};return function(){var x=a.div();n.add(x,h.resolve("search-widget"));var z=g.searchField(),A=(u.isSmallTouch()?g.dummyCounter:g.counter)(z.input()),D=g.replaceDrawer(),B=D.element(),C=m.create({next:p([],z.events.next),
prev:p([],z.events.previous),replace:k(["value"]),replaceAll:k(["value"]),search:k(["term","matchcase","isShift"]),interactive:k(["term","matchcase"]),encase:k(["matchcase"]),clear:k([])});c.setPressed(D.matchcase.element(),D.matchcase.selected());var F=d(B);e.linkElements(z.moreToggle.element(),B);y(F.visible(),z.moreToggle.element(),B);z.moreToggle.events.click.bind(function(){(F.visible()?F.hide:F.show)()});z.events.input.bind(function(){var a=w.get(z.input()),b=t.get(z.element());r.set(A.element(),
"height",b+"px");3<=a.length?G.throttle(a):(C.trigger.clear(),A.hide(),A.update(0,0))});D.replace.events.click.bind(function(){var a=w.get(D.input.element());C.trigger.replace(a)});D.replaceAll.events.click.bind(function(){var a=w.get(D.input.element());C.trigger.replaceAll(a)});D.matchcase.events.click.bind(function(){c.setPressed(D.matchcase.element(),D.matchcase.selected());C.trigger.encase(E())});var E=function(){return D.matchcase.selected()},G=f(function(a){A.show();C.trigger.interactive(a,
E())},500),H=l.bind(B,"transitionend",function(a){"opacity"===a.raw().propertyName&&n.remove(B,"ephox-chameleon-toolbar-more-open");y(F.visible(),z.moreToggle.element(),B)});s.append(x,[A.element(),z.element(),D.element()]);return{element:b.constant(x),search:z,focus:function(){z.focus()},drawer:D,counter:A,getCase:E,destroy:function(){H.unbind();z.destroy();D.destroy();A.destroy();F.destroy();v.remove(x)},events:C.registry}}});l("98","gt 8y 7 ha gv hb 97 hc hd 59 4a 33".split(" "),function(d,e,c,
a,b,f,g,h,k,m,p,n){return function(r){var l=r.content(),t=k();r=h(r);var s=f(l,t,r.get()),u=function(a){var b=a.endContainer();a=a.endOffset();l.setSelection(b,a,b,a)};r=d.button({execute:b.button});r=[e.input(t.search.input(),d.input({execute:function(a,b){s.enterSearchAction(a,b)}})),e.button(t.search.previous(),r),e.button(t.search.next(),r),e.button(t.search.moreToggle.element(),r),e.input(t.drawer.input.element(),d.input({execute:function(a,b){s.enterReplaceAction(a)}})),e.button(t.drawer.matchcase.element(),
r),e.button(t.drawer.replace.element(),r),e.button(t.drawer.replaceAll.element(),r)];var v=p.create({done:m([])});return{element:t.element,anchorName:c.constant("search-widget-anchor"),textkey:c.constant("action.search"),dialogTextkey:c.constant("search.menu"),destroy:function(){t.destroy()},keylayouts:c.constant(r),openWidget:function(){s.enterSearchAction(n.get(t.search.input()),g.shiftKeyState(!1))},closeWidget:function(){l.body().each(function(b){l.getSelection().each(u);a.clear(b)});s.clearLastSearch()},
events:v.registry}}});l("he",["4q"],function(d){return{text:d.generate([{text:["field","input"]}]).text,cata:function(d,c){return d.fold(c)}}});l("99","7 ha hb 97 hc he hd 59 4a 2z 2p 33 3x".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r){return function(l,t){var s=l.content(),u=g(),v=b(l),w=c(s,u,v.get()),v=k.create({toEditor:h([])}),y=f.text(u.search.element(),u.search.input());return{element:u.element,addEscape:function(a){p.append(u.search.element(),a.element())},open:function(){w.enterSearchAction(n.get(u.search.input()),
a.shiftKeyState(!1));r(u.focus,250)},close:function(){s.body().each(function(a){e.clear(a).fold(w.zeroCount,w.updateMatch)});w.clearLastSearch()},execute:function(b){if(m.hasFocus(u.search.input())){b=a.shiftKeyState(!0===b.raw().shiftKey);var c=n.get(u.search.input());w.enterSearchAction(c,b)}else b=n.get(u.drawer.input.element()),w.enterReplaceAction(b)},type:d.constant(y),events:v.registry,destroy:function(){u.destroy()}}}});l("9a","7d b 8b hf hg hh 7 r s hi he 7b ag 34 59 4a 4p 57 1a 1y 3y l 2z 2p 4l 4h 3x".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,r,l,t,s,u,v,w,y,x,z,A,D,B,C,F){var E=v.ensureWith("element addEscape open close execute type events destroy".split(" "),m.isFunctionOrEvents(["toEditor"]));return function(m,v){E(v);var F=m.content(),K=m.ui().tabstrip.element();y.add(v.element(),l.resolve("slick-widget"));var J=p.cata(v.type(),function(b,c){y.add(b,l.resolve("slick-widget-field"));y.add(c,l.resolve("slick-widget-input"));var d=x.bind(v.element(),"keydown",function(a){var b={original:g.constant(a)};
if(r.isEnter(b))v.execute(a),a.kill();else if(r.isTab(b)){var b=C.descendants(v.element(),"input,textarea"),c=e.findIndex(b,A.hasFocus);-1<c&&(c=(c+1)%b.length,0<=c&&c<b.length&&A.focus(b[c]));a.kill()}else r.isEscape(b)&&(P(),a.kill())}),f=x.bind(c,"blur",function(b){k.from(b.raw().relatedTarget).each(function(b){!0===B.ancestor(z.fromDom(b),function(a){return y.has(a,"ephox-polish-mobile-toolbar-hide")}).isSome()&&a.refreshInput(c)})});return{destroy:function(){d.unbind();f.unbind()}}}),L=b("shizniz"),
N=n.translate("toolbar.backbutton"),M=f([d.resolve("icon")]);L.content(M);w.set(L.element(),"title",N);c.toolbarButton(L.element(),N,!1,!1);v.addEscape(L);var O=u(!1);D.prepend(K,v.element());var S=s.create({done:t([]),abort:t([]),open:t([]),close:t([])}),P=function(){Q();F.toEditing()};v.events.toEditor.bind(P);var T=h.cached(function(a){return C.children(K,"."+d.resolve("toolbar"))}),Q=function(){v.close();O.set(!1);e.each(T(),function(a){y.remove(a,l.resolve("mobile-toolbar-hide"))});y.remove(v.element(),
l.resolve("mobile-toolbar-show"));y.add(v.element(),l.resolve("mobile-toolbar-hide"));S.trigger.close()};F.events.mousedown.bind(Q);Q();L.events.click.bind(function(){P();S.trigger.abort()});return{element:v.element,destroy:function(){F.events.mousedown.unbind(Q);J.destroy();v.destroy()},events:S.registry,open:function(){var a=x.bind(K,"transitionend",function(){v.open();S.trigger.open();a.unbind()});O.set(!0);e.each(T(),function(a){y.remove(a,l.resolve("mobile-toolbar-show"));y.add(a,l.resolve("mobile-toolbar-hide"))});
y.remove(v.element(),l.resolve("mobile-toolbar-hide"));y.add(v.element(),l.resolve("mobile-toolbar-show"))},close:Q,isOpen:function(){return O.get()}}}});l("5l","c r 97 98 99 7a 9a 7b 34 71 7c 59 4a 1y".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,r,l){var t=k.resolve("toolbar-dialog"),s=function(b){var c=a(b);return f(b,c,"search",t)},u=function(a){var c=b(a);return g(a,c,t)},v=function(a){return(d.detect().deviceType.isTouch()?u:s)(a)};return function(a){var b=a.filter();c.configure(b);var d=r.create({analytics:n(["message"])}),
f=e.cached(function(){var b=v(a);b.events.open.bind(function(){d.trigger.analytics("search_tool_open")});b.events.abort.bind(b.close);return b}),b=function(){var a=f();(a.isOpen()?a.close:a.open)()};a.shortcuts().events.search.bind(b);return{ui:m.ui({"find.general":{toggle:!1,hasPopup:!1,value:"search",textkey:h.key("action.search"),action:b,updateGeneral:function(a){l.add(a.element(),k.resolve("search"))},icon:!0,tooltip:p.get}}),events:d.registry,destroy:function(){f().destroy()}}}});l("9b","7 ed 7l 7w e7 ef 1a".split(" "),
function(d,e,c,a,b,f,g){var h=function(c){return a.isAnnotation(c)||g.has(c,b.overrideSpan())},k=function(a,b,f,g,k,m){var l=function(b){a(b,k,h)};c.cata(g.get(),d.noop,e.multiple(b,f,l,m),e.single(b,f,l,m))},m=function(a,b,c,d,e){k(a,b,c,d,e,b.toEditing)};return{face:d.curry(m,f.face),background:d.curry(m,f.background),foreground:d.curry(m,f.foreground),size:d.curry(m,f.size),partialSize:d.curry(function(a,b,c,e,f){k(a,b,c,e,f,d.noop)},f.size)}});l("9d",["2v"],function(d){return{color:d.immutable("hex",
"classes","name"),face:d.immutable("textkey","value","icon"),size:d.immutable("name","size")}});l("9c",["7","r","s","9d","7b"],function(d,e,c,a,b){var f=a.color,g=a.face,h=a.size;a=e.cached(function(){return[f("#FFF",["color-highlight-dark","color-option-white"],b.key("color.white")),f("#000",["color-highlight-light"],b.key("color.black")),f("#444",["color-highlight-light"],b.key("color.gray")),f("#777",["color-highlight-light"],b.key("color.metal")),f("#CCC",["color-highlight-light"],b.key("color.smoke")),
f("#FC1D00",["color-highlight-light"],b.key("color.red")),f("#C81500",["color-highlight-light"],b.key("color.darkred")),f("#FF8C00",["color-highlight-dark"],b.key("color.darkorange")),f("#FEBE00",["color-highlight-dark"],b.key("color.orange")),f("#FFFC00",["color-highlight-dark"],b.key("color.yellow")),f("#22AE50",["color-highlight-dark"],b.key("color.green")),f("#006400",["color-highlight-dark"],b.key("color.darkgreen")),f("#3CB371",["color-highlight-dark"],b.key("color.mediumseagreen")),f("#8FCD4E",
["color-highlight-dark"],b.key("color.lightgreen")),f("#00FF00 ",["color-highlight-dark"],b.key("color.lime")),f("#0000CD",["color-highlight-dark"],b.key("color.mediumblue")),f("#002360",["color-highlight-light"],b.key("color.navy")),f("#0173C1",["color-highlight-light"],b.key("color.blue")),f("#14B2F2",["color-highlight-dark"],b.key("color.lightblue")),f("#ee82ee",["color-highlight-light"],b.key("color.violet"))]});e=e.cached(function(){return[g(b.key("font.arial"),"Arial",c.none()),g(b.key("font.comicsans"),
"Comic Sans MS",c.none()),g(b.key("font.consolas"),"Consolas",c.none()),g(b.key("font.courier"),"Courier",c.none()),g(b.key("font.georgia"),"Georgia",c.none()),g(b.key("font.impact"),"Impact",c.none()),g(b.key("font.tahoma"),"Tahoma",c.none()),g(b.key("font.timesnr"),"Times New Roman",c.none()),g(b.key("font.trebuchet"),"Trebuchet MS",c.none()),g(b.key("font.verdana"),"Verdana",c.none())]});h=[h("font.small","10px"),h("font.medium","13px"),h("font.large","18px"),h("font.huge","32px")];return{colors:a,
faces:e,sizes:d.constant(h)}});l("io",["8b","hg","7b","1a","4e"],function(d,e,c,a,b){return function(f,g){var h=e();b.add(h.element(),f);d.button(h.element(),c.translate(g));a.set(h.element(),"title",c.translate(g));return h}});l("hn",["7"],function(d){return{configuration:d.constant({i18nNamespace:"font",cssNamespace:"font",property:"font-size",tag:"span",specials:["xx-small x-small small medium large x-large xx-large".split(" ")]})}});l("6a",["a"],function(d){return{isEmpty:function(e){return null===
e||void 0===e||""===e||d.isArray(e)&&0===e.length}}});l("ph","7 s p 6a x7 2o 1k 1s pi".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(a){var b=g.pNum(a)?"px":"";return a+b},p=function(a,b,d){return(f.isValidValue(a,b,d)?e.some(d):e.none()).fold(function(){return c.error("Invalid value: "+d)},function(a){return a===d?c.value(d):c.error("Invalid value: "+d)})},n=function(a){return b.identify(a).fold(function(a){return a},function(a,b,c){return h.round(10*b)/10+c})};return{identify:b.identify,
validate:function(b,e,f){return(a.isEmpty(b)?c.error("can not use empty value for font size."):c.value(b)).map(m).map(n).bind(d.curry(p,e,f))},sanitise:function(a){return n(a)}}});l("pg","a b 7 s ph 1s pi".split(" "),function(d,e,c,a,b,f,g){var h={px:1,em:0.1,"%":10,pt:1,rem:"0.1"},k=function(b,c,d){c=e.find(c,function(a){return e.contains(a,d)});return a.from(c).bind(function(c){var f=e.indexOf(c,d);return-1<f?a.from(c[b(f,c)]):a.none()}).getOr(d)};g=function(a,c,e,g){return b.identify(g).fold(function(b){return k(a,
e,b)},function(a,b,e){a=void 0!==h[e]?h[e]:1;var g=c*(void 0!==h[e]?h[e]:1);return(d.isNumber(b)&&0<=b?f.max(a,b+g):a)+e})};return{decrease:c.curry(g,function(a,b){return f.max(0,a-1)},-1),increase:c.curry(g,function(a,b){return f.min(b.length-1,a+1)},1)}});l("hj","8b am 53 7 9b io he hn 7b pg ph 34 59 4a 2v 2n 1y l 2z 2p 3d 33 3x".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u,v,w,y,x,z,A){var D=t.immutableBag(["i18nNamespace","cssNamespace","property","tag","specials"],[]);return function(t,
A){var F=D(h.configuration()),E=F.i18nNamespace(),G=F.cssNamespace(),H=c.div();u.add(H,n.resolve("fontsize-widget"));var I=c.span();u.add(I,n.resolve("fontsize-widget-field"));var K=c.div();u.add(K,n.resolve("fontsize-widget-exit"));var J=v.fromTag("input");u.add(J,n.resolve("fontsize-widget-input"));d.label(J,k.translate(E+".stepper.input"));var L=function(a){u.remove(J,n.resolve("slick-widget-invalid-input"));d.invalid(J,!1);z.set(J,a);b.partialSize(t.content(),t.undo(),t.selections(),a);e.speak(s.body(),
a)},N=function(){u.add(J,n.resolve("slick-widget-invalid-input"));d.invalid(J,!0);e.speak(s.body(),k.translate("aria.input.invalid"));w.focus(J)},M=function(a){return function(){var b=z.get(J),b=a(F.specials(),b);p.validate(b,F.tag(),F.property()).fold(N,L)}},O=M(m.decrease),M=M(m.increase),S=function(a,b){return f([n.resolve(G+a),n.resolve("stepper-button")],E+b)},P=S("-stepper-decrease",".stepper.decrease"),S=S("-stepper-increase",".stepper.increase");P.events.click.bind(O);S.events.click.bind(M);
x.append(I,[P.element(),J,S.element()]);y.append(H,I);y.append(H,K);var I=g.text(I,J),T=q.create({toEditor:l([]),size:l(["value"])}),Q=function(){z.set(J,"")},V=function(a){a=p.sanitise(a);p.validate(a,F.tag(),F.property()).fold(N,function(a){u.remove(J,n.resolve("slick-widget-invalid-input"));d.invalid(J,!1)});z.set(J,a)};return{element:a.constant(H),addEscape:function(a){y.append(K,a.element())},open:function(){w.focus(J)},close:a.noop,execute:function(){var a=z.get(J);p.validate(a,F.tag(),F.property()).fold(N,
function(a){L(a);T.trigger.toEditor()})},destroy:a.noop,type:a.constant(I),represent:function(a){a.fold(Q,V,V)},events:T.registry}}});l("hk","b s ft 7l 6a 7j 2v 2o 21 4l 2b pi".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var l=g.immutable("size"),q=function(b){b=a.toSelection(b.get()).fold(f.off,function(a){var b=a.startContainer();a=d.contains(["td","th"],k.name(b))?c.freefallLtr(a.startContainer()).element():a.startContainer();a=u(a);return f.on(a)});return l(b)},t=function(a){return a.body().bind(function(a){a=
h.get(a,"font-size");return e.from(a)})},s=function(a){var c=a.dom();if(!c.style)return!1;c=c.style.fontSize;return"body"!==k.name(a)&&!b.isEmpty(c)},u=function(a){var b=k.isText(a)?p.parent(a).getOrDie():a;return(s(b)?e.some(b):m.ancestor(b,s)).fold(function(){return h.get(b,"font-size")},function(a){return a.dom().style.fontSize})};return{getState:function(a,b){return{readState:q(a),fallbackSize:t(b).getOr("12px")}}}});l("9e","7 s hj 9a 7b hk 4p 3x".split(" "),function(d,e,c,a,b,f,g,h){return function(h,
m){var p=h.content(),n=g(e.none()),l=function(){var b=c(h,m),d=a(h,b),b={represent:b.represent,refreshValue:b.refreshValue,open:d.open,close:d.close,isOpen:d.isOpen};n.set(e.some(b));return b},q={toggle:!1,value:"size",textkey:b.key("font.size"),action:function(){var a=n.get().getOrThunk(l);if(a.isOpen())a.close();else{var b=f.getState(h.selections(),p);a.open();a.represent(b.readState.size())}},updateGeneral:d.noop,icon:!0,shortcut:!1,hasPopup:!1,hasDialog:!1};return{general:d.constant(q)}}});l("pl",
"8b 7 7b 34 59 4a 1a 1y 3y l 2z 2r".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){return function(l){var q=l.hex(),t=m.fromTag("span");h.add(t,a.resolve("palette-detail-action"));g.set(t,"title",c.get(l.name()));d.option(t,c.get(l.name()),!1,!1);var s=f.create({selected:b(["value"])}),u=k.bind(t,"click",function(){p.focus(t);s.trigger.selected(q)});return{element:function(){return t},value:e.constant(q),destroy:function(){u.unbind();n.remove(t)},events:s.registry}}});l("pm","b 8b fh 53 7 7b 34 3f 59 4a 1y 2o l 2p 2r".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t){return function(){var s=[],u=a.div(),v=l.fromTag("span");e.listBox(v);p.add(v,g.resolve("palette-detail-actions"));p.add(v,g.resolve("palette-color-options"));e.label(v,f.translate("aria.font.palette"));q.append(u,v);var w=h.create(),y=m.create({selected:k(["value"])});return{element:function(){return u},add:function(a){s.push(a.destroy);q.append(v,a.element());w.bind(a.events.selected,function(a){y.trigger.selected(a.value())})},remove:function(a){t.remove(a.element());
w.unbind(a.events.selected)},show:function(){p.add(u,g.resolve("palette-detail-active"));c.showPanel(u);n.remove(u,"display")},hide:function(){p.remove(u,g.resolve("palette-detail-active"));c.hidePanel(u);n.set(u,"display","none")},destroy:function(){d.each(s,b.apply);t.remove(u);s=[]},events:y.registry}}});l("ji","b gt 8y 6 7 s 9c pl pm 34 1y 4e 2o 68 3p 4h 1s".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u){var v=function(a){a.dom().click();return f.some(a)},w=function(a,c){var e=s.descendants(a,
c);if(0<q.get(a)&&0<e.length){var g=t.absolute(e[0]).top(),h=d.findIndex(e.slice(1),function(a){return t.absolute(a).top()!==g});return-1<h?f.some({rows:b.constant(u.ceil(e.length/(h+1))),columns:b.constant(h+1)}):f.none()}return f.none()};return{create:function(a){var b=void 0!==a?a:g.colors();a=k();b=d.map(b,function(a){var b=h(a);n.add(b.element(),d.map(a.classes(),m.resolve));p.add(b.element(),m.resolve("palette-color-option"));l.set(b.element(),"background-color",a.hex());return b});d.each(b,
a.add);return a},makeLayout:function(d,f,g){g=e.grid(a.deepMerge({trigger:v},g));var h=c.grid(d,{cell:b.constant(f)},4,5,g);return{layout:b.constant(h),refresh:function(){h.clear();w(d,f).each(function(a){h.resize(a.rows(),a.columns())})}}}}});l("pj",["ji","6u","1s"],function(d,e,c){var a=function(a){return e.closest(a,".ephox-polish-palette-detail-active")};return function(b,c){var e=d.makeLayout(c,".ephox-polish-palette-detail-action.ephox-polish-palette-color-option",{isValid:a}),h=e.layout();
return{isFocused:h.isFocused,enterGrid:h.enter,grid:h,refresh:e.refresh,destroy:h.destroy,clear:h.clear}}});l("pk","8b c eh lp 7 s 7b 34 1y l 2p 2r".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var l=e.detect().deviceType.isTouch;return function(){var e=m.fromTag("div");l()?d.presentation(e):d.menuItem(e,f.none(),f.none());k.add(e,h.resolve("color-widget"));var t=m.fromTag("div");k.add(t,h.resolve("color-widget-controls"));d.tabList(t);var s=m.fromTag("div");k.add(s,h.resolve("color-widget-palettes"));
d.toolbarGroup(s);var u=a("text-color");k.add(u.element(),h.resolve("tab-button"));u.content(c(g.translate("font.color")));d.tabButton(u.element(),g.translate("aria.font.color"));var v=a("highlight-color");k.add(v.element(),h.resolve("tab-button"));v.content(c(g.translate("font.highlight")));d.tabButton(v.element(),g.translate("aria.font.highlight"));p.append(t,u.element());p.append(t,v.element());p.append(e,t);p.append(e,s);return{element:b.constant(e),colorToggle:b.constant(u),highlightToggle:b.constant(v),
content:b.constant(s),controls:b.constant(t),destroy:function(){u.destroy();v.destroy();n.remove(s);n.remove(t)}}}});l("hl","8b fh gt 8y 7 9c pj pk ji 59 4a 4b 2p 32 1s".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t){return function(){var t=k.create(f.colors()),u=k.create(f.colors()),v=p.create({color:n(["value"],t.events.selected),highlight:n(["value"],u.events.selected),abort:m([])}),w=h(),y=w.colorToggle(),x=w.highlightToggle();d.linkTabToPanel(y.element(),t.element());d.linkTabToPanel(x.element(),
u.element());l.append(w.content(),t.element());l.append(w.content(),u.element());var z=g(w,t.element()),A=g(w,u.element()),D=a.flow(w.controls(),{item:b.constant(".ephox-pastry-statebutton")},c.flow({trigger:function(a,b){return q.descendant(a,".ephox-pastry-button").map(function(a){a.dom().click();return a})},executeOnArrow:!0})),B=a.multiple(w.element(),[D,z.grid,A.grid]);B.events.exit.bind(function(a){v.trigger.abort()});var C=function(){B.exit()},F=function(){u.hide();y.select();x.deselect();
e.tabSelected(y.element(),[x.element()]);t.show()};y.events.click.bind(function(){D.clickFocus(y.element());F()});x.events.click.bind(function(){D.clickFocus(x.element());t.hide();y.deselect();e.tabSelected(x.element(),[y.element()]);u.show()});return{element:w.element,destroy:function(){C();t.destroy();B.destroy();u.destroy();w.destroy()},open:function(){B.clear();B.refresh();y.click();F();B.enter()},close:C,events:v.registry}}});l("9f","7 54 9b hl 7b 59 4a 4b".split(" "),function(d,e,c,a,b,f,g,
h){return{widget:function(k){var m=k.content(),p=k.undo(),n=k.selections(),l=a(),q=g.create({color:h(["value"],l.events.color),highlight:h(["value"],l.events.highlight),done:f([]),abort:h([],l.events.abort)});l.events.color.bind(function(a){q.trigger.done();c.foreground(m,p,n,a.value());m.toEditing()});l.events.highlight.bind(function(a){q.trigger.done();c.background(m,p,n,a.value());m.toEditing()});return{element:l.element,name:d.constant("color"),textkey:d.constant(b.key("font.coloroption")),menuTextkey:d.constant(b.key("aria.color.menu")),
open:l.open,close:l.close,updateWidget:function(a){e.isHighContrast(k.smartview())?a.disable():l.open()},ability:d.noop,destroy:l.destroy,events:q.registry,label:d.constant(!1)}}}});l("xa",["7","s"],function(d,e){return function(){var c=e.none(),a=function(a){c.bind(function(c){c[a]()})};return{enter:d.curry(a,"enter"),exit:d.curry(a,"exit"),destroy:d.curry(a,"destroy"),set:function(a){c=e.some(a)}}}});l("pn","8b am gt 8y l3 an 53 hg hh 7 s xa 7b 34 59 4a 1a 1y 1b 3y l 2z 2p 3d 2r 2b 33 1s".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u,v,w,y,x,z,A,D,B,C,F,E){return function(G,E){var I=E.i18nNamespace(),K=E.cssNamespace(),J=s.create({plus:t([]),minus:t([]),validate:t([]),abort:t([])}),L=h(),N=h(),M=g.div(),O=g.div(),S=x.fromTag("input");d.label(S,l.translate(I+".stepper.input"));d.toolbarButton(L.element(),l.translate(I+".stepper.increase"),!1,!1);d.toolbarButton(N.element(),l.translate(I+".stepper.decrease"),!1,!1);u.set(S,"tabindex","-1");u.set(L.element(),"tabindex","-1");u.set(N.element(),
"tabindex","-1");v.add(O,q.resolve(K+"-stepper-input"));v.add(M,q.resolve(K+"-stepper-options"));v.add(L.element(),q.resolve("stepper-button"));L.content(k([q.resolve(K+"-stepper-increase")]));v.add(N.element(),q.resolve("stepper-button"));N.content(k([q.resolve(K+"-stepper-decrease")]));A.append(O,S);D.append(M,[L.element(),N.element()]);D.append(G,[O,M]);L.events.click.bind(function(){z.focus(L.element());J.trigger.plus()});N.events.click.bind(function(){z.focus(N.element());J.trigger.minus()});
var P=function(){S.dom().setSelectionRange(0,F.get(S).length)},T=y.capture(G,"click",function(a){w.eq(a.target(),O)&&Q.enter()}),Q=n(),V=v.toggler(S,q.resolve("invalid-"+K+"-size"));return{destroy:function(){L.destroy();N.destroy();Q.exit();Q.destroy();T.unbind();B.remove(S)},highlight:function(){V.on();u.set(S,"title",l.translate("aria.stepper.input.invalid"));e.shout(S,l.translate("aria.stepper.input.invalid"))},dehighlight:function(){V.off();u.remove(S,"title")},input:m.constant(S),focus:function(){z.focus(S);
P()},enter:Q.enter,exit:Q.exit,initLayout:function(){var d=a.single(S,[b.basic(f.ENTER()[0],function(){J.trigger.validate();return p.some(!0)})],p.none());d.events.enter.bind(P);var e=c.button({execute:function(a){a.dom().click();z.focus(a);return p.some(a)}}),d=a.multiple(G,[d,a.button(L.element(),e),a.button(N.element(),e)]);d.events.exit.bind(function(){C.parent(O).each(z.focus);J.trigger.abort()});Q.set(d)},events:J.registry}}});l("ho","53 7 pn pg ph 34 59 4a 4b 2v 1y 1b 3y 2r 33".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t){var s=m.immutableBag(["i18nNamespace","cssNamespace","property","tag","specials"],[]);return function(m){var v=s(m),w=d.div(),y=c(w,v);p.add(w,f.resolve(v.cssNamespace()+"-size-widget"));var x=function(){return t.get(y.input())},z=function(a){var c=x();a=a(c);a=b.sanitise(a);t.set(y.input(),a);A.trigger.action(a);y.dehighlight()};y.events.validate.bind(function(a){a=x();b.validate(a,v.tag(),v.property()).fold(function(){y.highlight()},function(a){t.set(y.input(),
a);A.trigger.action(a);y.dehighlight();A.trigger.close()})});y.events.plus.bind(function(b){z(e.curry(a.increase,v.specials()))});y.events.minus.bind(function(b){z(e.curry(a.decrease,v.specials()))});var A=h.create({close:g([]),action:g(["value"]),abort:k([],y.events.abort)}),D=l.bind(w,"click",function(a){(n.eq(a.target(),w)||n.eq(a.target(),y.input()))&&y.enter()});return{element:e.constant(w),input:y.input,getCurrentValue:x,focus:y.focus,enter:y.enter,initLayout:y.initLayout,destroy:function(){D.unbind();
y.destroy();q.remove(w)},updateInlineWidget:function(a,c){var d=function(a){b.validate(a,v.tag(),v.property()).each(function(a){t.set(y.input(),a);y.dehighlight()})};a.size().fold(function(){d(c);p.add(w,f.resolve("default-"+v.cssNamespace()+"-size"))},e.noop,function(a){d(a);p.remove(w,f.resolve("default-"+v.cssNamespace()+"-size"))})},open:e.noop,close:e.noop,events:A.registry}}});l("9g","8b 7 9b hm hn ho 7b hk 59 4a 4b 2z".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){return{widget:function(d,l){var t=
a.cata(l,e.constant(e.noop),e.constant(function(a){a.initLayout()})),s=d.content(),u=d.undo(),v=f(b.configuration());t(v);var w=m.create({done:k([]),abort:p([],v.events.abort)});v.events.close.bind(function(a){w.trigger.done()});v.events.action.bind(function(a){var b=n.active();s.focus();c.size(s,u,d.selections(),a.value());b.each(n.focus)});return{element:v.element,item:v.item,name:e.constant("size"),textkey:e.constant(g.key("font.size")),open:v.open,close:v.close,updateInlineWidget:function(){var a=
h.getState(d.selections(),s);v.updateInlineWidget(a.readState,a.fallbackSize)},ability:e.noop,destroy:v.destroy,events:w.registry}}}});l("hq","gu 7b gw 34 59 4a 1y 3y l 37".split(" "),function(d,e,c,a,b,f,g,h,k,m){return function(p,n,l,q){var t=l();l=c.okCancel("font-size");var s=d(n),u=null,v=f.create({close:b([]),open:b([]),analytics:b(["message"]),ok:b(["value"])});n=function(){u.unbind();s.hide();v.trigger.close()};s.setTitle(e.translate("font.size"));s.setContent(t.element());s.setControls(l.element());
s.events.close.bind(n);l.events.ok.bind(function(){v.trigger.ok(t.getCurrentValue())});l.events.cancel.bind(n);g.add(s.element(),a.resolve("widget-dialog"));return{show:function(){s.show();var a=k.fromDom(m);u=h.bind(a,"orientationchange",function(){p.foreground()});v.trigger.open()},element:s.element,contents:t,events:v.registry,destroy:function(){s.hide();s.destroy();t.destroy()}}}});l("9h","hp 7 9b hq hn ho 7b hk 59 4a 4b 1a 3y 3x".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q){return{widget:function(q,
s){var u=q.content(),v=q.smartview().uiContainer(),w=q.ui().tabstrip.element,y=q.undo(),x=f(b.configuration()),z=x.input(),A=d(w());n.set(z,"disabled","true");var D=l.bind(z,"touchstart",function(d){d.kill();A.closeMenus();var g=a(u,v,e.curry(f,b.configuration()));g.show();d=g.contents;var k=h.getState(q.selections(),u),m=function(){g.destroy();u.cursorIntoView()};d.updateInlineWidget(k.readState,k.fallbackSize);d.events.close.bind(m);d.events.action.bind(function(a){c.size(u,y,q.selections(),a.value())});
g.events.close.bind(g.destroy);g.events.ok.bind(function(a){c.size(u,y,q.selections(),a.value());m()})}),B=m.create({done:k([]),abort:p([],x.events.abort)});x.events.close.bind(function(a){B.trigger.done()});x.events.action.bind(function(a){c.size(u,y,q.selections(),a.value())});return{element:x.element,item:x.item,name:e.constant("size"),textkey:e.constant(g.key("font.size")),open:x.open,close:x.close,updateInlineWidget:function(){var a=h.getState(q.selections(),u);x.updateInlineWidget(a.readState,
a.fallbackSize)},ability:e.noop,destroy:function(){D.unbind();x.destroy()},events:B.registry}}}});l("9i","b ft 7l 6a 7j hr 21".split(" "),function(d,e,c,a,b,f,g){return{face:function(h){return c.toSelection(h.get()).map(function(c){var h=c.startContainer();c=d.contains(["td","th"],g.name(h))?e.freefallLtr(c.startContainer()).element():c.startContainer();c=f.value(c,"font-family");return a.isEmpty(c)?b.off():b.on(c)}).getOrThunk(b.unchanged)}}});l("5m","b c 7 s 9b 7f 7s 9c 9d 9e 9f 9g 9h 7b 9i 71 7j 59 4a".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u,v,w){return function(y,x){var z=y.content(),A=y.undo(),D=function(a){return d.map(a.split(/,\s?/g),function(a){return a.trim().replace(/^[\'\"](.*)[\'\"]$/,"$1")}).join(",")},B=(0===x.faces.length?a.none():a.some(x.faces)).fold(h.faces,function(b){return d.map(b,function(b){return k.face(q.raw(b.text),D(b.value),a.none())})}),C=e.detect().deviceType.isiOS(),F=w.create({analytics:v(["message","properties"])}),E=a.some(g.face),G=function(b){var c=D(b);b=d.find(B,
function(a){return a.value()===c});var e=k.face(q.raw(c),c,a.none());return void 0!==b&&null!==b?b:e},C=C?l:n,H=m(y,x);return{ui:s.ui({"fontface.dropdown":c.constant({name:"fontface",textkey:q.key("font.face"),menuTextkey:q.key("font.menu"),updateDropdown:function(b){var d=t.face(y.selections()).map(G);b.populate([{label:a.none,items:c.constant(B)}]);f.updateMenu(b,d,u.on(),B,E)},action:function(a){b.face(z,A,y.selections(),a)},values:B,render:E,describe:function(a){return q.translate("font.describe",
q.get(a.textkey()))},hasPopup:!0}),"fontcolor.widget":c.curry(p.widget,y),"fontsize.widget":c.curry(C.widget,y),"fontsize.general":H.general},c.identity),events:F.registry,destroy:c.noop}}});l("po","b 8b 30 h0 34 1a 1y 2z 32".split(" "),function(d,e,c,a,b,f,g,h,k){return function(h,p,n){var l=a(h,p,n);e.tabList(l.menu());d.map(l.tabs(),function(a){var d='.ephox-pastry-tablayout-content[data-ephox-pastry-tablayout-view="'+a.name()+'"]';f.set(a.element(),"tabindex","-1");g.add(a.element(),b.resolve("tab-button"));
k.descendant(l.body(),d).each(function(b){var d=c.generate("ephox-aria");f.set(a.element(),"id",d);e.tabButton(a.element(),a.name());e.tabPanel(b);e.linkTabToPanel(a.element(),b);e.labelledBy(b,d)})});return{element:l.element,tabs:l.tabs,body:l.body,menu:l.menu,destroy:l.destroy,events:l.events}}});l("xb","b 1o 7 1j 2o 32".split(" "),function(d,e,c,a,b,f){return function(g){var h=2===e.keys(g.integration).length,k=a.aboutTags(h,g.integration);return{content:function(a){return d.foldl(k,function(a,
b){return a.replace(b.str(),b.replace())},a)},dom:h?function(a){f.descendant(a,".ephox-polish-help-integration").each(function(a){b.set(a,"display","block")})}:c.noop}}});l("xc","8b 7 s 34 1y 3y l 2p 2r 32 o 37".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var l=function(a){var b=a.baseUrl;!0===a.source&&(b+="/licenses");return b+"/textbox-licenses.html"};return function(q,t,s){var u=c.none(),v=c.none(),w=l(s),y=function(a,b){var d=t.content(b.trim());u=c.some(d);x(a,d)},x=function(c,e){var f=g.fromHtml(e.trim());
t.dom(f);k.empty(c);b.remove(c,a.resolve("tablayout-loading"));z(f);var m=g.fromTag("div");d.document(m);h.append(m,f);h.append(c,m)},z=function(a){D();v=m.descendant(a,".ephox-license-link").map(function(a){return f.bind(a,"click",function(a){n.open(w,"","height=700,width=620,resizable=yes,scrollbars=yes")})})},A=function(a){q.get(function(b){b.fold(function(b){a("&nbsp;");p.error("Unable to download help article",b)},a)})},D=function(){v.each(function(a){a.unbind()})};return{render:function(c){u.fold(function(){b.add(c,
a.resolve("tablayout-loading"));A(e.curry(y,c))},function(a){x(c,a)})},destroy:function(){D()}}}});l("px",["6","vx","vy"],function(d,e,c){return{get:function(a,b,c,g){e.ajax(a,b,c,d.merge({dataType:"text",type:"GET"},g))},post:function(a,b,f,g,h){e.ajax(a,f,g,d.merge({dataType:"text",data:c.stringify(b),type:"POST"},h))}}});l("i1",["px","2m","p"],function(d,e,c){return{get:function(a,b){return e.nu(function(e){d.get(a,function(a){e(c.value(a))},function(a,b,d){e(c.error({message:a,status:b,text:d}))},
b)})}}});l("xd","a 1o 4o i1 7 p 1f 1j o".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(a,b){return a.map(function(a){return a.bind(function(a){var c=a[b];return void 0===c?f.error("Cannot find method "+b+" in help article list: "+e.keys(a)):d.isFunction(c)?f.value(c()):f.error("Key "+b+" in help article list was not a function")})})},p=function(a){a=c.addScript(a,b.identity);a.get(function(a){a.each(function(a){h.weakMatch(a.version,"Help articles").each(function(a){k.warn(a)})})});return{about:m(a,
"about"),accessibility:m(a,"accessibility"),a11ycheck:m(a,"a11ycheck"),markdown:m(a,"markdown"),shortcuts:m(a,"shortcuts")}};return function(b){!0===b.source?(b=b.baseUrl+"/help/"+g.get()+"/",b={about:a.get(b+"about.html"),accessibility:a.get(b+"accessibility.html"),a11ycheck:a.get(b+"a11ycheck.html"),markdown:a.get(b+"markdown.html"),shortcuts:a.get(b+"shortcuts.html")}):b=p(b.baseUrl+"/help_"+g.get()+".js?"+h.resourceParam());return b}});l("pp","c h2 7 s k xb xc xd 7b".split(" "),function(d,e,c,
a,b,f,g,h,k){var m=function(b,c){return b?a.some(c):a.none()};return function(a){var n={content:c.identity,dom:c.noop},l=d.detect(),q=h(a),l=!l.deviceType.isTouch();a=[m(l,e(k.translate("help.dialog.shortcuts"),g(q.shortcuts,n,a))),m(l,e(k.translate("help.dialog.accessibility"),g(q.accessibility,n,a))),m(!0,e(k.translate("help.dialog.markdown"),g(q.markdown,n,a))),m(l,e(k.translate("help.dialog.a11ycheck"),g(q.a11ycheck,n,a))),m(!0,e(k.translate("help.dialog.about"),g(q.about,f(a),a)))];return b.cat(a)}});
l("hs","b gt 8y h3 7 gu gv po pp 7b 3q 34 59 4a 1a 1y 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u){var v=function(a){var d={item:b.constant(".ephox-pastry-statebutton.ephox-pastry-tablayout-item")},f=e.flow({trigger:g.button,executeOnArrow:!0});return c.flow(a.menu(),d,f)},w=function(a){var d={stops:b.constant(["a"])},f=e.page({trigger:g.click,first:".ephox-pastry-tablayout-active"});return c.page(a.body(),d,f)};return function(b,e){var g=q.create({close:l([])}),A=f(b),D=k(e),B=h(a.left(),
D,"help");t.set(B.body(),"tabindex","-1");s.add(A.element(),n.resolve("help-modal"));var C=u.children(B.element());d.each(C,p.register);A.setTitle(m.translate("cog.help"));A.setContent(B.element());var F=v(B),C=w(B),E=c.multiple(A.element(),[F,C]);B.events.setActive.bind(function(a){F.clickFocus(a.item().element())});var G=function(){A.hide()};A.events.close.bind(function(){E.exit();G()});E.events.exit.bind(function(){G();g.trigger.close()});return{element:A.element,open:function(){A.show();E.enter()},
destroy:function(){B.destroy();A.destroy();E.destroy();d.each(D,function(a){a.renderer().destroy()})},hide:G,events:g.registry}}});l("9j",["hs","59","4a","q"],function(d,e,c,a){return function(a,f){var g=d(a,f),h=function(){k.trigger.analytics("help_screen_hide");k.trigger.close();m()},k=c.create({close:e([]),analytics:e(["message"])});g.events.close.bind(h);var m=function(){g.events.close.unbind(h);g.destroy()};return{show:function(){k.trigger.analytics("help_screen_show");g.open()},destroy:m,events:k.registry}}});
l("5n","7 79 9j 7b 71 7c 59 4a 3x".split(" "),function(d,e,c,a,b,f,g,h,k){return function(k,p){var n=k.content(),l=k.smartview(),q=k.shortcuts(),t=h.create({analytics:g(["message"])}),s=e.destroyable(),u=function(){var a=c(l.uiContainer(),p);s.set(a);a.events.close.bind(function(){n.toEditing();s.clear()});a.events.analytics.bind(function(a){t.trigger.analytics(a.message())});n.toReading();k.content().hideInlineSelection();a.show()};q.events.help.bind(u);return{ui:b.ui({"help.general":{toggle:!1,
value:"help",textkey:a.key("cog.help"),action:u,updateGeneral:d.noop,icon:!0,hasPopup:!1,hasDialog:!0,tooltip:f.get}}),events:t.registry,destroy:function(){s.clear()}}}});l("9l",["2v"],function(d){return d.immutable("prefix","suffix","style")});l("9m","b s 9k 4e 2o l 2p 3d 21 2r az 2b v".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l){return{rehighlight:function(q,t,s){var u=n.children(s),v=d.bind(u,function(a){return k.isText(a)?p.get(a):""}).join("");e.from(d.find(t,function(a){return l.startsWith(v,
a.prefix())&&l.endsWith(v,a.suffix())})).fold(function(){q.preserve(function(){m.unwrap(s)})},function(d){var e=f.fromTag("span");a.add(e,[c.highlightClass()]);b.setAll(e,d.style());q.preserve(function(){g.before(s,e);h.append(e,u);m.remove(s)})})},unhighlight:function(b,d){var e=n.children(d),k=f.fromTag("span");a.add(k,[c.placeholderClass()]);b.preserve(function(){g.before(d,k);m.unwrap(d);h.append(k,e)})}}});l("9n","b 7 ht hu 6o hv hw 9k hx fq cw 4e 2o l 21 6m az".split(" "),function(d,e,c,a,b,
f,g,h,k,m,p,n,l,q,t,s,u){var v=function(a,c){var f=d.bind(c,function(a){var c=b.sanitise(a.prefix()),d=b.sanitise(a.suffix()),c=b.unsafetoken(c+"[^"+d+"]*"+d);return{pattern:e.constant(c),style:a.style}});return g.findmany(a,f)},w=m("."+h.highlightClass(),p.unwrap);return{run:function(b,e){b.body().each(function(b){k.filterDom(b,[w]);b=s.descendants(b,t.isText);d.each(b,function(b){var g=u.get(b),g=v(g,e),k=d.bind(g,function(a){return[a.start(),a.finish()]}),m=c.subdivide(b,k);d.each(g,function(b){var c=
f.sublist(m,b.start(),b.finish()),c=d.map(c,function(a){return a.element()});a.wrapper(c,function(){var c=q.fromTag("span");n.add(c,[h.highlightClass()]);l.setAll(c,b.style());return a.nu(c)})})})})}}});l("5o","b 7 9k 9l 9m 9n 3j 4e 2o l 2g 2p 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l){return function(q,t,s){var u=q.filter(),v=q.content(),w=q.operations();c.configure(u);var y=void 0===s.external?[]:d.map(s.external,function(b){return a(b.prefix,b.suffix,b.style)});d.each(y,function(a){var b=
g(a.prefix(),a.suffix(),function(b){var d=m.fromTag("span");h.add(d,[c.highlightClass()]);k.setAll(d,a.style());var e=m.fromTag("div");n.append(d,m.fromText(a.prefix()+b+a.suffix()));n.append(e,d);return p.get(e)});t.customMacros().add(b)});q=function(a){v.getSelection().each(function(d){a.prev().each(function(a){l.ancestor(a,"."+c.placeholderClass()).each(function(a){b.rehighlight(w,y,a)})});l.ancestor(d.startContainer(),"."+c.highlightClass()).each(function(a){b.unhighlight(w,a)})})};return 0<y.length?
(v.events.nodeChanged.bind(q),{run:function(){f.run(v,y)},destroy:e.noop}):{run:e.noop,destroy:e.noop}}});l("5p","9o 7 83 7b 71 l".split(" "),function(d,e,c,a,b,f){return function(g){var h=g.content();return{ui:b.ui({"horizontalrule.general":{toggle:!1,value:"horizontalrule",textkey:a.key("insert.horizontalrule"),action:function(){c.insertAtCursor(h,[f.fromTag("hr")]).each(function(a){a=d.after(a.element());h.setRelativeSelection(a,a);h.toEditing()})},updateGeneral:e.noop,icon:!0,shortcut:!1,hasPopup:!1}}),
destroy:e.noop}}});l("pu","b am 6 7 p 7b 34 2v 1y 2o l 4h 33 e2".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q){var t=g.resolve("input-invalid-field"),s=function(a){return q(a,10).toString()===a&&0<=q(a,10)},u=function(a,c,d){var e=l.get(a);if(""===e)return b.value("");var f=p.fromTag("img");d=s(e)?e+d.getOr(""):e;m.set(f,c,d);d=m.getRaw(f,c);m.remove(f,c);return d.fold(function(){return b.error(a)},b.value)},v=function(a){k.remove(a,t)};return{highlight:function(a){e.shout(a,f.translate("aria.input.invalid"));
k.add(a,t)},dehighlight:v,clearHighlights:function(a){a=n.descendants(a,"."+t);d.each(a,v)},validate:function(e){return d.foldr(e,function(b,d){return b.bind(function(b){return u(d.input(),d.property(),d.defaultUnit()).map(function(e){l.set(d.input(),e);var f={};f[d.property()]=a.constant(e);return c.deepMerge(f,b)})})},b.value({}))},validateField:u,rule:h.immutable("input","property","defaultUnit")}});l("pv","b 8b fh 30 c 53 hg 7 gv 7b 34 1a 1y l 2z 2p 3d 32 2b".split(" "),function(d,e,c,a,b,f,g,
h,k,m,p,n,l,q,t,s,u,v,w){b.detect().browser.isFirefox();return function(b){var x=p.resolve("dialog-float-selected"),z=q.fromTag("fieldset");n.set(z,"role","radiogroup");b=q.fromHtml("<legend>"+m.translate(b)+"</legend>");var A=a.generate("ephox-aria");n.set(b,"id",A);n.set(z,"aria-labelledby",A);var D=f.div();l.add(D,p.resolve("dialog-float-options"));u.append(z,[b,D]);var B=function(){d.each(C,function(a){l.remove(a.element(),x);c.checked(a.element(),!1)})},C=d.map(["none","center","left","right"],
function(a){var b=g(),d=m.translate("align."+a);n.setAll(b.element(),{tabindex:"-1","data-float-value":a,title:d,"aria-label":d,role:"radio"});a=f.div();var d=f.div(),h=f.div(),k=f.div();e.hidden(a,!0);l.add(d,p.resolve("dialog-float-icon-inner-left"));l.add(h,p.resolve("dialog-float-icon-inner-center"));l.add(k,p.resolve("dialog-float-icon-inner-right"));u.append(a,[d,h,k]);b.events.click.bind(function(){B();l.add(b.element(),x);c.checked(b.element(),!0);t.focus(b.element())});l.add(b.element(),
p.resolve("dialog-float-container"));l.add(a,p.resolve("dialog-float-icon"));s.append(b.element(),a);return b});u.append(D,d.map(C,function(a){return a.element()}));var F=k.radio(z,"."+p.resolve("dialog-float-container"),"."+p.resolve("dialog-float-selected"));return{element:function(){return z},get:function(){return v.child(D,"."+x).map(function(a){return n.get(a,"data-float-value")})},select:function(a){B();a.each(function(a){v.child(D,'span[data-float-value="'+a+'"]').or(w.firstChild(D)).each(function(a){l.add(a,
x);c.checked(a,!0)})});F.refresh()},keylayout:h.constant(F),destroy:function(){d.each(C,function(a){a.destroy()})}}}});l("pw",["s","x7","2v","1s"],function(d,e,c,a){var b=c.immutable("size","unit"),f=function(a){return e.identify(a).fold(d.none,function(a,c,e){return d.some(b(c,e))})};return{fromHeight:function(b,c){return f(c).map(function(c){return a.ceil(b*c.size())+c.unit()})},fromWidth:function(b,c){return f(c).map(function(c){return a.ceil(1/b*c.size())+c.unit()})},calculate:function(a,b){return f(a).fold(d.none,
function(a){return f(b).fold(d.none,function(b){return d.some((a.size()+0)/(b.size()+0))})})}}});l("hy","8b fh 30 gt 8y 53 hh lp 7 s gv lq pu pv 9q 7b pw 34 1a 1y 1b 3y l 2z 3d 33 1v e2".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u,v,w,y,x,z,A,D,B,C,F,E){return function(){var G=f.div(),E=f.div(),I=f.div(),K=f.div();y.add(I,v.resolve("image-url-controls"));y.add(K,v.resolve("image-size-controls"));var J=q("image.dialog.fields.align"),L=n.input("image-url","image.dialog.fields.url"),N=n.input("image-alt",
"image.dialog.fields.alt"),M=n.input("image-width","image.dialog.fields.width"),O=n.input("image-height","image.dialog.fields.height"),S=A.fromTag("input");w.set(S,"type","hidden");var P=h("lock");y.add(P.element(),v.resolve("dialog-button"));var T=g([v.resolve("icon"),v.resolve("image-lock-button")]);w.set(P.element(),"title",s.translate("image.dialog.fields.constrain.on"));d.toolbarButton(P.element(),s.translate("image.dialog.fields.constrain.label"),!1,!0);e.press(P.element());P.select();P.content(T);
P.events.click.bind(function(){D.focus(P.element());var a=P.selected()?"on":"off";w.set(P.element(),"title",s.translate("image.dialog.fields.constrain."+a));(P.selected()?e.press:e.release)(P.element())});T=f.div();y.add(T,v.resolve("form-group"));y.add(T,v.resolve("form-group-lock"));var Q=A.fromHtml("<label>"+s.translate("image.dialog.fields.constrain.label")+"</label>"),V="constrain"+c.generate("");w.set(P.element(),"id",V);w.set(Q,"for",V);var W=function(a){a.isLocal()?(w.set(L.input(),"disabled",
"disabled"),C.set(L.input(),s.translate("image.dialog.fields.urllocal"))):(w.remove(L.input(),"disabled"),C.set(L.input(),a.url()))},$=function(a,b,c){var d=F(C.get(S),10);a=C.get(a);C.set(b,c(d,a).getOrThunk(function(){return C.get(b)}));l.dehighlight(b)},V=function(a){l.validateField(a.target(),"width",m.some("px")).fold(function(){l.highlight(a.target())},function(b){l.dehighlight(a.target());b=a.target();P.selected()&&(x.eq(b,M.input())?$(M.input(),O.input(),u.fromWidth):x.eq(b,O.input())&&$(O.input(),
M.input(),u.fromHeight))})},X=function(a){if(w.has(a.target(),"placeholder")){var b=w.get(a.target(),"placeholder");""===C.get(a.target())&&C.set(a.target(),b)}},Y=z.bind(M.input(),"input",V),da=z.bind(O.input(),"input",V),R=z.bind(M.input(),"focus",X),ca=z.bind(O.input(),"focus",X);B.append(T,[Q,P.element()]);B.append(E,[J.element()]);B.append(I,[L.element(),N.element()]);B.append(K,[M.element(),O.element(),T]);B.append(G,[I,K,E]);E=[b.input(L.input(),a.input({})),b.input(N.input(),a.input({})),
b.input(M.input(),a.input({})),b.input(O.input(),a.input({})),b.button(P.element(),a.button({execute:p.button})),J.keylayout()];return{element:k.constant(G),destroy:function(){P.destroy();Y.unbind();da.unbind();R.unbind();ca.unbind();J.destroy()},dehighlight:k.curry(l.clearHighlights,G),highlight:l.highlight,keylayouts:k.constant(E),set:function(a){W(a);C.set(N.input(),a.alt());C.set(M.input(),a.width());C.set(O.input(),a.height());var b=a.computedWidth().bind(function(b){return a.computedHeight().bind(function(a){return u.calculate(b,
a)})}).getOr(1);a.computedWidth().each(k.curry(w.set,M.input(),"placeholder"));a.computedHeight().each(k.curry(w.set,O.input(),"placeholder"));C.set(S,b);J.select(a.align())},get:function(){return l.validate([l.rule(M.input(),"width",m.some("px")),l.rule(O.input(),"height",m.some("px"))]).map(function(a){return t.properties({url:C.get(L.input()),alt:C.get(N.input()),width:a.width(),height:a.height(),isLocal:w.has(L.input(),"disabled"),align:J.get()})})}}}});l("9p","s gu gv 9q hy 7b gw 34 59 4a 4p 1y".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n){return function(l){var q=m.create({ok:k(["image","properties"]),close:k([])}),t=p(d.none()),s=e(l),u=g.okCancel("image-properties"),v=b();s.setContent(v.element());n.add(s.element(),h.resolve("dialog-narrow"));l=function(){var a=v.get();v.dehighlight();a.fold(function(a){v.highlight(a)},function(a){t.get().each(function(b){q.trigger.ok(b,a)})})};u.events.ok.bind(l);u.events.cancel.bind(function(){s.hide();q.trigger.close()});s.setTitle(f.translate("image.dialog.title"));
s.setControls(u.element());s.events.close.bind(function(){q.trigger.close()});var w=c.setup(s,u,v.keylayouts());return{element:s.element,open:function(){s.show();w.enter()},hide:function(){w.exit();s.hide()},destroy:function(){s.destroy();w.destroy();u.destroy();v.destroy()},represent:function(b){var c=a.divine(b);t.set(d.some(b));v.set(c)},execute:l,events:q.registry}}});l("9r","b 7 s 7b 59 4a 2v 1a 21".split(" "),function(d,e,c,a,b,f,g,h,k){var m=g.immutable("value","text","attrs"),p=function(a){return"img"===
k.name(a)};return{image:function(){var d=c.none(),g=f.create({properties:b(["image"]),contextmenu:b(["image"])});return{situation:function(b){b=d.map(function(b){return[m("imagemenu-properties",a.translate("image.context.properties"),{})]}).getOr([]);return{primary:e.constant(b),secondary:e.constant([]),submenus:e.constant([])}},handle:function(a){d.each(function(a){g.trigger.properties(a)})},assign:function(a){d=a.filter(p);d.each(g.trigger.contextmenu)},events:g.registry}},imageEdit:function(b,
f,g){var k=c.none(),l=function(b){return d.map(b,function(b){return m(b.spec.value,a.get(b.spec.textkey),{})})};return{situation:function(a){a=k.map(l).getOr([]);return{primary:e.constant(a),secondary:e.constant([]),submenus:e.constant([])}},handle:function(a){k.each(function(b){var c=h.get(a,"data-ephox-gopher-item-value");b=d.find(b,function(a){return a.spec.value===c});void 0!==b&&b.spec.action()})},assign:function(a){k=b()?c.some(f):a.filter(p).map(e.constant(g))}}}}});l("9s",["59","4a","4b"],
function(d,e,c){return{generate:function(a,b,f){a=function(){h();g.trigger.close()};var g=e.create({ok:c(f,b.events.ok),close:d([])});b.events.close.bind(a);var h=function(){b.destroy()};return{open:function(){b.open()},hide:a,destroy:h,represent:b.represent,events:g.registry}}}});l("5q","7 9p 9q 9r 9s 59 4a 4b".split(" "),function(d,e,c,a,b,f,g,h){return function(k,m){var p=a.image(k.content()),n=g.create({changed:f(["image"]),contextmenu:h(["image"],p.events.contextmenu)}),l=function(a){var d=k.content(),
f=e(k.smartview().uiContainer()),g=b.generate(k.keyboard(),f,["image","properties"]);g.events.ok.bind(function(a){c.apply(a.image(),a.properties());n.trigger.changed(a.image());g.destroy();d.domChanged();d.focus();d.uiChanged()});g.events.close.bind(function(a){g.destroy();d.focus()});g.represent(a);g.open()};p.events.properties.bind(function(a){l(a.image())});return{destroy:d.noop,situation:p.situation,handle:p.handle,assign:p.assign,events:n.registry}}});l("9u","b 1o 7 h6 4q 1a 2o".split(" "),function(d,
e,c,a,b,f,g){var h=b.generate([{html:["key","value"]},{css:["key","value"]}]),k=function(a,b){return d.flatten(e.mapToArray(a,function(a,c){var d=[];if(f.has(b,c)){var e=f.get(b,c);d.push(h.html(a,e))}g.getRaw(b,c).each(function(b){d.push(h.css(a,b))});return d}))},m=function(a){g.remove(a,"width");g.remove(a,"height");f.remove(a,"width");f.remove(a,"height")};b=c.curry(k,{width:"width",height:"height"});k=c.curry(k,{width:"height",height:"width"});c=c.constant([]);return{keepCrop:c,keepFlip:b,keepRotate:k,
keepResample:c,updater:function(b,c){var e=b(c);return a.effect(function(){m(c);d.each(e,function(a){a.fold(function(a,b){f.set(c,a,b)},function(a,b){g.set(c,a,b)})})})}}});l("i0",["6"],function(d){var e={strictMode:!1,key:"source protocol authority userInfo user password host port relative path directory file query anchor".split(" "),q:{name:"queryKey",parser:/(?:^|&)([^&=]*)=?([^&]*)/g},parser:{strict:/^(?:([^:\/?#]+):)?(?:\/\/((?:(([^:@\/]*)(?::([^:@\/]*))?)?@)?([^:\/?#]*)(?::(\d*))?))?((((?:[^?#\/]*\/)*)([^?#]*))(?:\?([^#]*))?(?:#(.*))?)/,
loose:/^(?:(?![^:@\/]+:[^:@\/]*@)([^:\/?#.]+):)?(?:\/\/)?((?:(([^:@\/]*)(?::([^:@\/]*))?)?@)?([^:\/?#]*)(?::(\d*))?)(((\/(?:[^?#](?![^?#\/]*\.[^?#\/.]+(?:[?#]|$)))*\/?)?([^?#\/]*))(?:\?([^#]*))?(?:#(.*))?)/}},c=function(a,b){for(var c=b.parser[b.strictMode?"strict":"loose"].exec(a),d={},e=14;e--;)d[b.key[e]]=c[e]||"";d[b.q.name]={};d[b.key[12]].replace(b.q.parser,function(a,c,e){c&&(d[b.q.name][c]=e)});return d};return{parse:function(a,b){var f=d.merge(e,b);return c(a,f)}}});l("hz",["v","i0","w"],
function(d,e,c){var a=function(a){return""!==a.trim()&&!d.contains(a,"://")};return{local:function(a){return d.startsWith(a,"data:")||d.startsWith(a,"blob:")||d.startsWith(a,"file:")},relative:a,sameDomain:function(b,c){if(""===b.trim()||""===c.trim())return!1;if(a(b))return!0;var d=e.parse(c),h=e.parse(b);return d.host===h.host&&d.port===h.port}}});l("9v",["hz","96","2v","i0"],function(d,e,c,a){var b=c.immutable("bannerMessage","consoleMessage"),f=function(a){return void 0!==a.message&&void 0!==
a.status&&void 0!==a.text};return{diagnoseImageEdit:function(c,h){var k=18===c.code||"SecurityError"===c.name?"imageedit.needsproxy":f(c)&&0===c.status?"imageedit.proxyerror":"imageedit.generic",m;m=a.parse(h);m=""===m.host||d.relative(h)?h:""===m.port?m.host:m.host+":"+m.port;k=e.get(k,[m]);m=f(c)?c.message+". Response code "+c.status+". Error details: "+c.text:c;return b(k,m)}}});l("i2",["py"],function(d){return{blobToImage:function(e){return d.blobToImage(e)},imageToBlob:function(e){return d.imageToBlob(e)},
blobToDataUri:function(e){return d.blobToDataUri(e)},blobToBase64:function(e){return d.blobToBase64(e)}}});l("9w","1 6 i1 s h6 hz 1a i2 w".split(" "),function(d,e,c,a,b,f,g,h,k){return function(m){var p={responseType:"blob"},n=function(a,b){var d=e.merge(b||{},m.headers(),p);return c.get(a,d)},l=function(a){return!(f.local(a)||f.sameDomain(a,k(d.location)))};return{getImage:function(c){var d=g.get(c,"src");return(l(d)?m.proxy(d):a.none()).fold(function(){return b.fromPromise(h.imageToBlob(c.dom()))},
n)}}}});l("9x",["7","7b","7c"],function(d,e,c){return{make:function(a,b,f){return{type:"general",spec:{value:a,textkey:e.key(b),action:f,updateGeneral:d.noop,icon:!0,hasPopup:!1,toggle:!1,tooltip:c.get}}}}});l("6l",["4j","7"],function(d,e){var c=e.constant(4);return{resolve:d.create("ephox-clipper").resolve,CORNER_SIZE:c}});l("pz","6l 3w 7 1a 1y 2o 3y l 3d 1s e2".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=function(a,b){var d={left:"0px",top:"0px",width:a.width()+"px",height:a.height()+"px"},
e={left:f.get(b,"left"),top:f.get(b,"top"),width:f.get(b,"width"),height:f.get(b,"height")};return{outside:c.constant(d),inside:c.constant(e)}};return{snap:function(c,l){var t=n(c,l),s=h.fromTag("div");b.add(s,d.resolve("dynamic-box"));f.setAll(s,t.outside());var u=h.fromTag("div");b.add(u,d.resolve("opaque-box"));f.setAll(u,t.outside());var v=function(a,b){return 2<m.abs(p(a,10)-p(b,10))},w=function(a){return e.nu(function(b){b(a)})},y=function(a,b){return e.nu(function(c){var d=g.bind(a,"transitionend",
function(){d.unbind();c(a)});f.setAll(a,b.inside())})};return{prepare:function(c,e,g){var h=a.get(e,"src"),m=f.get(e,"width");e=f.get(e,"height");f.setAll(l,{"background-image":"url("+h+")","background-size":m+" "+e,"background-position-x":-g.left()+"px","background-position-y":-g.top()+"px"});b.add(l,d.resolve("snapshot"));b.add(s,d.resolve("dynamic-box-animate"));k.append(c,[s,u]);f.reflow(c)},showcase:function(){var a=t.outside(),b=t.inside();return v(a.left,b.left)||v(a.top,b.top)||v(a.right,
b.right)||v(a.bottom,b.bottom)?y(s,t):w(s)}}}}});l("i3",["pz","3w","7"],function(d,e,c){return{slide:function(){return{animate:function(a,b,e,g){e=d.snap(e.box(),e.shade());e.prepare(a,b,{left:g.cropX,top:g.cropY,width:g.cropWidth,height:g.cropHeight});return e.showcase().map(c.constant(g))}}},none:function(){return{animate:function(a,b,c,d){return e.pure(d)}}}}});l("q0",["2v"],function(d){return d.immutableBag("displayWidth displayHeight cropX cropY cropWidth cropHeight".split(" "),[])});l("xe",
["3y","3x"],function(d,e){return{bind:function(c,a){return d.bind(c,"mousedown",function(b){b.kill();var c=b.target(),g=!1,h=d.bind(c,"mouseup",function(){g=!0;h.unbind()});e(function(){g||(h.unbind(),a(c))},250)})}}});l("q2",["2v"],function(d){var e=d.immutableBag(["top","left","width","height"],[]),c=d.immutableBag(["top","left"],[]);d=d.immutableBag(["top","left"],[]);return{boxModel:e,delta:c,cornersMovements:d}});l("xf",["q2","1s"],function(d,e){var c=function(a,b){var c=e.min(a.top()+a.height(),
e.max(0,a.top()+b.top())),d=c-a.top(),d=a.height()-d;return{top:c,height:d}},a=function(a,b,c){a=e.min(a.width(),e.max(b.left(),b.left()+b.width()+c.left()))-b.left()-b.width();return{width:b.width()+a}},b=function(a,b,c){return e.min(a.height(),e.max(b.top(),b.top()+c.top()+b.height()))-b.top()},f=function(a,b){var c=e.min(a.width()+a.left(),e.max(0,a.left()+b.left())),d=c-a.left(),d=a.width()-d;return{left:c,width:d}};return{nw:function(a,b,e){a=c(b,e);b=f(b,e);return d.boxModel({left:b.left,width:b.width,
top:a.top,height:a.height})},n:function(a,b,e){a=c(b,e);return d.boxModel({left:b.left(),width:b.width(),top:a.top,height:a.height})},ne:function(b,e,f){var m=c(e,f);b=a(b,e,f);return d.boxModel({left:e.left(),width:b.width,top:m.top,height:m.height})},e:function(b,c,e){b=a(b,c,e);return d.boxModel({left:c.left(),width:b.width,top:c.top(),height:c.height()})},se:function(c,e,f){var m=a(c,e,f);c=b(c,e,f);return d.boxModel({left:e.left(),width:m.width,top:e.top(),height:c})},s:function(a,c,e){a=b(a,
c,e);return d.boxModel({left:c.left(),width:c.width(),top:c.top(),height:a})},sw:function(a,c,e){a=b(a,c,e);e=f(c,e);return d.boxModel({left:e.left,width:e.width,top:c.top(),height:a})},w:function(a,b,c){a=f(b,c);return d.boxModel({left:a.left,width:a.width,top:b.top(),height:b.height()})},translate:function(a,b,c){var f=e.min(e.max(0,b.top()+c.top()),e.max(0,a.height()-b.height()));a=e.min(e.max(0,b.left()+c.left()),e.max(0,a.width()-b.width()));return d.boxModel({top:f,left:a,width:b.width(),height:b.height()})}}});
l("xg",["l3","an","s","3o"],function(d,e,c,a){return{navigation:function(b,f){var g=function(b,d,e){return function(){f(b,a(d,e));return c.some(!0)}};return[d.rule(d.and([d.isShift,d.inSet(e.LEFT())]),g(b,-1,0)),d.rule(d.and([d.isShift,d.inSet(e.RIGHT())]),g(b,1,0)),d.rule(d.and([d.isShift,d.inSet(e.UP())]),g(b,0,-1)),d.rule(d.and([d.isShift,d.inSet(e.DOWN())]),g(b,0,1)),d.basic(e.LEFT()[0],g(b,-10,0)),d.basic(e.RIGHT()[0],g(b,10,0)),d.basic(e.UP()[0],g(b,0,-10)),d.basic(e.DOWN()[0],g(b,0,10))]}}});
l("115",["6l","q2","1o","6","7"],function(d,e,c,a,b){var f=function(a,c,d){var f=c.top(),p=c.left()+c.width()/2-d.middle(),n=f+c.height()/2-d.middle(),l=c.left()+c.width()-d.right();a=c.left()-d.left();d=f+c.height()-d.bottom();c=e.cornersMovements({top:f,left:p});var p=e.cornersMovements({top:d,left:p}),q=e.cornersMovements({top:n,left:l}),n=e.cornersMovements({top:n,left:a}),t=e.cornersMovements({top:f,left:a}),f=e.cornersMovements({top:f,left:l}),l=e.cornersMovements({top:d,left:l});a=e.cornersMovements({top:d,
left:a});return{n:b.constant(c),s:b.constant(p),e:b.constant(q),w:b.constant(n),nw:b.constant(t),ne:b.constant(f),se:b.constant(l),sw:b.constant(a)}};return{calculate:function(a,c){var e={middle:b.constant(2*d.CORNER_SIZE()+1),right:b.constant(d.CORNER_SIZE()),left:b.constant(0),bottom:b.constant(d.CORNER_SIZE())};return f(a,c,e)},limitBounds:function(d,e){var f={};if(20>e.width()){var m=20-e.width();f.width=e.width()+m;f.left=e.left()===d.left()?d.left():e.left()-m}20>e.height()&&(m=20-e.height(),
f.height=e.height()+m,f.top=e.top()===d.top()?d.top():e.top()-m);return a.merge(e,c.map(f,b.constant))},doCalculate:f}});l("xj",["115","6l","q2","1a","2o"],function(d,e,c,a,b){var f=function(b){return c.boxModel({left:parseInt(a.get(b,"data-"+e.resolve("image-left")),10),top:parseInt(a.get(b,"data-"+e.resolve("image-top")),10),width:parseInt(a.get(b,"data-"+e.resolve("image-width")),10),height:parseInt(a.get(b,"data-"+e.resolve("image-height")),10)})},g=function(b,c){a.set(b,"data-"+e.resolve("image-left"),
c.left());a.set(b,"data-"+e.resolve("image-top"),c.top());a.set(b,"data-"+e.resolve("image-width"),c.width());a.set(b,"data-"+e.resolve("image-height"),c.height())};return{readPosition:f,writePosition:g,updatePosition:function(a,b){var c=f(a),e=b(c),c=d.limitBounds(c,e);g(a,c);return c},drawAtOrigin:function(a){var c=f(a);b.setAll(a,{left:c.left()+"px",top:c.top()+"px",width:c.width()+"px",height:c.height()+"px"})}}});l("xh",["q2","xj","s"],function(d,e,c){return function(a,b,f){var g=c.none();return{setTarget:function(a){g=
c.some(a)},clearTarget:function(){g=c.none()},mutate:function(c,k){g.each(function(g){var p=d.delta({top:k,left:c}),n=e.updatePosition(f,function(b){return g(a,b,p)});e.drawAtOrigin(f,a);b.update(n)})}}}});l("4c",["6l","7"],function(d,e){var c=d.resolve("magic-box");return{magicBox:e.constant(c)}});l("xn",["1a"],function(d){return{grab:function(e,c){d.set(e,"aria-grabbed",c)},effect:function(e,c){d.set(e,"aria-dropeffect",c)}}});l("xo","8b d4 30 2v 1a 1y l 2p".split(" "),function(d,e,c,a,b,f,g,h){var k=
a.immutable("help","ids"),m=function(a){b.set(a,"role","gridcell")};return{base:function(a,c){b.setAll(a,{role:"grid","aria-label":c})},row:function(a){b.set(a,"role","row")},cell:function(a,c){m(a);b.set(a,"aria-label",c)},gridcell:m,createHelp:function(a,m,l){var q=g.fromTag("div");d.presentation(q);f.add(q,e.resolve("aria-help"));for(var t=[],s=0;s<m;s++){var u=c.generate("ephox-aria"),v=g.fromTag("span");d.presentation(v);b.set(v,"id",u);f.add(v,e.resolve("aria-help"));h.append(v,g.fromText(l.col(s+
1)));h.append(q,v);t[s]=u}s=[];for(u=0;u<a;u++){var v=c.generate("ephox-aria"),w=g.fromTag("span");d.presentation(w);b.set(w,"id",v);f.add(w,e.resolve("aria-help"));h.append(w,g.fromText(l.row(u+1)));h.append(q,w);s[u]=[];for(w=0;w<m;w++)s[u][w]=t[w]+" "+v}return k(q,s)}}});l("116","115 xg 6l b xn xo 8y 2m 7 s 59 4a 1a 4e 2o l 68 2p 2s 3x w".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u,v,w,y,x){var z=function(a,d,e){var g=s.fromTag("div");t.set(g,"position","absolute");var h=s.fromTag("div");
v.append(g,h);e.each(function(a){f.cell(g,a);b.grab(g,!1)});q.add(g,[c.resolve("corner-wrapper"),c.resolve("corner-wrapper-"+d)]);q.add(h,[c.resolve("corner-element"),c.resolve("corner-"+a)]);l.set(g,"data-"+c.resolve("direction"),d);return g},A=function(a,b){t.setAll(a,{top:b.top()+"px",left:b.left()+"px"})},D=function(b,c,d){var e=c()<d()?0:1;a.each(b,function(a){t.set(a,"opacity",x(e))})};return function(a){var b=n.create({reposition:p(["direction","delta"])}),c=z("top","n",m.none()),f=z("bottom",
"s",m.none()),l=z("right","e",m.none()),r=z("left","w",m.none()),q=z("top-left","nw",m.some(a("image.crop.handle.nw"))),s=z("top-right","ne",m.some(a("image.crop.handle.ne"))),v=z("bottom-right","se",m.some(a("image.crop.handle.se"))),x=z("bottom-left","sw",m.some(a("image.crop.handle.sw"))),N=h.nu(function(a){y(function(){t.reflow(c);var b=w.get(c),d=u.get(c);a(k.constant(3*b+2*d))},0)}),M=b.trigger.reposition;a=[c,f,l,r,s,q,v,x];M=[g.single(q,e.navigation("nw",M),m.none()),g.single(s,e.navigation("ne",
M),m.none()),g.single(v,e.navigation("se",M),m.none()),g.single(x,e.navigation("sw",M),m.none())];return{elements:k.constant(a),keylayouts:k.constant(M),events:b.registry,refresh:function(a,b){var e=d.calculate(a,b);A(c,e.n());A(f,e.s());A(l,e.e());A(r,e.w());A(q,e.nw());A(x,e.sw());A(v,e.se());A(s,e.ne());N.get(function(a){D([c,f],b.width,a);D([l,r],b.height,a)})}}}});l("13y",["q2","7"],function(d,e){return{derive:function(c,a){return{leftRim:function(){var b=a.left(),e=c.height();return d.boxModel({top:0,
left:0,width:b,height:e})},topRim:function(){var b=a.left(),e=c.width()-a.left(),g=a.top();return d.boxModel({top:0,left:b,width:e,height:g})},rightRim:function(){return d.boxModel({top:a.top(),left:a.left()+a.width(),width:c.width()-a.width()-a.left(),height:c.height()-a.top()})},bottomRim:function(){return d.boxModel({top:a.top()+a.height(),left:a.left(),width:a.width(),height:c.height()-a.height()-a.top()})},shadeBox:e.constant(a)}}}});l("117","13y 6l 7 4e 2o l".split(" "),function(d,e,c,a,b,f){var g=
function(b){var c=f.fromTag("div");a.add(c,[e.resolve("panel-"+b),e.resolve("side-panel")]);return c},h=function(a,c){b.setAll(a,{top:c.top()+"px",left:c.left()+"px",width:c.width()+"px",height:c.height()+"px"})};return function(){var a=g("left"),b=g("top"),e=g("right"),f=g("bottom");return{elements:c.constant([a,b,e,f]),refresh:function(c,g){var l=d.derive(c,g);h(a,l.leftRim());h(b,l.topRim());h(e,l.rightRim());h(f,l.bottomRim())}}}});l("xi","4c xf 6l 116 117 b xn xo 7 s 59 4a 4b 1a 1y 2o l 2p 3d 2r 32".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u,v,w,y,x){return function(z,A,D,B){var C=u.fromTag("div");t.add(C,d.magicBox());h.base(C,B("image.crop.begin"));g.effect(C,"execute");var F=u.fromTag("div");q.set(F,"role","row");var E=b(),G=a(B),H=function(a){s.setAll(C,{top:a.top()+"px",left:a.left()+"px"})};B=function(a){var b=z();H(b);E.refresh(b,a);G.refresh(b,a);I.trigger.updated(a)};w.append(F,f.flatten([E.elements(),[A],G.elements()]));v.append(C,F);var I=n.create({updated:p(["newBounds"]),reposition:l(["direction",
"delta"],G.events.reposition)});B(D);A=G.keylayouts();return{element:k.constant(C),bitsbox:k.constant(F),keylayouts:k.constant(A),move:H,update:B,destroy:function(){y.remove(C)},events:I.registry,tryMovement:function(a){return x.closest(a,"."+c.resolve("corner-wrapper")).bind(function(a){a=q.get(a,"data-"+c.resolve("direction"));return void 0!==e[a]?m.some(e[a]):m.none()})}}}});l("q1","xe xf xg xh 6l q2 xi xj b iw xn xo 8y 7 s 59 4a 4b 1a 4e 3y l 2z 2p 32 2b 1s".split(" "),function(d,e,c,a,b,f,g,
h,k,m,p,n,l,q,t,s,u,v,w,y,x,z,A,D,B,C,F){var E=function(a){var b=a.width();a=a.height();var c=F.floor(0.125*a),d=F.floor(0.125*b);return f.boxModel({top:c,left:d,width:b-2*d,height:a-2*c})};return function(f,F,I,K){var J=z.fromTag("div");y.add(J,[b.resolve("panel-central"),b.resolve("side-panel")]);w.set(J,"tabindex","-1");n.cell(J,K("image.crop.handle.shade"));p.grab(J,!1);var L=E(f());h.writePosition(J,L);h.drawAtOrigin(J);var N=g(f,J,L,K);D.append(F,N.element());var M=a(f(),N,J),O=m.transform(M),
S=x.bind(J,"dblclick",function(){X.trigger.apply()}),P=d.bind(N.element(),function(a){N.tryMovement(a).orThunk(function(){return B.closest(a,"."+b.resolve("panel-central")).map(function(){return e.translate})}).each(T)}),T=function(a){O.off();M.clearTarget();M.setTarget(a);O.on();O.go(I)},Q=function(a,b){var c=h.updatePosition(J,function(c){return e[a](f(),c,b)});h.drawAtOrigin(J);N.update(c)};K=k.flatten([N.keylayouts(),[l.single(J,c.navigation("translate",Q),t.none())]]);var V=function(){var a=
f();return x.bind(C.defaultView(F),"resize",function(){var b=f();if(b.height()!==a.height()||b.width()!==a.width())X.trigger.cancel();else if(b.top()!==a.top()||b.left()!==a.left())N.move(b),a=b})}(),L=function(a){return function(){A.active(C.owner(F)).each(function(b){p.grab(b,a)})}},W=L("true"),$=L("false");k.each(K,function(a){a.events.enter.bind(W);a.events.exit.bind($)});N.events.reposition.bind(function(a){Q(a.direction(),a.delta())});var X=u.create({updated:v(["newBounds"],N.events.updated),
apply:s([]),cancel:s([])});return{element:N.element,keylayouts:q.constant(K),destroy:function(){O.destroy();V.unbind();P.unbind();S.unbind();N.destroy()},boxes:function(){return{box:f,magic:N.element,shade:q.constant(J)}},get:function(){return h.readPosition(J)},events:X.registry}}});l("i4","q0 q1 q2 7 68 3p 2s".split(" "),function(d,e,c,a,b,f,g){var h=function(a){var d=f.absolute(a),e=d.top(),h=b.get(a),d=d.left();a=g.get(a);return c.boxModel({top:e,left:d,width:a,height:h})};return function(c,f,
p,n,l){var q=a.curry(h,c),t=e(q,f,p,l);return{element:t.element,keylayouts:t.keylayouts,crop:function(){var a;a=t.get();var e=g.get(c),f=b.get(c);a=d({cropX:a.left(),cropY:a.top(),cropWidth:a.width(),cropHeight:a.height(),displayWidth:e,displayHeight:f});return n.animate(t.boxes().magic(),c,t.boxes(),a)},destroy:function(){t.destroy()},events:t.events}}});l("9y","i3 i4 am 9o gt 8y 7 aa 9t 79 7b h9 95 7i 3f 59 4a 2n 3y 2b 3x".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u,v,w,y,x){var z=function(b,
c){b.getSelection().bind(q.detect).fold(function(){b.setRelativeSelection(a.before(c),a.before(c))},function(c){b.setRelativeSelection(a.on(c.image()),a.on(c.image()))})};return function(a){var D=a.content(),B=u.create({ok:s(["cropAction","image","cleanup"])}),C=m.value(),F=m.value(),E=function(a){var g=D.body().getOrDie();c.speak(v.body(),p.translate("image.crop.announce"));var s=y.documentElement(a),u=e(a,s,s,d.slide(),p.translate),A=h(function(a,b){c.speak(v.body(),p.translate("aria.image.crop.size",
a,b))},500);u.events.updated.bind(function(a){a=a.newBounds();A.throttle(a.width(),a.height())});var E=function(){C.clear();T.exit();T.destroy();Q.unbindAll();P.clear()},N=function(){E();F.clear();u.destroy()},M=function(){N();q.select(D,a)},O=function(){E();u.crop().get(function(b){P.clear();c.speak(v.body(),p.translate("image.crop.apply"));var d=k.crop(b.cropX(),b.cropY(),b.cropWidth(),b.cropHeight()),e=n.changedBounds(a);B.trigger.ok(function(a){return l.resampleAction(e,a,d)},a,function(a){N();
return a})})};C.set(O);F.set(N);z(D,a);var S=function(){c.speak(v.body(),p.translate("image.crop.cancel"));M()},P=m.unbindable();x(function(){P.set(w.bind(g,"focus",function(a){S()}))});var T=f.inlineDialog(s,u.keylayouts(),b.inlineDialog({ok:O,cancel:S}));T.enter();var Q=t.create();Q.bind(D.events.domChanged,M);Q.bind(D.events.nodeChanged,function(a){v.inBody(a.node())&&M()});Q.bind(u.events.apply,O);Q.bind(u.events.cancel,M)};return{apply:function(){C.on(g.apply)},open:function(){a.content().getSelection().bind(q.detect).each(function(a){E(a.image())})},
destroy:function(){F.on(g.apply)},isActive:C.isSet,events:B.registry}}});l("9z",["gq","h4","h6","1a","i5"],function(d,e,c,a,b){var f=c.fToFR(e.single);return{run:function(a,b,d){return c.fromChain([a.getImage,b,f,d])},applyEdit:function(e){return function(f){var k=d.cata(f,function(a,b,c,d){return c},function(a,b,c){return b});a.set(e,"src",k);k=b.waitFor(e,"load",1E3);return c.map(k,function(){return f})}}}});l("i6",["s","p9"],function(d,e){var c=function(a){return 20<=a},a=function(a){return d.from(a).filter(c)};
return{ensureMin:a,parse:function(b,c){var g=a(b).getOr(0),h=a(c).getOr(0);return 0===g&&0===h?d.none():d.some(e(g,h))}}});l("a0","gq 3w 7 h6 ff i6 95 1a".split(" "),function(d,e,c,a,b,f,g,h){var k=function(a){return function(e){var f=e.image(),g=e.asset(),k=function(a){a.fold(function(){h.remove(f,"src")},function(a){d.cata(a,function(a,b,c,d){h.set(f,"src",c)},c.noop)})};return b.loadIfNeeded(f).bind(function(){return a(g).map(function(a){k(a);return a})})}},m=c.constant(a.pure),p=c.constant(function(b){return a.pure(b.asset())});
return function(a){a=f.parse(a.preferredWidth,a.preferredHeight);var b=a.fold(m,g.instance),c=a.fold(p,function(){return k(b)});return{assets:function(a){return e.mapM(a,b)},correlated:function(a){return e.mapM(a,c)}}}});l("a1",["7","s","7b"],function(d,e,c){return{edit:function(a,b,f,g){return{items:g,updatePalette:function(g){if(f())g.hide(e.none())&&a();else{var k=d.curry(g.show,e.some(c.translate("image.context.palette.show")));g=d.curry(g.hide,e.some(c.translate("image.context.palette.hide")));
(b().isSome()?k:g)()&&a()}}}},crop:function(a,b,c){return{items:c,updatePalette:function(c){(b()?c.show:c.hide)(e.none())&&a()}}}}});l("5r","7 8z 9t 9u 9v 9w 9x 9r 9y 9z a0 a1 7i 71 1a o".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s){return function(u,v,w){var y=f(u.communication()),x=e(u.ui),z=u.content(),A=function(a){return function(c){c.fold(function(c){c=b.diagnoseImageEdit(c,t.get(a,"src"));x.show(c.bannerMessage());s.error("Image edit operation failed: ",c.consoleMessage())},function(a){v.uploadAssets([a]);
z.focus();u.undo().save();z.domChanged()});l.select(z,a);return c}},D=function(a,b){u.undo().save();var c=m.applyEdit(a);return m.run(y,b,c)(a)},B=k(u);B.events.ok.bind(function(b){var c=b.image(),d=b.cropAction();b=b.cleanup();var e=a.updater(a.keepCrop,c);D(c,d).map(e).map(b).get(A(c))});var C=function(){return z.getSelection().bind(l.detect)},F=function(b,c){return function(){C().each(function(e){e=e.image();var f=d.identity,g=a.updater(c,e);D(e,b).map(g).map(f).get(A(e))})}},E=[g.make("crop-begin",
"image.crop.begin",B.open),g.make("rotate-left","image.toolbar.rotateleft",F(c.rotateLeft,a.keepRotate)),g.make("rotate-right","image.toolbar.rotateright",F(c.rotateRight,a.keepRotate)),g.make("flip-horizontal","image.toolbar.fliphorizontal",F(c.flipHorizontal,a.keepFlip)),g.make("flip-vertical","image.toolbar.flipvertical",F(c.flipVertical,a.keepFlip))],G=[g.make("crop-apply","image.crop.apply",B.apply)],F=q.ui({"edit.palette":d.curry(n.edit,u.ui().refresh,C,B.isActive,E),"crop.palette":d.curry(n.crop,
u.ui().refresh,B.isActive,G)},d.identity),E=h.imageEdit(B.isActive,G,E);w=p(w);return{destroy:function(){B.destroy()},ui:F,insertResample:d.constant(w),situation:E.situation,handle:E.handle,assign:E.assign,name:d.constant("imageEdit")}}});l("q3",["7","v"],function(d,e){var c=function(a){var b=e.startsWith(a,"www.")?"http://"+a:a;return{text:d.constant(a),href:d.constant(b)}};return{preprocess:c,auto:function(a){return c(a).href()}}});l("i7","b 9o 6 7 s 83 dz q3 ds 7i l 2p 3n".split(" "),function(d,
e,c,a,b,f,g,h,k,m,p,n,l){var q=function(a,b){a.setRelativeSelection(e.after(b),e.after(b))},t=function(a,b,c,d){var e=a.getSelection();return e.bind(m.detect).fold(function(){return e.fold(function(){return[]},function(a){return(a.collapsed()?c:d)(a)})},function(a){return b(a.image())})},s=function(d,e,f){var g=p.fromTag("a");u(g,c.deepMerge(e,{text:a.constant(b.none())}));n.wrap(f,g);m.select(d,f);return[g]},u=function(a,b){b.url().each(function(b){b=h.auto(b);g.attr(a,"href",b)});b.title().each(function(b){g.attr(a,
"title",b)});b.target().each(function(b){g.attr(a,"target",b)});b.action().each(function(b){b(a)});return b.text().map(function(b){return l.get(a).trim()!==b?(l.set(a,b),!0):!1}).getOr(!1)},v=function(a){return function(b){return{link:b,properties:a}}},w=function(d){return function(e){return{link:e,properties:c.deepMerge(d,{text:a.constant(b.some(l.get(e)))})}}},y=function(a){return function(b){var c=k.findDescendants(b.startContainer(),b.startOffset(),b.endContainer(),b.endOffset(),"a");b=0<c.length?
c:k.findAncestors(b.startContainer(),b.endContainer(),"a");return d.map(b,1===b.length?v(a):w(a))}},x=function(b,c){return t(b,a.curry(s,b,c),function(a){var d=p.fromTag("a");u(d,c);f.insertAtCursor(b,[d]);c.action().each(function(a){a(d)});q(b,d);return[d]},function(a){b.execCommand("CreateLink",!1,h.auto(c.url().getOr("")));a=b.getSelection().map(y(c)).getOr([]);d.each(a,function(a){u(a.link,a.properties);c.action().each(function(b){b(a.link)});q(b,a.link)});return d.map(a,function(a){return a.link})})};
return{hyperlink:function(d,e){var f=e.text().fold(a.constant(e),function(d){return c.deepMerge(e,{text:a.constant(b.some(0<d.trim().length?d:e.url().getOr("")))})});d.focus();return f.url().fold(a.constant([]),function(a){return 0<a.trim().length?x(d,f):[]})},setProperties:u}});l("i8",["87"],function(d){var e=function(a,b){var c=d.getEnd(b);a.setSelection(b,c,b,c)},c=function(a,b){a.setSelection(b,0,b,0)};return{selectEnd:e,moveToEnd:function(a){a.getSelection().each(function(b){e(a,b.endContainer());
a.focus()})},selectStart:c,moveToStart:function(a){a.getSelection().each(function(b){c(a,b.endContainer());a.focus()})}}});l("a2","9o i7 i8 a7 2r 3n 2b".split(" "),function(d,e,c,a,b,f,g){var h=function(b,c){return b.getSelection().bind(function(d){return a.sharedLinkOrClosest(d,b.isRoot).map(function(a){c(a);return a})})};return{insert:e.hyperlink,update:function(a,c){return h(a,function(h){c.text().fold(function(){e.setProperties(h,c)},function(n){""===n&&""!==f.get(h)?(a.setRelativeSelection(d.before(h),
d.before(h)),b.remove(h)):e.setProperties(h,c)&&(n=g.children(h).length,a.setRelativeSelection(d.on(h,n),d.on(h,n)))});a.focus()})},unlink:function(a){h(a,function(d){a.setSelection(d,0,d,g.children(d).length);var e=g.lastChild(d);b.unwrap(d);e.each(function(b){c.selectEnd(a,b)});a.focus()})}}});l("ah","81 7 s i9 fl 34 fm ia 1y 21 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=function(a){return a.getSelection().bind(function(b){return a.win().bind(function(a){return d.rectangleAt(a,b.startContainer(),
b.startOffset(),b.endContainer(),b.endOffset()).map(function(a){return{bounds:e.constant(a),element:e.constant(b.startContainer())}})})})},l=function(b,d,f){n(d).fold(function(){a.insertAtCursor(b,d,f)},function(a){var g=a.bounds();a=a.element();(m.isText(a)?p.parent(a):c.some(a)).each(function(a){a=b.directionAt(a);var c=d.translateScreen(g.left,g.top);f({left:c.left,top:c.top,height:e.constant(g.height),width:e.constant(g.width),direction:e.constant(a)})})})},q=function(a,c,d,e,f,g,h){var k=f.direction();
a=b.makeshift(a,c,f.left(),f.top(),f.width(),f.height(),k,g,h);c.show(d,a);d.setComponents([e.element()])};return{show:function(a,b,c,d,e){l(a,b,function(a){q(b,c,d,e,a,g(0,0))})},showExpandable:function(a,b,c,d,e){l(a,b,function(a){k.add(d.panel(),f.resolve("expandable-popup"));var m=g(22,14),p={maxHeightFunction:h.expandable()};q(b,c,d,e,a,m,p)})}}});l("ib","8b fh gt 8y 53 hg eh 7 gv 7b 34 4a 4b 1y 3d".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t){var s=function(a,b,c){a=f(a);b=m.translate(b);
a.content(g(b));q.add(a.element(),p.resolve(c));d.button(a.element(),b);return a},u=function(a){var c=b.div();q.add(c,p.resolve("main-controls"));t.append(c,a);return c},v=function(b,d,e){var f=s("remove","link.dialog.remove","link-remove"),g=s("cancel","button.cancel","link-cancel"),h=s(b,d,e);b=n.create({remove:l([],f.events.click),cancel:l([],g.events.click),execute:l([],h.events.click)});d=[a.button(f.element(),c.button({execute:k.click})),a.button(g.element(),c.button({execute:k.click})),a.button(h.element(),
c.button({execute:k.click}))];return{remove:f,cancel:g,execute:h,keylayouts:d,events:b.registry,destroy:function(){f.destroy();g.destroy();h.destroy()}}};return{insert:function(){var a=v("insert","link.dialog.insert","link-insert"),b=u([a.cancel.element(),a.execute.element()]);a.remove.disable();e.disable(a.remove.element());return{dialogTitle:h.constant(m.key("link.dialog.aria.insert")),elements:h.constant([a.remove.element(),b]),events:h.constant(a.events),keylayouts:h.constant(a.keylayouts),execute:a.execute,
destroy:a.destroy}},update:function(){var a=v("update","link.dialog.update","link-update"),b=u([a.cancel.element(),a.execute.element()]);return{dialogTitle:h.constant(m.key("link.dialog.aria.update")),elements:h.constant([a.remove.element(),b]),events:h.constant(a.events),keylayouts:h.constant(a.keylayouts),execute:a.execute,destroy:a.destroy}}}});l("a6",["b","7","34","cw"],function(d,e,c,a){var b=c.resolve("link-validation-highlight"),f=c.resolve("link-validation-invalid");c=c.resolve("link-validation-unknown");
var g=e.constant([b,f,c]);return{configure:function(b){d.each(g(),function(c){b.add(b.output(),c,a.removeClass(c));b.add(b.internal(),c,a.removeClass(c))})},allClasses:g,invalidLink:e.constant(f),unknownLink:e.constant(c),validationHighlight:e.constant(b)}});l("ic","7 s 7b a6 70 59 4a 2v 1a 1y 32".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){return{enabled:function(b){var l=e.none(),q=h.immutable("value","text","attrs"),t=g.create({properties:f(["link"]),follow:f(["link"]),ignore:f(["link"]),remove:f(["link"])}),
s={"linkmenu-properties":t.trigger.properties,"linkmenu-follow":t.trigger.follow,"linkmenu-ignore":t.trigger.ignore,"linkmenu-remove":t.trigger.remove};return{situation:function(b){b=l.map(function(b){var d=[q("linkmenu-properties",c.translate("link.context.edit"),{}),q("linkmenu-follow",c.translate("link.context.follow"),{}),q("linkmenu-remove",c.translate("link.context.remove"),{})];b=m.has(b,a.validationHighlight())?[q("linkmenu-ignore",c.translate("link.context.ignore"),{})]:[];return d.concat(b)}).getOr([]);
return{primary:d.constant(b),secondary:d.constant([]),submenus:d.constant([])}},handle:function(a){l.each(function(b){var c=k.get(a,"data-ephox-gopher-item-value"),c=s[c];void 0!==c&&c(b)})},assign:function(a){l=a.bind(function(a){return p.closest(a,"a[href]",b.isRoot)})},events:t.registry}},disabled:function(){var a=b.noSituation(),c=g.create({properties:f(["link"])});return{situation:a,handle:d.noop,assign:d.noop,events:c.registry}}}});l("id",["1s"],function(d){return{generate:function(e){return e+
"-"+d.floor(99999*d.random()).toString()}}});l("a4","b 7 id 89 34 2v cw 1a l 2p 2r 4h".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){var l=b.resolve("link-eph-cursor"),q=function(a){d.each(a,p.remove)},t=function(b,c){u("textbox-bookmark-top",b,m.prepend,c,a.top())},s=function(b,c){u("textbox-bookmark-bottom",b,m.append,c,a.bottom())},u=function(b,e,f,g,m){var l=c.generate(b);d.each(e,function(a){h.set(a,"href","#"+l)});b=n.children(g,"["+a.bookmarkDataAttr()+'="'+m+'"]');d.each(b,p.remove);0<e.length&&
(e=k.fromTag("span"),h.setAll(e,{id:l,style:"visibility: hidden;"}),h.set(e,a.bookmarkDataAttr(),m),f(g,e))};return{configure:function(b){b.add(b.internal(),l,g.remove);b.add(b.output(),l,g.remove);b.addExcludedContext(["."+l]);b.addSelector(b.input(),"["+a.bookmarkDataAttr()+"]",q);b.addSelector(b.output(),"["+a.bookmarkAnchorDataAttr()+'="'+a.top()+'"]',t);b.addSelector(b.output(),"["+a.bookmarkAnchorDataAttr()+'="'+a.bottom()+'"]',s)},properties:f.immutableBag("url text title target action invalid".split(" "),
[]),insertCursor:e.constant(l)}});l("ie","b an s 8c 89 a7 34 1a 1y 3y l 68 3p 2a 32 37".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s){return function(u,v){var w=g.resolve("cursor-pointer"),y=v.os.isOSX(),x=c.none(),z=function(a){return u.isInline()?l.absolute(a).top():0},A=function(a){var c=h.get(a,"href");if("top"===h.get(a,b.bookmarkAnchorDataAttr()))u.win().each(function(a){u.body().each(function(b){a.scrollTo(0,z(b))})});else if("bottom"===h.get(a,b.bookmarkAnchorDataAttr()))u.win().each(function(a){u.body().each(function(b){b=
z(b)+n.get(b)-a.innerHeight;a.scrollTo(0,b)})});else if(/^#/.test(c)){var d=c.substr(1);u.body().each(function(a){f.anchorTarget(a,d).each(function(a){u.win().each(function(b){q.setToElement(b,a)})})})}else s.open(c)},D=function(a,b){var c=y?e.META():e.CTRL();d.contains(c,a)&&b()},B=p.fromDom(s),C=c.none();u.events.ready.bind(function(b){b=b.api().body();var d=a.handle(b,function(a){var b=a.target();(y?a.raw().metaKey:a.raw().ctrlKey)&&t.closest(b,"a[href]").bind(function(b){a.prevent();A(b)})});
C=c.some(d);x=c.some(k.toggler(b,w))});var F=function(){x.each(function(a){a.on()})},E=function(){x.each(function(a){a.off()})},G=function(a){D(a.original().raw().which,E)};u.events.keyup.bind(G);var H=m.bind(B,"keyup",function(a){D(a.raw().which,E)}),I=function(a){D(a.original().raw().which,F)};u.events.keydown.bind(I);var K=m.bind(B,"keydown",function(a){D(a.raw().which,F)});return{follow:A,destroy:function(){C.each(function(a){a.unbind()});u.events.keyup.unbind(G);u.events.keydown.unbind(I);H.unbind();
K.unbind()}}}});l("q6","8b fh gt 8y 53 7 gv 7b 34 1a 1y 4e 2o 3y l 68 2p 3d 2r".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u,v,w){var y=k.resolve("inline-popup-expanded");return function(x,z,A,D){var B=t.fromTag("div");d.dialog(B,h.get(D));n.add(B,[k.resolve("expandable-inline-popup")]);D=b.div();p.add(D,k.resolve("inline-popup-content"));var C=b.div();n.add(C,[k.resolve("inline-popup-content-expand"),y]);var F=b.div();p.add(F,k.resolve("inline-popup-controls"));var E=b.div();p.add(E,k.resolve("inline-popup-expand-button-wrapper"));
var G=t.fromTag("span");n.add(G,[k.resolve("inline-popup-expand-button"),k.resolve("icon")]);var H=h.translate("aria.label.more");m.set(G,"title",H);d.button(G,H);d.group(C);d.linkElements(G,C);u.append(E,G);H=b.div();p.add(H,k.resolve("inline-popup-body"));v.append(H,[D,C,E]);v.append(B,[H,F]);v.append(D,x);v.append(C,z);v.append(F,A);p.add(B,y);var I="0px",K=function(){p.remove(B,y);p.add(C,k.resolve("expand-close"));d.hidden(C,!0);l.setAll(C,{opacity:"0",height:"0px",visibility:"hidden"});e.collapsed(G)},
J=q.bind(C,"transitionend",function(a){n.remove(C,[k.resolve("expand-close"),k.resolve("expand-open")])}),L=q.bind(G,"click",function(a){p.has(B,y)?K():(p.add(B,y),p.add(C,k.resolve("expand-open")),d.hidden(C,!1),l.setAll(C,{opacity:"1",height:I,visibility:"visible"}),e.expanded(G))});x=[a.button(G,c.button({execute:g.click}))];return{element:f.constant(B),keylayouts:f.constant(x),destroy:function(){w.remove(B);L.unbind();J.unbind()},show:function(){I=s.getOuter(C)+"px";K();l.reflow(B);p.add(B,k.resolve("enable-transition"))}}}});
l("11b",[],function(){return{setValue:function(d,e,c){d=d.dom();d.value=e;d.text=c}}});l("qa",["b","s"],function(d,e){var c=function(a,b){a.dom().add(b.dom())};return{getValue:function(a){var b=a.dom();a=b.selectedIndex;b=b.options[a];return void 0===b||-1===a?e.none():e.from(b.value)},add:c,addAll:function(a,b){d.each(b,function(b){c(a,b)})},setSelected:function(a,b){a.dom().selectedIndex=b}}});l("xp","b lq 7b l 11b qa".split(" "),function(d,e,c,a,b,f){var g=[{value:"",i18nKey:"link.properties.target.none"},
{value:"_blank",i18nKey:"link.properties.target.blank"},{value:"_top",i18nKey:"link.properties.target.top"},{value:"_self",i18nKey:"link.properties.target.self"},{value:"_parent",i18nKey:"link.properties.target.parent"}];return{target:function(h){var k=e.common("select","target-container","link.properties.target.label"),m=d.map(g,function(d){var e=a.fromTag("option");b.setValue(e,d.value,c.translate(d.i18nKey));return e});f.addAll(k.field(),m);var p=h.target().getOr("");h=d.findIndex(g,function(a){return a.value===
p});f.setSelected(k.field(),0<h?h:0);return{element:k.element,input:k.field}}}});l("q7","am gt 8y 53 7 s gv lq 7b xp 34 1a 1y 4e 2p 2r 33".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u){var v=function(){var b=a.div();l.add(b,p.resolve("invalid-link-info"));var c=h.comboBox("href-url-value","link.properties.url.label",f.some(b));n.setAll(c.input(),{placeholder:k.translate("link.properties.url.placeholder"),autocomplete:"off",autocorrect:"off"});var e=l.toggler(c.element(),p.resolve("link-is-invalid"));
return{input:c.input,element:c.element,dropArrow:c.dropArrow,showInvalid:function(){e.on();var f=a.span();q.add(f,[p.resolve("icon"),p.resolve("invalid-link-icon")]);t.append(b,f);var g=k.translate("link.properties.url.invalid");n.set(f,"title",g);f=d.describe(c.input(),g);n.set(f,"aria-live","assertive");t.append(b,f)},hideInvalid:function(){e.off();s.empty(b);n.remove(c.input(),"aria-describedby")}}};return function(a){var d=v();a.url().each(function(a){u.set(d.input(),a)});var f=h.input("text-to-display",
"link.properties.text.label");l.add(f.element(),p.resolve("text-to-display"));n.setAll(f.input(),{placeholder:k.translate("link.properties.text.placeholder"),autocomplete:"off",autocorrect:"off"});a.text().each(function(a){u.set(f.input(),a)});var q=h.input("title-text","link.properties.title.label");l.add(q.element(),p.resolve("title-container"));n.setAll(q.input(),{placeholder:k.translate("link.properties.title.placeholder"),autocomplete:"off",autocorrect:"off"});a.title().each(function(a){u.set(q.input(),
a)});var s=m.target(a);return{url:b.constant(d),text:b.constant(f),title:b.constant(q),target:b.constant(s),keylayouts:function(){return[c.input(d.input(),e.input({})),c.input(f.input(),e.input({})),c.input(q.input(),e.input({})),c.button(s.input(),e.button({execute:g.click,process:b.noop}))]}}}});l("q8",["a","b","oi","1s"],function(d,e,c,a){return function(a){var f=d.isNumber(a)?a:1E4,g=c.access("local.linkCache");a=g.read();var h=function(a){return 0>f-a.length?a.slice(0,f):a}(d.isArray(a)?a:[]),
k=function(){return h.slice(0)};return{add:function(a){if("#"!==a.charAt(0)){h.length>=f&&h.pop();var b=e.indexOf(h,a);-1<b&&h.splice(b,1);h.unshift(a)}},state:k,destroy:function(){g.write(k())}}}});l("xq",["b","1o"],function(d,e){return{stringArray:function(c){var a={};d.each(c,function(b){a[b]={}});return e.keys(a)}}});l("xr",["s"],function(d){return{url:function(e){return d.some(e.url())},title:function(d){return d.title()},innerText:function(e){e=e.innerText();return 0<e.length?d.some(e):d.none()}}});
l("11c",["4j"],function(d){return{resolve:d.create("ephox-tarot").resolve}});l("11d","53 7 s 1y l 2p 3d 11c 1s".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(a,c,d,e,g){var h=b.fromText(a.substr(0,c));c=b.fromText(a.substr(c,d));a=b.fromText(a.substr(e));g=b.fromTag(g);f.append(g,c);return[h,g,a]},p=function(b,f,h,k){var m=d.tag(f);g.append(m,h);k.each(function(b){a.add(m,b)});return{item:e.constant(b),marked:e.constant(c.some(m))}},n=function(a,b,d,e){var f=a.text,g=a.marker.start(),n=a.marker.length(),
l=0;0<e-(g+n)||0===g||(n>e?l=g-10:(e=k.floor((e-n)/2),l=g-e));e=f.substr(l);g-=l;b=m(e,g,n,g+n,b);f=e.length===f.length?c.none():c.some(h.resolve("anchor-before"));return p(a.item(),d,b,f)},l=function(b,c){var e=d.span();a.add(e,c);g.append(e,b);return e},q=function(a,c,d){var e=[];c=l(c,h.resolve("content-innertext"));0<a.length&&(a=l([b.fromText(a)],h.resolve("anchor-before")),e.push(a));e.push(c);0<d.length&&(d=l([b.fromText(d)],h.resolve("anchor-after")),e.push(d));return e};return{contentMarker:function(a,
b,d,e){var f=a.item().before(),g=a.item().after(),h=a.text;if(0===f.length&&0===g.length&&h.length>e)return n(a,b,d,e);e=a.marker.start();var k=a.marker.length();b=m(h,e,k,e+k,b);f=q(f,b,g);return p(a.item(),d,f,c.none())},contentUnderlined:q,attrMarker:n}});l("xs","53 s 1a 1y l 2p 3d 11c 11d".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(a,c,e){a=d.tag(c);f.append(a,b.fromText(e));return a};return{anchors:function(b,f){var k=f.item(),l=k.url(),t=d.div();a.add(t,h.resolve("item-line"));var s=
k.title().getOr(l);c.set(t,"title",s);k=f.marked().fold(function(){return m(b,"div",s)},function(a){return a});a.add(k,h.resolve("item-main-label"));l=e.from(l).map(function(c){return c!==s?(c=m(b,"div",c),a.add(c,h.resolve("item-secondary-label")),[c]):[]}).getOr([]);l=[k].concat(l);g.append(t,l);return t},standard:function(e,m){var l=m.item(),q=d.div();a.add(q,h.resolve("item-line"));var t=[l.before(),l.innerText(),l.after()].join("");c.set(q,"title",t);t=m.marked().fold(function(){var a=k.contentUnderlined(l.before(),
[b.fromText(l.innerText())],l.after()),c=d.div();g.append(c,a);return c},function(a){return a});a.add(t,h.resolve("item-main-label"));l.indent()&&a.add(t,h.resolve("indent"));f.append(q,t);return q},error:function(a,c){var e=d.span(),g=b.fromText(c);f.append(e,g);return e}}});l("11e",["o3","fm","o4","o6"],function(d,e,c,a){return function(b,f){return{position:function(g){g=g.isRtl()?c.allRtl():c.all();var h=e(0,0),k=d.element(b);a.fixed(k,f,h,g,{})}}}});l("11f","b 7 s k 2v xr 11d".split(" "),function(d,
e,c,a,b,f,g){var h=b.immutable("matchFunction","start","length"),k=function(a,b,c){for(var d=0,e=[],f=function(a){e.push(a);d++},g=0,h=a.length;g<h&&d<b;g++)c(a[g]).each(f);return e};return{unmarked:function(a,b){var f=b.getOr(1E3),f=a.length>f?a.slice(0,f):a;return d.map(f,function(a){return{item:e.constant(a),marked:c.none}})},match:function(b,d,f,g){var l=f.toLowerCase();f=g.getOr(1E3);return k(b,f,function(b){return a.findMap(d,function(a){return a(b).bind(function(d){var f=d.toLowerCase().indexOf(l);
if(-1<f){var g=l.length;return c.some({item:e.constant(b),marked:c.none,text:d,marker:h(a,f,g)})}return c.none()})})})},mark:function(a,b,c,e){return d.map(a,function(a){return(a.marker.matchFunction()===f.innerText?g.contentMarker:g.attrMarker)(a,b,c,e)})}}});l("11g","7 1a l 2p 2r 11c".split(" "),function(d,e,c,a,b,f){var g="data"+f.resolve("section-id");return{create:function(f,k){var m=c.fromTag("ol");e.set(m,g,k.id());var p=function(){b.empty(m)};return{element:d.constant(m),clear:p,add:function(b){var d=
c.fromTag("li");a.append(d,b);a.append(m,d);return d},spec:d.constant(k),destroy:function(){p()}}},dataIdAttribute:d.constant(g)}});l("xt","a b 8b am 30 c wx 53 7 s 59 4a 57 2v 1a 2n 1y 3y l 2p 2r 6u 32 m 2b 11e 11f 11c 11g q".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u,v,w,y,x,z,A,D,B,C,F,E,G,H){var I=f.detect().browser.isSafari(),K=function(a,b){I&&d.isFunction(a.dom().scrollIntoViewIfNeeded)?a.dom().scrollIntoViewIfNeeded(!1):a.dom().scrollIntoView(b)};f=q.immutableBag(["container","sections",
"translate"],["doc"]);q=q.immutableBag("id highlight contentLimit items render extractors".split(" "),["itemLimit"]);var J="data"+E.resolve("item-id");return{init:function(d,f){var q=f.doc().getOr(w.fromDom(H)),I=f.translate(),S={},P=g(),T=h.div();u.add(T,E.resolve("predictive-menu"));c.hidden(T,!0);var Q=C(d,T),V=function(){e.each(P.state(),function(a){W(a,[])})},W=function(a,c){x.remove(a.element());a.clear();var d={};0<c.length&&(e.each(c,function(c){var e=a.spec().render()(q,c),e=a.add(e),f=b.generate("");
t.set(e,J,f);d[f]={gui:k.constant(e),item:k.constant(c.item())}}),y.append(T,a.element()));S[a.spec().id()]=d},$=function(){return B.parent(T).isSome()},X=function(b){u.add(b,E.resolve("selected"));ea().bind(ha).each(function(b){a.speak(s.body(),b.item().url())})},Y=function(a){X(a);var b=T.dom().getBoundingClientRect(),c=a.dom().getBoundingClientRect();c.top<b.top?K(a,!0):c.bottom>b.bottom&&K(a,!1)},da=function(a){u.remove(a,E.resolve("selected"))},R=function(){A.descendant(T,"li").each(Y)},ca=function(){D.one("ol:last-child li:last-child",
T).each(Y)},ea=function(){return A.descendant(T,"li."+E.resolve("selected"))},fa=function(){return ea().bind(ha).map(function(b){b=b.item();a.speak(s.body(),I("link.dialog.autocomplete.accept",b.url()));return b})},ga=function(a){0===B.children(a).length?B.nextSibling(a).fold(R,ga):B.firstChild(a).fold(ca,Y)},ia=function(a){0===B.children(a).length?B.prevSibling(a).fold(ca,ia):B.lastChild(a).fold(R,Y)},ha=function(a){a=A.closest(a,"["+J+"]");var b=a.bind(function(a){return A.closest(a,"["+G.dataIdAttribute()+
"]")}),c=a.map(function(a){return t.get(a,J)});return b.map(function(a){return t.get(a,G.dataIdAttribute())}).bind(function(a){return m.from(S[a])}).bind(function(a){return c.bind(function(b){return m.from(a[b])})})},Z=v.capture(T,"mouseover",function(a){a=a.target();z.closest(a,"li."+E.resolve("selected"))||ha(a).fold(k.noop,function(a){ea().each(function(a){da(a)});X(a.gui())})}),aa=v.capture(T,"click",function(a){fa().each(ja.trigger.click)}),ja=n.create({click:p(["item"])}),ba=l.ensure(["url",
"indent"]);e.each(f.sections(),function(a){e.each(a.items(),ba);a=G.create(q,a);P.push(a)});V();return{element:k.constant(T),events:ja.registry,reset:V,resetFull:function(){e.each(P.state(),function(a){a.clear();var b=a.spec().items(),c=a.spec().itemLimit(),b=F.unmarked(b,c);W(a,b)})},filter:function(a){0<a.length?(S={},e.each(P.state(),function(b){var c=b.spec(),d=F.match(c.items(),c.extractors(),a,c.itemLimit()),c=F.mark(d,c.highlight(),"div",c.contentLimit());W(b,c)})):V()},show:function(b){y.append(f.container(),
T);Q.position(b);a.speak(s.body(),I("link.dialog.autocomplete.open"))},isShowing:$,hide:function(){$()&&a.speak(s.body(),I("link.dialog.autocomplete.close"));x.remove(T);ea().each(da)},getSelectedData:fa,moveup:function(){ea().fold(ca,function(a){da(a);B.prevSibling(a).fold(function(){B.parent(a).bind(B.prevSibling).fold(ca,ia)},Y)})},movedown:function(){ea().fold(R,function(a){da(a);B.nextSibling(a).fold(function(){B.parent(a).bind(B.nextSibling).fold(R,ga)},Y)})},destroy:function(){Z.unbind();aa.unbind();
e.each(P,function(a){a.destroy()});x.remove(T)}}},config:f,section:q}});l("q9","b c xq an 7 r s k id 7b 89 a7 34 59 4a 4p 2v 1a 4e 1b 2o 3y 2z 21 3n 33 2s xr xs xt v".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u,v,w,y,x,z,A,D,B,C,F,E,G,H,I){var K=e.detect().browser.isSafari(),J=u.immutable("url","indent","action","before","innerText","after"),L=u.immutable("url","indent","title","action"),N=u.immutable("url","action"),M=u.immutable("url","indent","action");return function(e,u,P,T){var Q=
t.create({change:q([])}),V=function(){var a=u.body().map(n.all).getOr([]),a=d.bind(a,function(a){var b=v.get(a,"href");return I.startsWith(b,"#")||v.has(a,p.bookmarkAnchorDataAttr())?[]:[b]}),a=T.state().concat(a),a=c.stringArray(a);return d.map(a,function(a){var c=g.none();return L(a,b.constant(!1),c,b.noop)})},W=function(a,b,c){a=a.replace(/[^0-9a-zA-Z$-_.+*(),]/g,"");var d=0<a.length?a:k.generate("textbox-heading");return g.some(M("#"+d,c,function(){v.set(b,"id",d)}))},$=function(a){var c="h1"!==
D.name(a),d=B.get(a);return v.has(a,"id")||v.has(a,"name")?(a=v.has(a,"id")?v.get(a,"id"):v.get(a,"name"),g.some(M("#"+a,c,b.noop))):0===d.trim().length?g.none():W(d,a,c)},X=function(a){v.remove(a,p.bookmarkAnchorDataAttr())},Y=function(a){var b=p.reservedUrls()[a.toLowerCase()];return function(a){v.set(a,p.bookmarkAnchorDataAttr(),b)}},da=function(){var a=u.body().map(n.findLinkTargets).getOr([]),b=1E3<a.length,a=d.map(a,function(a){return $(a).map(function(c){var d=(b?n.linkTargetFastText:n.linkTargetText)(50,
a);return J(c.url(),c.indent(),c.action(),d.before(),d.innerText(),d.after())})}),a=h.cat(a),c=function(a){return"\u2014 "+a+" \u2014"},e=Y(p.topAnchorUrl()),e=J(p.topAnchorUrl(),!1,e,"",c(p.topAnchorUrl()),""),f=Y(p.bottomAnchorUrl()),c=J(p.bottomAnchorUrl(),!1,f,"",c(p.bottomAnchorUrl()),"");return[e].concat(a).concat([c])};return{predict:function(b,c,h){var k=f.cached(function(){var a=V(),c=da(),a=H.config({container:P,translate:m.translate,sections:[H.section({id:"recent",highlight:"strong",contentLimit:50,
items:a,itemLimit:10,render:G.anchors,extractors:[E.title,E.url]}),H.section({id:"anchors",highlight:"strong",contentLimit:50,items:c,render:G.standard,extractors:[E.innerText,E.url]})]}),d=H.init(b,a);w.add(d.element(),[l.resolve("layer-menus"),l.resolve("tarot-inline")]);d.events.click.bind(function(a){d.hide();q(b,a.item())});a=F.get(b);x.setAll(d.element(),{"min-width":a+"px","box-sizing":"border-box"});return d}),n=s(g.none()),q=function(a,b){var c=b.url();C.set(a,c);K&&a.dom().click();n.set(g.some(b));
Q.trigger.change()},t=h.container(b);t.swallowKeys([a.UP(),a.DOWN()]);t.events.up.bind(function(a){a.stopper()();a=k();u(a);a.moveup()});t.events.down.bind(function(a){a.stopper()();a=k();u(a);a.movedown()});t.events.escape.bind(function(a){var b=k();b.isShowing()&&(b.hide(),a.stopper()())});t.events.enter.bind(function(a){k().getSelectedData().each(function(c){a.stopper()();var d=k();d.hide();d.reset();q(b,c)})});t.on();var u=function(a){if(!a.isShowing()){var c=C.get(b);""===c?a.resetFull():a.filter(c);
a.isShowing()||a.show(e.uiDirection())}},v=[z.bind(b,"input",function(a){Q.trigger.change();a=k();n.set(g.none());var c=C.get(b);0<c.length?(a.filter(c),a.isShowing()||a.show(e.uiDirection())):(a.reset(),a.hide())}),z.bind(b,"focus",function(a){k()}),z.bind(b,"blur",function(a){var c=k().hide;A.active().fold(c,function(a){y.eq(a,b)||c()})}),z.bind(P,"click",function(a){k().hide()}),z.bind(c,"click",function(a){a.stop();a=k();a.isShowing()?a.hide():u(a)})];return{destroy:function(){k().destroy();t.destroy();
d.each(v,function(a){a.unbind()})},getSelectedValue:function(){return n.get().fold(function(){var a=C.get(b),c=p.isReservedUrl(a)?Y(a):X;return N(a,c)},function(a){return N(a.url(),a.action())})}}},events:Q.registry}}});l("if","ak b lt gt 8y 7 s q6 q7 89 a4 q8 q9 34 ay 59 4a 4b 1a 1y 2o 33 qa".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u,v,w,y,x,z,A){return function(D,B,C,F,E,G,H){var I=n(1337),K=k(G),J=H();H=[K.url().element()];var L=[K.text().element(),K.title().element(),K.target().element()],
N=h(H,L,J.elements(),J.dialogTitle());y.add(N.element(),q.resolve("inline-link-dialog"));var M=d.popup(F.uiContainer,F.bounds,D,[],t.editorContainer()).initMenu(N.element());y.add(M.element(),q.resolve("bubble-box"));H=l(D,C,N.element(),I);var O=H.predict(K.url().input(),K.url().dropArrow(),B);G.invalid()&&(K.url().showInvalid(),H.events.change.bind(function(){K.url().hideInvalid()}));var S={before:function(){x.set(M.panel(),"visibility","hidden");M.open()},after:function(){x.remove(M.panel(),"visibility");
x.remove(M.panel(),"display")}},P=u.create({remove:v([],J.events().remove),cancel:s([]),execute:v([],J.events().execute)}),T=function(a){var b=a.command();a=a.data();w.has(a,m.bookmarkAnchorDataAttr())||"insertLink"!==b&&"updateLink"!==b||(b=w.get(a,"href"),I.add(b))};E.events.internal.bind(T);B=function(){P.trigger.cancel()};J.events().cancel.bind(B);M.events.close.bind(B);B=e.flatten([K.keylayouts(),N.keylayouts(),J.keylayouts()]);var Q=b.inlineDialog(N.element(),B,a.inlineDialog({ok:J.execute.click,
cancel:f.noop}));Q.events.exit.bind(function(){M.close();P.trigger.cancel()});return{showPopup:function(a){S.before();c.preserve(function(){a.showExpandable(D,C,F,M,N);S.after();N.show();Q.enter()},N.element())},hide:function(){M.closed()||Q.exit()},getValues:function(){var a=O.getSelectedValue(),b=z.get(K.text().input()).trim(),c=z.get(K.title().input());return p.properties({url:""===a.url()?g.none():g.some(a.url()),text:g.some(b),title:g.some(c),target:A.getValue(K.target().input()),action:g.some(a.action()),
invalid:!1})},destroy:function(){I.destroy();E.events.internal.unbind(T);O.destroy();Q.destroy();J.destroy();M.destroy();N.destroy()},events:P.registry}}});l("a3","c 7 s 79 ah ib 89 ic a4 ie if a6 59 4a 1a 1y 3n 3x".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u,v){return function(w,y){var x=w.filter(),z=w.content(),A=w.smartview(),D=h.enabled(z),B=w.internalevents(),C=d.detect();k.configure(x);var F=m(z,C),x=function(){z.getSelection().each(function(a){z.setSelection(a.startContainer(),a.startOffset(),
a.endContainer(),a.endOffset())})},E=C.browser.isIE()?x:e.noop,G=q.create({insert:l(["properties"]),update:l(["properties"]),unlink:l([])}),H=a.destroyable(),I=function(a,b){var c=p(w.region(),w.keyboard(),z,A,B,a,b);c.events.remove.bind(function(a){G.trigger.unlink();K()});c.events.cancel.bind(function(a){K();z.focus();E()});H.set(c);z.events.mousedown.bind(K);return c},K=function(){H.clear();z.events.mousedown.unbind(K)},J=function(a){var c=I(a,f.update);c.events.execute.bind(function(a){G.trigger.update(c.getValues());
K()});c.showPopup(b)};D.events.properties.bind(function(a){a=a.link();var b=t.has(a,g.bookmarkAnchorDataAttr())?g.getReservedUrl(t.get(a,g.bookmarkAnchorDataAttr())):t.get(a,"href");a=k.properties({url:c.from(b),text:c.from(u.get(a).trim()),title:c.from(t.get(a,"title")),target:c.from(t.get(a,"target")),action:c.none(),invalid:s.has(a,n.validationHighlight())});J(a)});D.events.follow.bind(function(a){z.focus();v(function(){F.follow(a.link())},0)});D.events.ignore.bind(function(a){y.ignore(a.link())});
D.events.remove.bind(function(){G.trigger.unlink()});return{showContext:J,showInsert:function(a){var c=I(a,f.insert);c.events.execute.bind(function(a){G.trigger.insert(c.getValues());K()});c.showPopup(b)},situation:D.situation,handle:D.handle,assign:D.assign,events:G.registry,destroy:function(){K();F.destroy()}}}});l("ig","b 8b 53 7 s io he 7b a4 34 59 4a 4p 1a 1y l 2z 2p 3d 2r 33 b0".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u,v,w,y,x,z){return function(A){var D=l(b.none());A=c.div();t.add(A,
m.resolve("link-widget"));var B=c.span();t.add(B,m.resolve("link-widget-field"));var C=s.fromTag("input");t.add(C,m.resolve("link-widget-input"));e.label(C,h.translate("link.properties.url.placeholder"));v.append(B,C);q.set(C,"type","url");q.set(C,"placeholder",h.translate("link.dialog.tooltip"));var F=g.text(B,C),E=f([m.resolve("link-widget-insert")],"insert.link"),G=f([m.resolve("link-widget-update")],"link.dialog.update"),H=f([m.resolve("link-widget-remove")],"link.dialog.remove");v.append(A,B);
var I=n.create({insert:p(["properties"]),update:p(["properties"]),unlink:p([]),toEditor:p([])}),K=function(a,c){return k.properties({url:b.some(a),text:b.from(c),title:b.none(),target:b.none(),action:b.none(),invalid:!1})},J=function(){var a=x.get(C),c=D.get().fold(function(){return K(a,a)},function(b){return b.text().fold(function(){return K(a,a)},function(b){return K(a,b)})});I.trigger.insert(c);D.set(b.none());I.trigger.toEditor()},L=function(){var a=x.get(C);I.trigger.update(K(a));D.set(b.none());
I.trigger.toEditor()};E.events.click.bind(J);G.events.click.bind(L);H.events.click.bind(function(){I.trigger.unlink();I.trigger.toEditor()});return{element:a.constant(A),addEscape:function(a){v.append(B,a.element())},type:a.constant(F),execute:function(){z.isVisible(E.element())?J():z.isVisible(G.element())&&L()},open:function(){u.focus(C)},close:a.noop,destroy:a.noop,represent:function(a){d.each([E.element(),G.element(),H.element()],y.remove);a.url().fold(function(){x.set(C,"http://");v.after(C,
E.element())},function(a){w.after(C,[G.element(),H.element()]);x.set(C,a)});D.set(b.some(a))},events:I.registry}}});l("a5",["9a","ic","ig","59","4a"],function(d,e,c,a,b){return function(f){var g=c(f),h=d(f,g);f=e.disabled();var k=b.create({insert:a(["properties"]),update:a(["properties"]),unlink:a([])});g.events.insert.bind(function(a){k.trigger.insert(a.properties())});g.events.update.bind(function(a){k.trigger.update(a.properties())});g.events.unlink.bind(function(a){k.trigger.unlink()});return{showContext:function(a){g.represent(a);
h.open()},showInsert:function(a){g.represent(a);h.open()},situation:f.situation,handle:f.handle,assign:f.assign,events:k.registry,destroy:function(){h.close();h.destroy()}}}});l("5s","c 7 s a2 7b a3 a4 a5 a6 a7 71 59 4a 1a 1y 3n".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s){return function(u,v){var w=u.content(),y=u.undo(),x=u.shortcuts(),z=d.detect().deviceType.isTouch()?h(u):f(u,v),A=l.create({analytics:n(["message"])});z.events.insert.bind(function(b){y.transaction(function(){var c=a.insert(w,
b.properties());u.internalevents().input(c)});w.domChanged();w.cursorIntoView();A.trigger.analytics("link_inserted")});z.events.update.bind(function(b){y.transaction(function(){var c=b.properties();a.update(w,c)});w.domChanged();w.cursorIntoView()});z.events.unlink.bind(function(b){y.save();a.unlink(w);w.domChanged();w.cursorIntoView()});var D=function(){w.getSelection().each(function(a){m.sharedLinkOrClosest(a,w.isRoot).fold(function(){w.selectWord();z.showInsert(g.properties({url:c.none(),text:w.getSelectedText(),
title:c.none(),target:c.none(),action:c.none(),invalid:!1}))},function(a){z.showContext(g.properties({url:c.from(q.get(a,"href")),text:c.from(s.get(a).trim()),title:c.from(q.get(a,"title")),target:c.from(q.get(a,"target")),action:c.none(),invalid:t.has(a,k.validationHighlight())}))})})},B=p.ui({"link.general":{toggle:!1,value:"link",textkey:b.key("insert.link"),action:D,updateGeneral:e.noop,icon:!0,shortcut:!0,hasPopup:!1,hasDialog:!0}});x.events.link.bind(D);return{ui:B,situation:z.situation,handle:z.handle,
assign:z.assign,events:A.registry,destroy:function(){z.destroy()}}}});l("a9",["4q"],function(d){var e=d.generate([{invalid:["invalidUrl"]},{unknown:["unknownUrl"]},{valid:["validUrl"]}]);return{cata:function(c,a,b,d){return c.fold(a,b,d)},derive:function(c,a){return"VALID"===a?e.valid(c):"INVALID"===a?e.invalid(c):e.unknown(c)}}});l("ii",["nl","nm","ni","7"],function(d,e,c,a){var b=[e.strict("url"),e.defaulted("fresh",!1)],f=c.objOf(b);d=c.objOf([e.field("urls","urls",d.strict(),c.arrOfObj(b))]);
return{one:a.constant(f),many:a.constant(d)}});l("a8","ih 1o a9 86 f1 f2 f3 f4 ii f7".split(" "),function(d,e,c,a,b,f,g,h,k,m){return function(p,n,l){var q=b(l),t=f.get("ephox.link.service.one",k.one(),p+"/1/check?url=${url}&fresh=${fresh}",n),s=f.post("ephox.link.service.many",k.many(),p+"/1/check",n),u=function(a){return{url:a.url,result:c.derive(a.url,a.result)}};return{checkOne:function(b,c){var d=h.now(),d=g.single(function(a,c){return t.execute({url:m(b),fresh:c})},q,b,d,void 0!==c?c:!1);return a.mapSync(d,
u)},checkMany:function(b,c){var f=h.now(),f=g.multiple(function(a,b){return s.execute({urls:a})},q,b,function(a){return d.indexOnKey(a.results,"url")},function(a){return a.url},f,void 0!==c?c:!1);return a.mapSync(f,function(a){return e.map(a,u)})},dumpCache:q.dump}}});l("qf",[],function(){return{recompose:function(d){var e="";""!==d.protocol&&(e+=d.protocol,e+=":");""!==d.authority&&(e=e+"//"+d.authority);e+=d.path;""!==d.query&&(e+="?",e+=d.query);""!==d.anchor&&(e+="#",e+=d.anchor);return e}}});
l("xu",["v"],function(d){return{remove:function(e){for(var c="";""!==e;)if(d.startsWith(e,"../"))e=d.removeLeading(e,"../");else if(d.startsWith(e,"./"))e=d.removeLeading(e,"./");else if(d.startsWith(e,"/./"))e="/"+d.removeLeading(e,"/./");else if("/."===e)e="/";else if(d.startsWith(e,"/../"))e="/"+d.removeLeading(e,"/../"),c=d.removeTrailing(c,c.substring(c.lastIndexOf("/")));else if("/.."===e)e="/",c=d.removeTrailing(c,c.substring(c.lastIndexOf("/")));else if("."===e||".."===e)e="";else{var a=e.match(/(^\/?.*?)(\/|$)/)[1];
e=d.removeLeading(e,a);c+=a}return c}}});l("xv",["v"],function(d){return{merge:function(e,c,a){if(""!==a&&""===e)return"/"+c;a=e.substring(e.lastIndexOf("/")+1);return d.removeTrailing(e,a)+c}}});l("qg",["v","i0","xu","xv"],function(d,e,c,a){return{transform:function(b,f){var g={strictMode:!0},h=e.parse(b,g),g=e.parse(f,g),k={};""!==g.protocol?(k.protocol=g.protocol,k.authority=g.authority,k.path=c.remove(g.path),k.query=g.query):(""!==g.authority?(k.authority=g.authority,k.path=c.remove(g.path),
k.query=g.query):(""===g.path?(k.path=h.path,k.query=""!==g.query?g.query:h.query):(d.startsWith(g.path,"/")?k.path=c.remove(g.path):(k.path=a.merge(h.path,g.path,b.authority),k.path=c.remove(k.path)),k.query=g.query),k.authority=h.authority),k.protocol=h.protocol);k.anchor=g.anchor;return k}}});l("ij",["qf","qg"],function(d,e){return{resolve:function(c,a){var b=e.transform(c,a);return d.recompose(b)}}});l("ac","b s p 89 2v 1a 2b v i0 ij 37".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var n=b.immutable("href",
"resolved");return function(b){var l=b.slice(0),t=function(b){var r=f.get(b,"href");if(h.startsWith(r,"#")||f.has(b,a.bookmarkAnchorDataAttr()))b=c.error(b);else{var t;t=g.owner(b).dom().baseURI;t=e.from(t).getOr(p.location);t=m.resolve(t,b.dom().href);if(d.contains(l,t))b=c.error(b);else{var w=k.parse(t).protocol;b="https"===w||"http"===w?c.value(n(r,t)):c.error(b)}}return b};return{extract:t,ignore:function(a){t(a).each(function(a){l.push(a.resolved())})},state:function(){return l.slice(0)}}}});
l("ad",["b"],function(d){return{generate:function(e){var c={};d.each(e,function(a){var b=a.resolved();a=a.href();c.hasOwnProperty(b)?d.contains(c[b],a)||c[b].push(a):c[b]=[a]});return c}}});l("5t","b 1o a8 a9 86 7 aa s k ab 88 a6 ac ad a7 ae 1y 4e o".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u,v,w){return function(y,x,z){var A=y.content(),D=y.filter(),B=y.communication(),C=y.undo(),F=y.viewablearea(),E=F.viewport(),G=l(x.ignore),H=n.validationHighlight(),I=n.invalidLink(),K=n.unknownLink();
n.configure(D);var J=c(z.url,B.mediatorHeaders(),x.cache),L=function(a){a=d.map(a,function(a){return s.cata(E.assess(a),h.none,f.compose(h.some,G.extract),h.none)});a=k.cat(a);a=m.partition(a);d.each(a.errors,P);var b=q.generate(a.values);a=e.keys(b);a=d.map(a,function(a){return{url:a}});a=J.checkMany(a);M(a,function(a){e.each(a,function(a){var c=b[a.url];void 0===c?w.warn("Link validator response from server was unknown: ",a.url,a.result):d.each(c,function(b){Q(a.result,b)})})})};y=function(){var a=
F.sections(),a=t.many(a),a=d.filter(a,function(a){return!u.has(a,p.embedChecking())});L(a)};var N=g(y,500).throttle;F.events.onChange.bind(N);A.events.domChanged.bind(N);var M=function(a,c){b.handle(a,function(a){w.error("Link Validation server failure: ",a)},function(a){c(a)})},O=function(a){return A.body().map(function(b){return t.hrefUrl(b,a)})},S=function(a,b){O(a).each(function(a){d.each(a,function(a){u.has(a,n.validationHighlight())||v.add(a,[H,b])})})},P=function(a){u.has(a,n.validationHighlight())&&
v.remove(a,n.allClasses())},T=function(a){O(a).each(function(a){d.each(a,P)})},Q=function(b,c){a.cata(b,function(a){S(c,I)},function(a){S(c,K)},function(a){T(c)})};C.events.undo.bind(y);C.events.redo.bind(y);return{destroy:f.noop,refresh:N,ignore:function(a){C.save();G.ignore(a);N();A.focus();A.domChanged();A.cursorIntoView()},state:function(){return{ignore:G.state(),cache:J.dumpCache()}}}}});l("11h",["s","is"],function(d,e){return{top:{rules:[{current:e.backtrack,next:e.sidestep,fallback:d.none()},
{current:e.sidestep,next:e.sidestep,fallback:d.some(e.backtrack)},{current:e.advance,next:e.sidestep,fallback:d.some(e.sidestep)}],inclusion:function(c,a,b){return!c.property().parent(b).exists(function(b){return c.eq(b,a.item())})}},all:{rules:void 0,inclusion:function(c,a,b){return c.property().isText(a.item())}}}});l("xw",["b","7","is","11h"],function(d,e,c,a){var b=c.walkers(),f=function(a,d,e,g){return c.walk(a,d,e,b.left(),g.rules).map(function(b){return a.property().isEmptyTag(b.item())||a.property().isBoundary(b.item())?
[]:(g.inclusion(a,b,d)?[b.item()]:[]).concat(f(a,b.item(),b.mode(),g))}).getOr([])},g=function(a,b,e){a=f(b,e,c.sidestep,a);return d.reverse(a).concat([e])};return{top:e.curry(g,a.top),all:e.curry(g,a.all)}});l("qh",["6q","xw"],function(d,e){var c=d();return{top:function(a){return e.top(c,a)},all:function(a){return e.all(c,a)}}});l("xx",["b","7","s","f9","hv"],function(d,e,c,a,b){var f=function(f,g){var m=b.generate(g,function(b,d){return f.property().isText(b)?c.some(a.range(b,d,d+f.property().getText(b).length)):
c.none()}),p=d.foldr(m,function(a,b){return f.property().getText(b.element())+a},"");return{list:e.constant(m),text:e.constant(p)}},g=function(a,c,d,f){var g=b.find(c.list(),function(b){return a.eq(b.element(),d)}).map(function(a){return a.start()+f});return{list:c.list,text:c.text,cursor:e.constant(g)}};return{from:function(a,b,c,d){b=f(a,b);return g(a,b,c,d)}}});l("qi",["6q","xx"],function(d,e){var c=d();return{from:function(a,b,d){return e.from(c,a,b,d)}}});l("ik",["7","s","qh","qi","21"],function(d,
e,c,a,b){return{get:function(f,g){var h=c.all(f),k=a.from(h,f,g),h=k.cursor().orThunk(function(){return b.isText(f)?e.none():e.some(k.text().length)});return{list:k.list,text:k.text,cursor:d.constant(h)}}}});l("qj",["4s","7","s","l","6p"],function(d,e,c,a,b){return function(f,g,h){return{patterns:function(){return[new b("(\\W)(\\w+)(\\W*)$","gi"),new b("(^)(\\w+)(\\W*)$","gi")]},useCursor:e.constant(!0),generate:function(b,f){var g=a.fromText(f.text());return d.species({elements:e.constant([g]),cursor:c.none,
dictation:e.constant(c.some(function(){return h(f.text())})),notify:c.none})},derive:function(a){var b=a.index+a[1].length,c=b+a[2].length;return g(a[2]).map(function(a){return{startIndex:e.constant(b),finishIndex:e.constant(c),text:e.constant(a)}})},label:f}}});l("qk","4s 7 s 6o l 6p".split(" "),function(d,e,c,a,b,f){return function(g,h){var k=a.sanitise(g);return{patterns:function(){return[new f("("+k+")","gi")]},useCursor:e.constant(!0),generate:function(a,f){var g=b.fromTag("span",a.dom());g.dom().innerHTML=
h;return d.species({elements:e.constant([g]),cursor:c.none,dictation:c.none,notify:c.none})},derive:function(a){var b=a.index;a=b+a[0].length;return c.some({startIndex:e.constant(b),finishIndex:e.constant(a)})}}}});l("ql","4s 7 s f9 6o 2o l 2p 3d 6p".split(" "),function(d,e,c,a,b,f,g,h,k,m){return function(p,n,l){var q=b.sanitise(n);return{patterns:function(){return[new m("^("+q+"\\s)(.+)","gi")]},useCursor:e.constant(!1),generate:function(b,m){var n=g.fromTag(p,b.dom());f.set(n,"list-style-type",
l);var q=g.fromTag("li",b.dom()),w=g.fromTag("li",b.dom());h.append(w,g.fromTag("br",b.dom()));k.append(n,[q,w]);k.append(q,m.clones());return d.species({elements:e.constant([n]),cursor:e.constant(c.some(a.point(w,0))),dictation:c.none,notify:c.none})},derive:function(a){var b=a[1];return c.some({startIndex:e.constant(a.index),finishIndex:e.constant(a.index+b.length)})}}}});l("qm","4s 7 s 6o l 3d 6p".split(" "),function(d,e,c,a,b,f,g){var h=function(a,h){return{patterns:function(){return[new g("^("+
a+")(.+)","gi")]},useCursor:e.constant(!1),generate:function(a,g){var k=b.fromTag(h,a.dom());f.append(k,g.clones());return d.species({elements:e.constant([k]),cursor:c.none,dictation:c.none,notify:c.none})},derive:function(a){var b=a[1];return c.some({startIndex:e.constant(a.index),finishIndex:e.constant(a.index+b.length)})}}};return{normal:function(b,c){var d=a.sanitise(b);return h(d,c)},spaced:function(b,c){var d=a.sanitise(b)+"\\s";return h(d,c)}}});l("qn","4s 7 s 6o l 2p 6p".split(" "),function(d,
e,c,a,b,f,g){return function(h,k,m,p){var n=a.sanitise(k),l=a.sanitise(m);return{patterns:function(){return[new g(n+"([^\\s].*?[^\\s])"+l,"gi"),new g(n+"([^\\s])"+l,"gi")]},useCursor:e.constant(!0),generate:function(a,g){var h=b.fromTag(p,a.dom()),k=b.fromText(g.text());f.append(h,k);return d.species({elements:e.constant([h]),cursor:c.none,dictation:c.none,notify:c.none})},derive:function(a){return c.some({startIndex:e.constant(a.index),finishIndex:e.constant(a.index+a[0].length),text:e.constant(a[1])})}}}});
l("qo","4s 7 s 6o l 6p".split(" "),function(d,e,c,a,b,f){return function(g,h){var k=a.sanitise(g);return{patterns:function(){return[new f("("+k+")","gi")]},useCursor:e.constant(!0),generate:function(a,f){return d.species({elements:e.constant([b.fromTag(h,a.dom())]),cursor:c.none,dictation:c.none,notify:c.none})},derive:function(a){return c.some({startIndex:e.constant(a.index),finishIndex:e.constant(a.index+a[0].length)})}}}});l("qp","4s 7 s l v 6p".split(" "),function(d,e,c,a,b,f){var g=function(b,
f){return d.species({elements:e.constant([a.fromText(f.text())]),cursor:c.none,dictation:c.none,notify:c.none})},h=function(){return{patterns:function(){return[/([^.?!][.?!]\s+)([a-z][^\s]*)/g,/^()([a-z][^\s]*)/g]},useCursor:e.constant(!0),generate:g,derive:function(a){var d=a.index,f=d+a[0].length;a=a[1]+b.capitalize(a[2]);return c.some({startIndex:e.constant(d),finishIndex:e.constant(f),text:e.constant(a)})}}}(),k=function(){return{patterns:function(){return[new f("([A-Z][A-Z]+)([a-z]+)","g")]},
useCursor:e.constant(!1),generate:g,derive:function(a){var d=a[2],d=b.capitalize(a[1].toLowerCase())+d.toLowerCase(),f=a.index;a=f+a[0].length;return c.some({startIndex:e.constant(f),finishIndex:e.constant(a),text:e.constant(d)})}}}();return{capitalise:e.constant(h),normalise:e.constant(k)}});l("qq","4s 7 s ci q3 1a l 2p".split(" "),function(d,e,c,a,b,f,g,h){return{patterns:function(){return[a.autolink()]},useCursor:e.constant(!0),generate:function(a,b){var p=g.fromTag("a");f.set(p,"href",b.href());
h.append(p,g.fromText(b.text()));return d.species({elements:e.constant([p]),cursor:c.none,dictation:c.none,notify:e.curry(c.some,[p])})},derive:function(a){var d=b.preprocess(a[1]),f=d.text(),d=d.href();return-1<f.indexOf("@")?c.none():c.some({startIndex:e.constant(a.index),finishIndex:e.constant(a.index+f.length),text:e.constant(f),href:e.constant(d)})}}});l("il","b qj qk ql qm qn qo 7 r 7b qp qq 6u 2b 3x".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t){var s=h.constant(function(a,b){return b});
return function(t,v,w){var y=w.whitelist.fold(s,function(a){return function(b,c){return d.contains(a,b)?c:[]}}),x=function(a){return{derive:a.derive,generate:a.generate,patterns:a.patterns,useCursor:a.useCursor,allowed:h.constant(!0)}},z=function(a,b){return{derive:a.derive,generate:a.generate,patterns:a.patterns,useCursor:a.useCursor,allowed:function(a){return!1===l.closest(a,b)}}};w=y("headings",[x(b.spaced("######","h6")),x(b.spaced("#####","h5")),x(b.spaced("####","h4")),x(b.spaced("###","h3")),
x(b.spaced("##","h2")),x(b.spaced("#","h1"))]);var A=y("lists",[x(a("ul","*","disc")),x(a("ol","1.","decimal")),x(a("ol","a.","lower-alpha")),x(a("ol","i.","lower-roman")),x(a("ol","1)","decimal")),x(a("ol","a)","lower-alpha")),x(a("ol","i)","lower-roman"))]),D=y("semantics",[x(f("bold","**","**","strong")),x(f("bold","__","__","strong")),x(f("italic","*","*","em")),x(f("italic","_","_","em"))]),B=y("entities",[x(c("(c)","&copy;")),x(c("-","&mdash;"))]),C=y("capitalisation",[x(p.normalise()),x(p.capitalise())]),
F=function(a){return m.translate("aria.autocorrect.announce",a)};t=t.hasAutocorrect()?y("autocorrect",[x(e("autocorrect",t.lookup,F))]):[];var F=y("hr",[x(g("---","hr"))]),E=k.cached(function(a){a.runOrOnLoaded(function(b){var c=k.cached(function(){q.owner(b).dom().execCommand("AutoUrlDetect",!1,!1)});a.events.focus.bind(function(){c()})});return y("link",[z(n,"a")])});return{headings:h.constant(w),semantics:h.constant(D),entities:h.constant(B),cases:h.constant(C),lists:h.constant(A),dynCustoms:function(){var a=
v.get();return d.map(a,x)},link:E,hr:h.constant(F),corrections:h.constant(t)}}});l("xy","b 1b 21 69 az 1s".split(" "),function(d,e,c,a,b,f){return{cloneAfter:function(g,h,k){var m=h;return d.map(g,function(d){var g=a.deep(d);c.isText(d)&&e.eq(k.endContainer(),d)&&b.get(d).length>k.endOffset()&&b.set(g,b.get(g).substring(0,k.endOffset()));if(c.isText(g)&&0<m){var h=b.get(g);d=f.min(h.length,m);h=h.substring(d);b.set(g,h);m-=d}return g})}}});l("xz",["s","k"],function(d,e){return{matcher:function(c,
a,b){var f=function(a){return b.fold(function(){return a&&1<a.length},function(b){return a&&0<a.length&&a.index+a[0].length===b})};return e.findMap(c,function(b){a:{if(!b.global)throw"Macro matching only works with global regexes: "+b;for(var c=b.exec(a);c;){if(f(c)){b=d.some(c);break a}c=b.exec(a)}b=d.none()}return b})}}});l("qr","4s m3 xy xz 6 7 s qh".split(" "),function(d,e,c,a,b,f,g,h){var k=function(a,e,g,h){e=c.cloneAfter(e,h.finishIndex(),g);var k=b.merge(h,{clones:f.constant(e)});return{build:function(b){b=
a.generate(b,k);return d.applicator({elements:b.elements,cursor:b.cursor,range:f.constant(g),dictation:b.dictation,notify:b.notify})}}};return{detect:function(b,c,d,f){var l=c.patterns(),t=b.cursor().filter(c.useCursor);return a.matcher(l,b.text(),t).bind(c.derive).bind(function(a){var b=h.top(d);if(0<b.length){var m=e(b[0],0,d,f);return g.some(k(c,b,m,a))}return g.none()})}}});l("qs","4s m3 xz 7 s hv".split(" "),function(d,e,c,a,b,f){var g=function(b,c,d){c=f.get(b,c);var e=f.get(b,d);return c.bind(function(b){return e.map(function(c){return{start:a.constant(b),
finish:a.constant(c)}})})},h=function(a,c){return c(a.start().element())&&c(a.finish().element())?b.some(a):b.none()};return{detect:function(b,f,p,n){p=f.patterns();n=b.cursor().filter(f.useCursor);return c.matcher(p,b.text(),n).bind(f.derive).bind(function(c){return g(b.list(),c.startIndex(),c.finishIndex()).bind(function(b){return h(b,f.allowed).map(function(b){var g=c.startIndex()-b.start().start(),h=c.finishIndex()-b.finish().start(),k=e(b.start().element(),g,b.finish().element(),h);return{build:function(b){b=
f.generate(b,c);return d.applicator({elements:b.elements,cursor:b.cursor,range:a.constant(k),dictation:b.dictation,notify:b.notify})}}})})})}}});l("im","ez b qr qs am 7 83 fz 2n".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(a,c,f){return c.doc().bind(function(m){m=a.build(m);var p=m.elements();e.map(p,d.doNotMerge);var l=h.handle(m.range());g.insertAt(c,l,p);e.map(p,d.clear);m.dictation().each(function(a){b.shout(k.body(),a())});m.notify().each(function(){f.input(p)});return m.cursor()})},
p=function(a,b,c,d,e){return a.detect(b,c,d,e).map(function(a){return{execute:f.curry(m,a)}})};return{block:f.curry(p,c),inline:f.curry(p,a)}});l("af","b ik 7 s k fy il im".split(" "),function(d,e,c,a,b,f,g,h){return function(k,m,p,n,l,q,t,s){var u=a.none(),v=a.none(),w=g(l,q,s),y=d.flatten([w.link(m),w.hr(),w.semantics(),w.entities()]),x=function(){return d.flatten([y,k.autocorrect().get()?w.corrections():[],k.capitalisation().get()?w.cases():[],w.dynCustoms()])},z=w.headings().concat(w.lists()),
A=function(a,c,g,h){var k=f.descend(c,g),m=e.get(k.element(),k.offset());g=d.filter(h,function(a){return a.allowed(c)});return b.findMap(g,function(b){return a(m,b,k.element(),k.offset())})},D=function(a,b){m.undoOperation(function(){a(function(){return b.execute(m,t)}).each(function(a){m.setSelection(a.element(),a.offset(),a.element(),a.offset())});m.domChanged()})};return{spaceDown:function(){m.getSelection().map(function(a){a.collapsed()&&(u=A(h.inline,a.startContainer(),a.startOffset(),x()))})},
spaceUp:function(){var b=c.curry(D,n.run);u.each(b);u=a.none()},enterDown:function(){m.getSelection().map(function(a){a.collapsed()&&(v=A(h.block,a.startContainer(),a.startOffset(),z.concat()));v=v.orThunk(function(){return A(h.inline,a.startContainer(),a.startOffset(),x())})})},enterUp:function(){var b=c.curry(D,c.apply);v.each(b);v=a.none()}}}});l("5u","7 7b 6y af ag 71 7c 59 4a".split(" "),function(d,e,c,a,b,f,g,h,k){return function(m,p,n,l){var q=m.profile(),t=m.content(),s=m.undo(),u=m.context(),
v=m.operations(),w=m.internalevents(),y=k.create({analytics:h(["message"])}),x=c(n.customs),z=a(q,t,s,v,p,x,w,l);t.events.keydown.bind(function(a){b.isSpace(a)&&z.spaceDown()});t.events.keyup.bind(function(a){b.isSpace(a)&&z.spaceUp()});u.events.preLinebreak.bind(function(a){z.enterDown()});u.events.postLinebreak.bind(function(a){z.enterUp()});var A=function(a){return function(){var b=a.get();a.setAndCache(!b)}},D=function(a){return function(b){(!0===a.get()?b.select:b.deselect)()}};p=function(a,
b,c){return{toggle:!0,value:a,textkey:e.key(b),action:A(c),updateGeneral:D(c),icon:!1,tooltip:g.get}};return{ui:f.ui({"capitalisation.general":p("capitalisation","cog.capitalisation",m.profile().capitalisation()),"autocorrect.general":p("autocorrect","cog.autocorrect",m.profile().autocorrect())}),destroy:d.noop,events:y.registry,customMacros:d.constant(x),state:function(){return{customs:x.state()}}}}});l("in","8b fh am c gt 8y 53 hg eh 7 gv lq 7b gw 34 59 4a 1a 1y 3y l 2z 2p 3d 2r 33".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t,s,u,v,w,y,x,z,A,D,B,C){var F=a.detect().deviceType.isTouch(),E=function(a){a.disable();e.disable(a.element())};return function(){var a=u.create({insert:s(["embed"]),input:s(["raw"])}),H=x.fromTag("span"),I=n.textarea("media-embed","media.embed"),K=l.translate("media.placeholder"),J=c.describe(I.textarea(),K);A.append(I.element(),J);J=g.span();d.hidden(J,!0);w.add(J,t.resolve("media-icon"));v.set(J,"alt",l.translate("media.insert"));var L=h(),N=l.translate("media.insert");
L.content(k(N));w.add(L.element(),[t.resolve("media-insert")]);q.makeDefault(L.element());d.button(L.element(),N);v.set(I.textarea(),"placeholder",K);E(L);a.registry.input.bind(function(){var a=C.get(I.textarea());L.disabled()?""!==a&&(L.enable(),e.enable(L.element())):""===a&&E(L)});var M=y.bind(I.textarea(),"input",a.trigger.input);D.append(H,[J,I.element(),L.element()]);var O=function(){var b=C.get(I.textarea());a.trigger.insert(b);F&&z.blur(I.textarea())},K=[f.input(I.textarea(),b.input({})),
f.button(L.element(),b.button({execute:p.click}))];L.events.click.bind(function(){O()});return{element:m.constant(H),execute:O,empty:function(){C.set(I.textarea(),"")},keylayouts:m.constant(K),events:a.registry,destroy:function(){M.unbind();L.destroy();B.remove(H)}}}});l("ai","ak 8b gt 8y 7 7b in 34 ay 4a 4b 4e".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n){return function(l){var q=l.region(),t=l.content(),s=l.smartview(),u=g(),v=a.inlineDialog(u.element(),u.keylayouts(),c.inlineDialog({ok:u.execute,
cancel:b.noop}));e.dialog(u.element(),f.translate("insert.media"));var w=d.popup(s.uiContainer,s.bounds,q,[],k.editorContainer()).initMenu(u.element());n.add(u.element(),[h.resolve("media-embed-dialog"),h.resolve("inline-dialog")]);v.events.exit.bind(function(){y()});var y=function(){w.closed()||(w.close(),u.empty(),t.focus(),v.exit())};l=m.create({insert:p(["embed"],u.events.insert)});return{element:u.element,showPopup:function(a){w.open();a.show(q,t,s,w,u);v.enter()},isClosed:w.closed,events:l.registry,
destroy:function(){y();v.destroy();u.destroy();w.destroy()}}}});l("aj","53 7 io he 7b 34 59 4a 1a 1y l 2z 2p ip 33".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,n,l,q,t){return function(s){s=d.div();m.add(s,f.resolve("media-widget"));var u=d.span();m.add(u,f.resolve("media-widget-field"));var v=p.fromTag(q.isLarge()?"textarea":"input");m.add(v,f.resolve("media-widget-input"));var w=b.translate("media.placeholder");k.set(v,"placeholder",w);k.set(v,"title",w);l.append(u,v);w=c([f.resolve("media-widget-insert")],
"insert.media");l.append(u,w.element());l.append(s,u);var y=a.text(u,v),x=h.create({insert:g(["embed"]),toEditor:g([])}),z=function(){var a=t.get(v);x.trigger.insert(a);x.trigger.toEditor()};w.events.click.bind(function(){z()});return{element:e.constant(s),addEscape:function(a){l.append(u,a.element())},open:function(){t.set(v,"");n.focus(v)},close:e.noop,execute:function(){z()},destroy:e.noop,type:e.constant(y),events:x.registry}}});l("5v","c 7 79 ah 9a 7b ai aj 71".split(" "),function(d,e,c,a,b,
f,g,h,k){return function(m){var p=m.content(),n=function(){var b=c.destroyable(),d=function(){b.clear();p.events.mousedown.unbind(d)};return{open:function(){var c=g(m);c.events.insert.bind(function(a){a=a.embed();m.insertFilteredHtmlAtCursor(a);p.cursorIntoView();d()});c.showPopup(a);p.events.mousedown.bind(d);b.set(c)},destroy:function(){d()}}},l=function(){var a=h(m);a.events.insert.bind(function(a){a=a.embed();m.insertFilteredHtmlAtCursor(a);p.cursorIntoView()});return b(m,a)},q=(d.detect().deviceType.isTouch()?
l:n)();return{ui:k.ui({"media.general":{toggle:!1,value:"media",textkey:f.key("insert.media"),action:q.open,updateGeneral:e.noop,icon:!0,shortcut:!1,hasPopup:!1,hasDialog:!0}}),destroy:function(){q.destroy()}}}});l("ao","7 34 1y l 2p 2r 6e 3x".split(" "),function(d,e,c,a,b,f,g,h){return function(k,m){var p=a.fromTag("div");c.add(p,e.resolve("mentions-business-card"));var n=k.initMenu(p),l=null,q=function(a,c,d){f.empty(p);b.append(p,d);n.open();a(c,n)};return{showFull:function(a){return function(b,
c){g(l);l=h(function(){q(a,b,c)},500)}}(m.showUnder),showMini:d.curry(q,m.showAtSide),hide:function(){g(l);n.close()},destroy:function(){g(l);n.destroy()}}}});l("ap","a 1p s p 2v l o".split(" "),function(d,e,c,a,b,f,g){var h=b.immutable("rawData","extra"),k=function(b,c,e){if(d.isArray(c)&&d.isArray(e))return a.value(h(c,e));g.error(b+" callback parameters were not both arrays",c,e);return a.error(b+" callback parameters were not both arrays")},m=function(b,c){if(e.isPrototypeOf(c))return a.value(f.fromDom(c));
g.error(b+" was not a DOM element",c);return a.error(b+" was not a DOM element")};return function(a){var b=c.none();return{fetch:function(b,c){a.fetch(b,function(a,b){var d=k("fetch()",a,b);c(d)})},fetchExtra:function(b,c,d){a.menuExtra(b,c,function(a,b){var c=k("menuExtra()",a,b);d(c)})},menuHover:function(d,e){b=c.some(d.userid);a.menuHover(d,function(a){a=m("menuHover() callback",a);b.is(d.userid)&&e(a)})},hover:function(b,c){a.hover(b.dom(),function(a){a=m("hover() callback",a);c(a)})},menuComplete:function(b){b=
a.menuComplete(b);return m("menuComplete result",b)},hoverSelector:function(){return a.hoverSelector},isTrigger:function(a){return 64===a}}}});l("aq",["b","cw"],function(d,e){return{configure:function(c){var a=[c.internal(),c.history(),c.output()];d.each(a,function(a){c.addSelector(a,"span.ephox-polish-incomplete-mention",e.unwrap)});c.addExcludedContext(["span.ephox-polish-incomplete-mention"])}}});l("qt","b gr 6 7 s 34 4q 4p 1a l 2g 3d 2r 32 b0 q".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,l,r,q,
t,s){var u=f.resolve("no-results"),v=f.resolve("loading-results"),w=g.generate([{none:["item"]},{extra:["value","item"]},{fetched:["userId","name","rawname","info","item"]}]);return function(g){var x=e.mainmenu(m.fromDom(s),f.resolve("mentions-list"),[]),z=h({}),A=function(a){return a.userid},D=function(a){return a.name},B=function(a,b){q.child(a,".ephox-gopher-item-text").each(function(a){p.set(a,b)})},C=function(a){return d.map(a,function(a){var b=e.item(m.fromDom(s),a.userid,a.name);B(b,a.name);
return b})},F=function(a){return d.foldr(a,function(a,b){var d={};d[b.userid]=b;return c.merge(a,d)},{})},E=function(a,b){var c=C(a),f=d.map(b,function(a){return e.item(m.fromDom(s),a.key,a.value)});return c.concat(f)},G=function(a){var b=k.get(a,"data-ephox-gopher-item-value"),c=z.get();return void 0!==c[b]?w.fetched(c[b].userid,c[b].name,c[b].rawname,c[b],a):d.contains([v,u],b)?w.none(a):w.extra(b,a)};return{element:a.constant(x),selected:function(){return q.descendant(x,".ephox-gopher-item-selected")},
setData:function(a,b){var d=F(a);z.set(c.merge(z.get(),d));d=0===a.length?[{userid:u,name:g.get("mentions.lookahead.noresults")}]:a;d=E(d,b);r.empty(x);l.append(x,d)},getInfo:G,getUserId:function(c){return G(c).fold(b.none,b.none,a.compose(b.some,A))},setLoading:function(){var a=[{userid:v,name:g.get("mentions.lookahead.searching")}],a=E(a,[]);r.empty(x);l.append(x,a)},getName:function(c){return G(c).fold(b.none,b.none,a.compose(b.some,D))},refind:function(a){a=k.get(a,"data-ephox-gopher-item-value");
return void 0!==a&&null!==a?q.descendant(x,'[data-ephox-gopher-item-value="'+a+'"]'):b.none()},isOpen:function(){return t.isVisible(x)}}}});l("iq","am 7 s qt 59 4a 4q 4p 2n 3n v 6e o q 3x".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,l,r,q,t){var s=g.generate([{nothing:[]},{refetch:["term"]},{open:["term"]}]);return function(g,l,n){var q=function(a){d.speak(k.body(),a)},r=a(n);g.setView(r.element());var t=h(""),A=function(a){B(a.rawData(),a.extra());g.reposition(c.none())},D=function(a){var b=r.selected();
a();return b.bind(r.refind)},B=function(a,b){q(n.get("mentions.lookahead.open"));g.updateItems(D,function(){r.setData(a,b)})},C=function(a){return r.isOpen()&&2<=a.length?s.refetch(a):2<=a.length?s.open(a):s.nothing()},F=function(a){a.fold(G,A)},E=f.create({accept:b(["information"]),menuHover:b(["element","info"]),none:b([])}),G=function(){g.cancel()};return{setData:B,isOpen:function(){return r.isOpen()},lookup:function(a,b){var c=p.startsWith(a,"@")?a.substring(1):a;t.set(c);var d=e.noop;C(c).fold(d,
function(a){l.fetch(a,F)},function(a){r.setLoading();g.open(b);l.fetch(a,F)})},close:function(){g.close()},onClick:function(a){r.getInfo(a).fold(function(){E.trigger.none()},function(a,b){l.fetchExtra(a,t.get(),F)},function(a,b,c,e,f){d.speak(k.body(),n.get("mentions.lookahead.selected",c));E.trigger.accept(e)})},onHover:function(a){q(m.get(a));r.getInfo(a).fold(e.noop,e.noop,function(a,b,c,d,e){E.trigger.menuHover(e,d)})},events:E.registry}}});l("ir","7 s 34 59 4a 4p 1y l 2p 2r b0".split(" "),function(d,
e,c,a,b,f,g,h,k,m,p){return function(l,r,q,t){var s=h.fromTag("div");g.add(s,c.resolve("mentions-lookahead-container"));var u=q.initMenu(s),v=f(e.none()),w=b.create({close:a([])}),y=function(){return p.isVisible(s)};q=function(){v.set(e.none());u.close()};u.events.close.bind(function(){r.close();w.trigger.close()});l.events.mousedown.bind(q);return{element:d.constant(s),destroy:function(){v.set(e.none());u.destroy()},setView:function(a){m.empty(s);k.append(s,a)},updateItems:function(a,b){a(b).fold(function(){r.setActiveMenu(s)},
function(a){r.select(a)})},reposition:function(a){a.isSome()&&v.set(a);y()&&v.get().each(function(a){t.showUnder(a,u)})},open:function(a){l.body().each(function(b){u.open();t.showUnder(a,u);v.set(e.some(a));r.open([r.sandbox()],b)})},isOpen:y,cancel:function(){v.set(e.none());w.trigger.close()},close:q,events:w.registry}}});l("ar",["s","iq","ir","4a","4b"],function(d,e,c,a,b){return function(f,g,h,k,m,p){var l=c(f,g,h,k),r=e(l,m,p);f=a.create({menuHover:b(["element","info"],r.events.menuHover),accept:b(["information"],
r.events.accept),close:b([],l.events.close)});r.events.none.bind(l.close);return{onHover:r.onHover,onClick:r.onClick,close:function(){r.isOpen()&&r.close();l.isOpen()&&l.cancel()},isOpen:l.isOpen,lookup:function(a,b){l.reposition(d.some(b));r.lookup(a,b)},destroy:function(){l.destroy()},events:f.registry}}});l("at","87 7 s f9 is 6o it 6p".split(" "),function(d,e,c,a,b,f,g,h){var k=function(){return new h(f.wordbreak(),"i")},m=function(a,b,d){return g.repeatLeft(a,d,function(a,b,c,d,e){return g.previousChar(d,
e).fold(function(){return b.kontinue()},function(a){return b.finish(a.ch())})}).fold(c.none,c.none,c.some)},p=function(b,c,d,e){return 0<=e&&"@"===d.charAt(e)?b.finish(a.point(c,e)):b.abort()},l=function(b,c,d,e){return b.finish(a.point(c,e))},r=function(b){return c.some(a.point(b,d.getEnd(b)))};return{isValidMention:function(a,c){return m(a,b.sidestep,c).fold(e.constant(!0),function(a){return null===a.match(/[0-9a-zA-Z]/)})},scan:function(a,b){return g.expandLeft(a,b,{regex:k,attempt:p}).fold(c.none,
c.none,c.some).bind(function(d){return g.expandRight(a,b,{regex:k,attempt:l}).fold(c.none,r,c.some).map(function(a){return{start:d.element,soffset:d.offset,finish:a.element,foffset:a.offset}})})}}});l("as","b s at 34 4q 21 6m 32 az".split(" "),function(d,e,c,a,b,f,g,h,k){var m=b.generate([{none:[]},{bare:["text","start","soffset","finish","foffset"]},{incomplete:["text","element"]},{complete:["text","element"]}]),p=a.resolve("incomplete-mention"),l=function(a,b){return c.scan(a,b).map(function(a){return m.bare("",
a.start(),a.soffset(),a.finish(),a.foffset())})},r=function(a){if(f.isText(a))return k.get(a);a=g.descendants(a,f.isText);return d.map(a,k.get).join("")},q=function(a,b){return a.collapsed()?h.closest(a.startContainer(),b.hoverSelector()).fold(function(){return h.closest(a.startContainer(),"."+p).fold(function(){return l(a.startContainer(),a.startOffset())},function(a){return e.some(m.incomplete(r(a),a))})},function(a){return e.some(m.complete(r(a),a))}).getOrThunk(m.none):m.none()};return{detect:function(a,
b){return a.getSelection().map(function(a){return q(a,b)}).getOrThunk(m.none)},detectOn:q,withinIncomplete:function(a){return h.closest(a,"."+p)}}});l("au","as 34 1y 1b l 2p 2r".split(" "),function(d,e,c,a,b,f,g){var h=function(a){c.remove(a,e.resolve("incomplete-mention"));g.unwrap(a)};return{cancel:h,create:function(){var a=b.fromTag("span");c.add(a,e.resolve("incomplete-mention"));var d=b.fromText("@");f.append(a,d);return a},validatePrevious:function(b,c){d.withinIncomplete(b).filter(function(b){return d.withinIncomplete(c).forall(function(c){return!a.eq(b,
c)})}).each(h)}}});l("av","b s 34 59 4a 4p 2n 3y l 6u 32 6e 3x".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,l,r){var q="."+c.resolve("mentions-business-card");return function(c,s){var u=f([]),v=null,w=null,y=b.create({contentHover:a(["target"]),stopHover:a([]),menuHover:a(["info"])});c.runOrOnLoaded(function(a){u.set([h.bind(a,"mouseover",function(a){D(a)}),h.bind(g.body(),"mouseover",function(a){p.closest(a.target(),q).each(z)}),h.bind(a,"mouseout",function(a){B(a)}),h.bind(g.body(),"mouseout",function(a){C(a)})])});
var x=function(a){l(v);l(w);v=r(function(){y.trigger.contentHover(a)},300)},z=function(){l(w)},A=function(){l(v);w=r(function(){y.trigger.stopHover()},300)},D=function(a){p.closest(a.target(),s).each(function(a){x(a);y.trigger.contentHover(a)})},B=function(a){if(!m.closest(a.target(),s))return!1;e.from(a.raw().relatedTarget||a.raw().toElement).map(k.fromDom).filter(function(a){return m.closest(a,s)}).isNone()&&A()},C=function(a){if(!m.closest(a.target(),q))return!1;e.from(a.raw().relatedTarget||a.raw().toElement).map(k.fromDom).filter(function(a){return m.closest(a,
q)}).isNone()&&A()};return{destroy:function(){d.each(u.get(),function(a){a.unbind()})},events:y.registry}}});l("aw",["a","ci","7b","9"],function(d,e,c,a){var b=function(a,b){return 1<arguments.length||/\{(\d+)\}/.test(a)?e.tokens.call(void 0,a,b):a};return function(e){return{get:function(g){var h=e[g];return d.isString(h)?b(h,a.prototype.slice.call(arguments,1)):c.translate.apply(void 0,arguments)}}}});l("iu",["7","fl","fm"],function(d,e,c){return function(a){return{show:function(b,f,g,h,k){f=c(0,
0);b=b.directionAt(a);b=e.mainmenu(g,d.constant(a),f,b);g.show(h,b);h.setComponents([a,k.element()])},showWith:function(b,c,g,h,k){b=b.directionAt(a);b=e.submenu(g,d.constant(a),b);g.show(h,b);h.setComponents([a,k.element()])}}}});l("ax",["7","iu","w"],function(d,e,c){return function(a,b,c,g){return{showAtSide:function(g,k){e(g).showWith(a,b,c,k,{element:d.constant(k.element())})},showUnder:function(g,k){e(g).show(a,b,c,k,{element:d.constant(k.element())})}}}});l("5w","84 ak al b am 9o an 7 83 ao ap aq ar as at au av aw ax ay 2n 2o l 2z 2p 21 6m 2r az b0 w".split(" "),
function(d,e,c,a,b,f,g,h,k,m,p,l,r,q,t,s,u,v,w,y,x,z,A,D,B,C,F,E,G,H,I){return function(K,J){var L=v(J.aria),N=K.content(),M=K.smartview(),O=K.region(),S=K.operations(),P=p(J),T=e.menuSystem(M.uiContainer,h.constant("mentions"),c.menu({focusActive:!1}));z.set(T.sandbox(),"z-index",I(void 0!==J.zIndex?J.zIndex:1E6));var Q=e.popup(T.sandbox,M.bounds,O,[],y.editorContainer()),M=w(O,N,M,T.sandbox()),V=r(N,T,Q,M,P,L),W=m(Q,M);l.configure(K.filter());var $=u(N,P.hoverSelector());V.events.menuHover.bind(function(a){P.menuHover(a.info(),
function(b){b.fold(h.noop,function(b){H.isVisible(a.element())&&W.showMini(a.element(),b)})})});$.events.contentHover.bind(function(a){P.hover(a.target(),function(b){b.fold(h.noop,function(b){V.close();W.showFull(a.target(),b)})})});$.events.stopHover.bind(function(a){W.hide()});T.events.itemHover.bind(function(a){a=a.item();V.onHover(a);N.backupSelection();D.focus(a);N.focus()});T.events.itemAction.bind(function(a){V.onClick(a.item())});N.events.nodeChanged.bind(function(a){N.getSelection().each(function(b){b.collapsed()&&
(q.detectOn(b,P).fold(V.close,V.close,h.noop,V.close),a.prev().each(function(a){s.validatePrevious(a,b.startContainer())}))})});N.events.keyup.bind(function(b){N.getSelection().each(function(c){c.collapsed()&&(a.contains(X,b.original().raw().which)||q.withinIncomplete(c.startContainer()).each(function(b){var c=F.descendants(b,C.isText),c=a.map(c,G.get).join("");V.lookup(c,b);W.hide()}))})});N.events.keypress.bind(function(a){var c=a.original();P.isTrigger(c.raw().which)&&N.getSelection().each(function(a){t.isValidMention(a.startContainer(),
a.startOffset())&&(a=function(){var a=s.create();k.insertAtCursor(N,[a]).each(function(a){N.setSelection(a.element(),a.offset(),a.element(),a.offset())});c.kill();b.speak(x.body(),L.get("mentions.initiated"))},q.detect(N,P).fold(a,a,h.noop,h.noop))})});var X=a.flatten([g.ENTER(),g.DOWN(),g.UP()]);K.context().events.preLinebreak.bind(function(a){Y(function(b,c){V.isOpen()?a.handler().handle():ca()},h.noop)});N.events.keydown.bind(function(b){var c=b.original().raw().which;a.contains(g.ESCAPE(),c)?
Y(function(){ca();b.original().kill()},h.noop):a.contains(X,c)&&V.isOpen()&&(T.simulateKey(b.original()),b.original().kill())});var Y=function(a,b){q.detect(N,P).fold(b,b,a,b)},da=function(a){Y(function(b,c){P.menuComplete(a).each(function(a){B.after(c,a);E.remove(c);var b=A.fromText(d.zeroWidth());B.after(a,b);N.setRelativeSelection(f.after(b),f.after(b));R()})},R)},R=function(){W.hide();V.close()},ca=function(){Y(function(a,c){b.speak(x.body(),L.get("mentions.lookahead.cancelled"));S.atomic(function(){s.cancel(c)});
R()},R)};V.events.close.bind(ca);V.events.accept.bind(function(a){da(a.information())});return{destroy:function(){V.destroy();W.destroy();$.destroy();T.destroy()}}}});l("b1",["b","s","7b","2v"],function(d,e,c,a){var b=a.immutable("textkey","value","icon");return function(a){var g=function(a){var d;d={zh:"zh_cn",pt:"pt_br"};d=void 0===d[a]?a:d[a];d=c.has("parlance."+d)?c.key("parlance."+d):c.raw(d);return b(d,a,e.none())},h=d.map(a.languages,g);return{build:function(b){return b.filter(function(b){return!d.contains(a.languages,
b)}).fold(function(){return h},function(a){return h.concat([g(a)])})}}}});l("5x","7 s 7k 7l b1 7b 71 7j 7n b2 3x".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){return function(l,r,q){var t=l.content(),s=l.undo(),u=b(q),v=function(){return t.on(function(a){return m.language(a).fold(h.off,h.on)}).getOrThunk(h.unchanged)};return{ui:g.ui({"parlance.dropdown":d.constant({name:"parlance",textkey:f.key("parlance.set"),menuTextkey:f.key("parlance.menu"),updateDropdown:function(a){var b=v(),c=b.fold(e.none,e.none,
e.some),c=u.build(c);a.populate([{label:e.none,items:d.constant(c)}]);b.fold(a.deactivate,d.noop,a.activate);b.fold(a.untick,d.noop,a.tick)},action:function(b){var e=function(a){return k.language(t.isRoot,a,b)};r.lock(function(){a.cata(l.selections().get(),d.noop,c.multiple(t,s,e),c.single(t,s,e));t.getSelection().each(function(a){r.check(a.startContainer(),a.startOffset(),a.endContainer(),a.endOffset())})});p(function(){t.uiChanged()},0)},values:u.build(e.none()),render:e.none(),toggle:!1,describe:function(){return f.key("parlance.set")}})},
d.identity),destroy:d.noop}}});l("qu",["8b","7","7b","l"],function(d,e,c,a){return function(){var b=a.fromTag("textarea");d.label(b,c.translate("plaincode.dialog.editor"));d.textarea(b);return{element:e.constant(b)}}});l("iv","8y l3 an s gu gv qu 7b gw 34 59 4a 1y 33".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,l,r,q){return function(t){var s=l.create({execute:p(["html"]),close:p([])}),u=b(t);r.add(u.element(),m.resolve("plaincode-modal"));u.setTitle(h.translate("plaincode.dialog.title"));var v=function(){w();
s.trigger.close()},w=function(){u.hide()},y=g();u.setContent(y.element());t=k.okCancel("plaincode");t.events.ok.bind(function(){s.trigger.execute(q.get(y.element()));v()});t.events.cancel.bind(function(){v()});u.events.close.bind(function(){x.exit();v()});u.setControls(t.element());var x=f.setup(u,t,[d.single(y.element(),[e.rule(e.is(c.ENTER()[0]),function(b){b.raw().stopPropagation();return a.none()})],a.none())]);return{element:u.element,open:function(){u.show();x.enter()},setHtml:function(a){q.set(y.element(),
a)},destroy:function(){u.destroy();x.destroy()},hide:w,events:s.registry}}});l("b3",["iv","59","4a"],function(d,e,c){return function(a){var b=d(a),f=function(){g.trigger.close();b.events.close.unbind(f);b.events.execute.unbind(h);b.destroy()},g=c.create({execute:e(["html"]),close:e([])}),h=function(a){g.trigger.execute(a.html())};b.events.close.bind(f);b.events.execute.bind(h);return{show:function(){b.open()},setHtml:b.setHtml,events:g.registry}}});l("5y",["7","b3"],function(d,e){return function(c,
a){var b=c.content(),f=c.shortcuts(),g=c.smartview(),h=a.setContent,k=a.getContent;f.events.plaincode.bind(function(){m()});var m=function(){var a=e(g.uiContainer());a.events.close.bind(function(){b.toEditing()});a.events.execute.bind(function(a){h(a.html())});b.toReading();a.setHtml(k());a.show()};return{destroy:d.noop}}});l("b4","b c 7 7w cw 1a 2r 2b".split(" "),function(d,e,c,a,b,f,g,h){var k=function(){return{configure:function(a){var c=[a.internal(),a.history(),a.output(),a.paste()];d.each(c,
function(c){a.addSelector(c,"[unselectable]",b.removeAttr("unselectable"))})},clean:function(a){f.remove(a,"unselectable")},disableNativeResize:function(a){f.set(a,"unselectable","on")}}},m=function(){return{configure:c.noop,clean:function(b){h.nextSibling(b).filter(a.isEmptyText).each(g.remove)},disableNativeResize:c.noop}};e=e.detect().browser;return e.isIE()?k():e.isFirefox()?m():{configure:c.noop,clean:c.noop,disableNativeResize:c.noop}});l("ix","7 s 59 4a 2o 68 2s v 1s".split(" "),function(d,
e,c,a,b,f,g,h,k){return function(){var m=a.create({grow:c(["x","y"])}),p=1,l=1,r=e.none(),q=function(a){return b.getRaw(a,"width").bind(function(a){return h.endsWith(a,"px")?e.some(parseInt(a,10)):e.none()}).getOrThunk(function(){return g.get(a)})};return{setTarget:function(a){r=e.some(a);l=g.get(a)/(f.get(a)+0)},setMultiplier:function(a){p=a},clearTarget:function(){r=e.none()},mutate:function(a,b){r.each(function(c){var d=q(c)+p*a,e=1===d?1:k.floor(d/l);5<=d&&5<=e&&(g.set(c,d),f.set(c,e));m.trigger.grow(a,
b)})},events:m.registry,destroy:d.noop}}});l("iy","7 34 59 4a 1a 1y 4e 2o 3y l 68 2p 3d 3p 2r 2s".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,l,r,q,t,s){var u="data-"+e.resolve("resize-direction"),v=function(a,c){var d=m.fromTag("span");g.add(d,[e.resolve(a),e.resolve("resize-eph-resizer")]);b.set(d,u,c);return d};return{create:function(){var g=v("element-se-resize","1"),y=v("element-ne-resize","1"),x=v("element-sw-resize","-1"),z=v("element-nw-resize","-1"),A=m.fromTag("div");f.add(A,e.resolve("resize-wrapper"));
r.append(A,[g,y,x,z]);var D=function(){t.remove(A)},B=a.create({click:c(["multiplier"])}),C=k.bind(A,"mousedown",function(a){f.has(a.target(),e.resolve("resize-eph-resizer"))&&(a.prevent(),a=b.get(a.target(),u),a=void 0!==a?parseInt(a,10):1,B.trigger.click(a))});return{refresh:function(a,b){l.append(a,A);var c;c=q.absolute(b);var e=p.get(b),f=s.get(b);c={top:c.top,height:d.constant(e),left:c.left,width:d.constant(f)};e=s.get(x)/2;h.setAll(x,{top:c.top()+c.height()-e+"px",left:c.left()-e+"px"});h.setAll(g,
{top:c.top()+c.height()-e+"px",left:c.width()+c.left()-e+"px"});h.setAll(y,{top:c.top()-e+"px",left:c.width()+c.left()-e+"px"});h.setAll(z,{top:c.top()-e+"px",left:c.left()-e+"px"})},clear:D,events:B.registry,destroy:function(){C.unbind();D()}}}}});l("b5","iw s b4 ix iy 34 59 4a 1y 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m){return function(p){var l=e.none(),r=a();r.events.grow.bind(function(){s()});var q=d.transform(r,{layerClass:f.resolve("layer-below-dialog")});q.events.stop.bind(function(){l.each(function(a){u.trigger.stop(a)})});
k.add(q.element(),f.resolve("resize-eph-block"));var t=b.create();t.events.click.bind(function(a){r.setMultiplier(a.multiplier());p.body().each(function(a){q.go(m.documentElement(a))})});var s=function(){t.clear();l.each(c.clean)},u=h.create({stop:g(["target"])});return{showHandles:function(a){var b=m.documentElement(a);r.setTarget(a);l=e.some(a);q.on();t.refresh(b,a)},hideHandles:s,events:u.registry,destroy:function(){t.destroy();r.destroy();q.destroy();l=e.none()}}}});l("5z","9o s 8c ag 7i b4 b5 21".split(" "),
function(d,e,c,a,b,f,g,h){return function(k){var m=k.content(),p=k.undo();k=k.filter();f.configure(k);var l=g(m),r=function(a){m.getSelection().bind(b.detect).each(function(c){p.save();b.remove(m,c.image());m.domChanged();p.save();a.original().kill()})},q=function(a){m.getSelection().bind(b.detect).each(function(b){m.setRelativeSelection(d.before(b.image()),d.before(b.image()));a.original().kill()})},t=function(a){m.getSelection().bind(b.detect).each(function(b){m.setRelativeSelection(d.after(b.image()),
d.after(b.image()));a.original().kill()})};k=function(){m.getSelection().bind(b.detect).fold(function(){l.hideHandles()},function(a){a=a.image();l.showHandles(a);b.reselect(m,a)})};m.events.loaded.bind(k);m.events.domChanged.bind(k);m.events.paint.bind(k);m.events.nodeChanged.bind(k);m.events.selectionchange.bind(k);var s=e.none();m.events.ready.bind(function(a){a=a.api().body();s=e.some(c.handle(a,function(a){"img"===h.name(a.target())&&b.select(m,a.target())}))});m.events.mousedown.bind(function(a){a=
a.original().target();"img"===h.name(a)&&f.disableNativeResize(a)});m.events.keydown.bind(function(b){a.isDel(b)||a.isBackspace(b)?r(b):a.isLeftOrUp(b)?q(b):a.isRightOrDown(b)&&t(b)});l.events.stop.bind(function(a){a=a.target();l.showHandles(a);b.reselect(m,a)});return{destroy:function(){l.destroy();s.each(function(a){a.unbind()})}}}});l("j2","b 1o 2v qx qy gh 1a 2o l 2p 2r m".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,l){var r=c.immutable("minRow","minCol","maxRow","maxCol"),q=function(a,b){var c=
a.grid().columns(),d=a.grid().rows(),f=c,g=0,h=0;e.each(a.access(),function(a){if(b(a)){var c=a.row(),e=c+a.rowspan()-1,k=a.column();a=k+a.colspan()-1;c<d?d=c:e>g&&(g=e);k<f?f=k:a>h&&(h=a)}});return r(d,f,g,h)},t=function(a,c,d,e){for(var f=c.grid().columns(),g=c.grid().rows(),h=0;h<g;h++)for(var p=!1,l=0;l<f;l++)if(!(h<d.minRow()||h>d.maxRow()||l<d.minCol()||l>d.maxCol()))if(b.getAt(c,h,l).filter(e).isNone()){var n=p,q=a[h].element(),r=k.fromTag("td");m.append(r,k.fromTag("br"));(n?m.append:m.prepend)(q,
r)}else p=!0},s=function(a,b){var c=d.filter(f.firstLayer(a,"tr"),function(a){return 0===a.dom().childElementCount});d.each(c,p.remove);b.minCol()!==b.maxCol()&&b.minRow()!==b.maxRow()||d.each(f.firstLayer(a,"th,td"),function(a){g.remove(a,"rowspan");g.remove(a,"colspan")});g.remove(a,"width");g.remove(a,"height");h.remove(a,"width");h.remove(a,"height")};return{extract:function(c,e){var g="."+e,h=function(a){return l.is(a.element(),g)},k=a.fromTable(c),m=b.generate(k),r=q(m,h),D="th:not("+g+"),td:not("+
g+")",B=f.filterFirstLayer(c,"th,td",function(a){return l.is(a,D)});d.each(B,p.remove);t(k,m,r,h);s(c,r);return c}}});l("b6","b iz 7 7l 3l fi j0 j1 j2 bl l 2p 2r 69".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,l,r,q){var t=function(a){d.each(a,function(a){r.empty(a);l.append(a,p.fromTag("br"))})},s=function(a){return m.table(a[0]).map(q.deep).map(function(a){return[k.extract(a,e.selectedClass())]})},u=function(a,e){var k=c.curry(e.filterDom,e.output()),m=h.register({doc:a.doc,win:a.win,body:a.body,
getSelection:a.getSelection,setSelection:a.setSelection});return function(e,h,p){d.each(h,k);var l=c.curry(b.toText,h);h=c.curry(b.toHtml,h);var l=g.buildClipboardContents(l,h),n=f.fromSafe(a);n.begin();m.setClipboard(e,l,function(){n.end();p.apply(void 0,arguments)})}},v=function(b,d,e){var f=function(b,f){a.cata(d.get(),c.noop,function(a){s(a).each(function(d){e(b,d,c.curry(f,a))})},c.noop)};b.events.cut.bind(function(a){f(a.original(),t)});b.events.copy.bind(function(a){f(a.original(),c.noop)})};
return function(a,b){var d=a.content(),e=a.filter(),f=a.selections();d.events.ready.bind(function(a){a=a.api();var b=u(a,e);v(a,f,b)});return{destroy:c.noop}}});l("qz",["4j"],function(d){return{resolve:d.create("ephox-cement").resolve}});l("j3",["qz","7"],function(d,e){var c=d.resolve("smartpaste-eph-bin");return{binStyle:e.constant(c)}});l("r0",["7","s","2p","2r"],function(d,e,c,a){return function(b,f){var g=function(b,c,f){b(f,c);return e.some({element:d.constant(c),cleanup:function(){a.remove(c)},
splits:d.constant([])})},h=function(a){return{none:e.none,start:d.curry(g,c.before,a),end:d.curry(g,c.after,a),middle:function(b,d,e){return g(c.after,a,d)}}},k=function(a){var b=function(a){return function(b,d){c.appendAt(b,d,a)}};return{prepend:d.curry(g,c.prepend,a),before:d.curry(g,c.before,a),after:d.curry(g,c.after,a),insertAt:function(c,d){return g(b(d),a,c)},append:d.curry(g,c.append,a)}};return{before:{text:h(b),element:{hasPrevious:k(b).insertAt,first:k(b).prepend,empty:k(b).before,otherwise:k(b).append}},
after:{text:h(f),element:{hasNext:k(f).insertAt,rightEdge:k(f).append,empty:k(f).after,otherwise:k(f).append}},general:{insertBefore:k(b).before,insertAfter:k(f).after}}}});l("j4","b 9o ft cx 83 r0 fi r1 2n l 21 2r 6u".split(" "),function(d,e,c,a,b,f,g,h,k,m,p,l,r){return function(c,t){var s=g.fromUnsafe(c),u=m.fromTag("span"),v=m.fromTag("span");d.each([u,v],c.markAsEphemeral);var w=f(u,v);return{backup:function(){c.getSelection().each(function(a){a.collapsed()?(b.insertAtCursor(c,[u]),l.unwrap(v),
s.begin()):h.both(w,a.startContainer(),a.startOffset(),a.endContainer(),a.endOffset())})},insert:function(f,g,h){c.setRelativeSelection(e.after(u),k.inBody(v)?e.before(v):e.after(u));b.insertAtCursorWith(c,f,g,h).each(function(a){!r.ancestor(a.element(),"table")||"td"!==p.name(a.element())&&"th"!==p.name(a.element())?c.setRelativeSelection(e.after(a.element()),e.after(a.element())):c.setSelection(a.element(),0,a.element(),0)});s.end();t.preserve(function(){a.cursorIntoView(c)});d.each([u,v],l.unwrap)},
cancel:function(){d.each([u,v],l.unwrap)}}}});l("r4","b gc 7 s 7l 1a e2".split(" "),function(d,e,c,a,b,f,g){var h=function(a,d){return b.cata(d.get(),c.constant([]),c.identity,c.constant([a]))};return{mergable:function(d,f){return b.cata(f.get(),a.none,function(b,f){return 0===b.length?a.none():e.retrieveBox(d).bind(function(d){return 1<b.length?a.some({bounds:c.constant(d),cells:c.constant(b)}):a.none()})},a.none)},unmergable:function(b,c){var e=function(a){return f.has(a,"rowspan")&&1<g(f.get(a,
"rowspan"),10)||f.has(a,"colspan")&&1<g(f.get(a,"colspan"),10)},l=h(b,c);return 0<l.length&&d.forall(l,e)?a.some(l):a.none()},selection:h}});l("jq",["7","s","r4","2v"],function(d,e,c,a){var b=function(a){return{element:d.constant(a),mergable:e.none,unmergable:e.none,selection:d.constant([])}};a=a.immutable("element","clipboard","generators");return{noMenu:b,forMenu:function(a,b,e){return{element:d.constant(e),mergable:d.constant(c.mergable(b,a)),unmergable:d.constant(c.unmergable(e,a)),selection:d.constant(c.selection(e,
a))}},notCell:function(a){return b(a)},paste:a}});l("j5","r2 b 7 s jn r3 jq bl js 21 3n".split(" "),function(d,e,c,a,b,f,g,h,k,m,p){var l=function(a){return"table"===m.name(a)||0===p.get(a).trim().length},r=function(b){var c=e.filter(b,function(a){return"table"===m.name(a)});return 1!==c.length?a.none():e.forall(b,l)?a.from(c[0]):a.none()};return{rules:function(a,e,m){var p=c.noop,l=function(d,l){return h.table(d,a.isRoot).bind(function(h){var n=a.doc().getOrDie(),n=f.paste(n),n=g.paste(d,l,n),r=
c.constant(m);return b.execute(e,k.pasteCells,p,r)(a,h,n).map(function(a){return a.startContainer()})})},n=function(a){return r(a).map(function(a){return{single:c.constant(a)}})};return{collapsed:c.constant(d(function(a,b,c){return h.cell(b,a)},n,function(a,b){return l(a.element(),b.single())},"custom arcade table insert collapsed")),ranged:c.constant(d(function(a,b,d){return h.cell(b.element(),a).map(function(a){return{left:c.constant(a),right:c.constant(a)}})},n,function(a,b){return l(a.left(),
b.single())},"custom arcade table insert ranged"))}},extractTable:r}});l("140",["b","2v","o"],function(d,e,c){var a="officeStyles htmlStyles isWord proxyBin isInternal backgroundAssets".split(" "),b=e.immutableBag([],a);return{nu:b,merge:function(c,e){var h={};d.each(a,function(a){e[a]().or(c[a]()).each(function(b){h[a]=b})});return b(h)}}});l("11j",["s","4q"],function(d,e){var c=e.generate([{error:["message"]},{paste:["elements","assets","correlated"]},{cancel:[]},{incomplete:["elements","assets",
"correlated","message"]}]),a=function(a,c,d,e,k){return a.fold(c,d,e,k)};return{error:c.error,paste:c.paste,cancel:c.cancel,incomplete:c.incomplete,cata:a,carry:function(b,e){return a(b,d.none,d.none,d.none,function(b,h,k,m){return a(e,d.none,function(a,b,e){return d.some(c.incomplete(a,b,e,m))},d.none,d.none)}).getOr(e)}}});l("13z",["140","11j","3u","2v"],function(d,e,c,a){var b=a.immutableBag(["response","bundle"],[]),f=function(a){return g(function(c){var d=b(a);c(d)})},g=function(a){return c(g,
function(b){a(b)})};return{call:function(a,c){a(b(c))},sync:g,pure:f,pass:function(a){return f({response:a.response(),bundle:a.bundle()})},done:b,error:function(a){return f({response:e.error(a),bundle:d.nu({})})},initial:function(){return f({response:e.paste([],[],[]),bundle:d.nu({})})},cancel:function(){return f({response:e.cancel(),bundle:d.nu({})})}}});l("11i","13z 140 11j b 7 k 2v".split(" "),function(d,e,c,a,b,f,g){var h=g.immutable("steps","input","label","capture"),k=function(a,b){return f.findMap(a,
function(a){return a.getAvailable(b).map(function(b){return h(a.steps(),b,a.label(),a.capture())})})},m=function(a,f){var g=b.curry(d.pass,a),h=function(){return f().map(function(b){var f=e.merge(a.bundle(),b.bundle());b=c.carry(a.response(),b.response());return d.done({response:b,bundle:f})})};return c.cata(a.response(),g,h,g,h)};return{choose:function(a,b,c){return k(a,c).getOrThunk(function(){var a=b.getAvailable(c);return h(b.steps(),a,b.label(),b.capture())})},run:function(b,c){return a.foldl(b,
function(a,b){return a.bind(function(a){return m(a,function(){return b(c,a)})})},d.initial())}}});l("11k",["c","7","3x"],function(d,e,c){var a=d.detect();d=function(a,b,c){b.control.block();a.dom().execCommand("paste");c();b.control.unblock()};var b=function(a,b,d){c(d,1)},f=(a=a.browser.isIE()&&10>=a.browser.version.major)?d:b;return{willBlock:e.constant(a),run:function(a,b,c){return f(a,b,c)}}});l("y0","11i 11j b 7 br 59 4a 11k".split(" "),function(d,e,c,a,b,f,g,h){return function(k,m){var l=g.create({cancel:f([]),
error:f(["message"]),insert:f(["elements","assets","correlated","isInternal"])}),n=b.tap(function(a){h.willBlock()&&(n.control.block(),a.preventDefault());var b=d.choose(k,m,a);b.capture()&&a.preventDefault();a=c.map(b.steps(),function(a){return a(n.control)});d.run(a,b.input()).get(function(a){var b=a.bundle().isInternal().getOr(!1);e.cata(a.response(),function(a){l.trigger.error(a)},function(a,c,d){l.trigger.insert(a,c,d,b)},function(){l.trigger.cancel()},function(a,c,d,e){l.trigger.insert(a,c,
d,b);l.trigger.error(e)})})});return{paste:n.instance,isBlocked:n.control.isBlocked,destroy:a.noop,events:l.registry}}});l("11l",["7"],function(d){return{blocking:function(d){return function(c){return function(a,b,f){c.block();return d(a,b,f).map(function(a){c.unblock();return a})}}},normal:function(e){return d.constant(e)}}});l("141",["2i","h4","3w","h5","s"],function(d,e,c,a,b){return{convert:function(f){var g=d.resolve("window.clipboardData.files"),h=void 0!==f.convertURL?f.convertURL:void 0!==
f.msConvertURL?f.msConvertURL:void 0;return void 0!==g&&void 0!==h&&0<g.length?(g=c.mapM(g,function(b){var c=a.createObjectURL(b);h.apply(f,[b,"specified",c]);return e.singleWithUrl(b,c)}),b.some(g)):b.none()}}});l("11m",["141","3w","7","s"],function(d,e,c,a){return{background:function(){var b=a.none();return{convert:function(a){b=d.convert(a)},listen:function(a){return b.fold(function(){return e.nu(function(a){a([])})},function(a){return a}).get(a)},clear:function(){b=a.none()}}},ignore:function(){return{convert:a.none,
listen:function(a){a([])},clear:c.noop}}}});l("11n",["s","k","6p"],function(d,e,c){var a=function(a,f){var g=new c(f,"i");return e.findMap(a,function(a){return null!==a.match(g)?d.some({type:a,flavor:f}):d.none()})};return{isValidData:function(a){return void 0!==a&&void 0!==a.types&&null!==a.types},getPreferredFlavor:function(b,c){return e.findMap(b,function(b){return a(c,b)})},getFlavor:a}});l("sa",["6","4q"],function(d,e){var c=e.generate([{none:[]},{error:["message "]},{blob:["blob"]}]);return d.merge(c,
{cata:function(a,b,c,d){return a.fold(b,c,d)}})});l("126",["2j"],function(d){return function(e,c){return new (d.getOrDie("Blob"))(e,c)}});l("127",["2j"],function(d){return function(e){return new (d.getOrDie("Uint8Array"))(e)}});l("ym","sa 126 127 bq s p v 9 1s".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(b,d){for(var f=a.atob(b),g=f.length,m=k.ceil(g/1024),l=new h(m),u=0;u<m;++u){for(var v=1024*u,w=k.min(v+1024,g),y=new h(w-v),x=0;v<w;++x,++v)y[x]=f[v].charCodeAt(0);l[u]=c(y)}return e(l,
{type:d})};return{convert:function(a){if(g.startsWith(a,"data:image/")&&11<a.indexOf(";base64,")){var b=a.indexOf(";"),c=a.substr(5,b-5);a=a.substr(b+8);try{return d.blob(m(a,c))}catch(e){return d.error(e)}}else return d.none()}}});l("s9",["ym"],function(d){return{toBlob:function(e){return d.convert(e)}}});l("142","11j b gq 7 2v 1a l 21 4h o".split(" "),function(d,e,c,a,b,f,g,h,k,m){var l=b.immutable("asset","image");return{createImages:function(a){var b=[],h=[],k=[];e.each(a,function(a){return c.cata(a,
function(c,d,e,m){c=g.fromTag("img");f.set(c,"src",e);b.push(c);h.push(a);k.push(l(a,c))},function(a,b,c){m.error("Internal error: Paste operation produced an image URL instead of a Data URI: ",b)})});return d.paste(b,h,k)},findImages:function(b,d){var g=[],m=e.bind(b,function(a){return"img"===h.name(a)?[a]:k.descendants(a,"img")});e.each(d,function(b){c.cata(b,function(a,c,d,h){e.each(m,function(a){f.get(a,"src")===d&&g.push(l(b,a))})},a.noop)});return g},updateSources:function(b,d){var g=[];e.each(b,
function(b,e){c.cata(b,function(a,c,h,k){a=d[e];f.set(a,"src",h);g.push(l(b,a))},a.noop)});return g}}});l("11o","s9 sa 13z 142 11j b h4 s 2v 1a l 21 2r 3d 4h".split(" "),function(d,e,c,a,b,f,g,h,k,m,l,n,r,q,t){var s=k.immutable("blob","image"),u=function(a,b){var c=d.toBlob(b);return e.cata(c,h.none,h.none,function(b){return h.some(s(b,a))})},v=function(a){var b=l.fromTag("div");q.append(b,a);return t.descendants(b,"img[src]")},w=function(a){return 0===a.indexOf("data:")&&-1<a.indexOf("base64")||
0===a.indexOf("blob:")},y=function(a){a=m.get(a,"src");return w(a)},x=function(a){return f.bind(v(a),function(a){var b=m.get(a,"src");return w(b)?u(a,b).toArray():[]})},z=function(a){a=f.filter(a,function(a){return"img"!==n.name(a)||!y(a)});return b.incomplete(a,[],[],"errors.local.images.disallowed")};return function(d){return function(e,h){return c.sync(function(e){var k=function(){c.call(e,{response:h.response(),bundle:h.bundle()})},m=function(d){var k=x(d),m=f.map(k,function(a){return a.blob()});
g.multiple(m).get(function(g){var m=f.map(k,function(a){return a.image()}),m=a.updateSources(g,m);c.call(e,{response:b.paste(d,g,m),bundle:h.bundle()})})},l=function(a,b,g,l){!1===d.allowLocalImages?(b=f.filter(v(a),y),f.each(b,r.remove),c.call(e,{response:0<b.length?z(a):h.response(),bundle:h.bundle()})):0===b.length?m(a):k()};b.cata(h.response(),k,l,k,l)})}}});l("143",["13z","140","11j","3w","o"],function(d,e,c,a,b){var f=function(a){return a.officeStyles().getOr(!0)},g=function(a){return a.htmlStyles().getOr(!1)},
h=function(a){return a.isWord().getOr(!1)};return{proxyBin:function(a){return{handle:function(f,g){return a.proxyBin().fold(function(){b.error(f);return d.pure({response:c.cancel(),bundle:e.nu({})})},g)}}},backgroundAssets:function(b){return a.nu(function(a){b.backgroundAssets().fold(function(){a([])},function(b){b.listen(a)})})},merging:function(a){var b=h(a);return b&&f(a)||!b&&g(a)},mergeOffice:f,mergeNormal:g,isWord:h,isInternal:function(a){return a.isInternal().getOr(!1)}}});l("144","qz 6 7 s 1y l 3m 2p 3d".split(" "),
function(d,e,c,a,b,f,g,h,k){return function(m,l){var n=l.translations,r=function(b,c,d){d(a.some(e.merge(c,{officeStyles:b,htmlStyles:b})))},q=function(c,e){var l=f.fromTag("div");b.add(l,d.resolve("styles-dialog-content"));var p=f.fromTag("p"),q=g.fromHtml(n("cement.dialog.paste.instructions"));k.append(p,q);h.append(l,p);var p={text:n("cement.dialog.paste.clean"),tabindex:0,className:d.resolve("clean-styles"),click:function(){y.destroy();r(!1,c,e)}},q={text:n("cement.dialog.paste.merge"),tabindex:1,
className:d.resolve("merge-styles"),click:function(){y.destroy();r(!0,c,e)}},y=m(!0);y.setTitle(n("cement.dialog.paste.title"));y.setContent(l);y.setButtons([p,q]);y.show();y.events.close.bind(function(){e(a.none());y.destroy()})};return{get:function(a,b){var c=l[a?"officeStyles":"htmlStyles"];"clean"===c?r(!1,l,b):"merge"===c?r(!0,l,b):q(l,b)},destroy:c.noop}}});l("11p",["13z","140","143","144","11j"],function(d,e,c,a,b){var f=function(f,h){var k=a(f,h);return function(a,f){var g=f.bundle(),h=f.response();
return d.sync(function(a){k.get(c.isWord(g),function(c){c=c.fold(function(){return{response:b.cancel(),bundle:f.bundle()}},function(a){return{response:h,bundle:e.nu({officeStyles:a.officeStyles,htmlStyles:a.htmlStyles})}});d.call(a,c)})})}};return{fixed:function(a,b){return function(c,f){return d.pure({response:f.response(),bundle:e.nu({officeStyles:a,htmlStyles:b})})}},fromConfig:f,fromConfigIfExternal:function(a,b){return function(k,m){return c.isInternal(m.bundle())?d.pure({response:m.response(),
bundle:e.nu({officeStyles:!0,htmlStyles:!0})}):f(a,b)(k,m)}}}});l("16f",["c","7","l","q"],function(d,e,c,a){var b=function(a){for(var b=[];null!==a.nextNode();)b.push(c.fromDom(a.currentNode));return b},f=function(a){try{return b(a)}catch(c){return[]}};d=d.detect().browser;var g=d.isIE()||d.isSpartan()?f:b,h=e.constant(e.constant(!0));return{find:function(b,c){var d=c.fold(h,function(a){return function(b){return a(b.nodeValue)}});d.acceptNode=d;d=a.createTreeWalker(b.dom(),NodeFilter.SHOW_COMMENT,
d,!1);return g(d)}}});l("161",["s","16f","v","q"],function(d,e,c,a){return{find:function(a){return e.find(a,d.some(function(a){return c.startsWith(a,"[if gte vml 1]")}))}}});l("14d","s 1a 1y 2o l 21 4l 69 4h v".split(" "),function(d,e,c,a,b,f,g,h,k,m){var l=function(a,c){var d=f.value(a),e=b.fromTag("div"),h=d.indexOf("]>");e.dom().innerHTML=d.substr(h+2);return g.descendant(e,function(a){return f.name(a)===c})},n=function(a){return f.isComment(a)?l(a,"v:shape"):d.none()},r=function(a){return k.descendants(a,
".rtf-data-image")};return{local:function(a){if("img"===f.name(a)){var b=e.get(a,"src");if(void 0!==b&&null!==b&&m.startsWith(b,"file://"))return a=h.shallow(a),b=b.split(/[\/\\]/),e.set(a,"data-image-id",b[b.length-1]),e.remove(a,"src"),e.set(a,"data-image-type","local"),c.add(a,"rtf-data-image"),d.some(a)}return d.none()},vshape:function(d){return n(d).map(function(d){var f=e.get(d,"o:spid"),f=void 0===f?e.get(d,"id"):f,g=b.fromTag("img");c.add(g,"rtf-data-image");e.set(g,"data-image-id",f.substr(7));
e.set(g,"data-image-type","code");a.setAll(g,{width:a.get(d,"width"),height:a.get(d,"height")});return g})},find:r,exists:function(a){return 0<r(a).length},scour:n}});l("15d","161 b 14d s k 2v 1a 3m 4h o".split(" "),function(d,e,c,a,b,f,g,h,k,m){var l=f.immutable("img","vshape"),n=function(b,c){var d=g.get(b,"v:shapes"),f=a.from(e.find(c,function(a){return g.get(a,"id")===d}));f.isNone()&&m.log("WARNING: unable to find data for image",b.dom());return f.map(function(a){var c=g.clone(b);c._rawElement=
b.dom();var d=g.clone(a);d._rawElement=a.dom();return l(c,d)})};return{extract:function(a){var f=h.fromHtml(a);a=e.bind(f,function(a){return k.descendants(a,"img")});var f=e.bind(f,d.find),g=b.cat(e.map(f,c.scour));a=e.map(a,function(a){return n(a,g)});return b.cat(a)}}});l("162","a b 7 s 1a 1y".split(" "),function(d,e,c,a,b,f){var g=function(a,c){var e=c.style;b.has(a,"width")&&b.has(a,"height")&&d.isString(e)&&(e=e.match(/rotation:([^;]*)/),null===e||"90"!==e[1]&&"-90"!==e[1]||b.setAll(a,{width:b.get(a,
"height"),height:b.get(a,"width")}))},h=function(a,b,c){return c.img()[a]===b},k=function(d,f,g){var k=b.get(f,g),k=c.curry(h,g,k);d=e.find(d,k);return a.from(d).map(function(a){b.remove(f,g);return a})};return{rotateImage:g,insertRtfCorrelation:function(a,c,d){e.each(c,function(c){k(a,c,d).each(function(a){a=a.vshape();var d=a["o:spid"],d=void 0===d?a.id:d;g(c,a);f.add(c,"rtf-data-image");b.set(c,"data-image-id",d.substr(7));b.set(c,"data-image-type","code")})})}}});l("15e","162 b 7 1a ns 2o 2r 4h 2b 8a".split(" "),
function(d,e,c,a,b,f,g,h,k,m){var l={p:"p, li[data-converted-paragraph]"},n=c.noop,r=function(b){var c=h.descendants(b,"li[data-converted-paragraph]");e.each(c,function(b){a.remove(b,"data-converted-paragraph")});b=h.descendants(b,"li");e.each(b,function(a){f.remove(a,"margin-left");f.remove(a,"margin-right");f.remove(a,"text-indent")})},q=function(a){a=k.children(a);e.each(a,function(a){b.getOption(a).each(function(b){"StartFragment"!==b&&"EndFragment"!==b||g.remove(a)})})};return{process:function(a,
b,c,e,f){var g=h.descendants(b,"img");q(b);d.insertRtfCorrelation(c,g,e);(f.mergeInline()?m.inlineStyles:n)(a,b,l);r(b)}}});l("15f","7 14l 2o 3y l 2p 2r 3x".split(" "),function(d,e,c,a,b,f,g,h){return function(k){return{play:function(m,l,n){var r=b.fromTag("div"),q=b.fromTag("iframe");c.setAll(r,{display:"none"});var t=a.bind(q,"load",function(){t.unbind();e.write(q,m);var a=q.dom().contentWindow.document;if(void 0===a)throw"sandbox iframe load event did not fire correctly";var c=b.fromDom(a),a=a.body;
if(void 0===a)throw"sandbox iframe does not have a body";a=b.fromDom(a);c=l(c,a);g.remove(r);h(d.curry(n,c),0)});f.append(r,q);f.append(k,r)}}}});l("145","13z 140 15d 15e 11j 7 15f l 3m 2g q".split(" "),function(d,e,c,a,b,f,g,h,k,m,l){var n=function(a){var b=1;return a.replace(/(<img[^>]*)src=".*?"/g,function(a,c,d){return c+'data-textbox-image="'+b++ +'"'})},r=function(b,c){var d=g(h.fromDom(l.body));return function(e,g){d.play(e,function(d,e){a.process(d,e,b,"data-textbox-image",{mergeInline:f.constant(c)});
return m.get(e)},g)}},q=function(a,f,g){return d.sync(function(h){var m=c.extract(a);r(m,f)(g,function(a){a=k.fromHtml(a);d.call(h,{response:b.paste(a,[],[]),bundle:e.nu({})})})})},t=function(a){var b=a.indexOf("<html"),c=a.indexOf("</html>");return-1<b&&-1<c?a.substr(b,c+7):a};return{handle:function(a,c,f){a=t(a.data());var g=n(a);return f.cleanDocument(g,c).fold(function(){return d.pure({response:b.error("errors.paste.word.notready"),bundle:e.nu({})})},function(a){return void 0===a||null===a||0===
a.length?d.pure({response:b.paste([],[],[]),bundle:e.nu({})}):q(g,c,a)})}}});l("146",["13z","140","142","b","h4"],function(d,e,c,a,b){return{handle:function(f){f=a.filter(f,function(a){return"file"===a.kind&&/image/.test(a.type)});var g=a.map(f,function(a){return a.getAsFile()});return d.sync(function(a){b.multiple(g).get(function(b){b=c.createImages(b);d.call(a,{response:b,bundle:e.nu({})})})})}}});l("16g",[],function(){return{validStyles:function(){return/^(mso-.*|tab-stops|tab-interval|language|text-underline|text-effect|text-line-through|font-color|horiz-align|list-image-[0-9]+|separator-image|table-border-color-(dark|light)|vert-align|vnd\..*)$/},
specialInline:function(){return/^(font|em|strong|samp|acronym|cite|code|dfn|kbd|tt|b|i|u|s|sub|sup|ins|del|var|span)$/}}});l("16n",[],function(){var d=function(d){return{fold:d,matches:function(c){return d(function(a){return 0===c.toLowerCase().indexOf(a.toLowerCase())},function(a){return a.test(c.toLowerCase())},function(a){return 0<=c.toLowerCase().indexOf(a.toLowerCase())},function(a){return c.toLowerCase()===a.toLowerCase()},function(){return!0},function(a){return!a.matches(c)})}}};return{starts:function(e){return d(function(c,
a,b,d,g,h){return c(e)})},pattern:function(e){return d(function(c,a,b,d,g,h){return a(e)})},contains:function(e){return d(function(c,a,b,d,g,h){return b(e)})},exact:function(e){return d(function(c,a,b,d,g,h){return d(e)})},all:function(){return d(function(d,c,a,b,f,g){return f()})},not:function(e){return d(function(c,a,b,d,g,h){return h(e)})},cata:function(d,c,a,b,f,g,h){return d.fold(c,a,b,f,g,h)}}});l("16h",["7","21","16n"],function(d,e,c){return{keyval:function(a,b,e,g){var h=g.name,k=void 0!==
g.condition?g.condition:d.constant(!0);g=void 0!==g.value?g.value:c.all();return h.matches(e)&&g.matches(b)&&k(a)},name:function(a,b){var c=e.name(a),g=b.name,h=void 0!==b.condition?b.condition:d.constant(!0);return g.matches(c)&&h(a)}}});l("16t",["b","1o","7","1a"],function(d,e,c,a){var b=function(b,c,h){d.each(c,function(c){a.remove(b,c)});e.each(h,function(c,d){a.set(b,d,c)})};return{filter:function(a,b){var c={};d.each(a.dom().attributes,function(a){b(a.value,a.name)||(c[a.name]=a.value)});return c},
clobber:function(a,c,h){h=d.map(a.dom().attributes,function(a){return a.name});e.size(c)!==h.length&&b(a,h,c)},scan:c.constant({})}});l("16u",["b","1o","1a","2o","v"],function(d,e,c,a,b){var f=function(a){var c={};a=void 0!==a&&null!==a?a.split(";"):[];d.each(a,function(a){a=a.split(":");2===a.length&&(c[b.trim(a[0])]=b.trim(a[1]))});return c},g=function(a){var b=e.keys(a);return d.map(b,function(b){return b+": "+a[b]}).join("; ")};return{filter:function(a,b){var c=a.dom().style,e={};d.each(void 0===
c?[]:c,function(c){var d;d=a.dom().style.getPropertyValue(c);b(d,c)||(e[c]=d)});return e},clobber:function(b,d,f){c.set(b,"style","");var l=e.size(d),n=e.size(f);0===l&&0===n?c.remove(b,"style"):0===l?c.set(b,"style",g(f)):(e.each(d,function(c,d){a.set(b,d,c)}),d=c.get(b,"style"),f=0<n?g(f)+"; ":"",c.set(b,"style",f+d))},scan:function(a,b,c){a=a.dom().getAttribute("style");var e=f(a),g={};d.each(b,function(a){var b=e[a];void 0===b||c(b,a)||(g[a]=b)});return g}}});l("16i",["16t","16u","7","l"],function(d,
e,c,a){var b=["mso-list"],f=function(a,c){var d=e.scan(a,b,c),f=e.filter(a,c);e.clobber(a,f,d)},g=function(a,b){var c=d.filter(a,b);d.clobber(a,c,{})};return{style:f,attribute:g,styleDom:function(b,c){f(a.fromDom(b),c)},attributeDom:function(b,c){g(a.fromDom(b),c)},validateStyles:function(a){var b=e.filter(a,c.constant(!1));e.clobber(a,b,{})}}});l("164","b 6 16h 16i 7 1a 1y 4e 2r 4h".split(" "),function(d,e,c,a,b,f,g,h,k,m){var l=function(a,b,e){a(e,function(a,f){return d.exists(b,function(b){return c.keyval(e,
a,f,b)})})};return{remover:function(n,r){var q=e.merge({styles:[],attributes:[],classes:[],tags:[]},r),t=m.descendants(n,"*");d.each(t,function(b){l(a.style,q.styles,b);l(a.attribute,q.attributes,b);d.each(q.classes,function(a){var c=f.has(b,"class")?h.get(b):[];d.each(c,function(c){a.name.matches(c)&&g.remove(b,c)})})});t=m.descendants(n,"*");d.each(t,function(a){d.exists(q.tags,b.curry(c.name,a))&&k.remove(a)})},unwrapper:function(a,f){var g=e.merge({tags:[]},f),h=m.descendants(a,"*");d.each(h,
function(a){d.exists(g.tags,b.curry(c.name,a))&&k.unwrap(a)})},transformer:function(a,f){var g=e.merge({tags:[]},f),h=m.descendants(a,"*");d.each(h,function(a){var e=d.find(g.tags,b.curry(c.name,a));void 0!==e&&null!==e&&e.mutate(a)})},validator:function(b){b=m.descendants(b,"*");d.each(b,function(b){a.validateStyles(b)})}}});l("168",["1o","2o","l"],function(d,e,c){var a=function(a,b,d){var k,m,l,n=c.fromDom(a);switch(a.nodeType){case 1:b?k="endElement":(k="startElement",e.setAll(n,d||{}));m="HTML"!==
a.scopeName&&a.scopeName&&a.tagName&&0>=a.tagName.indexOf(":")?(a.scopeName+":"+a.tagName).toUpperCase():a.tagName;break;case 3:k="text";l=a.nodeValue;break;case 8:k="comment";l=a.nodeValue;break;default:console.log("WARNING: Unsupported node type encountered: "+a.nodeType)}return{getNode:function(){return a},tag:function(){return m},type:function(){return k},text:function(){return l}}},b=function(b,c){return a(c.createElement(b),!0)};return{START_ELEMENT_TYPE:"startElement",END_ELEMENT_TYPE:"endElement",
TEXT_TYPE:"text",COMMENT_TYPE:"comment",FINISHED:b("HTML",window.document),token:a,createStartElement:function(b,c,e,k){var m=k.createElement(b);d.each(c,function(a,b){m.setAttribute(b,a)});return a(m,!1,e)},createEndElement:b,createComment:function(b,c){return a(c.createComment(b),!1)},createText:function(b,c){return a(c.createTextNode(b))}}});l("16j",["168"],function(d){return{create:function(e){var c=e.createDocumentFragment(),a=c;return{dom:a,receive:function(b){var f=function(a){a=a.getNode().cloneNode(!1);
c.appendChild(a);c=a},g=function(a,b){var d=e.createTextNode(a.text());c.appendChild(d)};switch(b.type()){case d.START_ELEMENT_TYPE:f(b);break;case d.TEXT_TYPE:g(b);break;case d.END_ELEMENT_TYPE:c=c.parentNode;null===c&&(c=a);break;case d.COMMENT_TYPE:break;default:throw{message:"Unsupported token type: "+b.type()};}},label:"SERIALISER"}}}});l("16k",["168"],function(d){return{tokenise:function(e,c){var a;c=c||window.document;a=c.createElement("div");c.body.appendChild(a);a.style.position="absolute";
a.style.left="-10000px";a.innerHTML=e;nextNode=a.firstChild||d.FINISHED;var b=[];endNode=!1;return{hasNext:function(){return void 0!==nextNode},next:function(){var e=nextNode,g=endNode;!endNode&&nextNode.firstChild?(b.push(nextNode),nextNode=nextNode.firstChild):endNode||1!==nextNode.nodeType?nextNode.nextSibling?(nextNode=nextNode.nextSibling,endNode=!1):(nextNode=b.pop(),endNode=!0):endNode=!0;e===d.FINISHED||nextNode||(c.body.removeChild(a),nextNode=d.FINISHED);e=e===d.FINISHED?e:e?d.token(e,g):
void 0;return e}}}}});l("165",["16j","16k"],function(d,e){var c=function(a,b,c){var d=c;for(c=b.length-1;0<=c;c--)d=b[c](d,{},a);return d};return{build:c,run:function(a,b,f){var g=d.create(a);b=e.tokenise(b,a);for(a=c(a,f,g);b.hasNext();)f=b.next(),a.receive(f);return g.dom}}});l("15k","b 164 165 l 2g 2r 2b".split(" "),function(d,e,c,a,b,f,g){return{removal:function(a){return function(b){e.remover(b,a)}},unwrapper:function(a){return function(b){e.unwrapper(b,a)}},transformer:function(a){return function(b){e.transformer(b,
a)}},validate:function(){return function(a){e.validator(a)}},pipeline:function(a){return function(d){var e=b.get(d),l=g.owner(d),e=c.run(l.dom(),e,a);f.empty(d);d.dom().appendChild(e)}},isWordContent:function(a,b){return 0<=a.indexOf("<o:p>")||b.browser.isSpartan()&&0<=a.indexOf('v:shapes="')||b.browser.isSpartan()&&0<=a.indexOf("mso-")||0<=a.indexOf("mso-list")||0<=a.indexOf("p.MsoNormal, li.MsoNormal, div.MsoNormal")||0<=a.indexOf("MsoListParagraphCxSpFirst")||0<=a.indexOf("<w:WordDocument>")},
go:function(c,e,f){var g=a.fromTag("div",c.dom());g.dom().innerHTML=e;d.each(f,function(a){a(g)});return b.get(g)}}});l("167",["b","168"],function(d,e){return function(c,a,b){return function(b,g,h){var k=function(a){b.receive(a)},m=function(a,b,c){c=void 0!==c?c:a.type()===e.END_ELEMENT_TYPE;return e.token(b,c,{})},l={emit:k,emitTokens:function(a){d.each(a,k)},receive:function(a){c(l,a,m)},document:window.document};a(l);return l}}});l("173","16u 168 7 1a 2o l".split(" "),function(d,e,c,a,b,f){return{getAttribute:function(b,
c){var d=f.fromDom(b.getNode());return a.get(d,c)},getStyle:function(a,c){var d=f.fromDom(a.getNode());return b.get(d,c)},isWhitespace:function(a){return a.type()===e.TEXT_TYPE&&/^[\s\u00A0]*$/.test(a.text())},getMsoList:function(a){a=f.fromDom(a.getNode());return d.scan(a,["mso-list"],c.constant(!1))["mso-list"]}}});l("178",["b","s"],function(d,e){var c=function(a,b,c){return a===b||a&&b&&a.tag===b.tag&&a.type===b.type&&(c||a.variant===b.variant)};return{guessFrom:function(a,b){var f=d.find(a,function(a){return"UL"===
a.tag||b&&c(a,b,!0)});return void 0!==f?e.some(f):0<a.length?e.some(a[0]):e.none()},eqListType:c}});l("16y",[],function(){var d=function(c,a){if(void 0===c||void 0===a)throw console.trace(),"brick";c.nextFilter.set(a)},e=function(c,a,b){a.nextFilter.get()(c,a,b)};return{next:d,go:e,jump:function(c){return function(a,b,f){d(b,c);e(a,b,f)}},isNext:function(c,a){return c.nextFilter.get()===a},setNext:function(c){return function(a,b,e){d(b,c)}}}});l("172","b 173 178 16y 7 2v 1a l".split(" "),function(d,
e,c,a,b,f,g,h){var k=f.immutable("level","token","type"),m=function(a,b,f,g){a=f.getCurrentListType();f=f.getCurrentLevel()==g.level()?a:null;return c.guessFrom(g.emblems(),f).filter(function(a){if(a="OL"===a.tag)a=!d.contains(["P"],b.tag())||/^MsoHeading/.test(e.getAttribute(b,"class"));return!a})};return{predicate:function(a,b){return g.has(h.fromDom(b.getNode()),"data-list-level")},action:function(c){return function(d,e,f){d=h.fromDom(f.getNode());var l=parseInt(g.get(d,"data-list-level"),10),
s=g.get(d,"data-list-emblems"),s=JSON.parse(s);g.remove(d,"data-list-level");g.remove(d,"data-list-emblems");d={level:b.constant(l),emblems:b.constant(s)};d.level();e.originalToken.set(f);m(e.listType.get(),f,e.emitter,d).each(e.listType.set);f=k(d.level(),e.originalToken.get(),e.listType.get());e.emitter.openItem(f.level(),f.token(),f.type());a.next(e,c.inside())}}}});l("174",["7"],function(d){return function(e,c,a){return{pred:e,action:c,label:d.constant(a)}}});l("175",["b","7","s"],function(d,
e,c){var a=function(a,c){return function(a,b,d){return c(a,b,d)}};return function(b,f,g){var h=a(b+" :: FALLBACK --- ",g);g=function(g,m,l){c.from(d.find(f,function(a){return a.pred(m,l)})).fold(e.constant(h),function(c){var d=c.label();return void 0===d?c.action:a(b+" :: "+d,c.action)})(g,m,l)};g.toString=function(){return"Handlers for "+b};return g}});l("16v","172 168 173 174 175 16y".split(" "),function(d,e,c,a,b,f){return{inside:function(c){return b("Inside.List.Item",[a(function(a,b){return b.type()===
e.END_ELEMENT_TYPE&&a.originalToken.get()&&b.tag()===a.originalToken.get().tag()},function(a,b,d){f.next(b,c.outside())},"Closing open tag")],function(a,b,c){a.emit(c)})},outside:function(g){return b("Outside.List.Item",[a(d.predicate,d.action(g),"Data List ****"),a(function(a,b){return b.type()===e.TEXT_TYPE&&c.isWhitespace(b)},function(a,b,c){a.emit(c)},"Whitespace")],function(a,b,c){b.emitter.closeAllLists();a.emit(c);f.next(b,g.outside())})}}});l("179",["2v"],function(d){var e=d.immutable("state",
"result"),c=d.immutable("state","value");return{state:d.immutable("level","type","types","items"),value:c,result:e}});l("17b",["179","s"],function(d,e){return{start:function(c,a){var b=c.items().slice(0),f=void 0!==a&&"P"!==a?e.some(a):e.none();f.fold(function(){b.push("P")},function(a){b.push(a)});var g=d.state(c.level(),c.type(),c.types(),b);return d.value(g,f)},finish:function(c){var a=c.items().slice(0);if(0<a.length&&"P"!==a[a.length-1]){var b=a[a.length-1];a[a.length-1]="P";c=d.state(c.level(),
c.type(),c.types(),a);return d.value(c,e.some(b))}return d.value(c,e.none())}}});l("17c",["179"],function(d){var e=function(c,a,b){for(var e=[];a(c);){var g=b(c);c=g.state();e=e.concat(g.result())}return d.result(c,e)};return{moveRight:function(c,a,b){return e(c,function(b){return b.level()<a},b)},moveLeft:function(c,a,b){return e(c,function(b){return b.level()>a},b)},moveUntil:e}});l("17e",["173"],function(d){return{from:function(e){var c={"list-style-type":"none"};e?(e=d.getStyle(e,"margin-left"),
e=void 0!==e&&"0px"!==e?{"margin-left":e}:{}):e=c;return e}}});l("17d","16i 168 178 179 17b 17e 7".split(" "),function(d,e,c,a,b,f,g){var h=function(b,c,d){var f=c.start&&1<c.start?{start:c.start}:{},h=b.level()+1,k=b.types().concat([c]);d=[g.curry(e.createStartElement,c.tag,f,d)];b=a.state(h,c,k,b.items());return a.result(b,d)},k=function(b){var c=b.types().slice(0),d=[g.curry(e.createEndElement,c.pop().tag)],f=b.level()-1;b=a.state(f,c[c.length-1],c,b.items());return a.result(b,d)},m=function(b,
c){var d=k(b),e=h(d.state(),c,c.type?{"list-style-type":c.type}:{});return a.result(e.state(),d.result().concat(e.result()))};return{open:h,openItem:function(h,k,l){var q=f.from(k);h=h.type()&&!c.eqListType(h.type(),l)?m(h,l):a.result(h,[]);q=[g.curry(e.createStartElement,"LI",{},q)];l=b.start(h.state(),k&&k.tag());var t=l.value().map(function(a){d.styleDom(k.getNode(),g.constant(!0));return[g.constant(k)]}).getOr([]);return a.result(l.state(),h.result().concat(q).concat(t))},close:k,closeItem:function(c){var d=
g.curry(e.createEndElement,"LI");c=b.finish(c);var f=c.value().fold(function(){return[d]},function(a){return[g.curry(e.createEndElement,a),d]});return a.result(c.state(),f)}}});l("17a","b 168 179 17b 17c 17d 7 s".split(" "),function(d,e,c,a,b,f,g,h){var k=function(a){if(0===a.length)throw"Compose must have at least one element in the list";var b=a[a.length-1];a=d.bind(a,function(a){return a.result()});return c.result(b.state(),a)},m=function(a){a=f.closeItem(a);var b=f.close(a.state());return k([a,
b])},l=function(a,c,d,e){return b.moveRight(a,d,function(a){var b=a.level()===d-1&&c.type?{"list-style-type":c.type}:{};a=f.open(a,c,b);b=f.openItem(a.state(),a.state().level()==d?e:void 0,c);return k([a,b])})},n=function(a,c){return b.moveLeft(a,c,m)},r=function(b,d,f,k){var m=1<f?a.finish(b):c.value(b,h.none());b=m.value().map(function(a){return[g.curry(e.createEndElement,a)]}).getOr([]);m.state().level();d=l(m.state(),d,f,k);return c.result(d.state(),b.concat(d.result()))};return{openItem:function(a,
b,d,e){a=a.level()>b?n(a,b):c.result(a,[]);a.state().level()===b?(b=a.state(),b=0<b.level()?f.closeItem(b):c.result(b,[]),d=f.openItem(b.state(),d,e),d=k([b,d])):d=r(a.state(),e,b,d);return k([a,d])},closeAllLists:n}});l("176",["b","179","17a"],function(d,e,c){var a=["disc","circle","square"];return function(b,f){var g=e.state(0,void 0,[],[]),h=function(a){d.each(a.result(),function(a){a=a(f);b.emit(a)})};return{closeAllLists:function(){var a=c.closeAllLists(g,0);g=a.state();h(a)},openItem:function(b,
d,e){e&&("UL"===e.tag&&a[b-1]===e.type&&(e={tag:"UL"}),b=c.openItem(g,b,d,e),g=b.state(),h(b))},getCurrentListType:function(){return g.type()},getCurrentLevel:function(){return g.level()}}}});l("16w",["176","7","4p"],function(d,e,c){var a={getCurrentListType:function(){return b().getCurrentListType()},getCurrentLevel:function(){return b().getCurrentLevel()},closeAllLists:function(){return b().closeAllLists.apply(void 0,arguments)},openItem:function(){return b().openItem.apply(void 0,arguments)}},
b=function(){return{getCurrentListType:e.constant({}),getCurrentLevel:e.constant(1),closeAllLists:e.identity,openItem:e.identity}};return function(f){var g=c(f),h=c(null),k=c(null);return{reset:function(a){g.set(f);h.set(null);k.set(null);_emitter=d(a,a.document);b=e.constant(_emitter)},nextFilter:g,originalToken:h,listType:k,emitter:a}}});l("16x",["168"],function(d){return function(){var e=!1,c="";return{check:function(a){return e&&a.type()===d.TEXT_TYPE?(c+=a.text(),!0):a.type()===d.START_ELEMENT_TYPE&&
"STYLE"===a.tag()?e=!0:a.type()===d.END_ELEMENT_TYPE&&"STYLE"===a.tag()?(e=!1,!0):!1}}}});l("16l","167 16v 16w 16x 16y q".split(" "),function(d,e,c,a,b,f){f={inside:function(){return h},outside:function(){return k}};var g=a(),h=e.inside(f),k=e.outside(f),m=c(k);return d(function(a,c,d){g.check(c)||b.go(a,m,c)},m.reset,"list.filters")});l("177",["b","6","1u","e2"],function(d,e,c,a){var b=[{regex:/^\(?[dc][\.\)]$/,type:{tag:"OL",type:"lower-alpha"}},{regex:/^\(?[DC][\.\)]$/,type:{tag:"OL",type:"upper-alpha"}},
{regex:/^\(?M*(CM|CD|D?C{0,3})(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})[\.\)]$/,type:{tag:"OL",type:"upper-roman"}},{regex:/^\(?m*(cm|cd|d?c{0,3})(xc|xl|l?x{0,3})(ix|iv|v?i{0,3})[\.\)]$/,type:{tag:"OL",type:"lower-roman"}},{regex:/^\(?[0-9]+[\.\)]$/,type:{tag:"OL"}},{regex:/^([0-9]+\.)*[0-9]+\.?$/,type:{tag:"OL",variant:"outline"}},{regex:/^\(?[a-z]+[\.\)]$/,type:{tag:"OL",type:"lower-alpha"}},{regex:/^\(?[A-Z]+[\.\)]$/,type:{tag:"OL",type:"upper-alpha"}}],f={"\u2022":{tag:"UL",type:"disc"},"\u00b7":{tag:"UL",
type:"disc"},"\u00a7":{tag:"UL",type:"square"}},g={o:{tag:"UL",type:"circle"},"-":{tag:"UL",type:"disc"},"\u25cf":{tag:"UL",type:"disc"},"\ufffd":{tag:"UL",type:"circle"}},h=function(a,b){return void 0!==a.variant?a.variant:"("===b.charAt(0)?"()":")"===b.charAt(b.length-1)?")":"."},k=function(b){var d=b.split(".");0===d.length?d=b:(b=d[d.length-1],d=0===b.length&&1<d.length?d[d.length-2]:b);d=a(d,10);return c(d)?{}:{start:d}};return{extract:function(a,c){var l=g[a]?[g[a]]:[],r=c&&f[a]?[f[a]]:c?[{tag:"UL",
variant:a}]:[],q=d.bind(b,function(b){return b.regex.test(a)?[e.merge(b.type,k(a),{variant:h(b.type,a)})]:[]}),l=l.concat(r).concat(q);return d.map(l,function(b){return void 0!==b.variant?b:e.merge(b,{variant:a})})}}});l("16z","b 177 16u 7 s 2o 2g 21 4l 3n 2b 1s 1u e2".split(" "),function(d,e,c,a,b,f,g,h,k,m,l,n,r,q){var t=function(b){return c.scan(b,["mso-list"],a.constant(!1))["mso-list"]},s=function(a){return h.isElement(a)&&f.getRaw(a,"font-family").exists(function(a){return d.contains(["wingdings",
"symbol"],a.toLowerCase())})};return{getMsoList:t,extractLevel:function(a){a=t(a);return(a=/ level([0-9]+)/.exec(a))&&a[1]?b.some(q(a[1],10)):b.none()},extractEmblem:function(a,c){var d=m.get(a).trim(),d=e.extract(d,c);return 0<d.length?b.some(d):b.none()},extractSymSpan:function(a){return k.child(a,s)},extractMsoIgnore:function(b){return k.descendant(b,function(b){return!!(h.isElement(b)?c.scan(b,["mso-list"],a.constant(!1)):[])["mso-list"]})},extractCommentSpan:function(a){return k.child(a,h.isComment).bind(l.nextSibling).filter(function(a){return"span"===
h.name(a)})},isSymbol:s,deduceLevel:function(a){return f.getRaw(a,"margin-left").bind(function(a){a=q(a,10);return r(a)?b.none():b.some(n.max(1,n.ceil(a/18)))})}}});aa("170",JSON);l("16m","b 16z s 1a 16f 21 2r 2b 170 e2".split(" "),function(d,e,c,a,b,f,g,h,k,m){var l=function(e,f,h,m){a.set(e,"data-list-level",f);f=k.stringify(h);a.set(e,"data-list-emblems",f);f=b.find(e,c.none());d.each(f,g.remove);d.each(m,g.remove);a.remove(e,"style");a.remove(e,"class")},n=function(a){return e.extractLevel(a).bind(function(b){return e.extractSymSpan(a).bind(function(c){return e.extractEmblem(c,
!0).map(function(d){return{mutate:function(){l(a,b,d,[c])}}})})})},r=function(a){return e.extractLevel(a).bind(function(b){return e.extractCommentSpan(a).bind(function(c){return e.extractEmblem(c,e.isSymbol(c)).map(function(d){return{mutate:function(){l(a,b,d,[c])}}})})})},q=function(a){return e.extractLevel(a).bind(function(b){return e.extractCommentSpan(a).bind(function(c){return e.extractEmblem(c,e.isSymbol(c)).map(function(d){return{mutate:function(){l(a,b,d,[c])}}})})})},t=function(a){return"p"!==
f.name(a)?c.none():e.extractLevel(a).bind(function(b){return e.extractMsoIgnore(a).bind(function(c){return e.extractEmblem(c,!1).map(function(d){return{mutate:function(){l(a,b,d,[h.parent(c).getOr(c)])}}})})})},s=function(a){return"p"!==f.name(a)?c.none():e.extractMsoIgnore(a).bind(function(b){var c=h.parent(b).getOr(b),d=e.isSymbol(c);return e.extractEmblem(b,d).bind(function(b){return e.deduceLevel(a).map(function(d){return{mutate:function(){l(a,d,b,[c])}}})})})};return{find:function(a){return n(a).orThunk(function(){return r(a)}).orThunk(function(){return q(a)}).orThunk(function(){return t(a)}).orThunk(function(){return s(a)})}}});
l("166",["15k","16l","16m","16n"],function(d,e,c,a){d=d.transformer({tags:[{name:a.pattern(/^(p|h\d+)$/),mutate:function(a){c.find(a).each(function(a){a.mutate()})}}]});return{filter:e,preprocess:d}});l("16o",["b","1a","2g","21","38"],function(d,e,c,a,b){var f=function(b){var c=b.dom().attributes,c=void 0!==c&&null!==c&&0<c.length;return"span"===a.name(b)?c:!0},g=function(a){return void 0===a.dom().attributes||null===a.dom().attributes?!0:0===a.dom().attributes.length||1===a.dom().attributes.length&&
"style"===a.dom().attributes[0].name};return{isNotImage:function(b){return"img"!==a.name(b)},hasContent:function(c){return g(c)?f(c)&&b.descendant(c,function(b){var c=!g(b),e=!d.contains("font em strong samp acronym cite code dfn kbd tt b i u s sub sup ins del var span".split(" "),a.name(b));return a.isText(b)||c||e}):!0},isList:function(b){return"ol"===a.name(b)||"ul"===a.name(b)},isLocal:function(a){a=e.get(a,"src");return/^file:/.test(a)},hasNoAttributes:g,isEmpty:function(a){return 0===c.get(a).length}}});
l("16p","b 1o s 1a 2o l 2g 2p 3d 21 2r az 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,l,n,r){var q=function(a,b){var c=f.fromTag(a);h.before(b,c);var e=b.dom().attributes;d.each(e,function(a){c.dom().setAttribute(a.name,a.value)});e=r.children(b);k.append(c,e);l.remove(b);return c},t=function(a){return r.prevSibling(a).bind(function(a){return m.isText(a)&&0===n.get(a).trim().length?t(a):"li"===m.name(a)?c.some(a):c.none()})};return{changeTag:q,addBrTag:function(a){0===g.get(a).length&&h.append(a,
f.fromTag("br"))},properlyNest:function(a){r.parent(a).each(function(c){c=m.name(c);d.contains(["ol","ul"],c)&&t(a).fold(function(){var c=f.fromTag("li");b.set(c,"list-style-type","none");h.wrap(a,c)},function(b){h.append(b,a)})})},fontToSpan:function(c){var d=q("span",c),f={"font-size":{1:"8pt",2:"10pt",3:"12pt",4:"14pt",5:"18pt",6:"24pt",7:"36pt"}};e.each({face:"font-family",size:"font-size",color:"color"},function(c,e){if(a.has(d,e)){var g=a.get(d,e);b.set(d,c,void 0!==f[c]&&void 0!==f[c][g]?f[c][g]:
g);a.remove(d,e)}})}}});l("163","16g 15k 166 16o 16p 7 1y 2o 2b 21 1a 16n".split(" "),function(d,e,c,a,b,f,g,h,k,m,l,n){var r=e.unwrapper({tags:[{name:n.pattern(/^([OVWXP]|U[0-9]+|ST[0-9]+):/i)}]});c=[e.pipeline([c.filter])];var q=e.removal({attributes:[{name:n.pattern(/^v:/)},{name:n.exact("href"),value:n.contains("#_toc")},{name:n.exact("href"),value:n.contains("#_mso")},{name:n.pattern(/^xmlns(:|$)/)},{name:n.exact("type"),condition:a.isList}]}),t=e.removal({attributes:[{name:n.exact("id")},{name:n.exact("name")}]}),
s=e.removal({tags:[{name:n.exact("script")},{name:n.exact("meta")},{name:n.exact("link")},{name:n.exact("style"),condition:a.isEmpty}],attributes:[{name:n.starts("on")},{name:n.exact('"')},{name:n.exact("lang")},{name:n.exact("language")}],styles:[{name:n.all(),value:n.pattern(/OLE_LINK/i)}]}),u=e.removal({styles:[{name:n.not(n.pattern(/width|height|list-style-type/)),condition:function(a){return!g.has(a,"ephox-limbo-transform")}},{name:n.pattern(/width|height/),condition:a.isNotImage}]}),v=e.removal({classes:[{name:n.not(n.exact("rtf-data-image"))}]}),
w=e.removal({styles:[{name:n.pattern(d.validStyles())}]}),y=e.removal({classes:[{name:n.pattern(/mso/i)}]}),x=e.unwrapper({tags:[{name:n.exact("img"),condition:a.isLocal},{name:n.exact("a"),condition:a.hasNoAttributes}]}),z=e.unwrapper({tags:[{name:n.exact("a"),condition:a.hasNoAttributes}]}),A=e.removal({attributes:[{name:n.exact("style"),value:n.exact(""),debug:!0}]}),D=e.removal({attributes:[{name:n.exact("class"),value:n.exact(""),debug:!0}]});d=e.unwrapper({tags:[{name:n.pattern(d.specialInline()),
condition:f.not(a.hasContent)}]});a=e.unwrapper({tags:[{name:n.exact("p"),condition:function(a){return function(b){return k.parent(b).exists(function(b){return m.name(b)===a&&1===k.children(b).length})}}("li")}]});var B=e.transformer({tags:[{name:n.exact("p"),mutate:b.addBrTag}]}),C=e.transformer({tags:[{name:n.pattern(/ol|ul/),mutate:b.properlyNest}]}),F=e.transformer({tags:[{name:n.exact("b"),mutate:f.curry(b.changeTag,"strong")},{name:n.exact("i"),mutate:f.curry(b.changeTag,"em")},{name:n.exact("u"),
mutate:function(a){a=b.changeTag("span",a);g.add(a,"ephox-limbo-transform");h.set(a,"text-decoration","underline")}},{name:n.exact("s"),mutate:f.curry(b.changeTag,"strike")},{name:n.exact("font"),mutate:b.fontToSpan,debug:!0}]}),E=e.removal({classes:[{name:n.exact("ephox-limbo-transform")}]}),G=function(){var a=/^file:\/\/\/[^#]+(#[^#]+)$/;return e.transformer({tags:[{name:n.exact("a"),condition:function(b){return(b=l.get(b,"href"))?a.test(b):!1},mutate:function(b){var c=l.get(b,"href");l.set(b,"href",
c.replace(a,"$1"))}}]})}(),H=e.removal({attributes:[{name:n.exact("href"),value:n.starts("file:///"),debug:!0}]});return{unwrapWordTags:r,removeWordAttributes:q,parseLists:c,removeExcess:s,cleanStyles:u,cleanClasses:v,mergeStyles:w,mergeClasses:y,removeLocalImages:x,removeVacantLinks:z,removeEmptyStyle:A,removeEmptyClass:D,pruneInlineTags:d,unwrapSingleParagraphsInlists:a,addPlaceholders:B,nestedListFixes:C,inlineTagFixes:F,cleanupFlags:E,distillAnchorsFromLocalLinks:G,removeLocalLinks:H,removeAnchors:t,
none:f.noop}});l("15i","b 14d 163 15k 166 167 168 7 l".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(a){return a.browser.isIE()&&11<=a.browser.version.major},l=function(a,b,c){var d=k.fromDom(a.getNode());return b(d).fold(function(){return[a]},function(b){var d=a.type()===g.END_ELEMENT_TYPE,e=[g.token(b.dom(),d)];!d&&c&&e.push(g.token(b.dom(),!0));return e})},n=function(a,b){return f(function(c,e){var f=l(e,a,b);d.each(f,c.emit)},h.noop,"image filters")},r=function(a,b){return m(b)&&a?[c.unwrapSingleParagraphsInlists]:
[]},q=function(a,b,d){a=[c.mergeStyles,c.mergeClasses];d=[c.cleanStyles,c.cleanClasses];return b?a:d},t=function(a,c,d){return m(d)||!a?[]:[b.preprocess]},s=function(a,b,d){if(!a)return[c.none];a=[c.unwrapWordTags];d=m(d)?[]:c.parseLists;return a.concat(d).concat([c.removeWordAttributes])};return{derive:function(b,f,g){var h,k;h=(k=g.browser.isFirefox()||g.browser.isSpartan())?e.local:e.vshape;var l=!k;h=m(g)?c.none:a.pipeline([n(h,l)]);h=[b?h:c.none];k=[k?c.none:c.removeLocalImages];return d.flatten([t(b,
f,g),h,[c.inlineTagFixes],s(b,f,g),[c.nestedListFixes],[c.removeExcess],k,q(b,f,g),[c.distillAnchorsFromLocalLinks,c.removeLocalLinks,c.removeVacantLinks],[c.removeEmptyStyle],[c.removeEmptyClass],[c.pruneInlineTags],[c.addPlaceholders],r(b,g),[c.cleanupFlags]])}}});l("15j","b s 114 6o ci 2v 1a 2o l 2p 3d 21 6u 3n 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,l,n,r,q,t){var s=b.link().source,u=function(b){var d=f.immutable("word","pattern"),e=a.unsafetoken(s),d=d("__INTERNAL__",e);return c.run(b,[d])},
v=function(a){return!r.closest(a,"a")},w=function(a){return e.from(a[0]).filter(v).map(function(b){var c=k.fromTag("a");m.before(b,c);l.append(c,a);g.set(c,"href",q.get(c));return c})};return{links:function(a){a=u(a);d.each(a,function(a){var b=a.exact(),c;(c=0>b.indexOf("@"))||(b=b.indexOf("://"),c=3<=b&&9>=b);c&&w(a.elements())})},position:function(a){d.each(a,function(a){n.isElement(a)&&h.getRaw(a,"position").isSome()&&h.remove(a,"position")})},list:function(a){var b=d.filter(a,function(a){return"li"===
n.name(a)});if(0<b.length){var c=t.prevSiblings(b[0]),e=k.fromTag("ul");m.before(a[0],e);0<c.length&&(a=k.fromTag("li"),m.append(e,a),l.append(a,c));l.append(e,b)}}}});l("149","b 15i 15j 15k 2g 2b".split(" "),function(d,e,c,a,b,f){var g=function(a){var b=f.children(a);d.each([c.links,c.position,c.list],function(a){a(b)})};return{go:function(c,d,f,l,n){g(f);f=b.get(f);d=e.derive(n,l,d);return a.go(c,f,d)},preprocess:g}});l("15g","13z 140 142 11j c 149 p 3m o".split(" "),function(d,e,c,a,b,f,g,h,k){var m=
b.detect(),l=function(a,b,c,d){try{var e=f.go(a,m,b,c,d),l=void 0!==e&&null!==e&&0<e.length?h.fromHtml(e):[];return g.value(l)}catch(p){return k.error(p),g.error("errors.paste.process.failure")}};return{transfer:function(b,f,g,h,k){return l(b,f,h,g).fold(function(a){return d.error(a)},function(b){return d.sync(function(f){k.get(function(g){var h=c.findImages(b,g);d.call(f,{response:a.paste(b,g,h),bundle:e.nu({})})})})})}}});l("147","15g b 3w s 2r 2b".split(" "),function(d,e,c,a,b,f){return{internal:function(g,
h,k){h=(void 0!==h?h.findClipboardTags(f.children(k)):a.none()).getOr([]);e.each(h,b.remove);h=c.nu(function(a){a([])});return d.transfer(g,k,!1,!0,h)},external:function(a,b,c,e,f){return d.transfer(a,b,e,c,f)}}});l("15h",["b","l","2g","3n"],function(d,e,c,a){return{encode:function(b){var d=e.fromTag("div");a.set(d,b);return c.get(d)},convert:function(a){a=a.trim().split(/\n{2,}|(?:\r\n){2,}/);a=d.map(a,function(a){return a.split(/\n|\r\n/).join("<br />")});return 1===a.length?a[0]:d.map(a,function(a){return"<p>"+
a+"</p>"}).join("")}}});l("148","13z 15h 140 11n 11j s k 3m 37".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(a){return 0<a.length},l=function(b){return a.isValidData(b)?g.findMap(b.types,function(a){return"text/plain"===a?f.some(b.getData(a)):f.none()}):f.none()},n=function(){var a=k.clipboardData;return void 0!==a?f.some(a.getData("text")):f.none()},r=function(a){a=e.encode(a);a=e.convert(a);a=h.fromHtml(a);return b.paste(a,[],[])};return{handle:function(e){return d.sync(function(f){var g=
(a.isValidData(e)?l:n)(e).filter(m).fold(b.cancel,r);d.call(f,{response:g,bundle:c.nu({})})})}}});l("11q","13z 140 143 145 146 147 148 11j c 149 7 l 3d 2b o".split(" "),function(d,e,c,a,b,f,g,h,k,m,l,n,r,q,t){var s=k.detect();return{plain:function(a,b,c){return g.handle(a)},autolink:function(a,b){var c=function(a,c,e){var f=n.fromTag("div");r.append(f,a);m.preprocess(f);a=q.children(f);return d.pure({response:h.paste(a,c,e),bundle:b.bundle()})},e=l.curry(d.pass,b);return h.cata(b.response(),e,c,e,
c)},noImages:function(){return function(a,b){return d.error("errors.local.images.disallowed")}},images:function(){return function(a,c){if(s.browser.isSafari()){var e=s.deviceType.isWebView()?"webview.imagepaste":"safari.imagepaste";return d.error(e)}return b.handle(a)}},internal:function(a,b){return function(d,e){var g=e.bundle();return c.proxyBin(g).handle("There was no proxy bin setup. Ensure you have run proxyStep first.",function(c){var d=q.owner(a);return f.internal(d,b,c)})}},external:function(a,
b){return function(d,e){var g=e.bundle();return c.proxyBin(g).handle("There was no proxy bin setup. Ensure you have run proxyStep first.",function(d){var e=c.merging(g),h=c.isWord(g),k=c.isInternal(g),m=c.backgroundAssets(g),l=q.owner(a);return k?f.internal(l,b,d):f.external(l,d,e,h,m)})}},gwt:function(b){return function(d,e){var f=c.mergeOffice(e.bundle());return a.handle(d,f,b)}},setBundle:function(a){return function(b,c){var f=e.merge(c.bundle(),e.nu(a));return d.pure({response:c.response(),bundle:f})}},
none:function(a,b){return d.cancel()}}});l("14a",["15k","1a","2g","38"],function(d,e,c,a){var b=function(b,c){return a.descendant(b,function(a){return e.has(a,"style")?-1<e.get(a,"style").indexOf("mso-"):!1})},f=function(a,b){var e=c.get(a);return d.isWordContent(e,b)};return{isWord:function(a,c){var d=a.browser;return(d.isIE()&&11<=d.version.major?b:f)(c,a)}}});l("11r","13z 140 j3 c 14a 1y 2b".split(" "),function(d,e,c,a,b,f,g){var h=a.detect();return function(a,m,l,n,r){return function(q,t){var s=
r(),u=t.response();return d.sync(function(r){var t=a(l);t.events.after.bind(function(a){a=a.container();m(a);f.add(a,c.binStyle());var k=b.isWord(h,a),l=g.children(a),l=n.findClipboardTags(l,k).isSome();d.call(r,{response:u,bundle:e.nu({isWord:k,isInternal:l,proxyBin:a,backgroundAssets:s})})});s.convert(q.data());t.run()})}}});l("16q","126 127 9 1s w e2".split(" "),function(d,e,c,a,b,f){return{convert:function(b,h){if(0===b.length)throw"Zero length content passed to Hex conversion";for(var k=new c(b.length/
2),m=0;m<b.length;m+=2){var l=b.substr(m,2),n=a.floor(m/2);k[n]=f(l,16)}k=e(k);return d([k],{type:h})}}});l("16a",["4q"],function(d){d=d.generate([{unsupported:["id","message"]},{supported:["id","contentType","blob"]}]);return{unsupported:d.unsupported,supported:d.supported,cata:function(d,c,a){return d.fold(c,a)}}});l("16r",["7","s"],function(d,e){var c=function(a,b,c,f,g){return-1===a||-1===b?e.none():e.some({start:d.constant(a),end:d.constant(b),bower:c,regex:d.constant(f),idRef:d.constant(g)})},
a=function(a,b,c){return function(){return a.substring(b,c)}},b=function(a,b){if(-1===b)return b;var c=0,d=a.length,e,f;do if(e=a.indexOf("{",b),f=a.indexOf("}",b),f>e&&-1!==e?(b=e+1,++c):(e>f||0>e)&&-1!==f&&(b=f+1,--c),b>d||-1===f)return-1;while(0<c);return b},f=function(b,d,e,f){b=a(b,e,f);return c(e,f,b,/[^a-fA-F0-9]([a-fA-F0-9]+)\}$/,"i")},g=function(b,d,e,f){b=a(b,e,f);return c(e,f,b,/([a-fA-F0-9]{64,})(?:\}.*)/,"s")};return{identify:function(a,c){var m=a.indexOf("{\\pict{",c),l=b(a,m),n=a.indexOf("{\\shp{",
c),r=b(a,n),q=d.curry(g,a,c,n,r),t=d.curry(f,a,c,m,l);return-1===m&&-1===n?e.none():-1===m?q():-1===n?t():n<m&&r>l?t():m<n&&l>r?q():m<n?t():n<m?q():e.none()},endBracket:b}});l("169",["16q","16a","16r","s","p"],function(d,e,c,a,b){var f=function(a,b){return c.identify(a,b)},g=function(a){return 0<=a.indexOf("\\pngblip")?b.value("image/png"):0<=a.indexOf("\\jpegblip")?b.value("image/jpeg"):b.error("errors.imageimport.unsupported")},h=function(a,c){var d=a.match(c);return d&&d[1]&&0===d[1].length%2?
b.value(d[1]):b.error("errors.imageimport.invalid")},k=function(b){b=b.match(/\\shplid(\d+)/);return null!==b?a.some(b[1]):a.none()},m=function(a){var b=a.bower(),c=a.regex();return k(b).map(function(f){var k=a.idRef()+f;return g(b).fold(function(a){return e.unsupported(k,a)},function(a){return h(b,c).fold(function(a){return e.unsupported(k,a)},function(b){return e.supported(k,a,d.convert(b,a))})})})},l=function(a){for(var b=[],c=function(){return a.length},d=function(a){var c=m(a);b=b.concat(c.toArray());
return a.end()},e=0;e<a.length;)e=f(a,e).fold(c,d);return b};return{nextBower:f,extractId:k,extractContentType:g,extractHex:h,images:function(a){a=a.replace(/\r/g,"").replace(/\n/g,"");return l(a)}}});l("15l",["169","16a","p"],function(d,e,c){return{images:function(a){return d.images(a)},toId:function(a){return e.cata(a,function(a,c){return a},function(a,c,d){return a})},toBlob:function(a){return e.cata(a,function(a,d){return c.error(d)},function(a,d,e){return c.value(e)})}}});l("15m","15l 142 b h4 s 1a 1y o".split(" "),
function(d,e,c,a,b,f,g,h){var k={local:function(a,c,d){return b.from(c[d])},code:function(a,e,f){e=c.find(e,function(b){return d.toId(b)===a});return b.from(e)}},m=function(a){var b=[],e=function(a){return!c.exists(b,function(b){return d.toId(b)===a})};return c.bind(a,function(a){var c=d.toId(a);return e(c)?(b.push(a),[a]):[]})};return{convert:function(l,n,r,q){var t=m(n),s=[],u=!1;l=c.bind(l,function(a,c){var e=f.get(a,"data-image-type"),m=f.get(a,"data-image-id");g.remove(a,"rtf-data-image");f.remove(a,
"data-image-type");f.remove(a,"data-image-id");return(void 0!==k[e]?k[e]:b.none)(m,t,c).fold(function(){h.log("WARNING: unable to find data for image ",a.dom());return[]},function(b){return d.toBlob(b).fold(function(b){u=!0;f.set(a,"alt",q(b));return[]},function(b){s.push(a);return[b]})})});a.multiple(l).get(function(a){var b=e.updateSources(a,s);r(a,b,u)})}}});l("14c","15l 15m 14d 59 4a 2b".split(" "),function(d,e,c,a,b,f){return function(g){var h=g.translations,k=b.create({insert:a(["elements",
"assets","correlated"]),incomplete:a(["elements","assets","correlated","message"])});return{events:k.registry,processRtf:function(a,b,g,l,q){l=d.images(l);var t=c.find(a);e.convert(t,l,function(c,d,e){var h=f.children(a);c=c.concat(b);d=d.concat(g);e?k.trigger.incomplete(h,c,d,"errors.imageimport.failed"):k.trigger.insert(h,c,d);q()},h)}}}});l("14b","14c b 14d 59 4a 2r 2b".split(" "),function(d,e,c,a,b,f,g){return function(h,k){var m=b.create({error:a(["message"]),insert:a(["elements","assets","correlated"]),
incomplete:a(["elements","assets","correlated","message"])}),l=d(k);l.events.incomplete.bind(function(a){m.trigger.incomplete(a.elements(),a.assets(),a.correlated(),a.message())});l.events.insert.bind(function(a){m.trigger.insert(a.elements(),a.assets(),a.correlated())});return{events:m.registry,gordon:function(a,b,d){var t=function(c){l.processRtf(a,b,d,c.rtf(),c.hide())},s=function(h){var k=c.find(a);e.each(k,f.remove);m.trigger.incomplete(g.children(a),b,d,h)},u=function(){var h=c.find(a);e.each(h,
f.remove);m.trigger.insert(g.children(a),b,d)},v=function(a){s(a.message())};if(!0===k.allowLocalImages&&!0===k.enableFlashImport){var w=h(k);w.events.response.bind(t);w.events.cancel.bind(u);w.events.failed.bind(v);w.events.error.bind(v);w.open()}else s("errors.local.images.disallowed")}}}});l("11s","13z 140 14b 14c 11j b 14d 7 s 4p l 3d 2r 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,l,n,r,q){return function(t,s){var u=c(t,s),v=a(s),w=m(k.none()),y=function(a){w.get().each(function(b){d.call(b,{response:a,
bundle:e.nu({})})})};u.events.insert.bind(function(a){y(b.paste(a.elements(),a.assets(),a.correlated()))});u.events.incomplete.bind(function(a){y(b.incomplete(a.elements(),a.assets(),a.correlated(),a.message()))});u.events.error.bind(function(a){a=a.message();a=b.error(a);y(a)});v.events.insert.bind(function(a){y(b.paste(a.elements(),a.assets(),a.correlated()))});v.events.incomplete.bind(function(a){y(b.incomplete(a.elements(),a.assets(),a.correlated(),a.message()))});return function(a,c){return d.sync(function(e){var m=
function(){d.call(e,{response:c.response(),bundle:c.bundle()})},t=function(c,d,t){w.set(k.some(e));var z=l.fromTag("div");n.append(z,c);a.rtf().fold(function(){g.exists(z)?u.gordon(z,d,t):m()},function(a){if(!0===s.allowLocalImages)v.processRtf(z,d,t,a,h.noop);else{a=g.find(z);var c=q.children(z);0<a.length?(f.each(a,r.remove),y(b.incomplete(c,d,t,"errors.local.images.disallowed"))):y(b.paste(c,d,t))}})};b.cata(c.response(),m,t,m,t)})}}});l("y1","11l 11m 11n 11o 11p 11q 11r 11s c 7 s 2v v 37".split(" "),
function(d,e,c,a,b,f,g,h,k,m,l,n,r,q){var t=n.immutable("data","rtf"),s=k.detect(),u=["^image/","file"],v=function(a,b){if(!a.isSupported())return l.none();var d=b.clipboardData;return c.isValidData(d)?c.getFlavor(d.types,"html").bind(function(a){a=d.getData(a.type);return r.contains(a,"<html")&&(r.contains(a,'xmlns:o="urn:schemas-microsoft-com:office:office"')||r.contains(a,'xmlns:x="urn:schemas-microsoft-com:office:excel"'))?l.some(t(a,D(b))):l.none()}):l.none()},w=function(a){return t(a,l.none())},
y=function(a){if(s.browser.isIE()||s.browser.isFirefox())return l.none();if(c.isValidData(a.clipboardData)){var b=a.clipboardData;return c.getPreferredFlavor(u,b.types).map(function(a){return b.items})}return l.none()},x=function(a,b){var d=c.isValidData(b.clipboardData)?b.clipboardData.types:[];return c.getFlavor(d,a.clipboardType()).map(function(a){return t(b,l.none())})},z=function(a){return s.browser.isIE()?l.some(q.clipboardData):c.isValidData(a.clipboardData)?l.some(a.clipboardData):l.none()},
A=function(a){if(s.browser.isSpartan())return l.none();a=a.clipboardData;var b=c.isValidData(a)?a.types:[];return 1===b.length&&"text/plain"===b[0]?l.some(a):l.none()},D=function(a){var b=a.clipboardData;return c.isValidData(b)?c.getFlavor(b.types,"rtf").bind(function(a){a=b.getData(a.type);return 0<a.length?l.some(a):l.none()}):l.none()},B=function(a,b,c,d){return{label:m.constant(a),getAvailable:b,steps:m.constant(c),capture:m.constant(d)}};return{internal:function(a,c,h,k){var l=m.curry(x,k);return B("Within Textbox.io (tables) pasting",
l,[d.normal(g(c,a,h,k,e.ignore)),d.normal(b.fixed(!0,!0)),d.normal(f.internal(h,k))],!1)},pastiche:function(c,k,m,l,p,n,q){return B("Outside of Textbox.io pasting (could be internal but another browser)",w,[d.normal(g(l,m,p,q,e.background)),d.normal(b.fromConfigIfExternal(c,k)),d.normal(f.external(p,q)),d.blocking(h(n,k)),d.normal(a(k))],!1)},gwt:function(a,c,e,g){return B("GWT pasting",m.curry(v,a),[d.normal(f.setBundle({isWord:!0})),d.normal(b.fromConfig(c,e)),d.normal(f.gwt(a)),d.blocking(h(g,
e))],!0)},image:function(a){return B("Image pasting",y,[d.normal(!1===a.allowLocalImages?f.noImages(m.noop):f.images())],!0)},text:function(){return B("Plain text pasting",z,[d.normal(f.plain),d.normal(f.autolink)],!0)},onlyText:function(){return B("Only plain text is available to paste",A,[d.normal(f.plain),d.normal(f.autolink)],!0)},none:function(){return B("There is no valid way to paste",l.some,[d.normal(f.none)],!1)}}});l("14e","qz c 1a 1y l 2g 3d".split(" "),function(d,e,c,a,b,f,g){var h=function(a){return b.fromHtml("<p>"+
a("cement.dialog.flash.press-escape")+"</p>")};return{paste:function(c){var f=b.fromTag("div");a.add(f,d.resolve("flashbin-helpcopy"));var l;l=e.detect().os.isOSX()?["\u2318"]:["Ctrl"];var n=b.fromHtml("<p>"+c("cement.dialog.flash.trigger-paste")+"</p>");l=b.fromHtml('<div><span class="ephox-polish-help-kbd">'+l+'</span> + <span class="ephox-polish-help-kbd">V</span></div>');a.add(l,d.resolve("flashbin-helpcopy-kbd"));g.append(f,[n,l,h(c)]);return f},noflash:function(c){var e=b.fromTag("div");a.add(e,
d.resolve("flashbin-helpcopy"));var f=b.fromHtml("<p>"+c("cement.dialog.flash.missing")+"</p>");g.append(e,[f,h(c)]);return e},indicator:function(e){var h=b.fromTag("div");a.add(h,d.resolve("flashbin-loading"));var l=b.fromTag("div");a.add(l,d.resolve("flashbin-loading-spinner"));var n=b.fromTag("p");e=e("loading.wait");f.set(n,e);c.set(n,"aria-label",e);g.append(h,[l,n]);return h}}});aa("14f",navigator);l("11t","14e qz c 7 1y 2o l 2p 3d 14f".split(" "),function(d,e,c,a,b,f,g,h,k,m){var l=c.detect(),
n=function(b,c,e,f){c=d.noflash(f);h.append(b,c);return{reset:a.noop}},r=function(a,b,c,e){var g=d.paste(e),h=d.indicator(e);k.append(a,[h,g,b.element()]);a=function(){f.set(g,"display","block");f.set(h,"display","none");c()};b.events.spin.bind(function(){f.set(g,"display","none");f.set(h,"display","block");f.remove(h,"height");f.remove(h,"padding");c()});b.events.reset.bind(a);b.events.hide.bind(function(){f.setAll(h,{height:"0",padding:"0"})});return{reset:a}};return function(c,d,f){var h=g.fromTag("div"),
k="flashbin-wrapper-"+(l.os.isOSX()?"cmd":"ctrl");b.add(h,e.resolve(k));var w;try{w=void 0!==(l.browser.isIE()?new ActiveXObject("ShockwaveFlash.ShockwaveFlash"):m.plugins["Shockwave Flash"])}catch(y){w=!1}c=(w?r:n)(h,c,d,f.translations);return{element:a.constant(h),reset:c.reset}}});l("14g","s 59 4a 4p 2t 2u".split(" "),function(d,e,c,a,b,f){return{responsive:function(){var g=a(d.none()),h=c.create({crashed:e([]),timeout:e([])});return{start:function(a,c,e,l){var r=c,q=f(function(){e()?b(q):0>=r?
(h.trigger.timeout(),b(q)):l()&&(b(q),h.trigger.crashed());r--},a);g.set(d.some(q))},stop:function(){g.get().each(function(a){b(a)})},events:h.registry}}}});l("14h",["a","b","2t","2u"],function(d,e,c,a){return function(b,f,g){var h=function(a){return e.forall(f,function(b){return d.isFunction(a[b])})},k=!0,m=a(function(){var a=b.dom();d.isFunction(a.PercentLoaded)&&100===a.PercentLoaded()&&h(a)&&(l(),g())},500),l=function(){k&&(c(m),k=!1)};return{stop:l}}});aa("14i",unescape);l("11u","14g 14h qz b 1o 30 c 50 7 s 59 4a 2n 1y 2o l 2z 2p 2t 6e o 2u 3x 14i 37".split(" "),
function(d,e,c,a,b,f,g,h,k,m,l,n,r,q,t,s,u,v,w,y,x,z,A,D,B){var C=h.install("ephox.flash"),F=g.detect(),E=m.none();return function(g){var h=n.create({response:l(["rtf"]),spin:l([]),cancel:l([]),error:l(["message"]),reset:l([]),hide:l([]),failed:l(["message"])}),m=!1,w=s.fromTag("div");q.add(w,c.resolve("flashbin-target"));var z=d.responsive();z.events.crashed.bind(function(){h.trigger.failed("flash.crashed")});z.events.timeout.bind(function(){h.trigger.failed("flash.crashed")});var L=function(){Q.stop();
if(!m){m=!0;try{var a=P.dom();b.each(S,function(b,c){var d=a[c];if(void 0===d)throw'Flash object does not have the method "'+c+'"';d.call(a,b)});h.trigger.reset();y(W);q.remove(w,c.resolve("flash-activate"));T();V()}catch(d){x.log("Flash dialog - Error during load: ",d)}}},N=C.permanent(L),M=function(){return!r.inBody(P)},O=function(){return!P.dom().SetVariable},S={setSpinCallback:C.permanent(function(){z.start(1E3,10,M,O);h.trigger.spin()}),setPasteCallback:C.permanent(function(a){z.stop();A(function(){""===
a?h.trigger.error("flash.crashed"):h.trigger.response(D(a))},0)}),setEscapeCallback:C.permanent(h.trigger.cancel),setErrorCallback:C.permanent(function(a){z.stop();h.trigger.error(a)}),setStartPasteCallback:C.permanent(k.noop)},P=function(){var a=g.replace(/^https?:\/\//,"//"),b='    <param name="allowscriptaccess" value="always">    <param name="wmode" value="opaque">    <param name="FlashVars" value="onLoad='+N+'">';if(F.browser.isIE()&&10===F.browser.version.major){var c=f.generate("flash-bin");
return s.fromHtml('<object classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" id="'+c+'"><param name="movie" value="'+a+'">'+b+"</object>")}return s.fromHtml('<object type="application/x-shockwave-flash" data="'+a+'">'+b+"</object>")}(),T=function(){t.setAll(P,{width:"2px",height:"2px"})};T();var Q=e(P,b.keys(S),L);v.append(w,P);var V=function(){F.browser.isFirefox()&&B.getSelection().removeAllRanges();u.focus(P)},W=null,$=function(){q.add(w,c.resolve("flash-activate"));t.remove(P,"height");t.remove(P,
"width");h.trigger.hide()},X=function(){t.set(w,"display","none");E.each(function(b){a.each(b,function(a){a.unbind()})})};return{focus:V,element:function(){return w},activate:function(){W=A($,3E3);h.trigger.spin();t.set(w,"display","block");V()},deactivate:X,destroy:function(){X();a.each(b.values(S),function(a){C.unregister(a)});C.unregister(N);Q.stop()},events:h.registry}}});l("y2","11t 11u 59 4a 3y l 37".split(" "),function(d,e,c,a,b,f,g){return function(h,k){var m=k.translations,l=a.create({response:c(["rtf",
"hide"]),cancel:c([]),error:c(["message"]),failed:c(["message"])});return{open:function(){var a=e(k.swf);a.deactivate();var c=f.fromDom(g),q=b.bind(c,"mouseup",a.focus),t=function(){v()},c=function(){v();l.trigger.cancel()};a.events.cancel.bind(c);a.events.response.bind(function(a){l.trigger.response(a.rtf(),t)});a.events.error.bind(function(a){v();l.trigger.error(a.message())});a.events.failed.bind(function(a){v();l.trigger.failed(a.message())});var s=h();s.setTitle(m("cement.dialog.flash.title"));
var u=d(a,s.reflow,k);u.reset();s.setContent(u.element());s.events.close.bind(c);s.show();a.activate();var v=function(){q.unbind();a.destroy();s.destroy()}},events:l.registry}}});l("14j",["7","1b"],function(d,e){return function(c,a,b,f){var g=e.eq(c,b)&&a===f;return{startContainer:d.constant(c),startOffset:d.constant(a),endContainer:d.constant(b),endOffset:d.constant(f),collapsed:d.constant(g)}}});l("11v","s 14j l 2p 2r 2b".split(" "),function(d,e,c,a,b,f){return function(g){var h=c.fromTag("br"),
k=d.none();return{cleanup:function(){b.remove(h)},toOn:function(a,b){var c=f.owner(b).dom().defaultView;k.each(function(a){g.set(c,a)})},toOff:function(b,c){var d=f.owner(c).dom().defaultView;a.append(c,h);k=g.get(d,e);g.set(d,e(h,0,h,0))}}}});l("15n","b l 2p 3d 2r 2b".split(" "),function(d,e,c,a,b,f){var g=function(g,k){var m=f.children(g);d.each(m,function(d){if(k(d)){var g=f.children(d),h=e.fromTag("div",f.owner(d).dom());a.append(h,g);c.before(d,h);b.remove(d)}})};return{consolidate:function(c,
d){f.nextSibling(c).filter(d).each(function(d){var e=f.children(d);a.append(c,e);b.remove(d)});g(c,d)}}});l("15o",["4j"],function(d){return{resolve:d.create("ephox-sloth").resolve}});l("14k","30 2v 15n 15o 1a 1y 4e 2o bs l 2g 2p 2r 32 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,l,n,r,q,t){var s=a.resolve("bin"),u=s+d.generate(""),v=k.onDirection("-100000px","100000px");return function(a){var d=m.fromTag("div");b.setAll(d,{contenteditable:"true","aria-hidden":"true"});h.setAll(d,{position:"fixed",
top:"0px",width:"100px",height:"100px",overflow:"hidden",opacity:"0"});g.add(d,[s,u]);var k=function(a){return f.has(a,u)};return{attach:function(a){r.empty(d);h.set(d,"left",v(a));n.append(a,d)},focus:function(){q.ancestor(d,"body").each(function(b){a.toOff(b,d)})},contents:function(){c.consolidate(d,k);var a=e.immutable("elements","html","container"),b=t.children(d),f=l.get(d);return a(b,f,d)},container:function(){return d},detach:function(){r.remove(d)}}}});l("11w","7 br 59 4a 11k 14k 2b".split(" "),
function(d,e,c,a,b,f,g){return function(h,k){var m=f(h),l=function(){h.cleanup();var a=m.contents();m.detach();r.trigger.after(a.elements(),a.html(),m.container())},n=e.tap(function(){r.trigger.before();m.attach(k);m.focus();b.run(g.owner(k),n,l)}),r=a.create({before:c([]),after:c(["elements","html","container"])}),q=d.noop;return{instance:d.constant(function(){n.instance()}),destroy:q,events:r.registry}}});l("y3",["81","59","4a","11v","11w"],function(d,e,c,a,b){var f={set:function(a,b){d.setExact(a,
b.startContainer(),b.startOffset(),b.endContainer(),b.endOffset())},get:function(a,b){return d.get(a).map(function(a){return b(a.start(),a.soffset(),a.finish(),a.foffset())})}};return function(d){var h=c.create({after:e(["container"])}),k=a(f),m=b(k,d);m.events.after.bind(function(a){k.toOn(d,a.container());h.trigger.after(a.container())});return{run:function(){m.instance()()},events:h.registry}}});l("11x","c 50 7 r s 14l 2n 2o 3y l 2p 2q 2r".split(" "),function(d,e,c,a,b,f,g,h,k,m,l,n,r){var q=e.install("ephox.keurig.init"),
t=b.none(),s=d.detect(),u=s.browser;d=u.isIE()||s.deviceType.isiOS()||s.deviceType.isAndroid();return{load:d?c.noop:a.cached(function(a){var c=m.fromTag("div");if(void 0===a)throw"baseUrl was undefined";var d=m.fromTag("iframe");h.setAll(c,{display:"none"});var e=k.bind(d,"load",function(){var g=q.ephemeral(function(a){var d=u.isSafari()&&s.os.isOSX()&&10===s.os.version.major&&12>s.os.version.minor;t=b.some(a);u.isSpartan()||d||r.remove(c)});f.write(d,'<script type="text/javascript" src="'+(a+"/wordimport.js")+
'">\x3c/script><script type="text/javascript">function gwtInited () {parent.window.'+g+"(com.ephox.keurig.WordCleaner.cleanDocument);};\x3c/script>");e.unbind()});n.execute(function(){l.append(g.body(),c);l.append(c,d)})}),cleanDocument:function(a,b){return t.map(function(c){return c(a,b)})},ready:function(){return t.isSome()},isSupported:c.constant(!d)}});l("y4",["11x"],function(d){return function(e){d.ready()||d.load(e);return{isSupported:d.isSupported,cleanDocument:d.cleanDocument}}});l("ri","y0 y1 y2 y3 b 30 y4 7 s".split(" "),
function(d,e,c,a,b,f,g,h,k){return function(m,l,n,r){var q=g(r.baseUrl),t=h.curry(c,l),s=void 0!==r.intraFlag?r.intraFlag:{clipboardType:f.generate("clipboard-type"),findClipboardTags:k.none},q=b.flatten([void 0!==r.intraFlag?[e.internal(n,a,m,s)]:[],[e.onlyText()],[e.gwt(q,l,r,t)],[e.image(r)]]);m=e.pastiche(l,r,n,a,m,t,s);return d(q,m)}});l("rj",["y0","y1"],function(d,e){return function(){return d([e.text()],e.none())}});l("rk","b 8b gt 8y hg eh 7 gu gv 34 59 4a 4p 1a 1y l 3d 2r 3x".split(" "),
function(d,e,c,a,b,f,g,h,k,m,l,n,r,q,t,s,u,v,w){return function(y,x){return function(z){var A=n.create({close:l([])}),D=h(y);D.events.close.bind(function(){A.trigger.close()});t.add(D.element(),m.resolve("external-dialog"));z&&t.add(D.element(),m.resolve("dialog-vertical-controls"));var B=s.fromTag("div"),C=r([]),F=function(a){var c=b();if(void 0===a.text)throw"dialog button did not specify text";c.content(f(a.text));e.button(c.element(),a.text);void 0!==a.tabindex&&q.set(c.element(),"tabindex",a.tabindex);
void 0!==a.className&&t.add(c.element(),a.className);void 0!==a.click&&c.events.click.bind(a.click);t.add(c.element(),m.resolve("dialog-button"));return c};return{element:D.element,events:A.registry,setTitle:D.setTitle,setContent:D.setContent,setButtons:function(a){v.empty(B);a=d.map(a,F);u.append(B,d.map(a,function(a){return a.element()}));C.set(a);D.setControls(B)},reflow:g.noop,show:function(){x.hideInlineSelection();D.show();var b=d.map(C.get(),function(b){return a.button(b.element(),c.button({execute:k.click}))}),
e=a.multipleAll(D.element(),b);e.events.exit.bind(function(){A.trigger.close()});w(function(){e.enter()},0)},destroy:function(){d.each(C.get(),function(a){a.destroy()});C.set([]);D.destroy()}}}}});l("rl",["9"],function(d){return function(e,c,a){var b={"errors.imageimport.unsupported":"errors.images.import.unsupported","errors.imageimport.invalid":"errors.images.import.invalid"};return{baseUrl:a.baseUrl,enableFlashImport:a.enableFlashImport,swf:a.swf,officeStyles:a.officeStyles,htmlStyles:a.htmlStyles,
translations:function(a){var c=d.prototype.slice.call(arguments,1);return e.translate.apply(void 0,[void 0!==b[a]?b[a]:a].concat(c))},allowLocalImages:a.allowLocalImages,intraFlag:c}}});l("j6","ri rj rk 7b rl j0".split(" "),function(d,e,c,a,b,f){var g=function(e,g,m,l){var n=c(e.uiContainer(),l),r=function(a){g.filterDom(g.paste(),a)},q=b(a,f.intraFlag(),m);return function(a){return d(a,n,r,q)}};return function(a,b,c,d){return!0===c.forceText?e:g(a,b,c,d)}});l("b7","j3 b 3q c s j4 j5 bc cf 95 j0 j6 96 59 4a cw 1a l 3d 21 6u 4h 2b v".split(" "),
function(d,e,c,a,b,f,g,h,k,m,l,n,r,q,t,s,u,v,w,y,x,z,A,D){return function(B,C,F,E){var G=a.detect(),H=B.filter(),I=B.content(),K=B.undo(),J=B.smartview(),L=B.region(),N=B.internalevents(),M=n(J,H,E,I),O=b.none(),S=t.create({analytics:q(["message"])}),P=function(a){var b=e.contains(["flash.clipboard.no.rtf","safari.imagepaste"],a.message())?"info":"error";T(a.message(),b)},T=function(a,b){r.getOrLog(a,[]).each(function(a){a=k(a,b);B.ui().displayBanner(a)});Q()},Q=function(){c.unblock();I.focus()};
H.add(H.history(),d.binStyle(),s.remove);!1===E.allowLocalImages&&H.addSelector(H.paste(),"img[src]",function(a){a=e.filter(a,function(a){a=u.get(a,"src");return D.startsWith(a,"data")||D.startsWith(a,"blob")});0!==a.length&&(T("errors.local.images.disallowed"),s.remove(a))});if(G.os.isiOS()&&G.browser.isSafari()){var V=G.deviceType.isWebView()?"webview.imagepaste":"safari.imagepaste";H.addSelector(H.paste(),'img[src^="webkit-fake-url"]',function(a){0!==a.length&&(T(V,"info"),s.remove(a))})}I.events.ready.bind(function(a){var d=
h.get(I,J,a.api().doc()),k=g.rules(I,L,d),n=f(I,B.operations()),q=a.api(),r=M(q.body());O=b.some(r);q.events.paste.bind(function(a){q.getSelection().filter(function(a){return e.forall(l.ignoreSelectors(),function(b){return!1===x.ancestor(a.startContainer(),b,I.isRoot)})}).each(function(b){r.isBlocked()||(n.backup(),c.block());r.paste(a.original().raw())})});r.events.cancel.bind(function(){Q();n.cancel()});var s=m.processResults(T);r.events.error.bind(P);r.events.insert.bind(function(a){F.correlated(a.correlated()).map(s).get(function(b){Q();
K.save();var c=v.fromTag("div");w.append(c,a.elements());H.filterDom(H.input(),c);c=A.children(c);e.each(c,function(a){y.isElement(a)&&u.set(a,"data-ephox-polish-cement-inserted",!0)});n.insert(c,[k.collapsed()],[k.ranged()]);I.body().each(function(a){a=z.descendants(a,"[data-ephox-polish-cement-inserted]");e.each(a,function(a){u.remove(a,"data-ephox-polish-cement-inserted")});N.input(a)});I.domChanged();S.trigger.analytics("paste_action");C.pasteUpload();C.uploadAssets(b)})})});return{destroy:function(){O.each(function(a){a.destroy()})},
events:S.registry}}});l("60",["b6","b7"],function(d,e){return function(c,a,b,f){var g=d(c,f.copy),h=e(c,a,b,f.paste);return{destroy:function(){g.destroy();h.destroy()}}}});l("rm",["b","1o","w"],function(d,e,c){var a=function(a){for(var b=[],d=a.start.charCodeAt(0);d<=a.finish.charCodeAt(0);d++)b.push(c.fromCharCode(d));return b},b=function(a){return{start:a,finish:a}};return function(){var c={latin:[{start:"A",finish:"Z"},{start:"a",finish:"z"},{start:"\u00c0",finish:"\u00ff"}],punctuation:[{start:"!",
finish:"/"},{start:":",finish:"@"},{start:"[",finish:"`"},{start:"{",finish:"~"},{start:"\u00a1",finish:"\u00bf"},{start:"\u2010",finish:"\u2027"},{start:"\u2030",finish:"\u205e"}],currency:[b("$"),{start:"\u00a2",finish:"\u00a5"},{start:"\u20a0",finish:"\u20bd"},b("\u5186"),b("\u5143"),b("\u5713"),b("\u5706")],"extended-latin-a":[{start:"\u0100",finish:"\u017f"}],"extended-latin-b":[{start:"\u0180",finish:"\u024f"}],arrows:[{start:"\u2190",finish:"\u21ff"},b("\u2794"),{start:"\u2798",finish:"\u27af"},
{start:"\u27b1",finish:"\u27be"}],mathematical:[{start:"\u2795",finish:"\u2797"},{start:"\u2200",finish:"\u22ff"}],miscellaneous:[{start:"\u2701",finish:"\u275e"},{start:"\u2761",finish:"\u2793"},b("\u27b0"),b("\u27bf")]},g={};e.each(c,function(b,c,e){g[c]=d.bind(b,a)});return g}});l("rn","53 7 gw 34 4a 4b 1y l 3d".split(" "),function(d,e,c,a,b,f,g,h,k){return{controls:function(h){var l=h+"-";h=d.div();g.add(h,a.resolve(l+"dialog-controls"));var n=c.button(l,"cancel","button.cancel"),r=c.button(l,
"insert","specialchar.insert");c.makeNormal(n.element());c.makeDefault(r.element());k.append(h,[n.element(),r.element()]);l=b.create({insert:f([],r.events.click),cancel:f([],n.events.click)});return{element:e.constant(h),ok:e.constant(r),cancel:e.constant(n),destroy:function(){r.destroy();n.destroy()},events:l.registry}}}});l("ro","b 1o xo h1 h2 7b 34 1a 1y 4e l 2p 3d 1s 37".split(" "),function(d,e,c,a,b,f,g,h,k,m,l,n,r,q,t){var s=function(a){var b=l.fromTag("span");k.add(b,g.resolve("special-char"));
var d=l.fromHtml(a);h.setAll(b,{"data-ephox-polish-special-char":a,"data-ephox-polish-char-code":a.charCodeAt(0).toString(16),tabindex:"-1"});c.gridcell(b);n.append(b,d);return b},u=function(a,b){var e=l.fromTag("div");m.add(e,[g.resolve("special-char-row"),g.resolve("special-char-row-"+b)]);c.row(e);d.each(a,function(a){n.append(e,s(a))});return e},v=function(a,b,e){var h=l.fromTag("div");k.add(h,g.resolve(b));c.base(h,f.translate("specialchar.grid"));a=d.chunk(a,e);a=d.map(a,function(a){return u(a,
b)});r.append(h,a);return h};return{generateItems:function(c){var d=600>=q.min(t.innerWidth,t.innerHeight)?12:16;return e.mapToArray(c,function(c,e){var g=v(c,e,d);return b(f.translate("specialchar."+e),a(g))})}}});l("j7","b 3q gt 8y h3 7 rm gu gv lq po 7b rn ro 34 59 4a 1a 1y 3y 2z 2p 6u 32 2b 33".split(" "),function(d,e,c,a,b,f,g,h,k,m,l,n,r,q,t,s,u,v,w,y,x,z,A,D,B,C){var F=function(b){var d={item:f.constant(".ephox-pastry-statebutton.ephox-pastry-tablayout-item")},e=c.flow({trigger:k.button,executeOnArrow:!0});
return a.flow(b.menu(),d,e)},E=function(a){return A.closest(a,".ephox-pastry-tablayout-active")},G=function(b){var d={row:f.constant(".ephox-pastry-tablayout-active ."+t.resolve("special-char-row")),cell:f.constant(".ephox-pastry-tablayout-active ."+t.resolve("special-char"))},e=c.tabular({trigger:k.click,isValid:E});return a.tabular(b.body(),d,e)};return function(f){var A=u.create({insert:s(["string"]),close:s([])}),E=h(f);f=g();f=q.generateItems(f);var J=m.input("specialchar","specialchar.selects"),
L=l(b.left(),f,t.resolve("specialchars"));w.add(L.body(),t.resolve("specialchar-body"));w.add(E.element(),t.resolve("specialchar-dialog"));d.each(B.children(L.element()),e.register);var N=y.bind(E.element(),"click",function(a){a=a.target();D.closest(a,"[data-ephox-polish-special-char]").each(function(a){x.focus(a);var b=v.get(a,"data-ephox-polish-special-char");a=J.input();b=C.get(a)+b;C.set(a,b)})}),M=r.controls("specialchar");E.setTitle(n.translate("specialchar.dialog"));E.setContent(L.element());
E.setControls(M.element());z.after(L.element(),J.element());f=function(){E.hide();C.set(J.input(),"");A.trigger.close()};var O=F(L),S=G(L),P=k.setup(E,M,[O,S,a.input(J.input(),c.input({}))]);L.events.setActive.bind(function(a){O.clickFocus(a.item().element())});E.events.close.bind(function(){P.exit();A.trigger.close()});M.events.cancel.bind(f);E.events.close.bind(f);M.events.insert.bind(function(){A.trigger.insert(C.get(J.input()))});return{element:E.element(),events:A.registry,open:function(){E.show();
P.enter()},destroy:function(){N.unbind();E.destroy();L.destroy();M.destroy();P.destroy()},close:function(){E.hide();C.set(J.input(),"")}}}});l("b8",["j7","59","4a","4b"],function(d,e,c,a){return function(b,f){var g=d(f),h=c.create({insert:a(["string"],g.events.insert),close:e([])}),k=function(){h.trigger.close();g.close()};g.events.close.bind(k);return{show:function(){b.toReading();g.open()},close:k,destroy:function(){g.events.close.unbind(k);g.destroy()},events:h.registry}}});l("61","9o 7 83 79 7b b8 71 l".split(" "),
function(d,e,c,a,b,f,g,h){return function(k){var m=k.content(),l=k.smartview(),n=function(a){a=h.fromText(a.string());c.insertAtCursor(m,[a]).each(function(a){a=d.after(a.element());m.setRelativeSelection(a,a);m.focus();m.toEditing()})},r=a.destroyable(),q=function(){r.clear()};return{ui:g.ui({"specialchar.general":{toggle:!1,value:"specialchar",textkey:b.key("specialchar.open"),action:function(){var a=f(m,l.uiContainer());r.set(a);a.events.close.bind(function(){m.focus();q()});a.events.insert.bind(function(a){n(a);
q()});k.content().hideInlineSelection();a.show()},updateGeneral:e.noop,icon:!0,shortcut:!1,hasPopup:!1,hasDialog:!0}}),destroy:q}}});l("b9","7 s 6v 7b cc 70 71 7c 1a".split(" "),function(d,e,c,a,b,f,g,h,k){return function(m,l,n,r,q){var t=m.content(),s=m.profile().nativeSpelling(),u=function(a){k.set(a,"spellcheck","false")},v=function(a){k.set(a,"spellcheck","true")};t.runOrOnLoaded(function(){var a=s.get()?v:u;t.body().each(a)});m=g.ui({"spelling.general":{toggle:!0,value:"spellcheck",textkey:a.key("cog.spellcheck"),
action:function(){var a=!s.get();s.setAndCache(a);a=a?v:u;t.body().each(a)},updateGeneral:function(a){(s.get()?a.select:a.deselect)()},icon:!0,tooltip:h.get}});return b({events:c(["analytics"]),init:d.noop,hasDropdown:d.constant(!1),hasAutocorrect:d.constant(!1),check:d.noop,scanView:d.noop,lock:d.apply,situation:f.noSituation,handle:d.noop,assign:d.noop,destroy:function(){t.body().each(function(a){k.remove(a,"spellcheck")})},state:d.constant({}),ui:m,lookup:d.constant(e.none()),name:d.constant("spelling-disabled")})}});
l("j8",["f9","4q","dy"],function(d,e,c){var a=e.generate([{single:["element"]},{range:["start","soffset","finish","foffset"]}]);return{cata:function(a,c,d){return a.fold(c,d)},single:a.single,range:function(b,e,g,h){var k=c.after(g,h,b,e),m=k?d.point(b,e):d.point(g,h);b=k?d.point(g,h):d.point(b,e);return a.range(m.element(),m.offset(),b.element(),b.offset())}}});l("y5",["2v"],function(d){return d.immutable("suggestions","ignore")});l("y6",["84","6p"],function(d,e){return{clean:function(c){var a=new e(d.zeroWidth(),
"g"),b=new e("[\u2018\u2019]","g");return c.replace(a,"").replace(b,"'")}}});l("rp",["y5","y6","1o","s"],function(d,e,c,a){return function(b){var f={},g=function(a){return f.hasOwnProperty(a)&&void 0!==f[a]?f[a]:{}},h=function(a,b){var c=g(a);b(c);f[a]=c},k=function(a,b){var c=g(a);return b(c)},m=function(b,c,f){h(b,function(b){var g=e.clean(c);b.hasOwnProperty(g)&&void 0!==b[g]||(b[g]=d(a.some(f),!1))})},l=function(b,c){h(b,function(b){var f=e.clean(c),g=b.hasOwnProperty(f)?b[f]:void 0,g=void 0!==
g?g.suggestions():a.none(),g=d(g,!0);b[f]=g})};c.each(void 0!==b?b:{},function(a,b){c.each(a,function(a,c){!0===a.ignore&&l(b,c);void 0!==a.suggestions&&m(b,c,a.suggestions)})});return{add:m,get:function(b,c){return k(b,function(b){var d=e.clean(c);return b.hasOwnProperty(d)?a.from(b[d]):a.none()})},ignore:l,suggestions:function(b,c){return k(b,function(b){var d=e.clean(c);return(b.hasOwnProperty(d)?a.from(b[d]):a.none()).bind(function(a){return a.suggestions()})})},state:function(){return c.map(f,
function(a,b){return c.map(a,function(a,b){return{ignore:a.ignore(),suggestions:a.suggestions().getOr([])}})})},destroy:function(){f={}}}}});l("j9",["rp"],function(d){return function(e){return d(e)}});l("ja",["cw","1y"],function(d,e){return{configure:function(c){c.add(c.internal(),"ephox-cram-annotation-wrap",d.unwrap);c.add(c.output(),"ephox-cram-annotation-wrap",d.unwrap);c.add(c.paste(),"ephox-cram-annotation-wrap",d.unwrap);c.addExcludedContext([".ephox-cram-annotation-wrap"])},isWrap:function(c){return e.has(c,
"ephox-cram-annotation-wrap")}}});l("67","b 6 2l 7 s 7b".split(" "),function(d,e,c,a,b,f){var g={en_au:"en_gb",en_bz:"en_gb",en_ca:"en_gb",en_gb:"en_gb",en_ie:"en_gb",en_in:"en_gb",en_jm:"en_gb",en_my:"en_gb",en_nz:"en_gb",en_ph:"en_gb",en_sg:"en_gb",en_tt:"en_gb",en_za:"en_gb",en_zw:"en_gb",en_us:"en_us",en:"en_us"},h="da de en en_au en_br en_gb en_uk en_us es fi fr it nb nl pt pt_pt sv".split(" "),k=function(c,d){return{value:a.constant(c),textkey:a.constant(d),icon:b.none}};return{determine:function(a){if("no.language"===
a)a=b.some(a);else{var f=e.merge(c.localeList(),g);a=c.determineFrom(a,f);a=""!==a&&d.contains(h,a)?b.some(a):b.none()}return a},get:function(){return[k("no.language",f.key("spelling.none")),k("en_us",f.key("parlance.en_us")),k("en_gb",f.key("parlance.en_gb")),k("da",f.key("parlance.da")),k("de",f.key("parlance.de")),k("es",f.key("parlance.es")),k("fi",f.key("parlance.fi")),k("fr",f.key("parlance.fr")),k("it",f.key("parlance.it")),k("nb",f.key("parlance.no")),k("nl",f.key("parlance.nl")),k("pt",f.key("parlance.pt_br")),
k("pt_pt",f.key("parlance.pt_pt")),k("sv",f.key("parlance.sv"))]},isOn:function(a){return"no.language"!==a},offKey:a.constant("no.language")}});l("jb","7 s 7b 67 71 7j 59 4a v".split(" "),function(d,e,c,a,b,f,g,h,k){var m=function(b,g){var h=a.get();return{"spelling.dropdown":{name:"spellcheck",textkey:c.key("spelling.menu"),menuTextkey:"",updateDropdown:function(a){a.populate([{label:e.none,items:d.constant(h)}]);var c=b.profile().spelling().get();f.on(c).fold(a.untick,d.noop,a.tick)},action:function(a){b.profile().spelling().setAndCache(a);
k.startsWith(a,"en")||b.profile().autocorrect().set(!1);g.trigger.change(a)},values:h,render:e.none(),describe:function(a){return c.key("spelling.menu")},hasPopup:!0,toggle:!1}}},l=function(b,d,e){var f=b.profile().spelling().get()!==a.offKey();return{"spelling.general":{toggle:!0,value:"spellcheck",textkey:c.key("cog.spellcheck"),action:function(){var c=(f=!f)?d:a.offKey();b.profile().spelling().setAndCache(c);e.trigger.change(c)},updateGeneral:function(a){f?a.select():a.deselect()},icon:!1}}};return function(a,
c,e){var f=h.create({change:g(["language"])});a=e?m(a,f):l(a,c,f);return{ui:b.ui(a),hasDropdown:d.constant(e),events:f.registry}}});l("y7",["s","2v"],function(d,e){var c=e.immutable("area","f");return function(){var a=[],b=!1,e=function(){b=!0;d.from(a.shift()).fold(function(){b=!1},function(a){a.f()(a.area(),e)})};return{enqueue:function(d,h){a.push(c(d,h));b||e()},destroy:function(){a=[]}}}});l("16b",["7"],function(d){return{stop:d.constant("trampoline.stop"),run:function(d){for(;"trampoline.stop"!==
d;)d=d()}}});l("15r","s is ae 16b 15q 4q".split(" "),function(d,e,c,a,b,f){var g=f.generate([{inline:["item","mode","lang"]},{text:["item","mode"]},{empty:["item","mode"]},{boundary:["item","mode","lang"]},{concluded:["item","mode"]}]),h=function(a,b,c,e){var f=a.property().isElement(b)?d.from(a.attrs().get(b,"lang")):d.none();return a.property().isText(b)?g.text(b,c):e(b,c)?g.concluded(b,c):a.property().isBoundary(b)?g.boundary(b,c,f):a.property().isEmptyTag(b)?g.empty(b,c):g.inline(b,c,f)},k=function(a,
b,c,d){return e.walk(a,b,c,e.walkers().right(),void 0).fold(function(){return g.concluded(b,c)},function(b){return h(a,b.item(),b.mode(),d)})},m=function(b,d,f,g,h,k){return function(){return d.fold(function(a,c,d){(c===e.advance?g.openInline:g.closeInline)(d,a);return l(b,a,c,f,g,h,k)},function(c,d){var e=h(b,c);g.addDetail(e);return f(c,d)?a.stop():l(b,c,d,f,g,h,k)},function(a,c){g.addEmpty(a);return l(b,a,c,f,g,h,k)},function(d,m,r){var x=k.assess(d);return c.cata(x,function(c){return m!==e.backtrack?
l(b,d,e.sidestep,f,g,h,k):a.stop()},function(a){(m===e.advance?g.openBoundary:g.closeBoundary)(r,d);return l(b,d,m,f,g,h,k)},function(b){return a.stop()})},function(b,c){return a.stop()})}},l=function(a,b,c,d,e,f,g){b=k(a,b,c,d);return m(a,b,d,e,f,g)};return{walk:function(c,d,f,g,k,l){var p=function(a,b){return c.eq(a,f)&&(b!==e.advance||c.property().isText(a)||0===c.property().children(a).length)},w=b.nu(g),y=h(c,d,e.advance,p);a.run(function(){return m(c,y,p,w,k,l)});return w.done()}}});l("15s",
["b","7","10c","2v"],function(d,e,c,a){var b=a.immutableBag(["elements","lang","words"],[]);return{fromWalking:function(a,g){var h=d.map(g,function(a){var e=a.details();a=a.lang();var f=d.map(e,function(a){return a.text()}).join(""),e=d.map(e,function(a){return a.item()}),f=c.words(f);return b({lang:a,words:f,elements:e})});return{zones:e.constant(h)}}}});l("14m","7 s mn 152 15p 15q 15r 15s".split(" "),function(d,e,c,a,b,f,g,h){var k=function(a,b,c,d,h,k){return(a.eq(b,c)?e.some(b):a.property().parent(b)).map(function(e){e=
f.calculate(a,e).getOr(d);return g.walk(a,b,c,e,h,k)})},m=function(a,b,d,f,g,m){b=c.subset(a,b,d).bind(function(b){return 0===b.length?e.none():k(a,b[0],b[b.length-1],f,g,m)}).getOr([]);return h.fromWalking(a,b)},l=function(a,c){return function(d,e){return d.eq(e,a.item())?a:d.eq(e,c.item())?c:b.detail(d,e)}},n=function(){return{zones:d.constant([])}};return{fromRange:function(b,c,e,f,g){c=a.getEdges(b,c,e,d.constant(!1));e=l(c.left(),c.right());return m(b,c.left().item(),c.right().item(),f,e,g)},
transformEdges:l,fromBounded:function(a,c,d,e,f){return m(a,c,d,e,b.detail,f)},fromBoundedWith:m,fromInline:function(b,c,d,e){c=a.byBoundary(b,c);var f=l(c.left(),c.right());return c.isEmpty()?n():m(b,c.left().item(),c.right().item(),d,f,e)},empty:n}});l("11y",["7","m4","14m"],function(d,e,c){var a=function(a,d,e,k){return a.property().isBoundary(d)?c.fromBounded(a,d,d,e,k):a.property().isEmptyTag(d)?b():c.fromInline(a,d,e,k)},b=function(){return c.empty()};return{single:a,range:function(b,d,h,k,
m,l,n){d=e.toLeaf(b,d,h);k=e.toLeaf(b,k,m);return b.eq(d.element(),k.element())?a(b,d.element(),l,n):c.fromRange(b,d.element(),k.element(),l,n)},empty:b}});l("y8",["6q","11y"],function(d,e){var c=d();return{single:function(a,b,d){return e.single(c,a,b,d)},range:function(a,b,d,g,h,k){return e.range(c,a,b,d,g,h,k)},empty:function(){return e.empty()}}});l("rq","j8 y7 7 y8 4p 2n".split(" "),function(d,e,c,a,b,f){return function(g,h){var k=b(g),m=e(),l=function(b,c,e,g){e=d.cata(e,function(b){return f.inBody(b)?
a.single(b,k.get(),h):a.empty()},function(b,c,d,e){return f.inBody(b)&&f.inBody(d)?a.range(b,c,d,e,k.get(),h):a.empty()});c(b,e,k.get(),g)};return{run:function(a,b,d){l(a,b,d,c.identity)},setLang:k.set,schedule:function(a,b,c,d){m.enqueue(c,function(c,e){void 0!==d&&d()?e():l(a,b,c,e)})},destroy:function(){m.destroy()}}}});l("y9",["b","1o","7"],function(d,e,c){return{update:function(a,b,c){var g=e.keys(c);d.each(g,function(d){a.add(b,d,c[d])});return g},getInCache:function(a,b,e){return d.filter(e,
function(d){return a.get(b,d.word()).fold(c.constant(!1),function(a){return a.suggestions().isSome()})})}}});l("171",["7","ae"],function(d,e){return{anything:d.constant({assess:e.inView})}});l("16s","s m4 171 152 15p 15q 14m".split(" "),function(d,e,c,a,b,f,g){var h=c.anything(),k=function(a,b,c,e,f,k){a=g.fromBoundedWith(a,b,c,e,k,h).zones();1===a.length?(a=a[0],f=a.lang()===f?d.some(a):d.none()):f=d.none();return f},m=function(a,c,d,e,f){return k(a,c,d,e,f,b.detail)};return{fromRange:function(b,
c,d,e,h){var m=f.strictBounder(e,h);c=a.getEdges(b,c,d,m);d=g.transformEdges(c.left(),c.right());return k(b,c.left().item(),c.right().item(),e,h,d)},fromBounded:m,fromInline:function(b,c,d,h){var l=f.strictBounder(d,h),l=a.getEdges(b,c,c,l),s=g.transformEdges(l.left(),l.right());l.isEmpty()?(s=b.property().isText(c)?b.property().getText(c):b.property().children(c).length,l=e.toLeaf(b,c,0),c=e.toLeaf(b,c,s),b=m(b,l.element(),c.element(),d,h)):b=k(b,l.left().item(),l.right().item(),d,h,s);return b},
empty:function(){return d.none()}}});l("16c",["m4","16s"],function(d,e){var c=function(a,b,c,d){return a.property().isBoundary(b)?e.fromBounded(a,b,b,c,d):a.property().isEmptyTag(b)?e.empty():e.fromInline(a,b,c,d)};return{single:c,range:function(a,b,f,g,h,k,m){b=d.toLeaf(a,b,f);g=d.toLeaf(a,g,h);return a.eq(b.element(),g.element())?c(a,b.element(),k,m):e.fromRange(a,b.element(),g.element(),k,m)}}});l("15t",["6q","16c"],function(d,e){var c=d();return{single:function(a,b,d){return e.single(c,a,b,d)},
range:function(a,b,d,g,h,k){return e.range(c,a,b,d,g,h,k)}}});l("14n","b s 15t 21 6m az 2b".split(" "),function(d,e,c,a,b,f,g){var h=function(c){return d.bind(c,function(c){return b.descendants(c,a.isText)})};return{textnodes:h,text:function(b){b=h(b);return d.map(b,function(b){return a.isText(b)?f.get(b):""}).join("")},parsed:function(a,b,d){return e.from(a[0]).bind(function(a){return c.single(a,b,d).bind(function(a){a=a.words();return 1===a.length?e.some(a[0]).map(function(a){return a.word()}):
e.none()})})},children:function(a){return d.bind(a,g.children)}}});l("11z","b 14n s 3d 2r az".split(" "),function(d,e,c,a,b,f){return{clobber:function(g,h){var k=e.children(g),m=e.textnodes(g);return c.from(g[0]).bind(function(e){a.before(e,k);e=c.from(m[0]);e.each(function(a){f.set(a,h)});d.each(m.slice(1),function(a){f.set(a,"")});d.each(g,b.remove);return e})}}});l("120","113 13v 13w 7 s hu 1a 1y l".split(" "),function(d,e,c,a,b,f,g,h,k){var m=e.resolve("annotation"),l=e.resolve("lingo"),n=c.resolve("annotation-wrap");
return{nu:function(){var a=k.fromTag("span");h.add(a,n);g.set(a,"aria-invalid","spelling");return f.nu(a)},set:function(a,b,c){g.set(a,m,c);g.set(a,l,b)},label:a.constant(n),detail:function(c){return d.id(c).bind(function(d){return b.from(g.get(c,m)).bind(function(e){return b.from(g.get(c,l)).map(function(b){return{id:a.constant(d),word:a.constant(e),lang:a.constant(b)}})})})}}});l("121",["b","113","13w","1y"],function(d,e,c,a){var b=c.resolve("wrap-disabled");return{enable:function(c){c=e.all(c);
d.each(c,function(c){a.remove(c,b)})},disable:function(c){c=e.all(c);d.each(c,function(c){a.add(c,b)})}}});l("14o",["2v"],function(d){return d.immutable("id","elements","word","lang")});l("14p",[],function(){var d=function(d){return{fold:d}};return{success:function(e){return d(function(c,a){a(e)})},fail:function(e){return d(function(c,a){c(e)})}}});l("122","b 1o 14o 14p 113 14n 2n".split(" "),function(d,e,c,a,b,f,g){var h=function(a,e){var f={};d.each(a,function(a){b.marker(a,e.label()).filter(g.inBody).each(function(a){e.detail(a).each(function(d){var e=
d.id(),g=d.word();d=d.lang();var h=b.all(a);0<h.length&&(f[e]=c(e,h,g,d))})})});return f},k=function(a,b,c,d){var e=f.text(a);a=f.parsed(a,c,d);return e===b&&a.is(b)},m=function(b,c,f){b=e.values(b);return d.map(b,function(b){return b.lang()===f&&k(b.elements(),b.word(),c,b.lang())?a.success(b):a.fail(b)})};return{validate:k,verify:function(a,b,c,e,f){b=h(a.elements(),b);a=m(b,f,a.lang());d.each(a,function(a){var b=function(a){return function(b){d.each(b.elements(),a)}};a.fold(b(e),b(c))})}}});l("ye",
"b 11z 120 x8 113 121 x9 122 7 hu 2r".split(" "),function(d,e,c,a,b,f,g,h,k,m,l){var n=function(a){return b.marker(a,c.label())};return{highlight:function(e,k,n,s){h.verify(k,c,f.enable,l.unwrap,e.lang());n=g.matchWords(k.elements(),n,s);n=g.annotates(n,c.label());return d.bind(n,function(f){return f.current().fold(function(){var g=f.match(),h=g.word();if(e.ignore(g))return[];g=m.wrapper(g.elements(),c.nu)||[];d.each(g,function(a){b.set(a,f.id());c.set(a,k.lang(),h)});return[a.created(g)]},function(b){return[a.preserved(b)]})})},
marker:n,substitute:function(a,c){var d=n(a).fold(k.constant([]),b.all);return e.clobber(d,c)},detail:function(a){return c.detail(a)}}});l("ya",["b","ye","7"],function(d,e,c){return{highlight:function(a,b,f,g){var h={operation:a,internal:a,ignore:c.constant(!1),lang:c.constant(g)},k=d.map(f,function(a){return a.word()}),m=d.filter(k,function(a,b){return d.indexOf(k,a)===b});h.operation(function(){e.highlight(h,b,m,c.constant(!1))})}}});l("yb","y9 y6 b 3w 7 p n".split(" "),function(d,e,c,a,b,f,g){var h=
function(d,h){return a.nu(function(a){var l={words:c.map(d.words(),function(a){return e.clean(a.word())})};h.correction(l,d.lang(),function(c){c=f.value({spelling:b.constant(c),zone:b.constant(d)});a(c)},function(b){b=f.error(new g(b));a(b)})})};return{scan:function(f,g,l){var n=function(a){var g=a.zone(),h=d.update(f,g.lang(),a.spelling());a=c.filter(g.words(),function(a){a=e.clean(a.word());return c.contains(h,a)});return{zone:b.constant(g),words:b.constant(a)}};l=c.map(l,function(a){return h(a,
g)});return a.par(l).map(function(a){a=c.bind(a,function(a){return a.fold(b.constant([]),c.pure)});return c.map(a,n)})}}});l("rr",["y9","ya","yb","b","7"],function(d,e,c,a,b){return function(f,g){var h=function(c){return a.map(c,function(a){var c=d.getInCache(f,a.lang(),a.words());return{zone:b.constant(a),words:b.constant(c),lang:a.lang}})},k=function(b,c,d){a.each(c,function(a){e.highlight(b,a.zone(),a.words(),d)})};return{local:function(a,b,c,d){b=b.zones();b=h(b);k(a,b,c);d()},remote:function(a,
b,d,e){b=b.zones();c.scan(f,g,b).get(function(b){k(a,b,d);e()})},destroy:b.noop}}});l("rs",["s","o"],function(d,e){return{active:function(c){var a={};c.autocorrect().get(function(b){b.fold(function(a){e.log("Error loading autocorrect list")},function(b){a=b.corrections})});return{lookup:function(b){return a.hasOwnProperty(b)?d.from(a[b]):d.none()}}},inactive:function(){return{lookup:d.none}}}});l("123",["nm","ni","7"],function(d,e,c){d=e.objOf([d.strict("language"),d.strict("words")]);return{many:c.constant(d)}});
l("124","ih b 1o 30 86 f1 f3 7".split(" "),function(d,e,c,a,b,f,g,h){var k=function(a,b){return d.readOptFrom(a,b).getOrThunk(function(){return f()})},m=a.generate("good-spelling");return{execute:function(a,f,l,q,t,s){var u=k(f,l);s=g.multiple(function(b,c){return a.execute({language:l,words:b})},u,q,function(a){return a.spell},h.identity,t,void 0!==s?s:!1);f[l]=u;return b.mapSync(s,function(a){e.each(q,function(b){d.hasKey(a,b)||u.set(b,m,t)});var b={};c.each(a,function(a,c){u.get(t,c).is(m)||(b[c]=
a)});return b})},initCaches:function(a){var b={};c.each(void 0!==a?a:{},function(a,c){b[c]=f(a)});return b},correct:h.constant(m)}});l("yc",["1o","f2","f4","123","124"],function(d,e,c,a,b){return function(f,g,h){var k=b.initCaches(h),m=e.post("ephox.spelling.service.many",a.many(),f,g);return{checkMany:function(a,d,e){e=c.now();return b.execute(m,k,a,d,e)},dumpCache:function(){return d.map(k,function(a){return a.dump()})}}}});l("yd",["7","v"],function(d,e){var c={image:d.constant("1"),spelling:d.constant("1")};
return{corsQuery:function(a){return e.ensureTrailing(a,"/")+"version"},spelling:function(a){var b=c.spelling();return e.ensureTrailing(a,"/")+b+"/"}}});l("rt","6 i1 2m yc 7 h6 yd 59 4a o".split(" "),function(d,e,c,a,b,f,g,h,k,m){return function(l,n,r,q,t){var s=g.spelling(n),u=a(s+"correction",l.mediatorHeaders(),t),v=k.create({failed:h(["resource"])});t=c.nu(function(a){var b=d.merge(l.headers(),{dataType:"json"});e.get(s+"autocorrect?language="+r,b).get(a)});var w=f.bind(t,function(){return u.checkMany(r,
["startup"],!0)});w.get(function(a){a.fold(function(a){m.error("Unable to communicate with the spelling service:",a);v.trigger.failed(n)},b.noop)});return{correction:function(a,b,c,d){w.get(function(e){e.fold(d,function(){u.checkMany(q?b:r,a.words).get(function(a){a.fold(function(a){m.error("Error response from the spelling service:",a);d(a)},function(a){c(a)})})})})},autocorrect:b.constant(t),events:v.registry,state:function(){return u.dumpCache()}}}});l("jc","rq rr rs 67 rt 59 4a hx fq cw".split(" "),
function(d,e,c,a,b,f,g,h,k,m){return function(l){var n=l.content(),r=l.profile(),q=b(l.communication(),l.url(),l.language(),l.multilingual(),l.fromServiceState()),t=l.autocorrectOn()?c.active(q):c.inactive(),s=g.create({failed:f(["resource"])}),u=function(a){s.trigger.failed(a.resource())};q.events.failed.bind(u);var v=d(l.language(),l.viewable().viewport()),w=e(l.cache(),q),y=function(a){n.body().each(function(b){h.filterDom(b,[k("."+a,m.unwrap)])})},x=function(){return!a.isOn(r.spelling().get())},
z=function(){y("ephox-cram-annotation-wrap")};return{run:function(b,c){var d=r.spelling().get();a.isOn(d)&&(v.setLang(d),v.run(b,w.local,c),v.schedule(b,w.remote,c,x))},refresh:function(){var b=r.spelling().get();a.isOn(b)||z()},clear:z,lookup:t.lookup,destroy:function(){q.events.failed.unbind(u);v.destroy();w.destroy()},state:q.state,events:s.registry}}});l("yg",["7","34"],function(d,e){var c=function(a){a="data-"+e.resolve(a);return d.constant(a)};return{value:c("spelling-value"),type:c("spelling-type"),
overflow:c("spelling-overflow"),overflowMenu:c("spelling-overflow-menu"),spelling:c("spelling-suggestion")}});l("yf",["yg","7b","2v"],function(d,e,c){var a=c.immutable("primary","secondary","submenus"),b=c.immutable("value","text","attrs"),f=c.immutable("textkey","value","items");return{generate:function(c,h){var k;if(c.length>h){k=c.slice(0,h);var m=b(d.overflow(),e.translate("spelling.context.more"),{}),l=c.slice(h),n={};n[d.overflow()]=d.overflowMenu();l=f(e.key("spelling.context.morelabel"),d.overflowMenu(),
l);k=a(k.concat([m]),[l],n)}else k=a(c,[],{});return k}}});l("yh","ye s yg 59 4a 1a".split(" "),function(d,e,c,a,b,f){return function(){var g=b.create({incorrect:a(["substitution"])}),h=e.none(),k={};k[c.spelling()]=function(a){h.each(function(b){b=d.substitute(b,f.get(a,c.value()));g.trigger.incorrect(b)})};return{assign:function(a){h=a},run:function(a){var b=f.get(a,c.type()),b=k[b];void 0!==b&&b(a)},events:g.registry}}});l("ru","b ye 7 i8 yf yg yh 2v".split(" "),function(d,e,c,a,b,f,g,h){var k=
h.immutable("value","text","attrs");return function(h,l,n){var r=g();r.events.incorrect.bind(function(b){l.save();h.focus();h.domChanged();b.substitution().each(function(b){a.selectEnd(h,b)})});var q=c.curry(function(a,b,c,e){return a.marker(e).bind(a.detail).bind(function(a){return c(a).map(function(a){return d.map(a,function(a){var c={};c[f.type()]=b;c[f.value()]=a;return k(a,a,c)})})})},e,f.spelling(),function(a){return n.suggestions(a.lang(),a.word())});return{assign:r.assign,handle:function(a){r.run(a)},
situation:function(a){a=q(a).getOr([]);return b.generate(a,4)},destroy:c.noop}}});l("rv",["7","ag","59","4a"],function(d,e,c,a){return function(b,f){var g=a.create({lookup:c(["element"])}),h=function(a){b.getSelection().each(a)},k=function(){h(function(a){g.trigger.lookup(a.startContainer())})};b.events.keyup.bind(function(a){e.isSpace(a)&&k()});b.events.nodeChanged.bind(function(a){a.prev().each(g.trigger.lookup)});return{events:g.registry,destroy:d.noop}}});l("jd","j8 c jt 7 ft br ru rv dy q".split(" "),
function(d,e,c,a,b,f,g,h,k,m){var l=e.detect().browser;return function(e,m,q,t,s,u,v,w,y){var x=g(m,s,w),z=h(m,q),A=function(d){m.getSelection().each(function(e){var f=b.toLeaf(e.endContainer(),e.endOffset()),g=b.toLeaf(e.startContainer(),e.startOffset()),h;(h=e.collapsed())||(h=!l.isIE())||(h=k.after(e.endContainer(),e.endOffset(),e.startContainer(),e.startOffset()));e=h?c(g.element(),g.offset(),f.element(),f.offset()):e;return(h?t.lightweightWith:a.apply)(d,e)})},D=f.tap(function(a){a=a.element();
a=d.single(a);B(a)});z.events.lookup.bind(function(a){D.instance(a)});var B=function(a){y.run(A,a)};return{destroy:function(){x.destroy();z.destroy()},scan:B,situation:x.situation,lock:function(a){var b=D.control.isBlocked();D.control.block();a();b||D.control.unblock()},assign:x.assign,handle:x.handle}}});l("ba","j8 j9 b 7 s f9 ft cf ja jb 67 jc jd cc 96 59 4a 2v 1a 2b".split(" "),function(d,e,c,a,b,f,g,h,k,m,l,n,r,q,t,s,u,v,w,y){var x=v.immutableBag("communication profile content undo viewable cache url autocorrectOn language fromServiceState multilingual".split(" "),
[]);return function(v,A,D,B,C){C=A.language.getOr(C);var F=v.communication(),E=v.profile(),G=v.filter(),H=v.content(),I=v.operations(),K=v.undo(),J=v.smartview(),L=v.shortcuts(),N=v.context(),M=v.viewablearea();k.configure(G);v.profile().spelling().set(C);var O=e(A.words),S=n(x({communication:F,profile:E,content:H,undo:K,viewable:M,cache:O,url:D.url,autocorrectOn:D.autocorrect,language:B,fromServiceState:A.service,multilingual:D.multilingual})),P=b.none();A=u.create({analytics:s(["message"])});S.events.failed.bind(function(a){a=
t.get("error.code.spelling.not.found",[a.resource()]);a=h(a);v.ui().displayBanner(a)});H.events.ready.bind(function(a){H.body().each(function(a){w.set(a,"spellcheck",!1)});a=a.api().doc();a=r(a,H,N,I,K,L,J,O,S);S.refresh();P=b.some(a)});B=m(v,B,D.menu);B.events.change.bind(function(a){(l.isOn(a.language())?Q:S.clear)();H.uiChanged();H.domChanged()});var T=function(a){c.each(a,function(a){a=d.single(a);V(a)})},Q=D.scanView?function(){var a=M.sections();T(a)}:S.clear;D.scanView&&M.events.onChange.bind(Q);
var V=function(a){P.each(function(b){b.scan(a)})};return q({events:A.registry,destroy:function(){H.body().each(function(a){w.remove(a,"spellcheck")});P.each(function(a){a.destroy()});O.destroy();S.destroy()},state:function(){return{words:O.state(),service:S.state(),language:b.some(v.profile().spelling().get())}},init:a.noop,hasDropdown:B.hasDropdown,hasAutocorrect:a.constant(D.autocorrect),ui:B.ui,check:function(a,b,c,e){a=k.isWrap(a)?g.toLeaf(a,b):f.point(a,b);c=k.isWrap(c)?g.toLeaf(c,e):f.point(c,
e);c=d.range(a.element(),a.offset(),c.element(),c.offset());V(c)},scanView:Q,situation:function(b){var c={primary:a.constant([]),secondary:a.constant([]),submenus:a.constant({})};return P.fold(a.constant(c),function(a){return a.situation(b)})},lock:function(a){return P.fold(function(){return a()},function(b){return b.lock(a)})},assign:function(a){P.each(function(b){b.assign(a.bind(y.firstChild).or(a))})},handle:function(a){P.each(function(b){b.handle(a)})},lookup:S.lookup,name:a.constant("spelling")})}});
l("62",["b9","ba"],function(d,e){return function(c,a,b,f,g){return(!0===b.service?e:d)(c,a,b,f,g)}});l("jf","84 7 e7 1y l 2p 2b".split(" "),function(d,e,c,a,b,f,g){var h=function(e){e=b.fromTag(e);var g=b.fromText(d.zeroWidth());f.append(e,g);a.add(e,c.styleSpan());return e},k=function(a,b,c,d){var e=h(d);g.firstChild(e).each(function(d){a(c,e);b.setSelection(d,0,d,0)})};return{nu:h,insertAfter:e.curry(k,f.after),insertBefore:e.curry(k,f.before)}});l("bg","b c 7 s f9 ft jg 7l gf bl 1b 21 az".split(" "),
function(d,e,c,a,b,f,g,h,k,m,l,n,r){var q=e.detect().browser,t=function(a,b){return f.toLeaf(a,b)},s=function(a){return n.isText(a)&&0!==r.get(a).trim().length},u=function(a){return n.isElement(a)&&"br"===n.name(a)},v=function(a){return d.exists([s,u],function(b){return b(a)})},w=function(a){return n.isText(a.element())&&0===a.offset()||n.isElement(a.element())},y=function(d,e,f){var h=c.constant(d);return(!1===e&&w(d)?a.some(!0):a.none()).fold(h,function(a){return g.seekLeft(d.element(),v,f).fold(h,
function(a){return b.point(a,n.isText(a)?r.get(a).length:0)})})},x=function(a,b){return l.eq(a.element(),b.element())};return{context:function(b){return b.getSelection().bind(function(d){if(d.collapsed()){var e=d.startContainer();return m.cell(e,b.isRoot).bind(function(a){return m.table(e,b.isRoot).map(function(b){return{cell:c.constant(a),table:c.constant(b),start:c.constant(e),selection:c.constant(d)}})})}return a.none()})},selectedCells:function(a,d){return h.cata(a.get(),c.constant([]),c.identity,
function(a){var c=q.isFirefox()?t(a.startContainer(),a.startOffset()):b.point(a.startContainer(),a.startOffset()),e=q.isFirefox()?t(a.endContainer(),a.endOffset()):b.point(a.endContainer(),a.endOffset());a=y(e,a.collapsed()||x(c,e),d);return k.sharedOne(function(a){return m.cell(a,d)},[c.element(),a.element()]).toArray()})}}});l("rw",[],function(){var d=function(d){return{fold:d}};return{none:function(e){return d(function(c,a,b,d){return c(e)})},first:function(e){return d(function(c,a,b,d){return a(e)})},
middle:function(e,c){return d(function(a,b,d,g){return d(e,c)})},last:function(e){return d(function(c,a,b,d){return d(e)})}}});l("jh","b 7 s rw bl 1b".split(" "),function(d,e,c,a,b,f){var g=function(a,g){return b.table(a,g).bind(function(g){g=b.cells(g);var k=d.findIndex(g,function(b){return f.eq(a,b)});return 0>k?c.none():c.some({index:e.constant(k),all:e.constant(g)})})};return{next:function(b,c){return g(b,c).fold(function(){return a.none(b)},function(c){return c.index()+1<c.all().length?a.middle(b,
c.all()[c.index()+1]):a.last(b)})},prev:function(b,c){return g(b,c).fold(function(){return a.none()},function(c){return 0<=c.index()-1?a.middle(b,c.all()[c.index()-1]):a.first(b)})}}});l("bb","je 7 jf g8 bg jh".split(" "),function(d,e,c,a,b,f){return{upOrLeft:function(g){b.context(g).each(function(b){f.prev(b.cell()).fold(e.noop,function(){a.isFirstInContent(g,b.table())&&d.isLeft(b.cell(),b.selection())&&c.insertBefore(g,b.table(),"p")},e.noop,e.noop)})},right:function(g){b.context(g).each(function(b){f.next(b.cell()).fold(e.noop,
e.noop,e.noop,function(){a.isLastInContent(g,b.table())&&d.isRight(b.cell(),b.selection())&&c.insertAfter(g,b.table(),"p")})})}}});l("bd","b 8b 7 ho 7b bg 7c 7j 59 4a 4b 2o 2z".split(" "),function(d,e,c,a,b,f,g,h,k,m,l,n,r){var q={cssNamespace:"table-cell-border",i18nNamespace:"table.cell.border",property:"border-width",tag:"table",specials:[["thin","medium","thick"]]};return{widget:function(t){var s=t.content(),u=a(q);u.initLayout();e.dialog(u.element(),b.translate("aria.table.cell.border.size"));
var v=m.create({done:k([]),abort:l([],u.events.abort)});u.events.close.bind(function(a){v.trigger.done();s.focus()});u.events.action.bind(function(a){var b=r.active();s.focus();var e=f.selectedCells(t.selections(),s.isRoot);d.each(e,function(b){n.set(b,"border-width",a.value());n.getRaw(b,"border-style").fold(function(){n.set(b,"border-style","solid")},c.noop)});b.each(r.focus)});var w=function(){u.enter();u.open()};return{element:u.element,destroy:u.destroy,name:c.constant("cellborderwidth"),textkey:c.constant(b.key("table.cell.border.width")),
tooltip:g.get,label:c.constant(!1),updateWidget:function(a){var b=f.selectedCells(t.selections(),s.isRoot);0<b.length?(a.enable(),a=n.getRaw(b[0],"border-width").fold(h.off,h.on),u.updateInlineWidget({size:c.constant(a)},"1px")):a.disable();w()},events:v.registry,open:w,close:u.close}}}});l("be","8b dd 53 7 54 ji 7b bg 34 7c 59 4a 2v 4e 2p".split(" "),function(d,e,c,a,b,f,g,h,k,m,l,n,r,q,t){var s=r.immutableBag(["name","textkey","menuTextkey","action","shortname"],[]);return{widget:function(r,v){var w=
s(v),y=r.content(),x=c.div();d.label(x,g.translate(w.textkey()));q.add(x,[k.resolve("palette-cell-colors"),k.resolve(w.shortname()+"-cell-colors")]);var z=f.create();t.append(x,z.element());var A="."+k.resolve(w.shortname()+"-cell-colors")+" ."+k.resolve("palette-detail-action"),D=f.makeLayout(x,A,{}),A=D.layout(),B=n.create({done:l([]),abort:l([])});z.events.selected.bind(function(a){a=a.value();var b=h.selectedCells(r.selections(),y.isRoot);w.action()(b,a);B.trigger.done()});var C=function(){F.enter();
D.refresh()},F=e(x,[A]);F.events.exit.bind(function(){B.trigger.abort()});return{element:a.constant(x),destroy:function(){F.destroy();z.destroy()},name:a.constant(w.name()),textkey:a.constant(g.key(w.textkey())),tooltip:m.get,label:a.constant(!1),updateWidget:function(a){b.isHighContrast(r.smartview())?a.disable():(0===h.selectedCells(r.selections(),y.isRoot).length?a.disable():a.enable(),C())},events:B.registry,open:C,close:function(){B.trigger.done()}}}}});l("rx",["1a","2o","l","2p","3d"],function(d,
e,c,a,b){return{render:function(f,g,h,k){var m=c.fromTag("table");e.setAll(m,{"border-collapse":"collapse",width:"100%"});d.set(m,"border","1");var l=c.fromTag("tbody");a.append(m,l);for(var n=[],r=0;r<f;r++){for(var q=c.fromTag("tr"),t=0;t<g;t++){var s=r<h||t<k?c.fromTag("th"):c.fromTag("td");t<k&&d.set(s,"scope","row");r<h&&d.set(s,"scope","col");a.append(s,c.fromTag("br"));e.set(s,"width",100/g+"%");a.append(q,s)}n.push(q)}b.append(l,n);return m}}});l("jj",["s","83","rx","bl"],function(d,e,c,a){return{insert:function(b,
f,g,h,k){return b.getSelection().bind(function(m){var l=c.render(f,g,h,k);e.insertAtCursor(b,[l]).each(function(c){a.firstCell(l).each(function(a){b.setSelection(a,0,a,0)})});return d.some(l)})}}});l("yi","8b fh am 53 lp 7 7b 34 1a 1y 4e 2z 2p".split(" "),function(d,e,c,a,b,f,g,h,k,m,l,n,r){return function(q){var t=b(q);m.add(t.element(),h.resolve("choice-button"));var s=a.span();k.set(t.element(),"title",g.translate("table."+q));k.set(t.element(),"tabindex","-1");d.button(t.element(),g.translate("table."+
q),!1);var u=c.describe(t.element(),g.translate("aria.table.headerdescription"));r.append(t.element(),u);t.events.click.bind(function(){n.focus(t.element());e.pressed(t)});l.add(s,[h.resolve(q),"ephox-pastry-icon-content","ephox-polish-icon"]);t.content({element:f.constant(s)});return t}});l("14r",["7","s6"],function(d,e){var c=e.resolve("table-picker"),a=e.resolve("table-picker-row"),b=e.resolve("table-picker-cell"),f=e.resolve("table-picker-button");return{table:d.constant(c),row:d.constant(a),
cell:d.constant(b),button:d.constant(f)}});l("14q","gg 14r 1a 4h 32 e2".split(" "),function(d,e,c,a,b,f){var g="."+e.cell(),h="."+e.row();return{cells:function(b){return a.descendants(b,g)},rows:function(b){return a.descendants(b,h)},grid:function(a,b,e){b=f(c.get(a,b),10);a=f(c.get(a,e),10);return d.grid(b,a)},button:function(a){return b.child(a,"."+e.button()).getOr(a)}}});l("15u",["7","gg","1s"],function(d,e,c){var a=function(a,b,d,k,l){k=c.max(k,c.min(l,a.row()));a=c.max(b,c.min(d,a.column()));
return e.address(k,a)},b=function(b,c){var h=a(b,1,c.maxCols,1,c.maxRows),k;k=e.address(h.row()+1,h.column()+1);k=a(k,c.minCols,c.maxCols,c.minRows,c.maxRows);return{selection:d.constant(h),full:d.constant(k)}};return{resize:function(a,c){var d;d=e.address(a.row()+1,a.column()+1);return b(d,c)},grow:function(a,c,d,k){a=e.address(a.rows()+d,a.columns()+c);return b(a,k)}}});l("14s","gg 15u 2z 68 3p 2s 1s".split(" "),function(d,e,c,a,b,f,g){return function(g,k){var l=!1,p=function(a,b,d){var e=d.full();
e.row()===b.rows()&&e.column()===b.columns()||a.setSize(e.row(),e.column());a=a.setSelection(d.selection().row(),d.selection().column());c.focus(a)};return{on:function(){l=!0},off:function(){l=!1},mousemove:function(c,r,q,t){if(l){var s;s=f.get(c.element());var u=a.get(c.element());s=d.dimensions(s,u);u=b.absolute(c.element());u=d.coords(u.left(),u.top());q=d.coords(q,t);q=g.pickerCell(u,s,r,q);q=e.resize(q,k);p(c,r,q)}},manual:function(a,b,c,d){l&&(c=e.grow(b,c,d,k),p(a,b,c))}}}});l("125","b xo 8b 7 59 4a gg 14q 14r 14s s6 tp 1a 1y 4e 3y l 2z 2p 3d gi 2r e2".split(" "),
function(d,e,c,a,b,f,g,h,k,l,p,n,r,q,t,s,u,v,w,y,x,z,A){return function(e,B,C){var F=f.create({select:b(["rows","cols","rowHeaders","columnHeaders"])}),E=u.fromTag("table");c.presentation(E);c.hidden(E,!0);q.add(E,k.table());var G=u.fromTag("tbody");w.append(E,G);var H=0,I=0,K=function(a,b){H=b;I=a;J()},J=function(){z.empty(G);var a=C.ids();n.repeat(I,function(b){var c=u.fromTag("tr");q.add(c,k.row());var d=n.repeat(H,function(c){var d=u.fromTag("td");q.add(d,p.resolve("cell-"+c+"-"+b));q.add(d,k.cell());
var e=u.fromTag("button");r.set(e,"type","button");r.set(e,"aria-labelledby",a[b][c]);q.add(e,k.button());w.append(d,e);return d});y.append(c,d);w.append(G,c)})},L=function(a,b){var c=h.cells(E);d.each(c,function(a){q.remove(a,p.resolve("picker-selected"))});c=h.rows(E).slice(0,a);d.each(c,function(a,c){var e=h.cells(a).slice(0,b);d.each(e,function(a,b){var d=h.grid(E,"data-picker-header-row","data-picker-header-col"),d=c<d.rows()||b<d.columns()?[p.resolve("picker-selected"),p.resolve("picker-header")]:
[p.resolve("picker-selected")];t.add(a,d)})});r.set(E,"data-picker-col",b-1);r.set(E,"data-picker-row",a-1);c=h.cells(c[c.length-1]).slice(0,b);return h.button(c[c.length-1])},N=function(){var a=A(r.get(E,"data-picker-col"),10)+1,b=A(r.get(E,"data-picker-row"),10)+1;return g.grid(b,a)},M={element:a.constant(E),setSelection:L,setSize:K},O=l(e,B),S=s.bind(E,"mousemove",function(a){O.mousemove(M,g.grid(I,H),a.raw().pageX,a.raw().pageY)}),P=function(a,b){O.manual(M,N(),a,b)},T=x.realClick.bind(E,function(a){Q();
a.raw().preventDefault()}),Q=function(){var a=h.grid(E,"data-picker-row","data-picker-col"),b=h.grid(E,"data-picker-header-row","data-picker-header-col");F.trigger.select(a.rows()+1,a.columns()+1,b.rows(),b.columns())};return{element:function(){return E},destroy:function(){T.unbind();S.unbind();z.remove(E)},setSize:K,setHeaders:function(a,b){r.set(E,"data-picker-header-row",a);r.set(E,"data-picker-header-col",b)},setSelection:L,on:O.on,off:O.off,reset:function(){K(B.minRows,B.minCols);var a=L(1,1);
v.focus(a)},refresh:function(){var a=N();J();return L(a.rows(),a.columns())},events:F.registry,sendLeft:a.curry(P,e.isRtl()?1:-1,0),sendRight:a.curry(P,e.isRtl()?-1:1,0),sendUp:a.curry(P,0,-1),sendDown:a.curry(P,0,1),sendExecute:Q}}});l("yj",["125"],function(d){return function(e,c,a){return d(e,c,a)}});l("ry","xo 8b fh am gt 8y l3 an 53 7 s yi 7b 34 4a 4b yj 1a 1y 4e l 2z 3d 32".split(" "),function(d,e,c,a,b,f,g,h,k,l,p,n,r,q,t,s,u,v,w,y,x,z,A,D){return function(k,C){var F=d.createHelp(C.maxRows,
C.maxCols,{row:function(a){return r.translate("table.picker.rows",a)},col:function(a){return r.translate("table.picker.cols",a)}}),E=u(k,C,F);e.label(E.element(),r.translate("table.picker.label"));var G=a.describe(E.element(),r.translate("table.picker.describepicker")),H=x.fromTag("div");v.set(H,"tabIndex","-1");e.group(H);y.add(H,[q.resolve("insert-table"),q.resolve("toolbar-menu")]);var I=x.fromTag("div");w.add(I,q.resolve("table-controls"));e.toolbarGroup(I,r.translate("table.picker.header"));
var K=n("row-header"),J=n("column-header");A.append(I,[K.element(),J.element()]);A.append(H,[I,E.element(),G,F.help()]);var L=function(){E.setHeaders(K.selected()?1:0,J.selected()?1:0);var a=z.active(),b=E.refresh();a.each(function(a){z.hasFocus(a)||z.focus(b)})},F=function(a,b){return function(){b();return p.some(!0)}},F=f.single(E.element(),[g.basic(h.LEFT()[0],F("left",E.sendLeft)),g.basic(h.RIGHT()[0],F("right",E.sendRight)),g.basic(h.UP()[0],F("up",E.sendUp)),g.basic(h.DOWN()[0],F("down",E.sendDown)),
g.rule(g.inSet(h.SPACE().concat(h.ENTER())),F("execute",E.sendExecute))],p.none());F.events.enter.bind(function(){z.focus(E.element())});var N=f.flow(I,{item:l.constant(".ephox-pastry-statebutton")},b.flow({trigger:function(a){return D.descendant(a,".ephox-pastry-button").map(function(a){a.dom().click();return a})}})),M=f.multiple(H,[F,N]);K.events.click.bind(function(){N.clickFocus(K.element());L()});J.events.click.bind(function(){N.clickFocus(J.element());L()});I=t.create({select:s(["rows","cols",
"rowHeaders","columnHeaders"],E.events.select),exit:s([],M.events.exit)});return{element:function(){return H},destroy:function(){M.destroy();K.destroy();J.destroy();E.destroy()},setSize:E.setSize,setSelection:E.setSelection,on:function(){E.on();M.enter()},off:function(){E.off();M.isFocused()&&M.exit()},reset:function(){E.setHeaders(0,0);K.deselect();c.release(K.element());J.deselect();c.release(J.element());E.reset()},events:I.registry}}});l("jk",["6","ry","59","4a"],function(d,e,c,a){return function(b,
f){var g=a.create({enabled:c(["enabled"]),select:c(["rows","cols","rowHeaders","columnHeaders"]),insert:c(["table"]),done:c([]),abort:c([])}),h=d.merge({minCols:7,maxCols:10,minRows:4,maxRows:10},f),k=e(b,h);k.events.select.bind(function(a){l();g.trigger.done();g.trigger.select(a.rows(),a.cols(),a.rowHeaders(),a.columnHeaders())});k.events.exit.bind(function(){l();g.trigger.abort()});var l=function(){k.off()};return{element:k.element,open:function(){k.reset();k.on()},close:l,destroy:function(){k.destroy()},
events:g.registry}}});l("rz",["gg","1s"],function(d,e){var c=function(a,b,c,g){var h=a.width()/b.columns();a=a.height()/b.rows();c=e.floor(c/h);g=e.floor(g/a);return d.address(g,c)};return{findCellRtl:function(a,b,d,e){var h=a.x()+b.width()-e.x();a=e.y()-a.y();return c(b,d,h,a)},findCellLtr:function(a,b,d,e){var h=e.x()-a.x();a=e.y()-a.y();return c(b,d,h,a)}}});l("jl",["7","rz"],function(d,e){var c={pickerCell:e.findCellLtr,isRtl:d.constant(!1)},a={pickerCell:e.findCellRtl,isRtl:d.constant(!0)};return{ltr:c,
rtl:a}});l("bf","7 jj jk 7b 7c 4a 4b jl bl".split(" "),function(d,e,c,a,b,f,g,h,k){return{widget:function(k,l){var n=k.content(),r=c(k.region().uiDirection().isRtl()?h.rtl:h.ltr,l),q=k.undo(),t=f.create({done:g([],r.events.done),abort:g([],r.events.abort)});r.events.select.bind(function(a){q.save();e.insert(n,a.rows(),a.cols(),a.rowHeaders(),a.columnHeaders()).each(function(a){q.save();n.domChanged()});n.toEditing()});return{element:r.element,name:d.constant("table"),textkey:d.constant(a.key("insert.table")),
menuTextkey:d.constant(a.key("table.menu")),tooltip:b.get,label:d.constant(!1),updateWidget:function(a){n.getSelection().each(function(b){a.enable()});r.open()},destroy:r.destroy,events:t.registry,open:r.open,close:r.close}}}});l("yk",["32"],function(d){return{set:function(d,c){d.dom().checked=c},find:function(e){return d.descendant(e,"input:checked")}}});l("s0","30 7 gv 7b 1a yk l 2p 3d 2r 33".split(" "),function(d,e,c,a,b,f,g,h,k,l,p){return function(){var n=g.fromTag("fieldset"),r=g.fromHtml("<legend>"+
a.translate("table.border")+"</legend>");h.append(n,r);var q=d.generate(""),r=function(a){var c=g.fromTag("input");b.setAll(c,{type:"radio",id:"tableborder"+a+q,value:a,name:q});return c},t=r("1"),s=r("0");k.append(n,[t,g.fromHtml('<label for="tableborder1'+q+'">'+a.translate("border.on")+"</label>"),s,g.fromHtml('<label for="tableborder0'+q+'">'+a.translate("border.off")+"</label>")]);var u=c.radio(n,'input[type="radio"]',"input:checked");return{element:function(){return n},get:function(){return f.find(n).map(function(a){return p.get(a)})},
select:function(a){f.set(s,!1);f.set(t,!1);a.each(function(a){"0"===a?f.set(s,!0):"1"===a&&f.set(t,!0)});u.refresh()},keylayout:e.constant(u),destroy:function(){l.remove(n)}}}});l("s1","b gt 8y 53 7 s lq pu 34 1a 1y 3y 3d 2r 33".split(" "),function(d,e,c,a,b,f,g,h,k,l,p,n,r,q,t){return function(){var s=a.div();p.add(s,k.resolve("table-size-controls"));var u=g.input("table-width","table.width"),v=g.input("table-height","table.height");d.map([u,v],function(a){l.set(a.input(),"placeholder","Auto")});
r.append(s,[u.element(),v.element()]);var w=[c.input(u.input(),e.input({})),c.input(v.input(),e.input({}))],y=function(a){var b=a.target();h.validateField(b,"width",f.some("px")).fold(function(){h.highlight(b)},function(a){h.dehighlight(b)})},x=[n.bind(u.input(),"input",y),n.bind(v.input(),"input",y)];return{element:function(){return s},get:function(){return h.validate([h.rule(u.input(),"width",f.some("px")),h.rule(v.input(),"height",f.some("px"))])},set:function(a){a.width().bind(b.curry(t.set,u.input()));
a.height().bind(b.curry(t.set,v.input()))},keylayouts:b.constant(w),highlight:h.highlight,dehighlight:b.curry(h.clearHighlights,s),destroy:function(){q.remove(s);d.each(x,function(a){a.unbind()})}}}});l("jp","7 s s2 2v dv 1a 2o e1 2g 2r 32".split(" "),function(d,e,c,a,b,f,g,h,k,l,p){var n=a.immutableBag(["floatval","caption","summary","border","dimensions"],[]),r=function(a){a=f.get(a,"border");return"0"===a||"1"===a?e.some(a):e.none()},q=function(a){var b=g.getRaw(a,"width");a=g.getRaw(a,"height");
return{width:d.constant(b),height:d.constant(a)}};return{divine:function(a,b){var c=h.divine(b),d=f.get(b,"summary"),e=p.child(b,"caption").map(function(b){b=k.get(b);return a.filterHtml(a.output(),b)}).getOr(""),g=r(b),l=q(b);return n({floatval:c,caption:e,summary:d,border:g,dimensions:l})},properties:n,apply:function(a,d){d.floatval().each(function(c){b.runFloat(a,c)});d.border().each(function(b){f.set(a,"border",b)});""===d.summary()?f.remove(a,"summary"):c.setSummary(a,d.summary());""===d.caption()?
p.child(a,"caption").each(l.remove):c.setCaption(a,d.caption());c.setDimensions(a,d.dimensions())}}});l("jo","gt 8y 53 7 s gu gv lq pv s0 s1 jp 7b gw 34 59 4a 1y 3d 33".split(" "),function(d,e,c,a,b,f,g,h,k,l,p,n,r,q,t,s,u,v,w,y){return function(x,z){var A=u.create({ok:s(["properties"]),close:s([])}),D=f(z);D.setTitle(r.translate("table.dialog"));v.add(D.element(),t.resolve("dialog-narrow"));var B=c.div(),C=k("table.float"),F=h.input("tablesummary","table.summary"),E=h.input("tablecaption","table.caption"),
G=p(),H=l();w.append(B,[E.element(),F.element(),H.element(),G.element(),C.element()]);var I=q.okCancel("table");I.events.ok.bind(function(){N()});I.events.cancel.bind(function(){D.hide();A.trigger.close()});D.events.close.bind(function(){D.hide();A.trigger.close()});D.setContent(B);D.setControls(I.element());var K=g.setup(D,I,[e.input(E.input(),d.input({})),e.input(F.input(),d.input({})),H.keylayout()].concat(G.keylayouts()).concat([C.keylayout()])),J=function(){return G.get().map(function(c){c={width:a.constant(b.some(c.width())),
height:a.constant(b.some(c.height()))};return n.properties({floatval:C.get(),caption:L(E.input()),summary:L(F.input()),border:H.get(),dimensions:c})})},L=function(a){return y.get(a).trim()},N=function(){J().fold(function(a){G.highlight(a)},function(a){A.trigger.ok(a)})};return{element:D.element,events:A.registry,open:function(){D.show();K.enter()},represent:function(a){a=n.divine(x,a);C.select(a.floatval());void 0!==a.summary()&&y.set(F.input(),a.summary());void 0!==a.caption()&&y.set(E.input(),a.caption());
G.set(a.dimensions());H.select(a.border())},execute:N,destroy:function(){C.destroy();G.destroy();H.destroy();I.destroy();D.destroy();K.destroy()},hide:function(){K.exit();D.hide()}}}});l("bi","b gc 7 s dn jn jo jp 7b 9s jq 2v jr bl js 1a 21 32".split(" "),function(d,e,c,a,b,f,g,h,k,l,p,n,r,q,t,s,u,v){return function(w,y,x,z,A,D,B,C){var F=a.none(),E=function(a,b){var c=r.getWidth(a);r.setWidth(a,c/2);r.setWidth(b,c/2)},G={"tablemenu-delete-table":f.erase,"delete-row":f.execute(y,t.eraseRows,c.noop,
C),"delete-column":f.execute(y,t.eraseColumns,c.noop,C),"make-header-column":f.execute(y,t.makeColumnHeader,c.noop,C),"make-header-row":f.execute(y,t.makeRowHeader,c.noop,C),"unmake-header-column":f.execute(y,t.unmakeColumnHeader,c.noop,C),"unmake-header-row":f.execute(y,t.unmakeRowHeader,c.noop,C),"insert-row-before":f.execute(y,t.insertRowBefore,c.noop,C),"insert-row-after":f.execute(y,t.insertRowAfter,c.noop,C),"insert-column-before":f.execute(y,t.insertColumnBefore,E,C),"insert-column-after":f.execute(y,
t.insertColumnAfter,E,C),"tablemenu-table-properties":function(c,d,e){c=g(w,B);var f=l.generate(A,c,["properties"]);f.events.ok.bind(function(a){x.activate();F.bind(function(c){q.table(c.element(),x.isRoot).each(function(c){b.runTransaction(x,D,function(){h.apply(c,a.properties())})})});f.destroy()});f.events.close.bind(function(a){f.destroy();x.activate();x.focus()});x.deactivate();f.represent(d);f.open();return a.none()},"cell-merge":f.execute(y,t.mergeCells,c.noop,C),"cell-unmerge":f.execute(y,
t.unmergeCells,c.noop,C),"cell-split-cols":f.execute(y,t.splitCellIntoColumns,E,C),"cell-split-rows":f.execute(y,t.splitCellIntoRows,c.noop,C)},H=n.immutable("value","text","attrs");return{handle:function(a){x.doc().each(function(c){F.each(function(c){var d=c.element();q.table(d,x.isRoot).each(function(d){var f=s.get(a,"data-ephox-gopher-item-value"),g=G[f];void 0!==g&&b.runTransaction(x,D,function(){g(x,d,c).each(function(a){x.setSelection(a.startContainer(),a.startOffset(),a.endContainer(),a.endOffset());
e.clear(d)})})})})})},assign:function(a){F=a.bind(function(a){return q.cell(a,x.isRoot).bind(function(a){return v.ancestor(a,"table").map(function(b){return p.forMenu(z,b,a)})}).orThunk(function(){return q.notCell(a,x.isRoot).map(function(a){return p.notCell(a)})})})},situation:function(a){a=F.map(function(a){var b=a.element(),b=q.cell(b,x.isRoot).isSome();return d.flatten([b?[H("tablemenu-row",k.translate("table.context.row.menu"),{})]:[],b?[H("tablemenu-column",k.translate("table.context.column.menu"),
{})]:[],[H("tablemenu-table",k.translate("table.context.table.menu"),{})],a.mergable().isSome()?[H("cell-merge",k.translate("table.context.cell.merge"),{})]:[],a.unmergable().isSome()?[H("cell-unmerge",k.translate("table.context.cell.unmerge"),{})]:[],b&&1===a.selection().length&&a.mergable().isNone()&&a.unmergable().isNone()?[H("cell-split-cols",k.translate("table.context.cell.split-cols"),{}),H("cell-split-rows",k.translate("table.context.cell.split-rows"),{})]:[]])}).getOr([]);var b=F.map(function(a){var b=
a.element();a=function(a,d,e){var f=a+"-menu",g="th"===u.name(b)?"unmake":"make",h="make"===g?"header":"normal";d=[H("insert-"+a+"-before",k.translate("table.context."+a+"."+d),{}),H("insert-"+a+"-after",k.translate("table.context."+a+"."+e),{}),H("delete-"+a,k.translate("table.context.common.delete"),{}),H(g+"-header-"+a,k.translate("table.context.common."+h),{})];return{textkey:c.constant(k.key("table.context."+a+".title")),value:c.constant(f),items:c.constant(d)}};var e={textkey:c.constant(k.key("table.context.table.title")),
value:c.constant("table-menu"),items:c.constant([H("tablemenu-table-properties",k.translate("table.context.table.properties"),{}),H("tablemenu-delete-table",k.translate("table.context.common.delete"),{})])};return d.flatten([[a("row","insertabove","insertbelow")],[a("column","insertleft","insertright")],[e]])}).getOr([]);return{primary:c.constant(a),secondary:c.constant(b),submenus:c.constant({"tablemenu-row":"row-menu","tablemenu-column":"column-menu","tablemenu-table":"table-menu"})}},destroy:c.noop}}});
l("bj","jt e5 7 s jn jq jh bl js 4h 32".split(" "),function(d,e,c,a,b,f,g,h,k,l,p){var n=function(g,n,t,s){return t.fold(a.none,a.none,function(b,c){return e.firstCursor(c).bind(function(b){return a.some(d(b,0,b,0))})},function(a){return h.table(a,n.isRoot).bind(function(e){b.execute(g,k.insertRowAfter,c.noop,s)(n,e,f.noMenu(a));e=l.descendants(e,"tr");if(0<e.length)return p.descendant(e[e.length-1],"td,th").map(function(a){return d(a,0,a,0)})})})};return{forward:function(a,b,c,d){return n(a,b,g.next(c),
d)},backward:function(a,b,c,d){return n(a,b,g.prev(c),d)}}});l("yl",["59","4a"],function(d,e){return function(){var c=e.create({drag:d(["xDelta","yDelta"])});return{mutate:function(a,b){c.trigger.drag(a,b)},events:c.registry}}});l("s4",["s","59","4a","yl"],function(d,e,c,a){return function(){var b=c.create({drag:e(["xDelta","yDelta","target"])}),f=d.none(),g=a();g.events.drag.bind(function(a){f.each(function(c){b.trigger.drag(a.xDelta(),a.yDelta(),c)})});return{assign:function(a){f=d.some(a)},get:function(){return f},
mutate:g.mutate,events:b.registry}}});l("jv","b iw 7 s 59 4a s4 s5 s6 rh 1a 1y 1b 2o 3y 21 6u 32 e2".split(" "),function(d,e,c,a,b,f,g,h,k,l,p,n,r,q,t,s,u,v,w){var y=k.resolve("resizer-bar"),x=k.resolve("resizer-bar-dragging");return function(k,A,D){var B=g(),C=e.transform(B,{}),F=a.none(),E=function(b,c){return a.from(p.get(b,c))};B.events.drag.bind(function(a){E(a.target(),"data-row").each(function(b){b=l.getInt(a.target(),"top");q.set(a.target(),"top",b+a.yDelta()+"px")});E(a.target(),"data-column").each(function(b){b=
l.getInt(a.target(),"left");q.set(a.target(),"left",b+a.xDelta()+"px")})});var G=function(a,b){var c=l.getInt(a,b),d=w(p.get(a,"data-initial-"+b),10);return c-d};C.events.stop.bind(function(){B.get().each(function(a){F.each(function(b){E(a,"data-row").each(function(c){var d=G(a,"top");p.remove(a,"data-initial-top");O.trigger.adjustHeight(b,d,w(c,10))});E(a,"data-column").each(function(c){var d=G(a,"left");p.remove(a,"data-initial-left");O.trigger.adjustWidth(b,d,w(c,10))});h.refresh(k,b,D,A)})})});
var H=function(a,b){O.trigger.startAdjust();B.assign(a);p.set(a,"data-initial-"+b,w(q.get(a,b),10));n.add(a,x);q.set(a,"opacity","0.2");C.go(k.parent())},I=t.bind(k.parent(),"mousedown",function(a){h.isRowBar(a.target())&&H(a.target(),"top");h.isColBar(a.target())&&H(a.target(),"left")}),K=t.bind(k.view(),"mouseover",function(b){if("table"===s.name(b.target())||u.ancestor(b.target(),"table"))F="table"===s.name(b.target())?a.some(b.target()):v.ancestor(b.target(),"table"),F.each(function(a){h.refresh(k,
a,D,A)})}),J=function(a){("table"===s.name(a.target())||"div"===s.name(a.target())&&n.has(a.target(),y)&&!n.has(a.target(),x))&&h.destroy(k)},L=[k.view()].concat(r.eq(k.view(),k.parent())||r.contains(k.view(),k.parent())?[]:[k.parent()]),N=d.map(L,function(a){return t.bind(a,"mouseout",J)}),M=t.bind(k.view(),"dragstart",function(a){a.raw().preventDefault()}),O=f.create({adjustHeight:b(["table","delta","row"]),adjustWidth:b(["table","delta","column"]),startAdjust:b([])});return{destroy:function(){I.unbind();
K.unbind();d.map(N,function(a){a.unbind()});M.unbind();C.destroy();h.destroy(k)},refresh:function(a){h.refresh(k,a,D,A)},on:C.on,off:C.off,hideBars:c.curry(h.hide,k),showBars:c.curry(h.show,k),events:O.registry}}});l("bm",["59","4a","ju","jv","jw"],function(d,e,c,a,b){return function(f,g){var h=b.height,k=a(f,g,h),l=e.create({beforeResize:d([]),afterResize:d([]),startDrag:d([])});k.events.adjustHeight.bind(function(a){l.trigger.beforeResize();var b=h.delta(a.delta(),a.table());c.adjustHeight(a.table(),
b,a.row(),h);l.trigger.afterResize()});k.events.startAdjust.bind(function(a){l.trigger.startDrag()});k.events.adjustWidth.bind(function(a){l.trigger.beforeResize();var b=g.delta(a.delta(),a.table());c.adjustWidth(a.table(),b,a.column(),g);l.trigger.afterResize()});return{on:k.on,off:k.off,hideBars:k.hideBars,showBars:k.showBars,destroy:k.destroy,events:l.registry}}});l("63","b 7 s bb bc bd be bf 7b bg bh 7g bi bj 71 bk bl bm 2o".split(" "),function(d,e,c,a,b,f,g,h,k,l,p,n,r,q,t,s,u,v,w){return function(y,
x){var z=y.content(),A=y.keyboard(),D=y.undo(),B=y.smartview(),C=function(){return M.getOr(s.only(z.element()))},F=r(y.filter(),y.region(),z,y.selections(),A,D,B.uiContainer(),C),E=function(a,b,c){D.save();d.each(b,function(b){a(b,c)});D.save();z.focus()},G=e.curry(E,function(a,b){w.set(a,"background-color",b)}),E=e.curry(E,function(a,b){w.set(a,"border-color",b);w.getRaw(a,"border-style").fold(function(){w.set(a,"border-style","solid")},e.noop)}),G=t.ui({"table.widget":e.curry(h.widget,y,x),"cell.palette":e.constant({items:[{type:"widget",
build:e.curry(g.widget,y,{action:G,shortname:"background",name:"cellbackgroundcolor",textkey:"table.cell.color.background",menuTextkey:"table.cell.color.background"})},{type:"widget",build:e.curry(g.widget,y,{action:E,shortname:"border",name:"cellbordercolor",textkey:"table.cell.color.border",menuTextkey:"table.cell.color.border"})},{type:"widget",build:e.curry(f.widget,y)}],updatePalette:function(a){var b=l.selectedCells(y.selections(),z.isRoot),d=e.curry(a.show,c.some(k.translate("table.context.palette.show")));
a=e.curry(a.hide,c.some(k.translate("table.context.palette.hide")));(0<b.length?d:a)()&&y.ui().refresh()}})},e.identity),H=function(a){var b=a.stopper();n.context(z).bind(function(c){n.cata(c,function(c){u.cell(c.startContainer(),z.isRoot).each(function(c){(a.shift()?q.backward:q.forward)(y.region(),z,c,C).fold(b,function(a){b();z.setSelection(a.startContainer(),a.startOffset(),a.endContainer(),a.endOffset())})})},e.noop)})},I=function(b){a.upOrLeft(z)},K=function(b){a.right(z)},J=A.editor();J.on();
J.events.tab.bind(H);J.events.left.bind(I);J.events.up.bind(I);J.events.right.bind(K);var L=z.cursor(),N=c.none(),M=c.none();z.events.ready.bind(function(a){a=b.get(z,B,a.api().doc());M=c.some(a);var d=p(y.region()),e=v(a,d);e.events.beforeResize.bind(D.save);e.events.afterResize.bind(function(){z.focus();D.save();z.domChanged();L.restore()});e.on();e.events.startDrag.bind(L.save);N=c.some(e);a=y.selections();a.events.beforeScan.bind(function(){e.hideBars()});a.events.afterScan.bind(function(){e.showBars()})});
return{ui:G,destroy:function(){F.destroy();N.each(function(a){a.destroy()});J.off();J.events.tab.unbind(H);J.events.left.unbind(I);J.events.up.unbind(I);J.events.right.unbind(K);J.destroy()},handle:F.handle,assign:F.assign,situation:F.situation,name:e.constant("table")}}});l("64",["7","59","4a"],function(d,e,c){return function(){var a=c.create({pasteUpload:e([]),uploadAssets:e(["assets"]),registerBlob:e(["id","blob","bloburl","data"])});return{destroy:d.noop,events:a.registry,pasteUpload:a.trigger.pasteUpload,
uploadAssets:a.trigger.uploadAssets,registerBlob:a.trigger.registerBlob}}});l("s7",["b","7","2v"],function(d,e,c){var a=c.immutable("withSpaces","withoutSpaces"),b=function(a){return d.filter(a.split(/[\.,-\/#!$%\^&\*;:{}=\-_`~()\s\u00A0]/gim),function(a){return 0<a.length}).length};return{count:function(c){return{words:e.constant(b(c)),characters:e.constant(a(c.length,c.replace(/[\s\u00A0]/gim,"").length))}}}});l("jx","8y 7 4t gu 7b 34 s7 59 4a 4e l 2z 3n v".split(" "),function(d,e,c,a,b,f,g,h,k,
l,p,n,r,q){return function(t,s){var u=t().uiContainer(),v=k.create({close:h([])}),w=a(u);w.setTitle(b.translate("wordcount.dialog"));l.add(w.element(),[f.resolve("dialog-wordcount"),f.resolve("dialog-narrow")]);var u=s().body().getOrDie(),y=c.toText(u,e.constant(!1)),x=r.get(u),u=s().getSelectedText().getOr(""),y=g.count(y),x=x.length,u=g.count(u),z=p.fromHtml(q.supplant('<table class="ephox-polish-tabular ephox-polish-wordcount-table" tabindex="-1">    <thead>        <tr>            <th scope="col"> ${headerCounts}&nbsp;</th>            <th scope="col"> ${headerDocument}&nbsp;</th>            <th scope="col"> ${headerSelection}&nbsp;</th>        </tr>    </thead>    <tbody>        <tr>            <td>${wordCountLabel}&nbsp;</td>            <td class="ephox-polish-wordcount-document-words">${documentCountWords}&nbsp;</td>            <td class="ephox-polish-wordcount-selection-words">${selectionCountWords}&nbsp;</td>        </tr>        <tr>            <td>${wordCountCharsNoSpacesLabel}&nbsp;</td>            <td class="ephox-polish-wordcount-document-charsnospaces">${documentCharactersNoSpaces}&nbsp;</td>            <td class="ephox-polish-wordcount-selection-charsnospaces">${selectionCharactersNoSpaces}&nbsp;</td>        </tr>        <tr>            <td>${wordcountCharsLabel}&nbsp;</td>            <td class="ephox-polish-wordcount-document-chars">${documentCountCharsWithSpaces}&nbsp;</td>            <td class="ephox-polish-wordcount-selection-chars">${selectionCountCharsWithSpaces}&nbsp;</td>        </tr>    </tbody></table>',
{headerCounts:b.translate("wordcount.counts"),headerDocument:b.translate("wordcount.document"),headerSelection:b.translate("wordcount.selection"),wordCountLabel:b.translate("wordcount.words"),wordCountCharsNoSpacesLabel:b.translate("wordcount.charactersnospaces"),wordcountCharsLabel:b.translate("wordcount.characters"),documentCountWords:y.words(),selectionCountWords:u.words(),documentCharactersNoSpaces:y.characters().withoutSpaces(),selectionCharactersNoSpaces:u.characters().withoutSpaces(),documentCountCharsWithSpaces:x,
selectionCountCharsWithSpaces:u.characters().withSpaces()}));w.setContent(z);var A=d.multiple(w.element(),[]),u=function(){D();v.trigger.close()},D=function(){w.hide()};w.events.close.bind(u);A.events.exit.bind(u);return{element:w.element,events:v.registry,open:function(){w.show();A.enter();n.focus(z)},destroy:function(){A.destroy();w.destroy()},hide:D}}});l("bn",["jx","59","4a"],function(d,e,c){return function(a,b){var f=d(a,b),g=c.create({close:e([])});f.events.close.bind(function(){g.trigger.close();
f.destroy()});return{show:function(){f.open()},events:g.registry}}});l("65",["7","7b","71","bn"],function(d,e,c,a){return function(b){var f=b.content,g=b.smartview;return{ui:c.ui({"wordcount.general":{toggle:!1,value:"wordcount",textkey:e.key("wordcount.open"),action:function(){var c=a(g,f);c.events.close.bind(function(){b.ui().tabstrip.focused()||f().focus()});b.content().hideInlineSelection();c.show()},updateGeneral:d.noop,icon:!0,shortcut:!1,hasPopup:!1,hasDialog:!0}}),destroy:d.noop}}});l("43",
"b 1o 6 7 s 55 56 3k 46 5c 5d 5e 5f 5g 5h 5i 5j 5k 5l 5m 5n 5o 5p 5q 5r 5s 5t 5u 5v 5w 5x 5y 5z 60 61 62 58 63 64 65 66 1f 67 59 4a 4b 2v 1a 68 69 2b 2s 3x".split(" "),function(d,e,c,a,b,f,g,h,k,l,p,n,r,q,t,s,u,v,w,y,x,z,A,D,B,C,F,E,G,H,I,K,J,L,N,M,O,S,P,T,Q,V,W,$,X,Y,aa,R,ca,ea,fa,ga,ia){var ha=aa.immutableBag("accessibility formatting alignindent directionality table font parlance media imageEdit blocktag specialchar wordcount link linkvalidator horizontalrule help fileupload findreplace plaincodeview macros spelling".split(" "),
[]);return function(Z,aa,da){var ba=function(a,b,c,d){return b.bundled?a.apply(void 0,d.concat([b])):c()},U=u(Z,aa,da);aa=ba(n,Z.formatting,O.basic,[U]);var ka=ba(p,Z.alignindent,O.basic,[U]),pa=ba(q,Z.directionality,O.basic,[U]),ma=ba(S,Z.table,O.table,[U]),la=ba(r,Z.blocktag,O.basic,[U]),na=ba(y,Z.font,O.basic,[U]),oa=ba(T,Z.wordcount,O.basic,[U]),sa=ba(G,Z.media,O.basic,[U]),ya=ba(N,Z.specialchar,O.basic,[U]),qa=ba(F,Z.linkvalidator,O.linkvalidator,[U,da.linkvalidator]),Fa=ba(C,Z.link,O.basic,
[U,qa]),Ma=ba(A,Z.horizontalrule,O.basic,[U]),za=ba(x,Z.help,O.dialog,[U]),ra=function(a,c,d,e){var f=Z.ui.locale.code,g=void 0!==f?f:V.get();return(!0===c.bundled?W.determine(g):b.none()).fold(function(){return d()},function(b){var d=U.profile().spelling().get(),d=void 0!==f||!0!==c.menu&&d!==W.offKey()||!1===d?b:d;return a.apply(void 0,e.concat([c,b,d]))})}(M,Z.spelling,O.spelling,[U,da.spelling]),Ka=ba(I,Z.parlance,O.basic,[U,ra]),La=ba(J,Z.resize,O.basic,[U]),va=ba(E,Z.macros,O.macros,[U,ra,da.macros]),
Aa=ba(z,Z.highlighter,O.highlighter,[U,va]),Ga=ba(t,Z.draganddrop,O.draganddrop,[U]),ta=P(),ua=ba(B,Z.imageEdit,O.imageEdit,[U,ta]),Ha=ba(D,Z.image,O.image,[U]),Na=ba(v,Z.fileupload,O.dialog,[U,ta,ua.insertResample(),Ga]),Oa=ba(L,Z.smartclipboard,O.basic,[U,ta,ua.insertResample()]),Pa=ba(H,Z.mentions,O.basic,[U]),Qa=ba(w,Z.findreplace,O.basic,[U]),Ra=ba(l,Z.accessibility,O.basic,[U]),Ia=ba(s,Z.embed,O.basic,[U,da.embed]);da=function(){var a=U.content();return a.body().fold(a.getContent,function(a){a=
ea.deep(a);return Q.output(U.filter(),a)})};var xa=function(a){var b=U.filter(),c=U.content();a=b.filterHtml(b.input(),a);c.resetContent(a);Aa.run();qa.refresh();ra.scanView();return a},ba=ba(K,{getContent:da,setContent:xa,bundled:Z.plaincodeview.bundled},O.basic,[U]);U.contextmenu().register("table",ma);U.contextmenu().register("imageEdit",ua);U.contextmenu().register("image",Ha);U.contextmenu().register("spelling",ra);U.contextmenu().register("link",Fa);var Ja=ha({formatting:aa,alignindent:ka,directionality:pa,
table:ma,font:na,imageEdit:ua,parlance:Ka,blocktag:la,wordcount:oa,specialchar:ya,media:sa,link:Fa,linkvalidator:qa,horizontalrule:Ma,help:za,fileupload:Na,findreplace:Qa,accessibility:Ra,plaincodeview:ba,macros:va,spelling:ra});U.content().events.ready.bind(function(){U.ui().init(U.keyboard(),U.undo(),Ja);ra.init(U.content());Aa.run();qa.refresh()});U.content().events.loaded.bind(function(){ia(function(){wa.trigger.loaded();Ba()},0)});var wa=X.create({loaded:$([]),ready:Y([],U.content().events.ready),
focus:$([]),dirty:Y([],U.laundry().events.dirty),internal:$(["command","data"]),paint:$(["dimensions"])}),Ba=U.content().isInline()?a.noop:function(){U.content().body().each(function(a){a=fa.documentElement(a);var b=U.content().element();wa.trigger.paint(f({width:ga.get(b),docWidth:ga.get(a),height:ca.get(b),docHeight:ca.get(a)}))})};U.content().events.paint.bind(Ba);U.content().events.nodeChanged.bind(Ba);U.content().events.focus.bind(function(){wa.trigger.focus()});U.internalevents().events.internal.bind(function(a){var b=
a.command();"insertLink"===b&&(a=R.get(a.data(),"href"),wa.trigger.internal(b,a))});ba=U.content().isInline()?function(){var a=U.ui(),b=U.content(),c=a.state(),c=void 0!==c.toolbar&&void 0!==c.toolbar.drag?c.toolbar.drag.isSome():!1;b.activate();b.focus();U.viewablearea().setOn();c||a.position();a.refresh()}:a.noop;aa=U.content().isInline()?function(){U.content().deactivate();U.content().blur();U.viewablearea().setOff()}:a.noop;return k.internal({activateInline:ba,deactivateInline:aa,element:U.ui().element,
viewport:U.ui().viewport,connect:U.ui().connect,focus:U.content().focus,blur:U.content().blur,getContent:da,toTransfer:a.compose(g.changed,da),setContent:function(a){var b=U.undo();b.disable(function(){var c=xa(a);b.reset(c)});U.laundry().setDirty(!1)},insertHtmlAtCursor:U.insertFilteredHtmlAtCursor,isDirty:U.laundry().isDirty,setDirty:U.laundry().setDirty,fromTransfer:function(a){var b=U.undo();g.cata(a,function(a){b.disable(function(){xa(a)});b.replaceTop()},function(a){xa(a);b.save()})},uploader:a.constant(ta),
state:function(){var a=U.state();return c.merge(a,{spelling:ra.state(),macros:va.state(),filters:U.filter().customFilters().state(),linkvalidator:qa.state(),embed:Ia.state()})},destroy:function(){U.content().deactivate();var b=d.map(e.values(Ja),a.apply);d.each(b.concat([Ia,Ha,ua,ra,La,va,Aa,ta,Oa,Pa,U,Ga]),function(a){a.destroy()})},events:wa.registry,communication:U.communication,fullscreen:U.fullscreen,content:U.content,ui:U.ui,undo:U.undo,smartview:U.smartview,keyboard:U.keyboard,filter:U.filter,
operations:U.operations,macros:a.constant(va),getMode:h.pencil,isPrettyPrinting:function(){return!0===Z.content.prettyprint}})}});na.define("bp",[],function(){return'/*\n * Keep this file as small as possible.\n * It is injected into the JavaScript, so it needs to be tiny.\n */\n\n/*\n * Animate from 0 to 359, not 0 to 360, as they are the same and FireFox does nothing\n *\n * Until we have token replacement, manual shorthand for "ephox-polish-spin"\n */\n\n@keyframes e-p-spin {\n  0% {\n    transform: rotate(0deg);\n  }\n  100% {\n    transform: rotate(359deg);\n  }\n}\n\n/* Until we have token replacement, manual shorthand for "ephox-polish-spinner-img" */\n\n.e-p-s-img {\n  animation: e-p-spin 2s infinite linear;\n  width: 30px;\n  height: 30px;\n  margin: 2px 2em 0 auto;\n  background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQBAMAAADt3eJSAAAAIVBMVEUAAABAQEBDQ0NERERERERCQkJDQ0NERERDQ0NEREREREQTPu3mAAAACnRSTlMAENDPwGBwsKB/qy4kVgAAAFpJREFUCNdjAAImAwYI4FoApooFuBYwWgAZXoZMCsJLgAyhpQwMUYpABmMiA4OYAAMCaC2GklqLwIxFMAmoYkmQYmGQdkOQgYpMBkIgA4tAVmggLAU7QwFIAADjyQ3FWhtneAAAAABJRU5ErkJggg==") 0/cover;\n}'});
l("6c","s 2n l 2p 2r 3n bp".split(" "),function(d,e,c,a,b,f,g){var h=0,k=d.none();return{add:function(){if(0===h){var b=c.fromTag("style");f.set(b,g);a.append(e.body(),b);k=d.some(b)}h++},remove:function(){0!==h&&0===--h&&(k.each(b.remove),k=d.none())}}});l("44","6 7 s 6a 56 46 6b 58 6c 49 6d 4p 2o l 68 2g 2p 2r 6e 3x".split(" "),function(d,e,c,a,b,f,g,h,k,l,p,n,r,q,t,s,u,v,w,y){return function(x,z){var A=h.state(z),D=n(null),B=q.fromTag("div"),C=function(){s.set(B,'<div class="e-p-s-img"></div>');
F()},F=void 0===x.content.inline?e.noop:function(){if(!1===x.ui.toolbar.visible)r.set(B,"display","none");else{var a={isInline:e.constant(!0),element:e.constant(x.content.inline)},a=p.offsetFrom(a,B,t.get(B),x.ui);r.setAll(B,{position:"absolute",left:a.left+"px",top:a.top-4+"px"})}},E=null,G=e.die("API unavailable while the editor is loading"),H={body:e.constant(c.none()),doc:G,execCommand:G,getSelectedText:G,focus:G,deactivate:e.noop,blur:e.noop},I=void 0===x.content.inline?D.get:function(){return s.get(x.content.inline)};
return f.internal({activateInline:F,blur:G,communication:e.constant(g(x)),connect:function(a){E=y(C,1E3);u.append(a,B);k.add();return!1},content:e.constant(H),deactivateInline:e.noop,destroy:function(){w(E);k.remove();v.remove(B)},element:e.constant(B),events:l.events(),failure:function(){w(E);k.remove();s.set(B,"<p>Unable to load editor. See browser console for details.</p>")},filter:A.filter,focus:G,fromTransfer:function(a){b.cata(a,D.set,D.set)},fullscreen:h.fullscreen,getContent:I,getMode:G,insertHtmlAtCursor:G,
isDirty:A.laundry.isDirty,isPrettyPrinting:function(){return!0===x.content.prettyprint},keyboard:l.keyboard,macros:A.macros,operations:l.operations,setContent:function(a){void 0===x.content.inline?D.set(a):s.set(x.content.inline,a);A.laundry.setDirty(!1)},setDirty:A.laundry.setDirty,smartview:l.smartview,state:function(){var b=I(),b=a.isEmpty(b)?{}:{content:{raw:b,marked:b},undo:{initial:{raw:b,marked:b}}};return d.deepMerge(A.getState(),b)},toTransfer:e.compose(b.changed,D.get),ui:l.ui,undo:e.constant(h.undo()),
uploader:e.constant(h.uploader()),viewport:e.constant(B)})}});l("6f",["40","43","3k"],function(d,e,c){var a=c.pencil(),b=c.code(),f=function(a){var b=a.old().toTransfer();a.nu().fromTransfer(b)},g={transition:f,factory:d,style:c.pencil},h={transition:f,factory:e,style:c.code};return{goingToDesign:function(a){return a===b},alternate:function(c){return c===b?a:b},detect:function(a){return a===b?g:h}}});l("6g","4o 7 s p 6f 3h 59 4a o".split(" "),function(d,e,c,a,b,f,g,h,k){var l=function(a,b){return{destroy:e.noop,
init:e.noop,setMode:e.die("Code view is not enabled, cannot switch modes"),events:h.create({change:g([]),ready:g([])}).registry}},p=function(l,m){var p=m.css+"/codemirror.css",t=h.create({change:g([]),ready:g(["type"])}),s=c.none(),u=function(){var a=f.load.codeview(m.js).map(function(a){return a.map(e.constant(!0))});s=c.some(a)},v=function(b){b(a.value(!0))};return{init:function(a){s.fold(function(){d.addStylesheet(p,v).get(function(b){b.fold(function(a){k.error(a);k.error("Code View disabled due to error loading stylesheet")},
function(){u();t.trigger.ready(a)})})},function(b){t.trigger.ready(a)})},setMode:function(a){return s.fold(function(){throw"Cannot set mode before Code View has loaded";},function(c){c.get(function(c){c.fold(function(b){t.trigger.ready(a);k.error(b);k.error("Code View non-functional due to error downloading script file")},function(){var c=b.detect(a),d=l.swap(c.factory,{},{});t.trigger.change();c.transition(d);d.destroy()})})})},events:t.registry,destroy:e.noop}};return function(a,b){return(!0===
b.bundled?p:l)(a,b)}});l("6h","8b bq 53 br 79 3k 7b 34 59 4a 1a 2n 1y 4e 2o bs 3y 2p 6s 2r 2b 2s".split(" "),function(d,e,c,a,b,f,g,h,k,l,p,n,r,q,t,s,u,v,w,y,x,z){return function(e,n){var x=l.create({change:k(["type"])}),z=w.removeClasses([h.resolve(f.none()),h.resolve(f.wait()),h.resolve(f.pencil()),h.resolve(f.code())]),F=c.div();d.hidden(F,"true");q.add(F,[h.resolve("html-switch-wrapper"),h.resolve("layer-editor")]);var E=c.div();q.add(E,[h.resolve("html-switch"),h.resolve("icon")]);v.append(F,
E);var G=function(a){z(E);r.add(E,h.resolve(a));p.set(E,"data-icon",a);p.remove(E,"title")},H=function(a,b){var c=p.get(E,"data-icon");a!==c&&(M=c,G(a),p.set(E,"title",b))},I=function(a){n.showButton&&a!==f.none()?H(a,g.translate("toolbar.switch-"+a)):G(f.none());J.control.unblock()},K=b.unbindable(),J=a.tap(function(){x.trigger.change(p.get(E,"data-icon"))});n.showButton&&K.set(u.bind(F,"click",J.instance));var L=function(a){v.append(a,F)},N=s.onDirection("right","left"),M=f.none();I(M);return{render:L,
destroy:function(){y.remove(F);K.clear()},switchto:I,spin:function(){H(f.wait(),g.translate("loading.wait"));J.control.block()},stopSpin:function(){"spin"!==M&&I(M)},init:function(a){var b=e.get();L(b.viewport());b.events.paint.bind(function(a){a=a.dimensions();a=a.width()-a.docWidth();var c=N(b.element());t.set(F,c,a+"px")});I(f.none())},events:x.registry}}});l("jy","ak b s8 53 7 54 7b 1f cn 34 co cp cq cr ay le 1a 2n 1y 4e 3y l 2p 2r q".split(" "),function(d,e,c,a,b,f,g,h,k,l,p,n,r,q,t,s,u,v,w,
y,x,z,A,D,B){return function(C,B,E,G,H,I){var K=z.fromTag("div");G.updateUi(K);y.add(K,[t.editorContainer(),"ephox-textbox-font",l.resolve("layer-editor"),l.resolve("fullscreen-maximized")]);u.set(K,"lang",h.get());k.addClasses(K);var J=s(),L=d.toolbar(J,g.translate);B.events.toolbar.bind(L.enter);L.events.exit.bind(C.focus);var N=p(),M=v.body(),O=a.div();w.add(O,l.resolve("socket"));var S=e.map(["dragover","drop"],function(a){return x.bind(O,a,function(a){a.kill()})});J.integrate(K,L,N,O);r.build(K,
H.sideBar,H.bottomBar);var P=c({layerClass:l.resolve("layer-below-editor"),background:"rgba(255, 255, 255, 0.92)"}),T=l.resolve("body-fullscreen"),Q=H.autoresize?n(H):q();Q.events.change.bind(function(a){L.refresh();E.refresh()});return{element:function(){return K},socket:function(a){A.append(O,a.element())},viewport:b.constant(O),connect:function(a){P.show();w.add(M,T);A.append(a,K);f.detect(K);Q.hookup(C.element());return!0},destroy:function(){e.each(S,function(a){a.unbind()});L.destroy();w.remove(M,
T);D.remove(K);P.destroy();Q.destroy();N.destroy()},banners:N.element,displayBanner:N.display,hideBanner:N.hide,position:function(){J.init(L,N,O,H,I)},refresh:function(){J.update();L.refresh()},toolbar:L}}});l("bt",["7","73","jy","76"],function(d,e,c,a){return{build:function(a,f,g,h,k,l,p,n){var r=c(a,f,g,l,p,n),q=h.full(r);q.init();return{element:r.element,socket:r.socket,viewport:r.viewport,init:function(c,d,f){d=q.config(a.isInline(),d,k,f);e.setup(r,l,a,c,g,d);q.loaded()},connect:r.connect,destroy:function(){r.destroy();
q.destroy()},displayBanner:r.displayBanner,hideBanner:r.hideBanner,position:d.noop,refresh:r.refresh,tabstrip:r.toolbar,state:d.constant(n)}},bounds:function(){return a.view}}});l("6i","s 6f 43 bt 5b 59 4a 2n 1b 2b q".split(" "),function(d,e,c,a,b,f,g,h,k,l,p){return function(n){var p=d.none(),q=d.none(),t=g.create({maximize:f([]),restore:f([])}),s=function(d){p=l.parent(n.get().element());p.getOrDie("maximize called on editor that is not in the DOM.");n.swap(c,{ui:{layout:a,isFullScreen:!0},fullscreen:{layout:void 0!==
d.layout()?d.layout():b}}).destroy();var e=n.get();e.fullscreen().select();e.connect(h.body());e.events.ready.bind(function(){e.focus();t.trigger.maximize()})},u=function(a){n.swap(c,{ui:{layout:void 0!==a.layout()?a.layout():b,isFullScreen:!1}}).destroy();var d=n.get();d.fullscreen().deselect();a=p.getOrDie("restore called on editor that was not previously in the DOM.");n.get().connect(a);d.events.ready.bind(function(){d.focus();t.trigger.restore()})};return{init:function(a){if(e.goingToDesign(a)){a=
n.get();var b=n.get().element();q.each(function(a){if(k.eq(a,b))throw"Fullscreen init called twice on the same instance";});q=d.some(b);a.fullscreen().events.maximize.bind(s);a.fullscreen().events.restore.bind(u)}},destroy:function(){},events:t.registry}}});l("bu",["a","b"],function(d,e){return function(){var c=[];return{setCallback:function(a){d.isFunction(a)&&c.push(a)},done:function(a){e.each(c,function(b){b.apply(null,[a])});c=[]}}}});l("jz","s9 sa 30 h5 7 s e0 1a".split(" "),function(d,e,c,a,
b,f,g,h){var k=function(a){return a.result};return{blobTob64:function(a,b){var c=h.get(b,g.blobId());h.remove(b,g.blobId());a.get(c).each(function(a){h.remove(b,g.blobId());h.set(b,"src",k(a.data()))})},b64ToBlob:function(b,k){var l=h.get(k,"src"),r=function(a){console.warn("Unable to read Base64 image data: ",a,l);return f.none()};b.lookupByData(l).fold(function(){var g=d.toBlob(l);return e.cata(g,f.none,r,function(d){var e=a.createObjectURL(d),g=c.generate("image");return f.some(b.add(g,d,e,{result:l}))})},
f.some).each(function(a){h.set(k,g.blobId(),a.id());h.set(k,"src",a.objurl())})}}});l("bv",["b","jz","e0","cw"],function(d,e,c,a){return{configure:function(b,f){b.addSelector(b.output(),"img["+c.blobId()+"]",function(a){d.each(a,function(a){e.blobTob64(f,a)})});b.addSelector(b.input(),"img:not(["+c.blobId()+"])[src]",function(a){d.each(a,function(a){e.b64ToBlob(f,a)})});var g=a.removeClass(c.uploadInProgress());b.add(b.output(),c.uploadInProgress(),g);b.add(b.history(),c.uploadInProgress(),g);b.add(b.internal(),
c.uploadInProgress(),g)},blobId:c.blobId}});l("c0","b gq 7 s p e0 4q 2v 1a 1y 6s 32 o".split(" "),function(d,e,c,a,b,f,g,h,k,l,p,n,r){var q=h.immutable("image","blobInfo"),t=g.generate([{failure:["error"]},{success:["result","images","blob"]}]),s=function(a,b,c,e){d.each(b,function(a){k.set(a,"src",e.location);k.remove(a,f.blobId())});return w(a,c)},u=function(a,b,c,d,e,g){var h=a.lookupByData(e.result).getOrThunk(function(){return a.add(b,c,d,e)});k.set(g,f.blobId(),h.id());return q(g,h)},v=function(a,
c){var d=k.get(c,f.blobId());return a.get(d).fold(function(){return b.error(d)},function(a){return b.value(q(c,a))})},w=function(a,c){return a.get(c).fold(function(){return b.error("Internal error with blob cache")},function(d){a.remove(c);return b.value(d)})};return{prepareForUpload:function(b,c,d){var e=b.isActive(c);b.register(d,c);l.add(d,f.uploadInProgress());return e?a.none():a.some(c)},handleUpload:function(a,b,e,g,h,k,l){var m=function(){r.error("Internal error with blob cache",h);l(t.failure({status:c.constant(666)}))};
a.upload(k,h,function(a){var c=b.findById(g,h);d.each(c,p.removeClass(f.uploadInProgress()));a.fold(function(a){l(t.failure(a))},function(a){s(e,c,h,a).fold(m,function(b){l(t.success(a,c,b))})});b.report(h,c,a.isValue())})},registerAssets:function(a,f,g){return d.bind(g,function(d){return e.cata(d,function(c,d,e,g){return n.descendant(f,'img[src="'+e+'"]').fold(function(){return[b.error("Image that was just inserted could not be found: "+e)]},function(f){return[b.value(u(a,c,d,e,g,f))]})},c.constant([]))})},
registerBlob:u,findBlobs:function(a,b,c){c=a.findAll(c);return a.inProgress()?[]:d.map(c,function(a){return v(b,a)})}}});l("bw","gq h4 3w 9u h6 h9 9z 95 c0".split(" "),function(d,e,c,a,b,f,g,h,k){var l=function(l){var m=function(c){var m=c.image(),n=c.blobInfo(),s=f.changedBounds(m);return h.resampleAction(s,n.blob(),function(f){if(f===n.blob())return b.pure(c);var h=a.updater(a.keepResample,m),s=g.applyEdit(m);f=e.single(f).bind(s).map(h);return b.map(f,function(a){return d.cata(a,function(a,b,c,
d){return k.registerBlob(l,a,b,c,d,m)},function(a,b,d){return c})})})};return function(a){return c.mapM(a,m)}};return{instance:function(a,b){return!0===a.immediate?c.pure:l(b)}}});l("sb",["s","7b"],function(d,e){var c={400:"errors.http.400",401:"errors.http.401",403:"errors.http.403",404:"errors.http.404",407:"errors.http.407",409:"errors.http.409",413:"errors.http.413",415:"errors.http.415",500:"errors.http.500",501:"errors.http.501"};return{get:function(a,b){return d.from(c[a]).map(function(a){return e.translate(a,
b)})}}});l("k0",["a","7","r","96","sb"],function(d,e,c,a,b){var f=function(b){return d.isString(b)&&""!==b.trim()?{description:e.constant(b),link:e.constant(null)}:a.get("error.imageupload.generic")},g=function(c,d){var f=d.status();return b.get(f,c).fold(function(){var b;b=0===f?"error.imageupload.cors":400<=f&&500>f?"error.code.images.not.found":"error.imageupload";return a.get(b,[c])},function(a){return{description:e.constant(a),link:e.constant(null)}})},h=function(a,b){return{instance:function(){return c.cached(function(c){c=
b(c);a.show(c)})}}};return{simple:function(a){return h(a,f)},url:function(a,b){return h(a,e.curry(g,b))}}});l("sc",["6","nj","vy","7"],function(d,e,c,a){return{json:function(){return{get:function(b,c,d,h){e.get(b,c,d||a.identity,h)},post:function(b,c,d,h){e.ajax(b,"POST",c,d||a.identity,h)},ajaxData:function(b,f,g,h,k,l){f=d.merge(l||{},{data:void 0!==f?c.stringify(f):""});e.ajax(b,g,h,k||a.identity,f)}}}}});l("yn",["2j"],function(d){return function(){return new (d.getOrDie("FormData"))}});l("sd",
["a","b","yn","2v","v"],function(d,e,c,a,b){var f=["jpg","png","gif","jpeg"];return{failureObject:a.immutable("message","status","contents"),getFilename:function(a,c){var k;d.isString(a.name)&&!b.endsWith(a.name,".tmp")?k=a.name:d.isString(a.type)&&b.startsWith(a.type,"image/")?(k=a.type.substr(6),k=e.contains(f,k)?c+"."+k:c):k=c;return k},buildExtra:function(a,b,d){var e=c();e.append(a,b,d);return{data:e,contentType:!1,processData:!1}}}});l("se","a 6 px vy p sd v ij".split(" "),function(d,e,c,a,
b,f,g,h){return function(k){var l=function(){var a=k.url,b=a.lastIndexOf("/"),a=0<b?a.substr(0,b):a,a=void 0===k.basePath?a:k.basePath;return g.endsWith(a,"/")?a:a+"/"}();return{upload:function(g,n,r){g=g.blob();var q=function(a,c,d){r(b.error(f.failureObject(a,c,d)))},t=f.getFilename(g,n);n=e.merge(!0!==k.credentials?{}:{xhrFields:{withCredentials:!0}},f.buildExtra("image",g,t));c.post(k.url,{},function(c){var e;try{var f=a.parse(c);if(d.isString(f.location))e=f.location;else{q("JSON response did not contain a string location",
500,c);return}}catch(g){e=c}c=e.split(/\s+/);c=h.resolve(l,1===c.length&&""!==c[0]?c[0]:t);r(b.value({location:c}))},q,n)}}}});l("sf","a p sd 2v o 3x".split(" "),function(d,e,c,a,b,f){var g=a.immutable("id","filename","blob","base64");return function(a){return{upload:function(k,l,p){var n=function(a){p(e.error(a))},r=function(a){d.isString(a)?p(e.value({location:a})):(b.error("Image upload result was not a string"),n(""))},q=c.getFilename(k.blob(),l),t=g(l,q,k.blob(),k.data().result);f(function(){a(t,
r,n)},0)}}}});l("k2",["sd","se","sf"],function(d,e,c){return{direct:function(a){return e(a)},custom:function(a){return c(a)},failureObject:function(a,b,c){return d.failureObject(a,b,c)},getFilename:function(a,b){return d.getFilename(a,b)},buildExtra:function(a,b,c){return d.buildExtra(a,b,c)}}});l("k1",["6","p","sc","k2"],function(d,e,c,a){return function(b,f){return{upload:function(g,h,k){g=g.blob();h=a.getFilename(g,h);h=d.merge(b.headers(),a.buildExtra("image",g,h));c.json().post(f,function(a){k(e.value(a))},
function(b,c,d){k(e.error(a.failureObject(b,c,d)))},h)}}}});l("bx","a 7 k0 k1 k2 2v".split(" "),function(d,e,c,a,b,f){var g=f.immutable("uploader","errors");return{choose:function(f,k,l){return!0!==f.bundled?g({upload:e.die},{instance:e.constant(e.die("Image Upload is disabled"))}):d.isString(f.service)?g(a(l,f.service),c.url(k,f.service)):d.isFunction(f.handler)?g(b.custom(f.handler),c.simple(k)):g(b.direct(f.direct),c.url(k,f.direct.url))}}});l("by",["1o","h5","s","2v"],function(d,e,c,a){var b=
a.immutable("id","blob","objurl","data");return function(){var a={},g=function(a){e.revokeObjectURL(a.objurl())};return{add:function(c,d,e,g){d=b(c,d,e,g);return a[c]=d},get:function(b){return c.from(a[b])},remove:function(b){var c=a[b];delete a[b];void 0!==c&&g(c)},lookupByData:function(b){return c.from(d.find(a,function(a){return a.data().result===b}))},destroy:function(){d.each(a,g);a={}}}}});l("bz","b k3 e0 59 4a 1a 4h".split(" "),function(d,e,c,a,b,f,g){var h="data-"+e.resolve("image-upload"),
k=function(a,b){return g.descendants(a,"img["+h+'="'+b+'"]')},l=function(a){return g.descendants(a,"img:not(["+h+"])["+c.blobId()+"]")};return function(){var c=[],e=[],g=b.create({complete:a(["response"])}),q=function(a){c=d.filter(c,function(b,c){return b!==a});!1===t()&&(g.trigger.complete(e),e=[])},t=function(){return 0<c.length};return{findById:k,findAll:l,register:function(a,b){f.set(a,h,b);c.push(b)},report:function(a,b,c){d.each(b,function(a){f.remove(a,h);e.push({success:c,element:a.dom()})});
q(a)},inProgress:t,isActive:function(a){return d.contains(c,a)},events:g.registry}}});l("6j","a b s 8z bu ab 6f bv bw bx 59 4a by bz c0 o".split(" "),function(d,e,c,a,b,f,g,h,k,l,p,n,r,q,t,s){return function(u,v){var w=r(),y=b(),x=q(),z=a(u.ui),A=l.choose(v,z,u.communication()),D=A.uploader(),B=A.errors(),C=k.instance(v,w),F=n.create({begin:p([]),finish:p([])}),E=function(a){F.trigger.finish();y.done(a)};x.events.complete.bind(function(a){E(a.response())});var G=function(a,b,c,d){t.handleUpload(D,
x,w,a,b,c,function(a){a.fold(function(a){d(a)},I)})},H=function(a){u.content().body().each(function(b){var c=B.instance(),d=t.registerAssets(w,b,a.assets());e.each(d,function(a){a.fold(function(a){s.error(a)},function(a){!0===v.immediate&&K(b,a,c)})})})},I=function(a,b,c){u.undo().rewrite(c.objurl(),a.location)},K=function(a,b,c){!1!==v.bundled&&t.prepareForUpload(x,b.blobInfo().id(),b.image()).each(function(d){G(a,d,b.blobInfo(),c)})},J=function(a){e.each(a,function(a){x.report(a,c.none(),!1)})},
L=function(a,b){var c=f.partition(b),d=c.values;J(c.errors);var g=B.instance();C(d).get(function(b){b=f.partition(b);0<b.errors.length&&(z.showKey("imageedit.generic"),s.error("Image resample on upload errors: ",b.errors),J(b.errors));e.each(b.values,function(b){K(a,b,g)})})},N=function(a){d.isFunction(a)&&y.setCallback(a);!0!==v.bundled?E([]):u.content().body().fold(function(){E([])},function(a){F.trigger.begin();var b=t.findBlobs(x,w,a);0!==b.length||x.inProgress()?L(a,b):E([])})};return{init:function(a){g.goingToDesign(a)&&
(a=u.filter(),h.configure(a,w),u.uploader().events.uploadAssets.bind(H),u.uploader().events.pasteUpload.bind(function(){!0===v.immediate&&N()}),u.uploader().events.registerBlob.bind(function(a){var b=a.id(),c=a.blob(),d=a.bloburl();a=a.data();w.add(b,c,d,a)}));z.reset()},events:F.registry,reconstitute:N,destroy:function(){w.destroy()}}}});l("45","b 6f 3k 6g 6h 6i 6j".split(" "),function(d,e,c,a,b,f,g){return function(h,k,l,p){var n=f(h),r=g(k,l.imageupload),q=a(h,l.codeview),t=b(h,l.codeview),s=[n,
r,t],u=s.concat([q]);n.events.restore.bind(function(){p.restore();w(u,c.code())});n.events.maximize.bind(function(){p.save();w(s,c.code())});r.events.begin.bind(t.spin);r.events.finish.bind(t.stopSpin);q.events.change.bind(function(a){h.get().events.loaded.bind(function(){k.focus()});k.reconnect()});t.events.change.bind(function(a){v(a.type())});q.events.ready.bind(function(a){t.switchto(a.type())});var v=function(a){r.reconstitute(function(){h.get().getMode()!==a&&(t.spin(),q.setMode(a))})},w=function(a,
b){d.each(a,function(a){a.init(b)})};k.events.connected.bind(function(){w(u,e.alternate(k.getMode()))});return{setMode:v,uploadImages:r.reconstitute,destroy:function(){t.destroy();h.destroy();d.each(u,function(a){a.destroy()})}}}});l("47",["c","6"],function(d,e){return{settings:function(c){var a={ui:{toolbar:{display:!1}},spelling:{bundled:!1},highlighter:{bundled:!1},table:{bundled:!1},resize:{bundled:!1},codeview:{bundled:!1},imageEdit:{bundled:!1},imageupload:{immediate:!0},linkvalidator:{bundled:!1}},
a=d.detect().deviceType.isTouch()?a:{};return e.deepMerge(a,void 0===c.content||void 0===c.content.inline?{}:{fullscreen:{bundled:!1},codeview:{bundled:!1},plaincodeview:{bundled:!1}})}}});l("6k","b 7 s 1f 1a bs 21 2b v".split(" "),function(d,e,c,a,b,f,g,h,k){var l={isRtl:e.constant(!1)},p={isRtl:e.constant(!0)},n=function(a){return d.exists(["ar","fa","he"],function(b){return k.startsWith(a,b)})};return function(a){var d=n(a);return{directionAt:function(a){return"rtl"===(g.isText(a)?h.parent(a):
c.some(a)).map(f.getDirection).getOr("ltr")?p:l},uiDirection:function(){return d?p:l},updateUi:function(a){b.set(a,"dir",d?"rtl":"ltr")},destroy:e.noop}}});l("48","6 7 r 1f 6k 59 4a".split(" "),function(d,e,c,a,b,f,g){return function(h,k){var l=g.create({create:f(["instance"]),loaded:f([]),focus:f([]),dirty:f([]),internal:f(["command","data"])}),p=c.cached(function(){l.trigger.loaded()}),n=function(a){a.events.focus.bind(function(){l.trigger.focus()});a.events.dirty.bind(function(){l.trigger.dirty()});
a.events.internal.bind(function(a){l.trigger.internal(a.command(),a.data())});a.events.loaded.bind(p)};n(h);var r=h,q=e.compose(b,a.get);return{get:function(){return r},swap:function(a,b){var c=r,f=d.deepMerge(k,b),g=c.state(),f=a(f,q(),g);n(f);l.trigger.create(f);r=f;return{old:e.constant(c),nu:e.constant(f),destroy:function(){c.destroy()}}},destroy:function(){r.destroy()},events:l.registry}}});l("2f","b 3q 6 t 40 41 42 43 44 45 46 47 48 49 4a 4b l o q 37".split(" "),function(d,e,c,a,b,f,g,h,k,l,
p,n,r,q,t,s,u,v,w,y){var x=function(a){return c.deepMerge(f.settings(a.resources),a,n.settings(a))};return function(n,A){var D=x(n);a.setLanguage(D.ui.locale.code);var B=c.deepMerge(f.state(),A),C=e.capture(u.fromDom(w),y),F=k(D,B),E=r(F,D),G=g(E),B=l(E,G,D,C),C=t.create({loaded:s([],E.events.loaded),focus:s([],E.events.focus),dirty:s([],E.events.dirty),connected:s([],G.events.connected),internal:s(["command","data"],E.events.internal)});a.waitForLoad().get(function(c){c=a.getFailures(c);0===c.length?
(E.swap("code"===D.codeview.mode?b:h).destroy(),G.reconnect()):(d.each(c,function(a){v.error(a)}),v.error("Required resources are not available. Cancelling editor load."),F.failure())});return p.external({activateInline:G.activateInline,communication:q.communication,connect:G.connect,content:G.content,deactivateInline:G.deactivateInline,element:G.element,events:C.registry,filter:G.filter,focus:G.focus,getContent:G.getContent,getMode:G.getMode,insertHtmlAtCursor:G.insertHtmlAtCursor,isDirty:G.isDirty,
isPrettyPrinting:G.isPrettyPrinting,keyboard:G.keyboard,macros:G.macros,operations:G.operations,setContent:G.setContent,setDirty:G.setDirty,smartview:G.smartview,state:G.state,ui:G.ui,undo:G.undo,setMode:B.setMode,uploadImages:B.uploadImages,destroy:B.destroy})}});l("1l","2d 24 2e 7 2f 1a 2g".split(" "),function(d,e,c,a,b,f,g){var h=function(a,c,h){var l=d.withOptions(a,h);l.content&&l.content.tabindex&&(0,f.remove)(a,"tabindex",l.content.tabindex);h=b(l);var r=g.get(a),q=f.get(a,"style");c(a);g.set(a,
"");h.connect(a);e.set(h,r);return{polish:h,restore:function(b){g.set(a,b);null!==q&&void 0!==q&&0<q.length?f.set(a,"style",q):f.remove(a,"style");l.content&&l.content.tabindex&&(0,f.set)(a,"tabindex",l.content.tabindex);return a}}};return{replace:function(a,b){return h(a,c.explicit,b)},takeover:function(b,c){return h(b,a.noop,c)}}});l("1c",["1l","6"],function(d,e){return{replace:function(c,a){var b=e.deepMerge(a,{platform:{fillscreen:!0}}),b=d.takeover(c,b);return{polish:b.polish,restore:b.restore}}}});
l("1d","a b 1o 2h i 6 s v n".split(" "),function(d,e,c,a,b,f,g,h,k){var l=function(a,b){var c={};if(void 0===a)return c;e.each(b,function(b){var e=b.name(),e=a[e];void 0!==e&&(b.validate(e),c[b.output()]=d.isArray(b.contents)?l(e,b.contents):e)});return c},p=function(a){return e.map(void 0===a?[]:a,function(a){var c=l,d=b.string("prefix"),e=b.string("suffix"),g;g=[b.string("color"),b.string("background-color")];g=f.merge(b.object("style"),{contents:g});return c(a,[d,e,g])})},n=function(a,c,d){if(void 0===
a[c])return d;b.bool(c).validate(a[c]);return a[c]},r=function(a){if(void 0===a||void 0===a.fonts)return[];a=a.fonts;if(!d.isArray(a))throw new k("The fonts configuration was not an array");var b=function(a,b){console.error(a+" :",b);throw new k(a);};return e.map(a,function(a){if(d.isString(a))return{value:a,text:a};d.isObject(a)||b("The fonts array value was not a string or object",a);void 0!==a.value&&d.isString(a.value)||b("The fonts value configuration was not a string or is undefined",a);void 0===
a.text||d.isString(a.text)||b("The fonts text configuration was not a string",a);void 0!==a.text&&d.isString(a.text)&&0===a.text.length&&b("The fonts text configuration was an empty string",a);return{value:a.value,text:a.text&&0<a.text.length?a.text:a.value}})},q=function(a){a=l(void 0===a?{}:a,[b.arrayOfStrings("languages")]);return void 0===a.languages?{}:{languages:e.map(a.languages,function(a){return a.toLowerCase()})}},t=function(a){return void 0===a.styles?{}:{styles:e.filter(a.styles,function(a){a=
a.rule;return!(void 0===a||"."===a||0<=a.indexOf("..")||0<=a.indexOf("#"))})}},s=function(a){var c=l(a,[b.arrayOfStrings("plugins")]),c=void 0===c.plugins?[]:c.plugins,e=l(a.ui,[b.string("locale","code")]),g=n(a,"autosubmit",!0),s=l(a.content,[b.arrayOfObjects("highlighters")]),u=l(a.paste,[b.string("style"),b.bool("enableFlashImport")]),D=l(a.css,[b.arrayOfStrings("stylesheets"),b.string("documentStyles")]),B=l(a.css,[b.arrayOfObjects("styles")]),C=l(a.ui,[b.bool("shortcuts","features")]),F=q(a.ui),
E;E=a.codeview;E=l(void 0===E?{}:E,[b.bool("enabled"),b.bool("showButton")]);E={bundled:void 0===E.enabled||!0===E.enabled,showButton:void 0===E.showButton||!0===E.showButton};var G;var H=a.spelling;if(void 0===H||void 0===H.url)G={service:!1};else{var I=n(H,"autocorrect",!0);if(d.isString(H.url))G={url:H.url,service:!0,autocorrect:I};else throw new k("Spelling URL was not a string");}var K;H=a.links;if(void 0===H||void 0===H.validation||void 0===H.validation.url)K={};else if(d.isString(H.validation.url))K=
{url:H.validation.url,bundled:!0};else throw new k("Link Validation URL was not a string");var J;H=a.links;if(void 0===H||void 0===H.embed||void 0===H.embed.url)J={};else if(d.isString(H.embed.url))J={url:H.embed.url,bundled:!0};else throw new k("Link Embed URL was not a string");H=a.images;H=f.merge({allowLocal:!0},void 0===H?{}:H);b.bool("allowLocal").validate(H.allowLocal);H=H.allowLocal;I=a.images;I=l((void 0===I?{}:I).editing,[b.bool("enabled"),b.string("proxy"),b.number("preferredWidth"),b.number("preferredHeight")]);
void 0!==I.enabled&&(I.bundled=I.enabled);var L;if(H){var N=a.images;L=!1===I.bundled?!0:!1;N=(void 0===N?{}:N).upload;if(void 0!==N)if(void 0!==N.handler){if(!d.isFunction(N.handler))throw new k("Image Upload Handler was not a function");L={handler:N.handler,immediate:L,bundled:!0}}else{if(!d.isString(N.url))throw new k("Image Upload URL was not a string");L={direct:l(N,[b.string("url"),b.string("basePath"),b.bool("credentials")]),immediate:L,bundled:!0}}else L={}}else L={};var N=a.ui,N=l((void 0===
N?{}:N).toolbar,[b.arrayOfToolbarGroups("items"),b.arrayOfStrings("contextual")]),M;var O=a.ui;if(void 0===O)M={};else{if(void 0===O.toolbar)M={};else if(M=O.toolbar,void 0!==M.offset){M=M.offset;if(!d.isObject(M)||void 0===M.top||void 0===M.left)throw new k("toolbar offset must be an object with left and top");if(!d.isNumber(M.top)&&!d.isNumber(M.left))throw new k("toolbar offset values must be numbers");M={draggable:!0,offset:{left:M.left,top:M.top}}}else M={};O=l(O.toolbar,[b.bool("visible"),b.bool("draggable")]);
M=f.deepMerge(M,O)}var S;O=a.basePath;if(void 0===O)S=void 0;else{if(!d.isString(O))throw new k("The basePath configuration value was not a string");S=h.removeTrailing(O,"/")}O=r(a.ui);a=l(a.ui,[b.string("aria-label","editorName")]);a=f.merge(a,{locale:e,toolbar:M});e=S;O={faces:O};s={external:p(s.highlighters)};M=u.style;return{resources:e,plugins:c,spelling:G,linkvalidator:K,embed:J,font:O,ui:a,shortcuts:C,autosubmit:g,highlighter:s,smartclipboard:{paste:"plain"===M?{forceText:!0}:{officeStyles:"retain"===
M?"merge":void 0!==M?M:"prompt",htmlStyles:"retain"===M?"merge":void 0!==M?M:"merge",allowLocalImages:H,enableFlashImport:!1===u.enableFlashImport?!1:!0}},parlance:F,content:D,imageEdit:I,imageupload:L,blocktag:t(B),fileupload:{allowLocalImages:H},platform:{toolbar:N,allowLocalImages:H},plaincodeview:{bundled:E.bundled},codeview:E}},u=function(d){var e=void 0===d.privateapi?{}:d.privateapi;d=l(e.ui,[b.func("bounds"),b.bool("showHelpHint"),b.domElement("bottomBar"),b.domElement("sideBar")]);var h=
l(e.integration,[b.string("type"),b.string("version")]),n=void 0===e.content?{}:e.content,p=l(n.macros,[b.arrayOfStrings("whitelist")]),n=l(n,[b.string("base")]);void 0!==p.whitelist&&(p.whitelist=g.some(p.whitelist));var q=a.paramList(),r=l(e.mentions,q),s=c.keys(r).length,e=l(e.output,[b.bool("prettyprint")]);if(0<s){if(s!==q.length)throw new k("Missing @mentions configuration. Expected "+q.length+" objects, was "+s);r.bundled=!0}return{ui:d,help:{integration:h},macros:p,content:f.merge(n,e),mentions:r}};
return function(a){a=void 0!==a?a:{};return f.deepMerge(s(a),u(a))}});l("u",["b"],function(d){return{getPath:function(e){var c=document.getElementsByTagName("script");return(c=d.find(c,function(a){return a.src.indexOf(e)===a.src.length-e.length}))?c.src.substring(0,c.src.indexOf(e)):void 0}}});l("5","67rstuv".split(""),function(d,e,c,a,b,f,g){var h=c.cached(function(){return a.from(f.getPath("textboxio.js")).map(function(a){return g.removeTrailing(a,"/")})}),k=function(a){return a+"/resources"};return{setupResources:function(c){return a.from(c.resources).orThunk(h).map(k).fold(e.die("basePath auto detection failed, please provide one in the editor configuration"),
function(a){a=b.load(a);return d.deepMerge(c,{resources:a})})},speculate:function(c){a.from(c).orThunk(h).map(k).each(b.load)}}});l("2w","4c c 7 s 1y 1b 3y l 2z 38 q 3x".split(" "),function(d,e,c,a,b,f,g,h,k,l,p,n){var r=function(a,b,c){var d=function(){var a=h.fromDom(p.activeElement);b(a)&&c()};return g.bind(a,"blur",function(){n(d,200)})},q=function(a,b,c){return g.bind(a,"focusout",function(a){u(a,b)&&c()})},t=function(a,b,c){return g.bind(a,"blur",function(a){u(a,b)&&c()})},s=function(){var a=
e.detect();return a.browser.isFirefox()?r:a.browser.isIE()?q:t}(),u=function(b,c){var d=a.from(b.raw().relatedTarget).getOr(p.activeElement);return c(h.fromDom(d))};return{register:function(a,c,e,h){var n=g.bind(a,"focus",function(a){k.hasFocus(a.target())&&e()}),p=s(a,function(e){return!l.closest(e,function(e){return f.eq(a,e)||f.eq(c(),e)||b.has(e,d.magicBox())})},h);return{destroy:function(){n.unbind();p.unbind()}}}}});l("2x",["4d","1a","1y","4e","2o"],function(d,e,c,a,b){return function(f,g,h){c.add(g,
d.base());return{toolbarShow:function(){c.add(g,d.active());b.set(f(),"display","block")},toolbarHide:function(){c.remove(g,d.active());b.set(f(),"display","none")},isVisible:function(){return c.has(g,d.active())},restore:function(){a.remove(g,[d.base(),d.active()]);e.setAll(g,h)}}}});l("1m","24 2w 2x 6 2f 2y 1a 2n 1b 2z 2g".split(" "),function(d,e,c,a,b,f,g,h,k,l,p){return{replace:function(n,r){var q=a.deepMerge(r,{content:{inline:n}}),t=g.clone(n),s=b(q),u=c(s.element,n,t),v=f(u.toolbarHide,u.toolbarShow,
!1),w=function(){var a=u.isVisible();v.on();!1===a&&s.activateInline()},y=function(){s.deactivateInline();v.off()},x=e.register(n,s.element,w,y),q=function(){l.active().each(function(a){k.eq(a,n)||y()})};q();s.events.connected.bind(q);s.events.loaded.bind(function(){s.content().getSelection().bind(w)});var z=s.focus,q={polish:a.merge(s,{focus:function(){w();z()}}),restore:function(a){x.destroy();u.restore();p.set(n,a);return n}};s.connect(h.body());d.set(s,p.get(n));return q}}});l("4f",["1a","l"],
function(d,e){return{attach:function(c,a,b,f){if(4!==arguments.length)throw"requires 4 parameters";var g=function(a){return function(){var b=e.fromTag("input");d.setAll(b,{type:"hidden",name:a});c.append(b.dom());return function(a){b.val(a)}}},h=b.getOrThunk(g(a)),k=f.getOrThunk(g(a+"_styles"));return function(a){h(a.content);k(a.styles)}}}});l("4g",[],function(){return function(d){var e=!1;return{submit:function(){e=!0;d.submit[0]?d.submit[0].click():d.submit.click?d.submit.click():d.submit();e=
!1},inprogress:function(){return e}}}});l("31",["4f","4g"],function(d,e){var c=function(a,b){var c=a.onsubmit,d=e(a);a.onsubmit=function(e){if(d.inprogress())return!0;b(function(){c&&!1===c.apply(a)||setTimeout(d.submit,0)});return!1};return{unbind:function(){a.onsubmit=c}}};return{attachToFormSubmit:c,attachToParentFormSubmit:function(a,b,e,g,h){if(5!==arguments.length)throw"requires 5 parameters";var k=a.parents("form:first");if(0!==k.size()){var l=k.get(0),p=d.attach(k,b,g,h);c(l,function(a){p(e());
a()})}}}});l("1n","30 2d 24 2e 31 s 2f 1a 2o l 2p 2r 32 2b 33".split(" "),function(d,e,c,a,b,f,g,h,k,l,p,n,r,q,t){var s=function(a,b,d,h){k.set(b,"display","none");var l=g(e.withOptions(b,h)),m=t.get(b);l.connect(a);c.set(l,m);var p=!0===h.autosubmit?u(b,l):f.none();return{polish:l,restore:function(c){p.each(function(a){a.unbind()});t.set(b,c);d.fold(function(){k.remove(b,"display")},function(a){k.set(b,"display",a)});n.remove(a);return b}}},u=function(a,d){return r.closest(a,"form").map(function(e){return b.attachToFormSubmit(e.dom(),
function(b){d.uploadImages(function(){t.set(a,c.get(d));b()})})})};return{replace:function(b,c){var e=k.getRaw(b,"display");return q.parent(b).fold(function(){return null},function(){var f=h.get(b,"id"),f=f?"ephox_"+f:d.generate("ephox"),g=l.fromTag("div");h.set(g,"id",f);k.copy(b,g);a.copyFrom(b,g);p.before(b,g);return s(g,b,e,c)})}}});l("e","1c 1d 5 1l 1m 1n 6 7 r".split(" "),function(d,e,c,a,b,f,g,h,k){var l={textarea:f,div:a,body:d},p={div:b,blockquote:b,article:b,aside:b,figure:b,figcaption:b,
footer:b,header:b,nav:b,section:b};return function(a){var b=function(b,d){var f=k.cached(function(){var b=g.deepMerge(e(d),a);return c.setupResources(b)});return{constructors:h.constant(b),options:f}};return{classic:function(a){return b(l,a)},inline:function(a){a=g.deepMerge({ui:{toolbar:{draggable:!0}}},a);return b(p,a)}}}});l("h",["i","7"],function(d,e){var c=function(a){return{name:a.name,required:e.constant(!1),validate:a.validate}};return{bool:e.compose(c,d.bool),func:e.compose(c,d.func),number:e.compose(c,
d.number),object:e.compose(c,d.object),string:e.compose(c,d.string)}});l("3","abcdef8ghij7klmno".split(""),function(d,e,c,a,b,f,g,h,k,l,p,n,r,q,t,s,u){return function(v){var w=a(),y=b(v),x=function(a,b){var c;c=d.isString(a)?t.one(a).getOrThunk(n.die("Selector did not match any elements: "+a)):q.fromDom(a);return w.getOrCreate(c,b)},z=function(a,b){d.isString(a)?u.error("Selector did not match a "+b+": ",a):u.error("Element was not a "+b+": ",a);throw new s("Unable to create textbox.io editor");},
A=c.detect(),D=function(a){d.isString(a)||p(a,[l.domElement("element")]);return d.isString(a)?t.all(a):e.map(a,q.fromDom)},B=function(a,b){var c=D(a),c=e.map(c,function(a){return w.getOrCreate(a,b)});return r.cat(c)};return f.makeReadOnly({replace:function(a,b){p(arguments,[l.stringOrDom("element"),k.object("options")]);return x(a,y.classic(b)).getOrThunk(n.curry(z,a,"div or textarea"))},replaceAll:function(a,b){p(arguments,[l.stringOrArray("elements"),k.object("options")]);return B(a,y.classic(b))},
inline:function(a,b){if(A.deviceType.isTouch())throw new s("Mobile does not not support inline editing");p(arguments,[l.stringOrDom("element"),k.object("options")]);return x(a,y.inline(b)).getOrThunk(n.curry(z,a,"supported tag for inline editing"))},inlineAll:function(a,b){if(A.deviceType.isTouch())throw new s("Mobile does not not support inline editing");p(arguments,[l.stringOrArray("elements"),k.object("options")]);return B(a,y.inline(b))},get:function(a){p(arguments,[l.string("selector")]);return w.get(a)},
getActiveEditor:function(){return w.getActiveEditor().getOr(null)},definePlugin:function(a,b){p(arguments,[l.string("namespace"),l.object("code")]);h.get(a).each(function(){throw new s("namespace "+a+" is already defined");});if(void 0===b.initialize||!d.isFunction(b.initialize))throw new s("plugin does not have an initialize function");return h.register(a,b)},version:g,isSupported:n.constant(!0)})}});l("4",["c","p","o","q"],function(d,e,c,a){var b=function(a){return e.error("ERROR: Textbox.io requires "+
a+" or above")},f=d.detect().os,g=d.detect().browser,h="CSS1Compat"===a.compatMode||"html"===a.doctype;return{supported:function(){if(g.isIE()&&11>g.version.major)return b("Internet Explorer 11");if(f.isOSX()&&g.isSafari()&&9>g.version.major)return b("Safari 9");if(f.isiOS()&&9>f.version.major)return b("iOS 9");if(!h&&g.isIE())return e.error("ERROR: Document is not in standards mode. Textbox.io requires standards mode on Internet Explorer.");h||void 0===c.warn||c.warn("WARNING: Document is not in standards mode. Textbox.io may experience user interface issues.");
return e.value()}}});l("0","1234567".split(""),function(d,e,c,a,b,f,g){var h=function(a){d.textboxio=a},k=g.compose(h,e);return function(){var e=d.install;d.install=function(g,l){d.install=e;a.supported().fold(k,function(){var a=null===l||void 0===l?{onprem:!0}:l,a=null===g||void 0===g?a:f.deepMerge(a,{resources:g});h(c(a));b.speculate(a.resources)})}}});oa("0")()})();
install();


/*
 *
 * More info at [www.dropzonejs.com](http://www.dropzonejs.com)
 *
 * Copyright (c) 2012, Matias Meno
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 */

(function() {
    var Dropzone, Emitter, camelize, contentLoaded, detectVerticalSquash, drawImageIOSFix, noop, without,
        __slice = [].slice,
        __hasProp = {}.hasOwnProperty,
        __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

    noop = function() {};

    Emitter = (function() {
        function Emitter() {}

        Emitter.prototype.addEventListener = Emitter.prototype.on;

        Emitter.prototype.on = function(event, fn) {
            this._callbacks = this._callbacks || {};
            if (!this._callbacks[event]) {
                this._callbacks[event] = [];
            }
            this._callbacks[event].push(fn);
            return this;
        };

        Emitter.prototype.emit = function() {
            var args, callback, callbacks, event, _i, _len;
            event = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
            this._callbacks = this._callbacks || {};
            callbacks = this._callbacks[event];
            if (callbacks) {
                for (_i = 0, _len = callbacks.length; _i < _len; _i++) {
                    callback = callbacks[_i];
                    callback.apply(this, args);
                }
            }
            return this;
        };

        Emitter.prototype.removeListener = Emitter.prototype.off;

        Emitter.prototype.removeAllListeners = Emitter.prototype.off;

        Emitter.prototype.removeEventListener = Emitter.prototype.off;

        Emitter.prototype.off = function(event, fn) {
            var callback, callbacks, i, _i, _len;
            if (!this._callbacks || arguments.length === 0) {
                this._callbacks = {};
                return this;
            }
            callbacks = this._callbacks[event];
            if (!callbacks) {
                return this;
            }
            if (arguments.length === 1) {
                delete this._callbacks[event];
                return this;
            }
            for (i = _i = 0, _len = callbacks.length; _i < _len; i = ++_i) {
                callback = callbacks[i];
                if (callback === fn) {
                    callbacks.splice(i, 1);
                    break;
                }
            }
            return this;
        };

        return Emitter;

    })();

    Dropzone = (function(_super) {
        var extend, resolveOption;

        __extends(Dropzone, _super);

        Dropzone.prototype.Emitter = Emitter;


        /*
         This is a list of all available events you can register on a dropzone object.

         You can register an event handler like this:

         dropzone.on("dragEnter", function() { });
         */

        Dropzone.prototype.events = ["drop", "dragstart", "dragend", "dragenter", "dragover", "dragleave", "addedfile", "addedfiles", "removedfile", "thumbnail", "error", "errormultiple", "processing", "processingmultiple", "uploadprogress", "totaluploadprogress", "sending", "sendingmultiple", "success", "successmultiple", "canceled", "canceledmultiple", "complete", "completemultiple", "reset", "maxfilesexceeded", "maxfilesreached", "queuecomplete"];

        Dropzone.prototype.defaultOptions = {
            url: null,
            method: "post",
            withCredentials: false,
            parallelUploads: 2,
            uploadMultiple: false,
            maxFilesize: 256,
            paramName: "file",
            createImageThumbnails: true,
            maxThumbnailFilesize: 10,
            thumbnailWidth: 120,
            thumbnailHeight: 120,
            filesizeBase: 1000,
            maxFiles: null,
            params: {},
            clickable: true,
            ignoreHiddenFiles: true,
            acceptedFiles: null,
            acceptedMimeTypes: null,
            autoProcessQueue: true,
            autoQueue: true,
            addRemoveLinks: false,
            previewsContainer: null,
            hiddenInputContainer: "body",
            capture: null,
            renameFilename: null,
            dictDefaultMessage: "Drop files here to upload",
            dictFallbackMessage: "Your browser does not support drag'n'drop file uploads.",
            dictFallbackText: "Please use the fallback form below to upload your files like in the olden days.",
            dictFileTooBig: "File is too big ({{filesize}}MiB). Max filesize: {{maxFilesize}}MiB.",
            dictInvalidFileType: "You can't upload files of this type.",
            dictResponseError: "Server responded with {{statusCode}} code.",
            dictCancelUpload: "Cancel upload",
            dictCancelUploadConfirmation: "Are you sure you want to cancel this upload?",
            dictRemoveFile: "Remove file",
            dictRemoveFileConfirmation: null,
            dictMaxFilesExceeded: "You can not upload any more files.",
            accept: function(file, done) {
                return done();
            },
            init: function() {
                return noop;
            },
            forceFallback: false,
            fallback: function() {
                var child, messageElement, span, _i, _len, _ref;
                this.element.className = "" + this.element.className + " dz-browser-not-supported";
                _ref = this.element.getElementsByTagName("div");
                for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                    child = _ref[_i];
                    if (/(^| )dz-message($| )/.test(child.className)) {
                        messageElement = child;
                        child.className = "dz-message";
                        continue;
                    }
                }
                if (!messageElement) {
                    messageElement = Dropzone.createElement("<div class=\"dz-message\"><span></span></div>");
                    this.element.appendChild(messageElement);
                }
                span = messageElement.getElementsByTagName("span")[0];
                if (span) {
                    if (span.textContent != null) {
                        span.textContent = this.options.dictFallbackMessage;
                    } else if (span.innerText != null) {
                        span.innerText = this.options.dictFallbackMessage;
                    }
                }
                return this.element.appendChild(this.getFallbackForm());
            },
            resize: function(file) {
                var info, srcRatio, trgRatio;
                info = {
                    srcX: 0,
                    srcY: 0,
                    srcWidth: file.width,
                    srcHeight: file.height
                };
                srcRatio = file.width / file.height;
                info.optWidth = this.options.thumbnailWidth;
                info.optHeight = this.options.thumbnailHeight;
                if ((info.optWidth == null) && (info.optHeight == null)) {
                    info.optWidth = info.srcWidth;
                    info.optHeight = info.srcHeight;
                } else if (info.optWidth == null) {
                    info.optWidth = srcRatio * info.optHeight;
                } else if (info.optHeight == null) {
                    info.optHeight = (1 / srcRatio) * info.optWidth;
                }
                trgRatio = info.optWidth / info.optHeight;
                if (file.height < info.optHeight || file.width < info.optWidth) {
                    info.trgHeight = info.srcHeight;
                    info.trgWidth = info.srcWidth;
                } else {
                    if (srcRatio > trgRatio) {
                        info.srcHeight = file.height;
                        info.srcWidth = info.srcHeight * trgRatio;
                    } else {
                        info.srcWidth = file.width;
                        info.srcHeight = info.srcWidth / trgRatio;
                    }
                }
                info.srcX = (file.width - info.srcWidth) / 2;
                info.srcY = (file.height - info.srcHeight) / 2;
                return info;
            },

            /*
             Those functions register themselves to the events on init and handle all
             the user interface specific stuff. Overwriting them won't break the upload
             but can break the way it's displayed.
             You can overwrite them if you don't like the default behavior. If you just
             want to add an additional event handler, register it on the dropzone object
             and don't overwrite those options.
             */
            drop: function(e) {
                return this.element.classList.remove("dz-drag-hover");
            },
            dragstart: noop,
            dragend: function(e) {
                return this.element.classList.remove("dz-drag-hover");
            },
            dragenter: function(e) {
                return this.element.classList.add("dz-drag-hover");
            },
            dragover: function(e) {
                return this.element.classList.add("dz-drag-hover");
            },
            dragleave: function(e) {
                return this.element.classList.remove("dz-drag-hover");
            },
            paste: noop,
            reset: function() {
                return this.element.classList.remove("dz-started");
            },
            addedfile: function(file) {
                var node, removeFileEvent, removeLink, _i, _j, _k, _len, _len1, _len2, _ref, _ref1, _ref2, _results;
                if (this.element === this.previewsContainer) {
                    this.element.classList.add("dz-started");
                }
                if (this.previewsContainer) {
                    file.previewElement = Dropzone.createElement(this.options.previewTemplate.trim());
                    file.previewTemplate = file.previewElement;
                    this.previewsContainer.appendChild(file.previewElement);
                    _ref = file.previewElement.querySelectorAll("[data-dz-name]");
                    for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                        node = _ref[_i];
                        node.textContent = this._renameFilename(file.name);
                    }
                    _ref1 = file.previewElement.querySelectorAll("[data-dz-size]");
                    for (_j = 0, _len1 = _ref1.length; _j < _len1; _j++) {
                        node = _ref1[_j];
                        node.innerHTML = this.filesize(file.size);
                    }
                    if (this.options.addRemoveLinks) {
                        file._removeLink = Dropzone.createElement("<a class=\"dz-remove\" href=\"javascript:undefined;\" data-dz-remove>" + this.options.dictRemoveFile + "</a>");
                        file.previewElement.appendChild(file._removeLink);
                    }
                    removeFileEvent = (function(_this) {
                        return function(e) {
                            e.preventDefault();
                            e.stopPropagation();
                            if (file.status === Dropzone.UPLOADING) {
                                return Dropzone.confirm(_this.options.dictCancelUploadConfirmation, function() {
                                    return _this.removeFile(file);
                                });
                            } else {
                                if (_this.options.dictRemoveFileConfirmation) {
                                    return Dropzone.confirm(_this.options.dictRemoveFileConfirmation, function() {
                                        return _this.removeFile(file);
                                    });
                                } else {
                                    return _this.removeFile(file);
                                }
                            }
                        };
                    })(this);
                    _ref2 = file.previewElement.querySelectorAll("[data-dz-remove]");
                    _results = [];
                    for (_k = 0, _len2 = _ref2.length; _k < _len2; _k++) {
                        removeLink = _ref2[_k];
                        _results.push(removeLink.addEventListener("click", removeFileEvent));
                    }
                    return _results;
                }
            },
            removedfile: function(file) {
                var _ref;
                if (file.previewElement) {
                    if ((_ref = file.previewElement) != null) {
                        _ref.parentNode.removeChild(file.previewElement);
                    }
                }
                return this._updateMaxFilesReachedClass();
            },
            thumbnail: function(file, dataUrl) {
                var thumbnailElement, _i, _len, _ref;
                if (file.previewElement) {
                    file.previewElement.classList.remove("dz-file-preview");
                    _ref = file.previewElement.querySelectorAll("[data-dz-thumbnail]");
                    for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                        thumbnailElement = _ref[_i];
                        thumbnailElement.alt = file.name;
                        thumbnailElement.src = dataUrl;
                    }
                    return setTimeout(((function(_this) {
                        return function() {
                            return file.previewElement.classList.add("dz-image-preview");
                        };
                    })(this)), 1);
                }
            },
            error: function(file, message) {
                var node, _i, _len, _ref, _results;
                if (file.previewElement) {
                    file.previewElement.classList.add("dz-error");
                    if (typeof message !== "String" && message.error) {
                        message = message.error;
                    }
                    _ref = file.previewElement.querySelectorAll("[data-dz-errormessage]");
                    _results = [];
                    for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                        node = _ref[_i];
                        _results.push(node.textContent = message);
                    }
                    return _results;
                }
            },
            errormultiple: noop,
            processing: function(file) {
                if (file.previewElement) {
                    file.previewElement.classList.add("dz-processing");
                    if (file._removeLink) {
                        return file._removeLink.textContent = this.options.dictCancelUpload;
                    }
                }
            },
            processingmultiple: noop,
            uploadprogress: function(file, progress, bytesSent) {
                var node, _i, _len, _ref, _results;
                if (file.previewElement) {
                    _ref = file.previewElement.querySelectorAll("[data-dz-uploadprogress]");
                    _results = [];
                    for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                        node = _ref[_i];
                        if (node.nodeName === 'PROGRESS') {
                            _results.push(node.value = progress);
                        } else {
                            _results.push(node.style.width = "" + progress + "%");
                        }
                    }
                    return _results;
                }
            },
            totaluploadprogress: noop,
            sending: noop,
            sendingmultiple: noop,
            success: function(file) {
                if (file.previewElement) {
                    return file.previewElement.classList.add("dz-success");
                }
            },
            successmultiple: noop,
            canceled: function(file) {
                return this.emit("error", file, "Upload canceled.");
            },
            canceledmultiple: noop,
            complete: function(file) {
                if (file._removeLink) {
                    file._removeLink.textContent = this.options.dictRemoveFile;
                }
                if (file.previewElement) {
                    return file.previewElement.classList.add("dz-complete");
                }
            },
            completemultiple: noop,
            maxfilesexceeded: noop,
            maxfilesreached: noop,
            queuecomplete: noop,
            addedfiles: noop,
            previewTemplate: "<div class=\"dz-preview dz-file-preview\">\n  <div class=\"dz-image\"><img data-dz-thumbnail /></div>\n  <div class=\"dz-details\">\n    <div class=\"dz-size\"><span data-dz-size></span></div>\n    <div class=\"dz-filename\"><span data-dz-name></span></div>\n  </div>\n  <div class=\"dz-progress\"><span class=\"dz-upload\" data-dz-uploadprogress></span></div>\n  <div class=\"dz-error-message\"><span data-dz-errormessage></span></div>\n  <div class=\"dz-success-mark\">\n    <svg width=\"54px\" height=\"54px\" viewBox=\"0 0 54 54\" version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" xmlns:sketch=\"http://www.bohemiancoding.com/sketch/ns\">\n      <title>Check</title>\n      <defs></defs>\n      <g id=\"Page-1\" stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\" sketch:type=\"MSPage\">\n        <path d=\"M23.5,31.8431458 L17.5852419,25.9283877 C16.0248253,24.3679711 13.4910294,24.366835 11.9289322,25.9289322 C10.3700136,27.4878508 10.3665912,30.0234455 11.9283877,31.5852419 L20.4147581,40.0716123 C20.5133999,40.1702541 20.6159315,40.2626649 20.7218615,40.3488435 C22.2835669,41.8725651 24.794234,41.8626202 26.3461564,40.3106978 L43.3106978,23.3461564 C44.8771021,21.7797521 44.8758057,19.2483887 43.3137085,17.6862915 C41.7547899,16.1273729 39.2176035,16.1255422 37.6538436,17.6893022 L23.5,31.8431458 Z M27,53 C41.3594035,53 53,41.3594035 53,27 C53,12.6405965 41.3594035,1 27,1 C12.6405965,1 1,12.6405965 1,27 C1,41.3594035 12.6405965,53 27,53 Z\" id=\"Oval-2\" stroke-opacity=\"0.198794158\" stroke=\"#747474\" fill-opacity=\"0.816519475\" fill=\"#FFFFFF\" sketch:type=\"MSShapeGroup\"></path>\n      </g>\n    </svg>\n  </div>\n  <div class=\"dz-error-mark\">\n    <svg width=\"54px\" height=\"54px\" viewBox=\"0 0 54 54\" version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" xmlns:sketch=\"http://www.bohemiancoding.com/sketch/ns\">\n      <title>Error</title>\n      <defs></defs>\n      <g id=\"Page-1\" stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\" sketch:type=\"MSPage\">\n        <g id=\"Check-+-Oval-2\" sketch:type=\"MSLayerGroup\" stroke=\"#747474\" stroke-opacity=\"0.198794158\" fill=\"#FFFFFF\" fill-opacity=\"0.816519475\">\n          <path d=\"M32.6568542,29 L38.3106978,23.3461564 C39.8771021,21.7797521 39.8758057,19.2483887 38.3137085,17.6862915 C36.7547899,16.1273729 34.2176035,16.1255422 32.6538436,17.6893022 L27,23.3431458 L21.3461564,17.6893022 C19.7823965,16.1255422 17.2452101,16.1273729 15.6862915,17.6862915 C14.1241943,19.2483887 14.1228979,21.7797521 15.6893022,23.3461564 L21.3431458,29 L15.6893022,34.6538436 C14.1228979,36.2202479 14.1241943,38.7516113 15.6862915,40.3137085 C17.2452101,41.8726271 19.7823965,41.8744578 21.3461564,40.3106978 L27,34.6568542 L32.6538436,40.3106978 C34.2176035,41.8744578 36.7547899,41.8726271 38.3137085,40.3137085 C39.8758057,38.7516113 39.8771021,36.2202479 38.3106978,34.6538436 L32.6568542,29 Z M27,53 C41.3594035,53 53,41.3594035 53,27 C53,12.6405965 41.3594035,1 27,1 C12.6405965,1 1,12.6405965 1,27 C1,41.3594035 12.6405965,53 27,53 Z\" id=\"Oval-2\" sketch:type=\"MSShapeGroup\"></path>\n        </g>\n      </g>\n    </svg>\n  </div>\n</div>"
        };

        extend = function() {
            var key, object, objects, target, val, _i, _len;
            target = arguments[0], objects = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
            for (_i = 0, _len = objects.length; _i < _len; _i++) {
                object = objects[_i];
                for (key in object) {
                    val = object[key];
                    target[key] = val;
                }
            }
            return target;
        };

        function Dropzone(element, options) {
            var elementOptions, fallback, _ref;
            this.element = element;
            this.version = Dropzone.version;
            this.defaultOptions.previewTemplate = this.defaultOptions.previewTemplate.replace(/\n*/g, "");
            this.clickableElements = [];
            this.listeners = [];
            this.files = [];
            if (typeof this.element === "string") {
                this.element = document.querySelector(this.element);
            }
            if (!(this.element && (this.element.nodeType != null))) {
                throw new Error("Invalid dropzone element.");
            }
            if (this.element.dropzone) {
                throw new Error("Dropzone already attached.");
            }
            Dropzone.instances.push(this);
            this.element.dropzone = this;
            elementOptions = (_ref = Dropzone.optionsForElement(this.element)) != null ? _ref : {};
            this.options = extend({}, this.defaultOptions, elementOptions, options != null ? options : {});
            if (this.options.forceFallback || !Dropzone.isBrowserSupported()) {
                return this.options.fallback.call(this);
            }
            if (this.options.url == null) {
                this.options.url = this.element.getAttribute("action");
            }
            if (!this.options.url) {
                throw new Error("No URL provided.");
            }
            if (this.options.acceptedFiles && this.options.acceptedMimeTypes) {
                throw new Error("You can't provide both 'acceptedFiles' and 'acceptedMimeTypes'. 'acceptedMimeTypes' is deprecated.");
            }
            if (this.options.acceptedMimeTypes) {
                this.options.acceptedFiles = this.options.acceptedMimeTypes;
                delete this.options.acceptedMimeTypes;
            }
            this.options.method = this.options.method.toUpperCase();
            if ((fallback = this.getExistingFallback()) && fallback.parentNode) {
                fallback.parentNode.removeChild(fallback);
            }
            if (this.options.previewsContainer !== false) {
                if (this.options.previewsContainer) {
                    this.previewsContainer = Dropzone.getElement(this.options.previewsContainer, "previewsContainer");
                } else {
                    this.previewsContainer = this.element;
                }
            }
            if (this.options.clickable) {
                if (this.options.clickable === true) {
                    this.clickableElements = [this.element];
                } else {
                    this.clickableElements = Dropzone.getElements(this.options.clickable, "clickable");
                }
            }
            this.init();
        }

        Dropzone.prototype.getAcceptedFiles = function() {
            var file, _i, _len, _ref, _results;
            _ref = this.files;
            _results = [];
            for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                file = _ref[_i];
                if (file.accepted) {
                    _results.push(file);
                }
            }
            return _results;
        };

        Dropzone.prototype.getRejectedFiles = function() {
            var file, _i, _len, _ref, _results;
            _ref = this.files;
            _results = [];
            for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                file = _ref[_i];
                if (!file.accepted) {
                    _results.push(file);
                }
            }
            return _results;
        };

        Dropzone.prototype.getFilesWithStatus = function(status) {
            var file, _i, _len, _ref, _results;
            _ref = this.files;
            _results = [];
            for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                file = _ref[_i];
                if (file.status === status) {
                    _results.push(file);
                }
            }
            return _results;
        };

        Dropzone.prototype.getQueuedFiles = function() {
            return this.getFilesWithStatus(Dropzone.QUEUED);
        };

        Dropzone.prototype.getUploadingFiles = function() {
            return this.getFilesWithStatus(Dropzone.UPLOADING);
        };

        Dropzone.prototype.getAddedFiles = function() {
            return this.getFilesWithStatus(Dropzone.ADDED);
        };

        Dropzone.prototype.getActiveFiles = function() {
            var file, _i, _len, _ref, _results;
            _ref = this.files;
            _results = [];
            for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                file = _ref[_i];
                if (file.status === Dropzone.UPLOADING || file.status === Dropzone.QUEUED) {
                    _results.push(file);
                }
            }
            return _results;
        };

        Dropzone.prototype.init = function() {
            var eventName, noPropagation, setupHiddenFileInput, _i, _len, _ref, _ref1;
            if (this.element.tagName === "form") {
                this.element.setAttribute("enctype", "multipart/form-data");
            }
            if (this.element.classList.contains("dropzone") && !this.element.querySelector(".dz-message")) {
                this.element.appendChild(Dropzone.createElement("<div class=\"dz-default dz-message\"><span>" + this.options.dictDefaultMessage + "</span></div>"));
            }
            if (this.clickableElements.length) {
                setupHiddenFileInput = (function(_this) {
                    return function() {
                        if (_this.hiddenFileInput) {
                            _this.hiddenFileInput.parentNode.removeChild(_this.hiddenFileInput);
                        }
                        _this.hiddenFileInput = document.createElement("input");
                        _this.hiddenFileInput.setAttribute("type", "file");
                        if ((_this.options.maxFiles == null) || _this.options.maxFiles > 1) {
                            _this.hiddenFileInput.setAttribute("multiple", "multiple");
                        }
                        _this.hiddenFileInput.className = "dz-hidden-input";
                        if (_this.options.acceptedFiles != null) {
                            _this.hiddenFileInput.setAttribute("accept", _this.options.acceptedFiles);
                        }
                        if (_this.options.capture != null) {
                            _this.hiddenFileInput.setAttribute("capture", _this.options.capture);
                        }
                        _this.hiddenFileInput.style.visibility = "hidden";
                        _this.hiddenFileInput.style.position = "absolute";
                        _this.hiddenFileInput.style.top = "0";
                        _this.hiddenFileInput.style.left = "0";
                        _this.hiddenFileInput.style.height = "0";
                        _this.hiddenFileInput.style.width = "0";
                        document.querySelector(_this.options.hiddenInputContainer).appendChild(_this.hiddenFileInput);
                        return _this.hiddenFileInput.addEventListener("change", function() {
                            var file, files, _i, _len;
                            files = _this.hiddenFileInput.files;
                            if (files.length) {
                                for (_i = 0, _len = files.length; _i < _len; _i++) {
                                    file = files[_i];
                                    _this.addFile(file);
                                }
                            }
                            _this.emit("addedfiles", files);
                            return setupHiddenFileInput();
                        });
                    };
                })(this);
                setupHiddenFileInput();
            }
            this.URL = (_ref = window.URL) != null ? _ref : window.webkitURL;
            _ref1 = this.events;
            for (_i = 0, _len = _ref1.length; _i < _len; _i++) {
                eventName = _ref1[_i];
                this.on(eventName, this.options[eventName]);
            }
            this.on("uploadprogress", (function(_this) {
                return function() {
                    return _this.updateTotalUploadProgress();
                };
            })(this));
            this.on("removedfile", (function(_this) {
                return function() {
                    return _this.updateTotalUploadProgress();
                };
            })(this));
            this.on("canceled", (function(_this) {
                return function(file) {
                    return _this.emit("complete", file);
                };
            })(this));
            this.on("complete", (function(_this) {
                return function(file) {
                    if (_this.getAddedFiles().length === 0 && _this.getUploadingFiles().length === 0 && _this.getQueuedFiles().length === 0) {
                        return setTimeout((function() {
                            return _this.emit("queuecomplete");
                        }), 0);
                    }
                };
            })(this));
            noPropagation = function(e) {
                e.stopPropagation();
                if (e.preventDefault) {
                    return e.preventDefault();
                } else {
                    return e.returnValue = false;
                }
            };
            this.listeners = [
                {
                    element: this.element,
                    events: {
                        "dragstart": (function(_this) {
                            return function(e) {
                                return _this.emit("dragstart", e);
                            };
                        })(this),
                        "dragenter": (function(_this) {
                            return function(e) {
                                noPropagation(e);
                                return _this.emit("dragenter", e);
                            };
                        })(this),
                        "dragover": (function(_this) {
                            return function(e) {
                                var efct;
                                try {
                                    efct = e.dataTransfer.effectAllowed;
                                } catch (_error) {}
                                e.dataTransfer.dropEffect = 'move' === efct || 'linkMove' === efct ? 'move' : 'copy';
                                noPropagation(e);
                                return _this.emit("dragover", e);
                            };
                        })(this),
                        "dragleave": (function(_this) {
                            return function(e) {
                                return _this.emit("dragleave", e);
                            };
                        })(this),
                        "drop": (function(_this) {
                            return function(e) {
                                noPropagation(e);
                                return _this.drop(e);
                            };
                        })(this),
                        "dragend": (function(_this) {
                            return function(e) {
                                return _this.emit("dragend", e);
                            };
                        })(this)
                    }
                }
            ];
            this.clickableElements.forEach((function(_this) {
                return function(clickableElement) {
                    return _this.listeners.push({
                        element: clickableElement,
                        events: {
                            "click": function(evt) {
                                if ((clickableElement !== _this.element) || (evt.target === _this.element || Dropzone.elementInside(evt.target, _this.element.querySelector(".dz-message")))) {
                                    _this.hiddenFileInput.click();
                                }
                                return true;
                            }
                        }
                    });
                };
            })(this));
            this.enable();
            return this.options.init.call(this);
        };

        Dropzone.prototype.destroy = function() {
            var _ref;
            this.disable();
            this.removeAllFiles(true);
            if ((_ref = this.hiddenFileInput) != null ? _ref.parentNode : void 0) {
                this.hiddenFileInput.parentNode.removeChild(this.hiddenFileInput);
                this.hiddenFileInput = null;
            }
            delete this.element.dropzone;
            return Dropzone.instances.splice(Dropzone.instances.indexOf(this), 1);
        };

        Dropzone.prototype.updateTotalUploadProgress = function() {
            var activeFiles, file, totalBytes, totalBytesSent, totalUploadProgress, _i, _len, _ref;
            totalBytesSent = 0;
            totalBytes = 0;
            activeFiles = this.getActiveFiles();
            if (activeFiles.length) {
                _ref = this.getActiveFiles();
                for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                    file = _ref[_i];
                    totalBytesSent += file.upload.bytesSent;
                    totalBytes += file.upload.total;
                }
                totalUploadProgress = 100 * totalBytesSent / totalBytes;
            } else {
                totalUploadProgress = 100;
            }
            return this.emit("totaluploadprogress", totalUploadProgress, totalBytes, totalBytesSent);
        };

        Dropzone.prototype._getParamName = function(n) {
            if (typeof this.options.paramName === "function") {
                return this.options.paramName(n);
            } else {
                return "" + this.options.paramName + (this.options.uploadMultiple ? "[" + n + "]" : "");
            }
        };

        Dropzone.prototype._renameFilename = function(name) {
            if (typeof this.options.renameFilename !== "function") {
                return name;
            }
            return this.options.renameFilename(name);
        };

        Dropzone.prototype.getFallbackForm = function() {
            var existingFallback, fields, fieldsString, form;
            if (existingFallback = this.getExistingFallback()) {
                return existingFallback;
            }
            fieldsString = "<div class=\"dz-fallback\">";
            if (this.options.dictFallbackText) {
                fieldsString += "<p>" + this.options.dictFallbackText + "</p>";
            }
            fieldsString += "<input type=\"file\" name=\"" + (this._getParamName(0)) + "\" " + (this.options.uploadMultiple ? 'multiple="multiple"' : void 0) + " /><input type=\"submit\" value=\"Upload!\"></div>";
            fields = Dropzone.createElement(fieldsString);
            if (this.element.tagName !== "FORM") {
                form = Dropzone.createElement("<form action=\"" + this.options.url + "\" enctype=\"multipart/form-data\" method=\"" + this.options.method + "\"></form>");
                form.appendChild(fields);
            } else {
                this.element.setAttribute("enctype", "multipart/form-data");
                this.element.setAttribute("method", this.options.method);
            }
            return form != null ? form : fields;
        };

        Dropzone.prototype.getExistingFallback = function() {
            var fallback, getFallback, tagName, _i, _len, _ref;
            getFallback = function(elements) {
                var el, _i, _len;
                for (_i = 0, _len = elements.length; _i < _len; _i++) {
                    el = elements[_i];
                    if (/(^| )fallback($| )/.test(el.className)) {
                        return el;
                    }
                }
            };
            _ref = ["div", "form"];
            for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                tagName = _ref[_i];
                if (fallback = getFallback(this.element.getElementsByTagName(tagName))) {
                    return fallback;
                }
            }
        };

        Dropzone.prototype.setupEventListeners = function() {
            var elementListeners, event, listener, _i, _len, _ref, _results;
            _ref = this.listeners;
            _results = [];
            for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                elementListeners = _ref[_i];
                _results.push((function() {
                    var _ref1, _results1;
                    _ref1 = elementListeners.events;
                    _results1 = [];
                    for (event in _ref1) {
                        listener = _ref1[event];
                        _results1.push(elementListeners.element.addEventListener(event, listener, false));
                    }
                    return _results1;
                })());
            }
            return _results;
        };

        Dropzone.prototype.removeEventListeners = function() {
            var elementListeners, event, listener, _i, _len, _ref, _results;
            _ref = this.listeners;
            _results = [];
            for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                elementListeners = _ref[_i];
                _results.push((function() {
                    var _ref1, _results1;
                    _ref1 = elementListeners.events;
                    _results1 = [];
                    for (event in _ref1) {
                        listener = _ref1[event];
                        _results1.push(elementListeners.element.removeEventListener(event, listener, false));
                    }
                    return _results1;
                })());
            }
            return _results;
        };

        Dropzone.prototype.disable = function() {
            var file, _i, _len, _ref, _results;
            this.clickableElements.forEach(function(element) {
                return element.classList.remove("dz-clickable");
            });
            this.removeEventListeners();
            _ref = this.files;
            _results = [];
            for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                file = _ref[_i];
                _results.push(this.cancelUpload(file));
            }
            return _results;
        };

        Dropzone.prototype.enable = function() {
            this.clickableElements.forEach(function(element) {
                return element.classList.add("dz-clickable");
            });
            return this.setupEventListeners();
        };

        Dropzone.prototype.filesize = function(size) {
            var cutoff, i, selectedSize, selectedUnit, unit, units, _i, _len;
            selectedSize = 0;
            selectedUnit = "b";
            if (size > 0) {
                units = ['TB', 'GB', 'MB', 'KB', 'b'];
                for (i = _i = 0, _len = units.length; _i < _len; i = ++_i) {
                    unit = units[i];
                    cutoff = Math.pow(this.options.filesizeBase, 4 - i) / 10;
                    if (size >= cutoff) {
                        selectedSize = size / Math.pow(this.options.filesizeBase, 4 - i);
                        selectedUnit = unit;
                        break;
                    }
                }
                selectedSize = Math.round(10 * selectedSize) / 10;
            }
            return "<strong>" + selectedSize + "</strong> " + selectedUnit;
        };

        Dropzone.prototype._updateMaxFilesReachedClass = function() {
            if ((this.options.maxFiles != null) && this.getAcceptedFiles().length >= this.options.maxFiles) {
                if (this.getAcceptedFiles().length === this.options.maxFiles) {
                    this.emit('maxfilesreached', this.files);
                }
                return this.element.classList.add("dz-max-files-reached");
            } else {
                return this.element.classList.remove("dz-max-files-reached");
            }
        };

        Dropzone.prototype.drop = function(e) {
            var files, items;
            if (!e.dataTransfer) {
                return;
            }
            this.emit("drop", e);
            files = e.dataTransfer.files;
            this.emit("addedfiles", files);
            if (files.length) {
                items = e.dataTransfer.items;
                if (items && items.length && (items[0].webkitGetAsEntry != null)) {
                    this._addFilesFromItems(items);
                } else {
                    this.handleFiles(files);
                }
            }
        };

        Dropzone.prototype.paste = function(e) {
            var items, _ref;
            if ((e != null ? (_ref = e.clipboardData) != null ? _ref.items : void 0 : void 0) == null) {
                return;
            }
            this.emit("paste", e);
            items = e.clipboardData.items;
            if (items.length) {
                return this._addFilesFromItems(items);
            }
        };

        Dropzone.prototype.handleFiles = function(files) {
            var file, _i, _len, _results;
            _results = [];
            for (_i = 0, _len = files.length; _i < _len; _i++) {
                file = files[_i];
                _results.push(this.addFile(file));
            }
            return _results;
        };

        Dropzone.prototype._addFilesFromItems = function(items) {
            var entry, item, _i, _len, _results;
            _results = [];
            for (_i = 0, _len = items.length; _i < _len; _i++) {
                item = items[_i];
                if ((item.webkitGetAsEntry != null) && (entry = item.webkitGetAsEntry())) {
                    if (entry.isFile) {
                        _results.push(this.addFile(item.getAsFile()));
                    } else if (entry.isDirectory) {
                        _results.push(this._addFilesFromDirectory(entry, entry.name));
                    } else {
                        _results.push(void 0);
                    }
                } else if (item.getAsFile != null) {
                    if ((item.kind == null) || item.kind === "file") {
                        _results.push(this.addFile(item.getAsFile()));
                    } else {
                        _results.push(void 0);
                    }
                } else {
                    _results.push(void 0);
                }
            }
            return _results;
        };

        Dropzone.prototype._addFilesFromDirectory = function(directory, path) {
            var dirReader, errorHandler, readEntries;
            dirReader = directory.createReader();
            errorHandler = function(error) {
                return typeof console !== "undefined" && console !== null ? typeof console.log === "function" ? console.log(error) : void 0 : void 0;
            };
            readEntries = (function(_this) {
                return function() {
                    return dirReader.readEntries(function(entries) {
                        var entry, _i, _len;
                        if (entries.length > 0) {
                            for (_i = 0, _len = entries.length; _i < _len; _i++) {
                                entry = entries[_i];
                                if (entry.isFile) {
                                    entry.file(function(file) {
                                        if (_this.options.ignoreHiddenFiles && file.name.substring(0, 1) === '.') {
                                            return;
                                        }
                                        file.fullPath = "" + path + "/" + file.name;
                                        return _this.addFile(file);
                                    });
                                } else if (entry.isDirectory) {
                                    _this._addFilesFromDirectory(entry, "" + path + "/" + entry.name);
                                }
                            }
                            readEntries();
                        }
                        return null;
                    }, errorHandler);
                };
            })(this);
            return readEntries();
        };

        Dropzone.prototype.accept = function(file, done) {
            if (file.size > this.options.maxFilesize * 1024 * 1024) {
                return done(this.options.dictFileTooBig.replace("{{filesize}}", Math.round(file.size / 1024 / 10.24) / 100).replace("{{maxFilesize}}", this.options.maxFilesize));
            } else if (!Dropzone.isValidFile(file, this.options.acceptedFiles)) {
                return done(this.options.dictInvalidFileType);
            } else if ((this.options.maxFiles != null) && this.getAcceptedFiles().length >= this.options.maxFiles) {
                done(this.options.dictMaxFilesExceeded.replace("{{maxFiles}}", this.options.maxFiles));
                return this.emit("maxfilesexceeded", file);
            } else {
                return this.options.accept.call(this, file, done);
            }
        };

        Dropzone.prototype.addFile = function(file) {
            file.upload = {
                progress: 0,
                total: file.size,
                bytesSent: 0
            };
            this.files.push(file);
            file.status = Dropzone.ADDED;
            this.emit("addedfile", file);
            this._enqueueThumbnail(file);
            return this.accept(file, (function(_this) {
                return function(error) {
                    if (error) {
                        file.accepted = false;
                        _this._errorProcessing([file], error);
                    } else {
                        file.accepted = true;
                        if (_this.options.autoQueue) {
                            _this.enqueueFile(file);
                        }
                    }
                    return _this._updateMaxFilesReachedClass();
                };
            })(this));
        };

        Dropzone.prototype.enqueueFiles = function(files) {
            var file, _i, _len;
            for (_i = 0, _len = files.length; _i < _len; _i++) {
                file = files[_i];
                this.enqueueFile(file);
            }
            return null;
        };

        Dropzone.prototype.enqueueFile = function(file) {
            if (file.status === Dropzone.ADDED && file.accepted === true) {
                file.status = Dropzone.QUEUED;
                if (this.options.autoProcessQueue) {
                    return setTimeout(((function(_this) {
                        return function() {
                            return _this.processQueue();
                        };
                    })(this)), 0);
                }
            } else {
                throw new Error("This file can't be queued because it has already been processed or was rejected.");
            }
        };

        Dropzone.prototype._thumbnailQueue = [];

        Dropzone.prototype._processingThumbnail = false;

        Dropzone.prototype._enqueueThumbnail = function(file) {
            if (this.options.createImageThumbnails && file.type.match(/image.*/) && file.size <= this.options.maxThumbnailFilesize * 1024 * 1024) {
                this._thumbnailQueue.push(file);
                return setTimeout(((function(_this) {
                    return function() {
                        return _this._processThumbnailQueue();
                    };
                })(this)), 0);
            }
        };

        Dropzone.prototype._processThumbnailQueue = function() {
            if (this._processingThumbnail || this._thumbnailQueue.length === 0) {
                return;
            }
            this._processingThumbnail = true;
            return this.createThumbnail(this._thumbnailQueue.shift(), (function(_this) {
                return function() {
                    _this._processingThumbnail = false;
                    return _this._processThumbnailQueue();
                };
            })(this));
        };

        Dropzone.prototype.removeFile = function(file) {
            if (file.status === Dropzone.UPLOADING) {
                this.cancelUpload(file);
            }
            this.files = without(this.files, file);
            this.emit("removedfile", file);
            if (this.files.length === 0) {
                return this.emit("reset");
            }
        };

        Dropzone.prototype.removeAllFiles = function(cancelIfNecessary) {
            var file, _i, _len, _ref;
            if (cancelIfNecessary == null) {
                cancelIfNecessary = false;
            }
            _ref = this.files.slice();
            for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                file = _ref[_i];
                if (file.status !== Dropzone.UPLOADING || cancelIfNecessary) {
                    this.removeFile(file);
                }
            }
            return null;
        };

        Dropzone.prototype.createThumbnail = function(file, callback) {
            var fileReader;
            fileReader = new FileReader;
            fileReader.onload = (function(_this) {
                return function() {
                    if (file.type === "image/svg+xml") {
                        _this.emit("thumbnail", file, fileReader.result);
                        if (callback != null) {
                            callback();
                        }
                        return;
                    }
                    return _this.createThumbnailFromUrl(file, fileReader.result, callback);
                };
            })(this);
            return fileReader.readAsDataURL(file);
        };

        Dropzone.prototype.createThumbnailFromUrl = function(file, imageUrl, callback, crossOrigin) {
            var img;
            img = document.createElement("img");
            if (crossOrigin) {
                img.crossOrigin = crossOrigin;
            }
            img.onload = (function(_this) {
                return function() {
                    var canvas, ctx, resizeInfo, thumbnail, _ref, _ref1, _ref2, _ref3;
                    file.width = img.width;
                    file.height = img.height;
                    resizeInfo = _this.options.resize.call(_this, file);
                    if (resizeInfo.trgWidth == null) {
                        resizeInfo.trgWidth = resizeInfo.optWidth;
                    }
                    if (resizeInfo.trgHeight == null) {
                        resizeInfo.trgHeight = resizeInfo.optHeight;
                    }
                    canvas = document.createElement("canvas");
                    ctx = canvas.getContext("2d");
                    canvas.width = resizeInfo.trgWidth;
                    canvas.height = resizeInfo.trgHeight;
                    drawImageIOSFix(ctx, img, (_ref = resizeInfo.srcX) != null ? _ref : 0, (_ref1 = resizeInfo.srcY) != null ? _ref1 : 0, resizeInfo.srcWidth, resizeInfo.srcHeight, (_ref2 = resizeInfo.trgX) != null ? _ref2 : 0, (_ref3 = resizeInfo.trgY) != null ? _ref3 : 0, resizeInfo.trgWidth, resizeInfo.trgHeight);
                    thumbnail = canvas.toDataURL("image/png");
                    _this.emit("thumbnail", file, thumbnail);
                    if (callback != null) {
                        return callback();
                    }
                };
            })(this);
            if (callback != null) {
                img.onerror = callback;
            }
            return img.src = imageUrl;
        };

        Dropzone.prototype.processQueue = function() {
            var i, parallelUploads, processingLength, queuedFiles;
            parallelUploads = this.options.parallelUploads;
            processingLength = this.getUploadingFiles().length;
            i = processingLength;
            if (processingLength >= parallelUploads) {
                return;
            }
            queuedFiles = this.getQueuedFiles();
            if (!(queuedFiles.length > 0)) {
                return;
            }
            if (this.options.uploadMultiple) {
                return this.processFiles(queuedFiles.slice(0, parallelUploads - processingLength));
            } else {
                while (i < parallelUploads) {
                    if (!queuedFiles.length) {
                        return;
                    }
                    this.processFile(queuedFiles.shift());
                    i++;
                }
            }
        };

        Dropzone.prototype.processFile = function(file) {
            return this.processFiles([file]);
        };

        Dropzone.prototype.processFiles = function(files) {
            var file, _i, _len;
            for (_i = 0, _len = files.length; _i < _len; _i++) {
                file = files[_i];
                file.processing = true;
                file.status = Dropzone.UPLOADING;
                this.emit("processing", file);
            }
            if (this.options.uploadMultiple) {
                this.emit("processingmultiple", files);
            }
            return this.uploadFiles(files);
        };

        Dropzone.prototype._getFilesWithXhr = function(xhr) {
            var file, files;
            return files = (function() {
                var _i, _len, _ref, _results;
                _ref = this.files;
                _results = [];
                for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                    file = _ref[_i];
                    if (file.xhr === xhr) {
                        _results.push(file);
                    }
                }
                return _results;
            }).call(this);
        };

        Dropzone.prototype.cancelUpload = function(file) {
            var groupedFile, groupedFiles, _i, _j, _len, _len1, _ref;
            if (file.status === Dropzone.UPLOADING) {
                groupedFiles = this._getFilesWithXhr(file.xhr);
                for (_i = 0, _len = groupedFiles.length; _i < _len; _i++) {
                    groupedFile = groupedFiles[_i];
                    groupedFile.status = Dropzone.CANCELED;
                }
                file.xhr.abort();
                for (_j = 0, _len1 = groupedFiles.length; _j < _len1; _j++) {
                    groupedFile = groupedFiles[_j];
                    this.emit("canceled", groupedFile);
                }
                if (this.options.uploadMultiple) {
                    this.emit("canceledmultiple", groupedFiles);
                }
            } else if ((_ref = file.status) === Dropzone.ADDED || _ref === Dropzone.QUEUED) {
                file.status = Dropzone.CANCELED;
                this.emit("canceled", file);
                if (this.options.uploadMultiple) {
                    this.emit("canceledmultiple", [file]);
                }
            }
            if (this.options.autoProcessQueue) {
                return this.processQueue();
            }
        };

        resolveOption = function() {
            var args, option;
            option = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
            if (typeof option === 'function') {
                return option.apply(this, args);
            }
            return option;
        };

        Dropzone.prototype.uploadFile = function(file) {
            return this.uploadFiles([file]);
        };

        Dropzone.prototype.uploadFiles = function(files) {
            var file, formData, handleError, headerName, headerValue, headers, i, input, inputName, inputType, key, method, option, progressObj, response, updateProgress, url, value, xhr, _i, _j, _k, _l, _len, _len1, _len2, _len3, _m, _ref, _ref1, _ref2, _ref3, _ref4, _ref5;
            xhr = new XMLHttpRequest();
            for (_i = 0, _len = files.length; _i < _len; _i++) {
                file = files[_i];
                file.xhr = xhr;
            }
            method = resolveOption(this.options.method, files);
            url = resolveOption(this.options.url, files);
            xhr.open(method, url, true);
            xhr.withCredentials = !!this.options.withCredentials;
            response = null;
            handleError = (function(_this) {
                return function() {
                    var _j, _len1, _results;
                    _results = [];
                    for (_j = 0, _len1 = files.length; _j < _len1; _j++) {
                        file = files[_j];
                        _results.push(_this._errorProcessing(files, response || _this.options.dictResponseError.replace("{{statusCode}}", xhr.status), xhr));
                    }
                    return _results;
                };
            })(this);
            updateProgress = (function(_this) {
                return function(e) {
                    var allFilesFinished, progress, _j, _k, _l, _len1, _len2, _len3, _results;
                    if (e != null) {
                        progress = 100 * e.loaded / e.total;
                        for (_j = 0, _len1 = files.length; _j < _len1; _j++) {
                            file = files[_j];
                            file.upload = {
                                progress: progress,
                                total: e.total,
                                bytesSent: e.loaded
                            };
                        }
                    } else {
                        allFilesFinished = true;
                        progress = 100;
                        for (_k = 0, _len2 = files.length; _k < _len2; _k++) {
                            file = files[_k];
                            if (!(file.upload.progress === 100 && file.upload.bytesSent === file.upload.total)) {
                                allFilesFinished = false;
                            }
                            file.upload.progress = progress;
                            file.upload.bytesSent = file.upload.total;
                        }
                        if (allFilesFinished) {
                            return;
                        }
                    }
                    _results = [];
                    for (_l = 0, _len3 = files.length; _l < _len3; _l++) {
                        file = files[_l];
                        _results.push(_this.emit("uploadprogress", file, progress, file.upload.bytesSent));
                    }
                    return _results;
                };
            })(this);
            xhr.onload = (function(_this) {
                return function(e) {
                    var _ref;
                    if (files[0].status === Dropzone.CANCELED) {
                        return;
                    }
                    if (xhr.readyState !== 4) {
                        return;
                    }
                    response = xhr.responseText;
                    if (xhr.getResponseHeader("content-type") && ~xhr.getResponseHeader("content-type").indexOf("application/json")) {
                        try {
                            response = JSON.parse(response);
                        } catch (_error) {
                            e = _error;
                            response = "Invalid JSON response from server.";
                        }
                    }
                    updateProgress();
                    if (!((200 <= (_ref = xhr.status) && _ref < 300))) {
                        return handleError();
                    } else {
                        return _this._finished(files, response, e);
                    }
                };
            })(this);
            xhr.onerror = (function(_this) {
                return function() {
                    if (files[0].status === Dropzone.CANCELED) {
                        return;
                    }
                    return handleError();
                };
            })(this);
            progressObj = (_ref = xhr.upload) != null ? _ref : xhr;
            progressObj.onprogress = updateProgress;
            headers = {
                "Accept": "application/json",
                "Cache-Control": "no-cache",
                "X-Requested-With": "XMLHttpRequest"
            };
            if (this.options.headers) {
                extend(headers, this.options.headers);
            }
            for (headerName in headers) {
                headerValue = headers[headerName];
                if (headerValue) {
                    xhr.setRequestHeader(headerName, headerValue);
                }
            }
            formData = new FormData();
            if (this.options.params) {
                _ref1 = this.options.params;
                for (key in _ref1) {
                    value = _ref1[key];
                    formData.append(key, value);
                }
            }
            for (_j = 0, _len1 = files.length; _j < _len1; _j++) {
                file = files[_j];
                this.emit("sending", file, xhr, formData);
            }
            if (this.options.uploadMultiple) {
                this.emit("sendingmultiple", files, xhr, formData);
            }
            if (this.element.tagName === "FORM") {
                _ref2 = this.element.querySelectorAll("input, textarea, select, button");
                for (_k = 0, _len2 = _ref2.length; _k < _len2; _k++) {
                    input = _ref2[_k];
                    inputName = input.getAttribute("name");
                    inputType = input.getAttribute("type");
                    if (input.tagName === "SELECT" && input.hasAttribute("multiple")) {
                        _ref3 = input.options;
                        for (_l = 0, _len3 = _ref3.length; _l < _len3; _l++) {
                            option = _ref3[_l];
                            if (option.selected) {
                                formData.append(inputName, option.value);
                            }
                        }
                    } else if (!inputType || ((_ref4 = inputType.toLowerCase()) !== "checkbox" && _ref4 !== "radio") || input.checked) {
                        formData.append(inputName, input.value);
                    }
                }
            }
            for (i = _m = 0, _ref5 = files.length - 1; 0 <= _ref5 ? _m <= _ref5 : _m >= _ref5; i = 0 <= _ref5 ? ++_m : --_m) {
                formData.append(this._getParamName(i), files[i], this._renameFilename(files[i].name));
            }
            return this.submitRequest(xhr, formData, files);
        };

        Dropzone.prototype.submitRequest = function(xhr, formData, files) {
            return xhr.send(formData);
        };

        Dropzone.prototype._finished = function(files, responseText, e) {
            var file, _i, _len;
            for (_i = 0, _len = files.length; _i < _len; _i++) {
                file = files[_i];
                file.status = Dropzone.SUCCESS;
                this.emit("success", file, responseText, e);
                this.emit("complete", file);
            }
            if (this.options.uploadMultiple) {
                this.emit("successmultiple", files, responseText, e);
                this.emit("completemultiple", files);
            }
            if (this.options.autoProcessQueue) {
                return this.processQueue();
            }
        };

        Dropzone.prototype._errorProcessing = function(files, message, xhr) {
            var file, _i, _len;
            for (_i = 0, _len = files.length; _i < _len; _i++) {
                file = files[_i];
                file.status = Dropzone.ERROR;
                this.emit("error", file, message, xhr);
                this.emit("complete", file);
            }
            if (this.options.uploadMultiple) {
                this.emit("errormultiple", files, message, xhr);
                this.emit("completemultiple", files);
            }
            if (this.options.autoProcessQueue) {
                return this.processQueue();
            }
        };

        return Dropzone;

    })(Emitter);

    Dropzone.version = "4.3.0";

    Dropzone.options = {};

    Dropzone.optionsForElement = function(element) {
        if (element.getAttribute("id")) {
            return Dropzone.options[camelize(element.getAttribute("id"))];
        } else {
            return void 0;
        }
    };

    Dropzone.instances = [];

    Dropzone.forElement = function(element) {
        if (typeof element === "string") {
            element = document.querySelector(element);
        }
        if ((element != null ? element.dropzone : void 0) == null) {
            throw new Error("No Dropzone found for given element. This is probably because you're trying to access it before Dropzone had the time to initialize. Use the `init` option to setup any additional observers on your Dropzone.");
        }
        return element.dropzone;
    };

    Dropzone.autoDiscover = true;

    Dropzone.discover = function() {
        var checkElements, dropzone, dropzones, _i, _len, _results;
        if (document.querySelectorAll) {
            dropzones = document.querySelectorAll(".dropzone");
        } else {
            dropzones = [];
            checkElements = function(elements) {
                var el, _i, _len, _results;
                _results = [];
                for (_i = 0, _len = elements.length; _i < _len; _i++) {
                    el = elements[_i];
                    if (/(^| )dropzone($| )/.test(el.className)) {
                        _results.push(dropzones.push(el));
                    } else {
                        _results.push(void 0);
                    }
                }
                return _results;
            };
            checkElements(document.getElementsByTagName("div"));
            checkElements(document.getElementsByTagName("form"));
        }
        _results = [];
        for (_i = 0, _len = dropzones.length; _i < _len; _i++) {
            dropzone = dropzones[_i];
            if (Dropzone.optionsForElement(dropzone) !== false) {
                _results.push(new Dropzone(dropzone));
            } else {
                _results.push(void 0);
            }
        }
        return _results;
    };

    Dropzone.blacklistedBrowsers = [/opera.*Macintosh.*version\/12/i];

    Dropzone.isBrowserSupported = function() {
        var capableBrowser, regex, _i, _len, _ref;
        capableBrowser = true;
        if (window.File && window.FileReader && window.FileList && window.Blob && window.FormData && document.querySelector) {
            if (!("classList" in document.createElement("a"))) {
                capableBrowser = false;
            } else {
                _ref = Dropzone.blacklistedBrowsers;
                for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                    regex = _ref[_i];
                    if (regex.test(navigator.userAgent)) {
                        capableBrowser = false;
                        continue;
                    }
                }
            }
        } else {
            capableBrowser = false;
        }
        return capableBrowser;
    };

    without = function(list, rejectedItem) {
        var item, _i, _len, _results;
        _results = [];
        for (_i = 0, _len = list.length; _i < _len; _i++) {
            item = list[_i];
            if (item !== rejectedItem) {
                _results.push(item);
            }
        }
        return _results;
    };

    camelize = function(str) {
        return str.replace(/[\-_](\w)/g, function(match) {
            return match.charAt(1).toUpperCase();
        });
    };

    Dropzone.createElement = function(string) {
        var div;
        div = document.createElement("div");
        div.innerHTML = string;
        return div.childNodes[0];
    };

    Dropzone.elementInside = function(element, container) {
        if (element === container) {
            return true;
        }
        while (element = element.parentNode) {
            if (element === container) {
                return true;
            }
        }
        return false;
    };

    Dropzone.getElement = function(el, name) {
        var element;
        if (typeof el === "string") {
            element = document.querySelector(el);
        } else if (el.nodeType != null) {
            element = el;
        }
        if (element == null) {
            throw new Error("Invalid `" + name + "` option provided. Please provide a CSS selector or a plain HTML element.");
        }
        return element;
    };

    Dropzone.getElements = function(els, name) {
        var e, el, elements, _i, _j, _len, _len1, _ref;
        if (els instanceof Array) {
            elements = [];
            try {
                for (_i = 0, _len = els.length; _i < _len; _i++) {
                    el = els[_i];
                    elements.push(this.getElement(el, name));
                }
            } catch (_error) {
                e = _error;
                elements = null;
            }
        } else if (typeof els === "string") {
            elements = [];
            _ref = document.querySelectorAll(els);
            for (_j = 0, _len1 = _ref.length; _j < _len1; _j++) {
                el = _ref[_j];
                elements.push(el);
            }
        } else if (els.nodeType != null) {
            elements = [els];
        }
        if (!((elements != null) && elements.length)) {
            throw new Error("Invalid `" + name + "` option provided. Please provide a CSS selector, a plain HTML element or a list of those.");
        }
        return elements;
    };

    Dropzone.confirm = function(question, accepted, rejected) {
        if (window.confirm(question)) {
            return accepted();
        } else if (rejected != null) {
            return rejected();
        }
    };

    Dropzone.isValidFile = function(file, acceptedFiles) {
        var baseMimeType, mimeType, validType, _i, _len;
        if (!acceptedFiles) {
            return true;
        }
        acceptedFiles = acceptedFiles.split(",");
        mimeType = file.type;
        baseMimeType = mimeType.replace(/\/.*$/, "");
        for (_i = 0, _len = acceptedFiles.length; _i < _len; _i++) {
            validType = acceptedFiles[_i];
            validType = validType.trim();
            if (validType.charAt(0) === ".") {
                if (file.name.toLowerCase().indexOf(validType.toLowerCase(), file.name.length - validType.length) !== -1) {
                    return true;
                }
            } else if (/\/\*$/.test(validType)) {
                if (baseMimeType === validType.replace(/\/.*$/, "")) {
                    return true;
                }
            } else {
                if (mimeType === validType) {
                    return true;
                }
            }
        }
        return false;
    };

    if (typeof jQuery !== "undefined" && jQuery !== null) {
        jQuery.fn.dropzone = function(options) {
            return this.each(function() {
                return new Dropzone(this, options);
            });
        };
    }

    if (typeof module !== "undefined" && module !== null) {
        module.exports = Dropzone;
    } else {
        window.Dropzone = Dropzone;
    }

    Dropzone.ADDED = "added";

    Dropzone.QUEUED = "queued";

    Dropzone.ACCEPTED = Dropzone.QUEUED;

    Dropzone.UPLOADING = "uploading";

    Dropzone.PROCESSING = Dropzone.UPLOADING;

    Dropzone.CANCELED = "canceled";

    Dropzone.ERROR = "error";

    Dropzone.SUCCESS = "success";


    /*

     Bugfix for iOS 6 and 7
     Source: http://stackoverflow.com/questions/11929099/html5-canvas-drawimage-ratio-bug-ios
     based on the work of https://github.com/stomita/ios-imagefile-megapixel
     */

    detectVerticalSquash = function(img) {
        var alpha, canvas, ctx, data, ey, ih, iw, py, ratio, sy;
        iw = img.naturalWidth;
        ih = img.naturalHeight;
        canvas = document.createElement("canvas");
        canvas.width = 1;
        canvas.height = ih;
        ctx = canvas.getContext("2d");
        ctx.drawImage(img, 0, 0);
        data = ctx.getImageData(0, 0, 1, ih).data;
        sy = 0;
        ey = ih;
        py = ih;
        while (py > sy) {
            alpha = data[(py - 1) * 4 + 3];
            if (alpha === 0) {
                ey = py;
            } else {
                sy = py;
            }
            py = (ey + sy) >> 1;
        }
        ratio = py / ih;
        if (ratio === 0) {
            return 1;
        } else {
            return ratio;
        }
    };

    drawImageIOSFix = function(ctx, img, sx, sy, sw, sh, dx, dy, dw, dh) {
        var vertSquashRatio;
        vertSquashRatio = detectVerticalSquash(img);
        return ctx.drawImage(img, sx, sy, sw, sh, dx, dy, dw, dh / vertSquashRatio);
    };


    /*
     * contentloaded.js
     *
     * Author: Diego Perini (diego.perini at gmail.com)
     * Summary: cross-browser wrapper for DOMContentLoaded
     * Updated: 20101020
     * License: MIT
     * Version: 1.2
     *
     * URL:
     * http://javascript.nwbox.com/ContentLoaded/
     * http://javascript.nwbox.com/ContentLoaded/MIT-LICENSE
     */

    contentLoaded = function(win, fn) {
        var add, doc, done, init, poll, pre, rem, root, top;
        done = false;
        top = true;
        doc = win.document;
        root = doc.documentElement;
        add = (doc.addEventListener ? "addEventListener" : "attachEvent");
        rem = (doc.addEventListener ? "removeEventListener" : "detachEvent");
        pre = (doc.addEventListener ? "" : "on");
        init = function(e) {
            if (e.type === "readystatechange" && doc.readyState !== "complete") {
                return;
            }
            (e.type === "load" ? win : doc)[rem](pre + e.type, init, false);
            if (!done && (done = true)) {
                return fn.call(win, e.type || e);
            }
        };
        poll = function() {
            var e;
            try {
                root.doScroll("left");
            } catch (_error) {
                e = _error;
                setTimeout(poll, 50);
                return;
            }
            return init("poll");
        };
        if (doc.readyState !== "complete") {
            if (doc.createEventObject && root.doScroll) {
                try {
                    top = !win.frameElement;
                } catch (_error) {}
                if (top) {
                    poll();
                }
            }
            doc[add](pre + "DOMContentLoaded", init, false);
            doc[add](pre + "readystatechange", init, false);
            return win[add](pre + "load", init, false);
        }
    };

    Dropzone._autoDiscoverFunction = function() {
        if (Dropzone.autoDiscover) {
            return Dropzone.discover();
        }
    };

    contentLoaded(window, Dropzone._autoDiscoverFunction);

}).call(this);

/*! Idle Timer - v1.0.1 - 2014-03-21
 * https://github.com/thorst/jquery-idletimer
 * Copyright (c) 2014 Paul Irish; Licensed MIT */
/*
 mousewheel (deprecated) -> IE6.0, Chrome, Opera, Safari
 DOMMouseScroll (deprecated) -> Firefox 1.0
 wheel (standard) -> Chrome 31, Firefox 17, IE9, Firefox Mobile 17.0

 //No need to use, use DOMMouseScroll
 MozMousePixelScroll -> Firefox 3.5, Firefox Mobile 1.0

 //Events
 WheelEvent -> see wheel
 MouseWheelEvent -> see mousewheel
 MouseScrollEvent -> Firefox 3.5, Firefox Mobile 1.0
 */
(function ($) {

    $.idleTimer = function (firstParam, elem) {
        var opts;
        if ( typeof firstParam === "object" ) {
            opts = firstParam;
            firstParam = null;
        } else if (typeof firstParam === "number") {
            opts = { timeout: firstParam };
            firstParam = null;
        }

        // element to watch
        elem = elem || document;

        // defaults that are to be stored as instance props on the elem
        opts = $.extend({
            idle: false,                // indicates if the user is idle
            timeout: 30000,             // the amount of time (ms) before the user is considered idle
            events: "mousemove keydown wheel DOMMouseScroll mousewheel mousedown touchstart touchmove MSPointerDown MSPointerMove" // define active events
        }, opts);

        var jqElem = $(elem),
            obj = jqElem.data("idleTimerObj") || {},

        /* (intentionally not documented)
         * Toggles the idle state and fires an appropriate event.
         * @return {void}
         */
            toggleIdleState = function (e) {

                var obj = $.data(elem, "idleTimerObj") || {};

                // toggle the state
                obj.idle = !obj.idle;

                // store toggle state date time
                obj.olddate = +new Date();

                // create a custom event, with state and name space
                var event = $.Event((obj.idle ? "idle" : "active") + ".idleTimer");

                // trigger event on object with elem and copy of obj
                $(elem).trigger(event, [elem, $.extend({}, obj), e]);
            },
            /**
             * Handle event triggers
             * @return {void}
             * @method event
             * @static
             */
            handleEvent = function (e) {

                var obj = $.data(elem, "idleTimerObj") || {};

                // this is already paused, ignore events for now
                if (obj.remaining != null) { return; }

                /*
                 mousemove is kinda buggy, it can be triggered when it should be idle.
                 Typically is happening between 115 - 150 milliseconds after idle triggered.
                 @psyafter & @kaellis report "always triggered if using modal (jQuery ui, with overlay)"
                 @thorst has similar issues on ios7 "after $.scrollTop() on text area"
                 */
                if (e.type === "mousemove") {
                    // if coord are same, it didn't move
                    if (e.pageX === obj.pageX && e.pageY === obj.pageY) {
                        return;
                    }
                    // if coord don't exist how could it move
                    if (typeof e.pageX === "undefined" && typeof e.pageY === "undefined") {
                        return;
                    }
                    // under 200 ms is hard to do, and you would have to stop, as continuous activity will bypass this
                    var elapsed = (+new Date()) - obj.olddate;
                    if (elapsed < 200) {
                        return;
                    }
                }

                // clear any existing timeout
                clearTimeout(obj.tId);

                // if the idle timer is enabled, flip
                if (obj.idle) {
                    toggleIdleState(e);
                }

                // store when user was last active
                obj.lastActive = +new Date();

                // update mouse coord
                obj.pageX = e.pageX;
                obj.pageY = e.pageY;

                // set a new timeout
                obj.tId = setTimeout(toggleIdleState, obj.timeout);

            },
            /**
             * Restore initial settings and restart timer
             * @return {void}
             * @method reset
             * @static
             */
            reset = function () {

                var obj = $.data(elem, "idleTimerObj") || {};

                // reset settings
                obj.idle = obj.idleBackup;
                obj.olddate = +new Date();
                obj.lastActive = obj.olddate;
                obj.remaining = null;

                // reset Timers
                clearTimeout(obj.tId);
                if (!obj.idle) {
                    obj.tId = setTimeout(toggleIdleState, obj.timeout);
                }

            },
            /**
             * Store remaining time, stop timer
             * You can pause from an idle OR active state
             * @return {void}
             * @method pause
             * @static
             */
            pause = function () {

                var obj = $.data(elem, "idleTimerObj") || {};

                // this is already paused
                if ( obj.remaining != null ) { return; }

                // define how much is left on the timer
                obj.remaining = obj.timeout - ((+new Date()) - obj.olddate);

                // clear any existing timeout
                clearTimeout(obj.tId);
            },
            /**
             * Start timer with remaining value
             * @return {void}
             * @method resume
             * @static
             */
            resume = function () {

                var obj = $.data(elem, "idleTimerObj") || {};

                // this isn't paused yet
                if ( obj.remaining == null ) { return; }

                // start timer
                if ( !obj.idle ) {
                    obj.tId = setTimeout(toggleIdleState, obj.remaining);
                }

                // clear remaining
                obj.remaining = null;
            },
            /**
             * Stops the idle timer. This removes appropriate event handlers
             * and cancels any pending timeouts.
             * @return {void}
             * @method destroy
             * @static
             */
            destroy = function () {

                var obj = $.data(elem, "idleTimerObj") || {};

                //clear any pending timeouts
                clearTimeout(obj.tId);

                //Remove data
                jqElem.removeData("idleTimerObj");

                //detach the event handlers
                jqElem.off("._idleTimer");
            },
            /**
             * Returns the time until becoming idle
             * @return {number}
             * @method remainingtime
             * @static
             */
            remainingtime = function () {

                var obj = $.data(elem, "idleTimerObj") || {};

                //If idle there is no time remaining
                if ( obj.idle ) { return 0; }

                //If its paused just return that
                if ( obj.remaining != null ) { return obj.remaining; }

                //Determine remaining, if negative idle didn't finish flipping, just return 0
                var remaining = obj.timeout - ((+new Date()) - obj.lastActive);
                if (remaining < 0) { remaining = 0; }

                //If this is paused return that number, else return current remaining
                return remaining;
            };


        // determine which function to call
        if (firstParam === null && typeof obj.idle !== "undefined") {
            // they think they want to init, but it already is, just reset
            reset();
            return jqElem;
        } else if (firstParam === null) {
            // they want to init
        } else if (firstParam !== null && typeof obj.idle === "undefined") {
            // they want to do something, but it isnt init
            // not sure the best way to handle this
            return false;
        } else if (firstParam === "destroy") {
            destroy();
            return jqElem;
        } else if (firstParam === "pause") {
            pause();
            return jqElem;
        } else if (firstParam === "resume") {
            resume();
            return jqElem;
        } else if (firstParam === "reset") {
            reset();
            return jqElem;
        } else if (firstParam === "getRemainingTime") {
            return remainingtime();
        } else if (firstParam === "getElapsedTime") {
            return (+new Date()) - obj.olddate;
        } else if (firstParam === "getLastActiveTime") {
            return obj.lastActive;
        } else if (firstParam === "isIdle") {
            return obj.idle;
        }

        /* (intentionally not documented)
         * Handles a user event indicating that the user isn't idle. namespaced with internal idleTimer
         * @param {Event} event A DOM2-normalized event object.
         * @return {void}
         */
        jqElem.on($.trim((opts.events + " ").split(" ").join("._idleTimer ")), function (e) {
            handleEvent(e);
        });


        // Internal Object Properties, This isn't all necessary, but we
        // explicitly define all keys here so we know what we are working with
        obj = $.extend({}, {
            olddate : +new Date(),          // the last time state changed
            lastActive: +new Date(),       // the last time timer was active
            idle : opts.idle,               // current state
            idleBackup : opts.idle,         // backup of idle parameter since it gets modified
            timeout : opts.timeout,         // the interval to change state
            remaining : null,               // how long until state changes
            tId : null,                     // the idle timer setTimeout
            pageX : null,                   // used to store the mouse coord
            pageY : null
        });

        // set a timeout to toggle state. May wish to omit this in some situations
        if (!obj.idle) {
            obj.tId = setTimeout(toggleIdleState, obj.timeout);
        }

        // store our instance on the object
        $.data(elem, "idleTimerObj", obj);

        return jqElem;
    };

    // This allows binding to element
    $.fn.idleTimer = function (firstParam) {
        if (this[0]) {
            return $.idleTimer(firstParam, this[0]);
        }

        return this;
    };

})(jQuery);
/*global define:false */
/*
 * =======================
 * jQuery Timer Plugin
 * =======================
 * Start/Stop/Resume a time in any HTML element
 */

(function(root, factory) {
    if (typeof define === 'function' && define.amd) {
        define(['jquery'], factory);
    } else {
        factory(root.jQuery);
    }
}(this, function($) {
    // PRIVATE
    var options = {
            seconds: 0,									// default seconds value to start timer from
            editable: false,							// this will let users make changes to the time
            restart: false,								// this will enable stop or continue after a timer callback
            duration: null,								// duration to run callback after
            // callback to run after elapsed duration
            callback: function() {
                alert('Time up!');
            },
            startTimer: function() {},
            pauseTimer: function() {},
            resumeTimer: function() {},
            resetTimer: function() {},
            removeTimer: function() {},
            repeat: false,								// this will repeat callback every n times duration is elapsed
            countdown: false,							// if true, this will render the timer as a countdown if duration > 0
            format: null,								// this sets the format in which the time will be printed
            updateFrequency: 1000,						// How often should timer display update (default 500ms)
            state: 'running'
        },
        display = 'html',	// to be used as $el.html in case of div and $el.val in case of input type text
    // Constants for various states of the timer
        TIMER_STOPPED = 'stopped',
        TIMER_RUNNING = 'running',
        TIMER_PAUSED = 'paused';

    /**
     * Common function to start or resume a timer interval
     */
    function startTimerInterval(timer) {
        var element = timer.element;
        $(element).data('intr', setInterval(incrementSeconds.bind(timer), timer.options.updateFrequency));
        $(element).data('isTimerRunning', true);
    }

    /**
     * Common function to stop timer interval
     */
    function stopTimerInterval(timer) {
        clearInterval($(timer.element).data('intr'));
        $(timer.element).data('isTimerRunning', false);
    }

    /**
     * Increment total seconds by subtracting startTime from the current unix timestamp in seconds
     * and call render to display pretty time
     */
    function incrementSeconds() {
        $(this.element).data('totalSeconds', getUnixSeconds() - $(this.element).data('startTime'));
        render(this);

        // Check if totalSeconds is equal to duration if any
        if ($(this.element).data('duration') &&
            $(this.element).data('totalSeconds') % $(this.element).data('duration') === 0) {

            // If 'repeat' is not requested then disable the duration
            if (!this.options.repeat) {
                $(this.element).data('duration', null);
                this.options.duration = null;
            }

            // If this is a countdown, then end it as duration has completed
            if (this.options.countdown) {
                stopTimerInterval(this);
                this.options.countdown = false;
                $(this.element).data('state', TIMER_STOPPED);
            }

            // Run the default callback
            this.options.callback();
        }
    }

    /**
     * Render pretty time
     */
    function render(timer) {
        var element = timer.element,
            sec = $(element).data('totalSeconds');

        if (timer.options.countdown && ($(element).data('duration') > 0)) {
            sec = $(element).data('duration') - $(element).data('totalSeconds');
        }

        $(element)[display](secondsToTime(sec, timer));
        $(element).data('seconds', sec);
    }

    /**
     * Method to make timer field editable
     * This method hard binds focus & blur events to pause & resume
     * and recognizes built-in pretty time (for eg 12 sec OR 3:34 min)
     * It won't recognize user created formats.
     * Users may not always want this hard bound. In such a case,
     * do not use the editable property. Instead bind custom functions
     * to blur and focus.
     */
    function makeEditable(timer) {
        var element = timer.element;
        $(element).on('focus', function() {
            pauseTimer(timer);
        });

        $(element).on('blur', function() {
            // eg. 12 sec 3:34 min 12:30 min
            var val = $(element)[display](), valArr;

            if (val.indexOf('sec') > 0) {
                // sec
                $(element).data('totalSeconds', Number(val.replace(/\ssec/g, '')));
            } else if (val.indexOf('min') > 0) {
                // min
                val = val.replace(/\smin/g, '');
                valArr = val.split(':');
                $(element).data('totalSeconds', Number(valArr[0] * 60) + Number(valArr[1]));
            } else if (val.match(/\d{1,2}:\d{2}:\d{2}/)) {
                // hrs
                valArr = val.split(':');
                $(element).data('totalSeconds', Number(valArr[0] * 3600) + Number(valArr[1] * 60) + Number(valArr[2]));
            }

            resumeTimer(timer);
        });
    }

    /**
     * Get the current unix timestamp in seconds
     * @return {Number} [unix timestamp in seconds]
     */
    function getUnixSeconds() {
        return Math.round(new Date().getTime() / 1000);
    }

    /**
     * Convert a number of seconds into an object of hours, minutes and seconds
     * @param  {Number} sec [Number of seconds]
     * @return {Object}     [An object with hours, minutes and seconds representation of the given seconds]
     */
    function sec2TimeObj(sec) {
        var hours = 0, minutes = Math.floor(sec / 60), seconds;

        // Hours
        if (sec >= 3600) {
            hours = Math.floor(sec / 3600);
        }

        // Minutes
        if (sec >= 3600) {
            minutes = Math.floor(sec % 3600 / 60);
        }
        // Prepend 0 to minutes under 10
        if (minutes < 10 && hours > 0) {
            minutes = '0' + minutes;
        }
        // Seconds
        seconds = sec % 60;
        // Prepend 0 to seconds under 10
        if (seconds < 10 && (minutes > 0 || hours > 0)) {
            seconds = '0' + seconds;
        }

        return {
            hours: hours,
            minutes: minutes,
            seconds: seconds
        };
    }

    /**
     * Convert the given seconds to an object made up of hours, minutes and seconds and return a pretty display
     * @param  {Number} sec [Second to display as pretty time]
     * @return {String}     [Pretty time]
     */
    function secondsToTime(sec, timer) {
        var time = '',
            timeObj = sec2TimeObj(sec);

        if (timer.options.format) {
            var formatDef = [
                {identifier: '%h', value: timeObj.hours, pad: false},
                {identifier: '%m', value: timeObj.minutes, pad: false},
                {identifier: '%s', value: timeObj.seconds, pad: false},
                {identifier: '%H', value: parseInt(timeObj.hours), pad: true},
                {identifier: '%M', value: parseInt(timeObj.minutes), pad: true},
                {identifier: '%S', value: parseInt(timeObj.seconds), pad: true}
            ];
            time = timer.options.format;

            formatDef.forEach(function(format) {
                time = time.replace(
                    new RegExp(format.identifier.replace(/([.*+?^=!:${}()|\[\]\/\\])/g, '\\$1'), 'g'),
                    (format.pad) ? ((format.value < 10) ? '0' + format.value : format.value) : format.value
                );
            });
        } else {
            if (timeObj.hours) {
                time = timeObj.hours + ':' + timeObj.minutes + ':' + timeObj.seconds;
            } else {
                if (timeObj.minutes) {
                    time = timeObj.minutes + ':' + timeObj.seconds + ' min';
                } else {
                    time = timeObj.seconds + ' sec';
                }
            }
        }
        return time;
    }

    /**
     * Convert a string time like 5m30s to seconds
     * If a number (eg 300) is provided, then return as is
     * @param  {Number|String} time [The human time to convert to seconds]
     * @return {Number}      [Number of seconds]
     */
    function timeToSeconds(time) {
        // In case the passed arg is a number, then use that as number of seconds
        if (!isNaN(Number(time))) {
            return time;
        }

        var hMatch = time.match(/\d{1,2}h/),
            mMatch = time.match(/\d{1,2}m/),
            sMatch = time.match(/\d{1,2}s/),
            seconds = 0;

        time = time.toLowerCase();

        // @todo: throw an error in case of faulty time value like 5m61s or 61m
        if (hMatch) {
            seconds += Number(hMatch[0].replace('h', '')) * 3600;
        }

        if (mMatch) {
            seconds += Number(mMatch[0].replace('m', '')) * 60;
        }

        if (sMatch) {
            seconds += Number(sMatch[0].replace('s', ''));
        }

        return seconds;
    }

    // TIMER INTERFACE
    function startTimer(timer) {
        var element = timer.element;
        if (!$(element).data('isTimerRunning')) {
            render(timer);
            startTimerInterval(timer);
            $(element).data('state', TIMER_RUNNING);
            timer.options.startTimer.bind(timer).call();
        }
    }

    function pauseTimer(timer) {
        var element = timer.element;
        if ($(element).data('isTimerRunning')) {
            stopTimerInterval(timer);
            $(element).data('state', TIMER_PAUSED);
            timer.options.pauseTimer.bind(timer).call();
        }
    }

    function resumeTimer(timer) {
        var element = timer.element;
        if (!$(element).data('isTimerRunning')) {
            $(element).data('startTime', getUnixSeconds() - $(element).data('totalSeconds'));
            startTimerInterval(timer);
            $(element).data('state', TIMER_RUNNING);
            timer.options.resumeTimer.bind(timer).call();
        }
    }

    function resetTimer(timer) {
        var element = timer.element;
        $(element).data('startTime', 0);
        $(element).data('totalSeconds', 0);
        $(element).data('seconds', 0);
        $(element).data('state', TIMER_STOPPED);
        $(element).data('duration', timer.options.duration);
        timer.options.resetTimer.bind(timer).call();
    }

    function removeTimer(timer) {
        var element = timer.element;
        stopTimerInterval(timer);
        timer.options.removeTimer.bind(timer).call();
        $(element).data('plugin_' + pluginName, null);
        $(element).data('seconds', null);
        $(element).data('state', null);
        $(element)[display]('');
    }

    // TIMER PROTOTYPE
    var Timer = function(element, userOptions) {
        var elementType;

        this.options = options = $.extend(this.options, options, userOptions);
        this.element = element;

        // Setup total seconds from options.seconds (if any)
        $(element).data('totalSeconds', options.seconds);

        // Setup start time if seconds were provided
        $(element).data('startTime', getUnixSeconds() - $(element).data('totalSeconds'));

        $(element).data('seconds', $(element).data('totalSeconds'));
        $(element).data('state', TIMER_STOPPED);

        // Check if this is a input/textarea element or not
        elementType = $(element).prop('tagName').toLowerCase();
        if (elementType === 'input' || elementType === 'textarea') {
            display = 'val';
        }

        if (this.options.duration) {
            $(element).data('duration', timeToSeconds(this.options.duration));
            this.options.duration = timeToSeconds(this.options.duration);
        }

        if (this.options.editable) {
            makeEditable(this);
        }

    };

    /**
     * Initialize the plugin with public methods
     */
    Timer.prototype = {
        start: function() {
            startTimer(this);
        },

        pause: function() {
            pauseTimer(this);
        },

        resume: function() {
            resumeTimer(this);
        },

        reset: function() {
            resetTimer(this);
        },

        remove: function() {
            removeTimer(this);
        }
    };

    // INITIALIZE THE PLUGIN
    var pluginName = 'timer';
    $.fn[pluginName] = function(options) {
        options = options || 'start';

        return this.each(function() {
            /**
             * Allow the plugin to be initialized on an element only once
             * This way we can call the plugin's internal function
             * without having to reinitialize the plugin all over again.
             */
            if (!($.data(this, 'plugin_' + pluginName) instanceof Timer)) {

                /**
                 * Create a new data attribute on the element to hold the plugin name
                 * This way we can know which plugin(s) is/are initialized on the element later
                 */
                $.data(this, 'plugin_' + pluginName, new Timer(this, options));

            }

            /**
             * Use the instance of this plugin derived from the data attribute for this element
             * to conduct whatever action requested as a string parameter.
             */
            var instance = $.data(this, 'plugin_' + pluginName);

            /**
             * Provision for calling a function from this plugin
             * without initializing it all over again
             */
            if (typeof options === 'string') {
                if (typeof instance[options] === 'function') {
                    /*
                     Pass in 'instance' to provide for the value of 'this' in the called function
                     */
                    instance[options].call(instance);
                }
            }

            /**
             * Allow passing custom options object
             */
            if (typeof options === 'object') {
                if (instance.options.state === TIMER_RUNNING) {
                    instance.start.call(instance);
                } else {
                    render(instance);
                }
            }
        });
    };

}));

var $jq = jQuery.noConflict();
// Disable caching of AJAX responses
$jq.ajaxSetup ({
    cache: false
});

//Pad function
$jq.strPad = function(i,l,s) {
	var o = i.toString();
	if (!s) { s = '0'; }
	while (o.length < l) {
		o = o + s;
	}
	return o;
};

//Numeric check
function IsNumeric(sText){

	var ValidChars = "0123456789.";
	var IsNumber=true;
	var Char;

	for (i = 0; i < sText.length && IsNumber == true; i++){ 
		Char = sText.charAt(i); 
		if(ValidChars.indexOf(Char) == -1){
			IsNumber = false;
		}
	}

	return IsNumber; 
}

//Display a notification
function hs_msg(msg,sticky,classname){
	sticky = sticky || false;
	classname = classname || false;
	
	if(classname) $("hs_msg").addClassName(classname);
	
	var space = 20;
	//Set body of message, use sizer span to get exact width
	$("hs_msg").update(msg);
	
	//Center
	var w = innerWinSize();
	var toppos = (w.height - 41) + "px";
	$("hs_msg").setStyle({top: toppos}); //26px high box plus 10 padding plus 5 space at bottom
	
	//Show
	new Effect.Parallel([
		new Effect.Move("hs_msg", { sync: true, x: 0, y: -30, mode: 'relative' }),
		new Effect.Appear("hs_msg", { sync: true })
	], { 
	  duration: 0.8
	});
	//Hide
	if(!sticky){
		setTimeout(function(){
			Effect.Fade('hs_msg', { duration: 1.0, onComplete: function(){
				//Reset position as effect moves it
				$("hs_msg").setStyle({top: toppos});
				//Reset class
				if(classname) $("hs_msg").removeClassName(classname);
			} });
		},3000);
	}
}

//Submit the login form
function login_form_sub(){
	new Ajax.Request("admin.php?pg=ajax_gateway&action=logincheck", 
		{method:"post", 
		 parameters: {username:$F("popup_username"), password:$F("popup_password")},
		 onSuccess: function(){
		 	Tips.hideAll();
		 	$jq.colorbox.close();
		 	did_re_login = true;
		 }
		}
	);
	return false;
}

//Preload images
function preloadImages(){
  var cache = [];
  // Arguments are image paths relative to the current page.
    var args_len = arguments.length;
    for (var i = args_len; i--;) {
      var cacheImage = document.createElement('img');
      cacheImage.src = arguments[i];
      cache.push(cacheImage);
    }
}

//Is a var defined
function hs_isdefined(variable)
{
    return (typeof(window[variable]) == "undefined")?  false: true;
}

function is_wysiwyg(){
	return ( !(typeof(textboxio) == "undefined") && textboxio.getActiveEditor() !== null );
}

function focus_note_body(field){
	if(! is_wysiwyg()){
		Field.focus(field);
	}
}

function get_note_body(field){
	if(is_wysiwyg()){
		// use jquery to see if it's empty. By default textbox has html tags that causes it not be blank.
		return ($jq("<div/>").html(textboxio.getActiveEditor().content.get()).text().trim() != "") ? textboxio.getActiveEditor().content.get() : "";
	}else{
		return ($F(field) ? $F(field) : "");
	}
}

function set_note_body(field,content){
	if(is_wysiwyg()){
		return textboxio.getActiveEditor().content.set(content)
	}else{
		return $(field).value = content;
	}
}

function append_wysiwyg_note_body(field, content)
{
	return textboxio.getActiveEditor().content.set(get_note_body(field) + content)
}

// send to page
function goPage(src){
	window.location.href = src;	
}

//By using idle timers we prevent periodically executed events from barraging a server when the user is
//not actually using the system. This is especially helpful with users who use multiple browser tabs.
//Note, can't use window blur/focus due to wysiwyg & other irregularities
function hs_PeriodicalExecuter(name,user_function,timeout){
	//Global variable name
	var varname = 'helpspot_pe_' + name;

    // Run the function every 300 seconds
	window[varname] = setInterval(user_function, timeout * 1000);
	
	$jq(document).bind("idle.idleTimer", function(){
		clearInterval(window[varname]);
	});
	
	$jq(document).bind("active.idleTimer", function(){
		user_function(); //Cause actions to occur as soon as back active for responsiveness
		window[varname] = setInterval(user_function, timeout * 1000);
	});

	//If idle for 180 seconds then stop execution
	$jq.idleTimer(cHD_IDLE_TIMEOUT * 1000);
}

//Alert box
function hs_alert(txt,options){
	var options = Object.extend({
	  errorlist:	true,
	  title: 		lg_js_notification
	}, arguments[1] || { });
	var body = "";
	
	if(options.errorlist){
		var list = txt.split(/(\r\n|[\r\n])/);
		body = '<ul class="alert-error-list">';
		for(i=0;i<list.length;i++){
			if(trim(list[i]) != "") body = body + '<li>'+list[i]+'</li>';
		}
		body = body + '</ul>';
	}else{
		body = txt.replace(/(\r\n|[\r\n])/g, "<br />");
	}

	$jq.colorbox({width: "500px",
				  opacity: 0.40, 
				  transition: 'none',
				  close: button_ok,
				  html: '<div class="alert-body">'+ body + '</div>' + '<div class="alert-title">'+options.title+'</div>',
				  onComplete: function(){
				  		$jq("#alert-button-ok").focus();
				  	}
				  });	
}

//Confirm box
function hs_confirm(txt,action,options){
	var options = Object.extend({
	  title: 		lg_js_confirmation
	}, arguments[1] || { });
	
	$jq.colorbox({width: "500px",
				  opacity: 0.40, 
				  transition: 'none',
				  close: button_cancel,
				  html: '<div class="alert-confirm-body">'+ txt + '</div>' + '<div class="alert-title">'+options.title+'</div>' + '<div class="alert-button-group">'+ button_ok +'</div>',
				  onComplete: function(){
				  	//Execute function or else go to URL
				  	if($jq.type(action) === "function"){
				  		$jq("#alert-button-ok").click(action);
				  	}else{
				  		$jq("#alert-button-ok").click(function(){goPage(action);});
				  	}
				  	
				  	//Add closing action
				  	$jq("#alert-button-ok").click(function(){
				  		$jq.colorbox.close();
				  	});
				  	
				  	//Focus
				  	$jq("#alert-button-ok").focus();
				  }
				  });	
				  
	return false;			  
}

function kbui(bookid){
	$jq.colorbox({width: "90%",
				  fixed: true,
				  height: "90%",
				  opacity: 0.80, 
				  close: button_close,
				  href: "admin.php?pg=ajax_gateway&action=kbui&xBook=" + bookid + "&rand=" + ajaxRandomString(),
				  onComplete: function(){
				  	kbui_gettoc(bookid);
				  }
				  });	
}

function kbui_showpage(pageid){
	$jq("#kbui-page").html(ajaxLoading());
	$jq("#kbui-page").load("admin.php?pg=ajax_gateway&action=kbui-page&xPage="+pageid+"&xPortal="+$jq("#xPortal").val());
}

function kbui_gettoc(bookid){
	$jq("#kbui-toc").load("admin.php?pg=ajax_gateway&action=kbui-toc&xBook="+bookid, function(){
		folderUI("kbui-toc");
		$jq("#kbui-toc .kbui:first").click(); //load first page in this toc
	});
}

function aKBL(link,text){
	//If the tPost box exists in forums use that
	if($jq("#tPost").length){
		var elem = "tPost";
		var docpath = document.postform.tPost;
	}else{
		var elem = "tBody";
		var docpath = document.requestform.tBody;	
	}

	if(elem == 'tBody' && editor_type == "wysiwyg" && is_wysiwyg("tBody")){
		// tinyMCE.execInstanceCommand(elem,"mceInsertContent",false,"<a href=\""+link+"\">"+text+"</a>");
		textboxio.getActiveEditor().content.insertHtmlAtCursor("<a href=\""+link+"\">"+text+"</a>");
	}else if(elem == 'tBody' && editor_type == "markdown"){
		insertAtCursor(docpath, "["+text+"]("+link+")");
	}else{		
		insertAtCursor(docpath, link);
	}

	$jq.colorbox.close();

	return false;
}

function folderUI(wrap){
	//Init array of open folders
	var sidebarOpenFolders = (getCookie("sidebarOpenFolders") ? getCookie("sidebarOpenFolders").split(",") : []);	

	//Click handler for folders
	$$("#" + wrap + " .folder").each(function(folder){
		$(folder).observe("click", function(event){
			Event.stop(event);
			$$("."+this.id).each(function(elem){
				elem.toggle();
			});
			$$("#"+this.id+" span.arrow").each(function(elem){
				elem.toggleClassName("arrow-open");
			});
			
			//Remember state
			var loc = indexInArray(sidebarOpenFolders, this.id);
			if(loc == -1){
				sidebarOpenFolders.push(this.id);
			}else{
				sidebarOpenFolders.splice(loc, 1);
			}
			
			//Save state cookie
			var cdate = new Date ( 2020, 1, 1 );
			setCookie("sidebarOpenFolders", sidebarOpenFolders.join(","), cdate);
		});
	});
}

//Get the url hash
function getHash(){
  var hash = window.location.hash;
  return hash.substring(1); //remove the #
}

//Open new page in original win from popup
function targetopener(mylink, closeme, closeonly){
	if (! (window.focus && window.opener))return true;
	window.opener.focus();
	if (! closeonly)window.opener.location.href=mylink.href;
	if (closeme)window.close();
	return false;
}

//Open a window
//ex: <a href="javascript:openWin(\'admin.php?pg=user.image\',\'ImagePick\',\'height=500, width=500, scrollbars=yes, toolbar=no, location=no, status=yes\');">
function openWin(loc,name,options){
	window.open(loc, "", options);
}

function showPopWin(page,winh,winw,name){
	openWin(page,name,'height='+winh+',width='+winw+',scrollbars=yes,toolbar=no,location=no,status=no,resizable=yes');
}

//close window with delay 
function hsCloseWin(time){
	if(!time){
		time = 2;
	}
	
	setTimeout("window.close()",time*1000);
}

//sets times when using quick time select function
function qtSet(id,from,to){
	times = Form.Element.getValue(id);
	if(times != ""){
		v = Form.Element.getValue(id).split("|");
		$(from).value = v[0];
		$('from_da').update(v[1]);
		$(to).value = v[2];
		$('to_da').update(v[3]);
		if(v[4]){
			//Only override grouping if it's currently a date type (and not a date agg type)
			if($jq("#graph_grouping").val().search("date_") != -1 && $jq("#graph_grouping").val().search("date_agg") == -1) setSelectToValue("graph_grouping",v[4]);
		}
	}
}

//js sidebar search
function sidebarReqSearch(evt){
	evt.keyCode == 13 ? sidebarSearchAction("request") : evt;
}

function sidebarSearchAction(type){
	if(type == "request"){
		var q = trim($jq("#sidebar-q").val());
        var doFullText = ($jq("#doFullTextSearch").get(0).checked) ? 1 : 0;
		
		//If just a number, use as reqid else search
		if(IsNumeric(q)){
			goPage("admin.php?pg=request&reqid=" + q);
		}else{
			//Handle different search types
			var name = q.split(" ");
			if(q.search(/@/) > 0){
				var url = "admin.php?pg=ajax_gateway&action=sidebarsearch&doFullText="+eq(doFullText)+"&search_type=2&q="+eq(q)+"&anyall=all&sEmail="+eq(q)+"&rand="+ajaxRandomString();
			}else if(name.length > 1){ 
				var url = "admin.php?pg=ajax_gateway&action=sidebarsearch&doFullText="+eq(doFullText)+"&search_type=3&q="+eq(q)+"&anyall=all&sFirstName="+eq(name[0])+"&sLastName="+eq(name[1])+"&rand="+ajaxRandomString();
			}else{
				var url = "admin.php?pg=ajax_gateway&action=sidebarsearch&doFullText="+eq(doFullText)+"&search_type=1&q="+eq(q)+"&anyall=any&sUserId="+eq(q)+"&sFirstName="+eq(q)+"&sLastName="+eq(q)+"&sEmail="+eq(q)+"&rand="+ajaxRandomString();
			}
			
			hs_overlay({width:'90%',href:url});
		}
	}
}

//shortcut flag
var shortcutsON = true;

function hs_shortcutsOff(){
	shortcutsON = false;
}

function hs_shortcutsOn(){
	shortcutsON = true;
}
	
//Set Cookie
function setCookie(name,value,expires,path,domain,secure) {
    var cookieString = name + "=" +escape(value) +
       ( (expires) ? ";expires=" + expires.toGMTString() : "") +
       ( (path) ? ";path=" + path : "") +
       ( (domain) ? ";domain=" + domain : "") +
       ( (secure) ? ";secure" : "");
    document.cookie = cookieString;
} 

//Get Cookie
function getCookie(cookie_name) {
		var str     = document.cookie;
        var cookies = str.split(';');
        for (var i = cookies.length; i--;)
        {
          var parts = cookies[i].split('=');
          if (parts[0].substring(0,1) == ' ')
              parts[0] = parts[0].substring(1,parts[0].length);

          if (unescape(parts[0]) == cookie_name){
             return unescape(parts[1]);
             }
        }
        return '';
}    

//Trim extra whitespace
function trim(stringToTrim) {
	return $jq.trim(stringToTrim);
	//return stringToTrim.replace(/^\s+|\s+$/g,"");
}

//Set focus to field
function setFieldFocus(fld){
	if(fld){
		fld.focus();
	}
}

//Clear the filler text in a form element
function clearFocusFill(obj,text,newclass){
	if(obj.value == text) obj.value = "";
	if(newclass) Element.addClassName(obj.id,newclass);
}

//Checkbox row highlight
function checkRowHighlight(rid){
	if(document.getElementById(rid+"_box")){
		if(document.getElementById(rid+"_box").checked){
			document.getElementById(rid).className = "boldcheckboxrow";
		}else{
			document.getElementById(rid).className = "";
		}			
	}
}

//Loop over checkbox sets and make lines bold. use with above.
function onloadRowHighlight(pre,len)
{
	for(var i=0; i<len; i++){
		checkRowHighlight(pre + i);
	}
}	

// Check any rows that are already checked. See #364
function checkRows() {
  $jq.each($jq(".checkbox-menu").find("input:checked"), function() {
    rowChecked(this.value);
  });
}
//Highlight a table row
function rowChecked(reqid){
	row = $("tr-"+reqid);
	box = $(reqid + "_checkbox");
	
	if(box.checked){
		Element.addClassName(box,"checkedfilterrow");
		Element.addClassName(row,"checkedfilterrow");				
	}else{
		Element.removeClassName(box,"checkedfilterrow");
		Element.removeClassName(row,"checkedfilterrow");
	}	
	
	//Make sure any hidden buttons are shown
	$("batch_action_buttons").removeClassName("thin-disabled");
}

//Sort ordering
function reorder_call(id,type){
	var url = "admin.php";
	var pars = "pg=ajax_gateway&action="+type+"&" + Sortable.serialize(id,{name:"sortorder"}) + "&rand=" + ajaxRandomString();
	
	var call = new Ajax.Request(
		url, 
		{
			method: 	 "get", 
			parameters:  pars, 
			onComplete:  function(){ $$("#tablesort .sortable").each(function(elem){ new Effect.Highlight(elem,{duration:1.0,startcolor:"#DCE8D8",keepBackgroundImage:true}); }); }
		});			
}

//Given a value go through a form and find the ID
//Fields is an array for form elements (usually) from Form.getInputs("rsform_1", "checkbox");
function findIDbyValue(fields,value){
	for(i=0;i < fields.length;i++){
		if(fields[i].value == value) return fields[i].id;
	}
}

//Find the currently checked value in a radio button group
function getCheckedRadioButton(buttonGroup){
	for(var i = 0; i < buttonGroup.length; i++){
		if(buttonGroup[i].checked){
			return i;	
		}
	}
}

//Find the currently selected option
function getSelectVal(elem){
	return $(elem).options[$(elem).selectedIndex].value;
}

// Return the index of a particular value
function hs_indexOf(thearray,item) {
    for (var i = 0; i < thearray.length; i++) {
        if (thearray[i] == item) {
            return i;
        }
    }
    return -1;
}

// Return true if the value is in an array
function hs_inArray (value)
// Returns true if the passed value is found in the
// array.  Returns false if it is not.
{
	var i;
	for (i=0; i < this.length; i++) {
		// Matches identical (===), not just similar (==).
		if (this[i] === value) {
			return true;
		}
	}
	return false;
};

//Find index in an array
function indexInArray(theArray, theValue){
	var arLength = theArray.length;

	for(var i=0; i < arLength; i++){
		if(theArray[i] == theValue){
			return i;
		}
	}

	return -1;
}

// Add ability to pad a string
function hs_pad(str, chr, num, prepend) {
  for (var i=str.length; i<num; i++) {
    str = ((prepend) ? (chr + str) : (str + chr));
  }
  return str;
}

// Use this function in textbox to prevent enter from submitting the form, optionally do a click event
function noenter(e, click_elem) {
	if (!e) var e = window.event
	if (e.keyCode) code = e.keyCode;
	else if (e.which) code = e.which;
	
	if(click_elem){
		if(code == 13){ 
			$(click_elem).onclick();
			return false;
		}else{
			return true;
		}
	}else{
		return !(code == 13); 
	}
}

//Set a select list to a value if the value exists
function setSelectToValue(selectname,v,reset){
	list = $(selectname).options;
	
	if(typeof(reset) != 'undefined') list.selectedIndex = 0;
	
	if(list && v){
		for(i=0; i < list.length; i++){
			if(list[i].value == v){
				list.selectedIndex = i;
				break;
			}
		}
	}
}

//Set a select list to a value if the text exists
function setSelectByText(selectname,v){
	list = $(selectname).options;
	
	if(list && v){
		for(i=0; i < list.length; i++){
			if(list[i].text == v){
				list.selectedIndex = i;
				break;
			}
		}
	}
}

function help_toggle(page,from){
	var from = (from ? from : "");
	new Ajax.Updater('help_toggle_body', "admin.php?pg=ajax_gateway&action=help&page="+page+"&from="+from+"&rand=" + ajaxRandomString());	
}

// CHECK RECORDSET ALL
function checkUncheckRsAll(id) {
	
	$$("input[name^=checktable]").each(function(elem){
		$(elem).checked = $(elem).checked ? false : true;
		$(elem).onclick();
	});
			
	return true;
}

// END CHECK ALL

//CHECK ONLY A GROUP OF REQUESTS
function checkUncheckRequestGroup(grouping){
	var boxes = $$('input.'+grouping);
	if($('groupcheckbox_'+grouping).checked){
		boxes.each(function(box){
			if(box.checked == false) box.click();
		});
	}else{
		boxes.each(function(box){
			if(box.checked == true) box.click();
		});	
	}	
}

//Create the stream view
streamViewCurrent = 0;
function streamViewInit(reqid, mode){
	streamViewCurrent = reqid;
	
	$("streamViewBody").update("<div class='streamview_loading'><img src='"+static_path+"/css/shared/general/big-loader.gif' /></div>");
	$("streamViewTop_reqid").update("");
	
	$jq.colorbox({
    width: "90%",
    height: "90%",
    opacity: 0.80,
    close: button_close,
    html: $jq("#streamView").html(),
    onLoad:function(){
      $jq("#cboxClose").hide();
    }
	});

  // Hide the prev next from sidebarsearch
  if (mode == "sidebarsearch") {
    $jq("#colorbox").find("#overflow-buttons .next, #overflow-buttons .prev").hide()
  }
}

function streamViewPrev(end){
	//Find the type we're dealing with (link- or takeit-)
	if($jq("[id^=link-]").length){
		var s = 'link-';
	}else{
		var s = 'takeit-';
	}
	
	//Find all links
	var prev = $jq("[id^="+s+"]").first().attr("id").replace(s,"");
	$jq("[id^="+s+"]").each(function(index){
		//At end
		if(prev == streamViewCurrent){
			hs_alert(end);
			return false;
		}
		
		//Loop over and find previous link
		if($jq(this).attr("id") == s+streamViewCurrent){
			showOverflow(prev.replace(s,""));
			return false;
		}
		prev = $jq(this).attr("id");
	});
}

function streamViewNext(end){
	//Find the type we're dealing with (link- or takeit-)
	if($jq("[id^=link-]").length){
		var s = 'link-';
	}else{
		var s = 'takeit-';
	}
	
	//Find all links
	var next = $jq("[id^="+s+"]").last().attr("id").replace(s,"");
	$jq($jq("[id^="+s+"]").get().reverse()).each(function(index){
		//At end
		if(next == streamViewCurrent){
			hs_alert(end);
			return false;
		}
		
		//Loop over and find next link
		if($jq(this).attr("id") == s+streamViewCurrent){
			showOverflow(next.replace(s,""));
			return false;
		}
		next = $jq(this).attr("id");
	});
}

//show the note menu
function showNoteItemMenu(){
	if($jq("#"+this.id+" .note-stream-item-menubtn").length){
		$jq("#"+this.id+" .note-stream-item-menubtn").fadeIn("fast");
		
		new Tip(this.id+"-menubtn", $jq("#"+this.id+" .note-stream-item-menu").html(), {
				title: "",
				style: "darkgrey",
				delay: 0,
				showOn: "click",
				hideOn: false,
				hideAfter: 1,
				stem: "topMiddle",
				width: "auto",
				hook: { target: "bottomMiddle", tip: "topMiddle" },
				offset: { x: 0, y: 0 }
			});	
	}
}

function hideNoteItemMenu(){
	if(!$jq(".prototip").is(":visible")) $jq("#"+this.id+" .note-stream-item-menubtn").hide();
}

function ms_select(id,value,fieldname){
	var field = id + "-hidden";
	
	//Set class
	$(id).toggleClassName('select-multiple-selected');
	
	//Insert hidden field
	if(!$(field)){
		$(id).insert({after:'<input type="hidden" id="'+field+'" name="'+fieldname+'[]" value="'+ value + '" />'});
	}else{
		$(field).remove();
	}
}

function ms_select_all(prefix){
	$$("."+prefix+"-select-multiple a").each(function(e){
		if(!$(e.id + "-hidden")){
			e.onclick();
		}
	});
}

function ms_remove_all(prefix){
	$$("."+prefix+"-select-multiple a").each(function(e){
		if($(e.id + "-hidden")){
			e.onclick();
		}
	});
}

function ms_expand(prefix){
	$$("."+prefix+"-select-multiple")[0].setStyle({height:"500px"});
}

function yes_no_btn(type,id,val){
	if(type == "yes"){
		$(id+"-yes").addClassName("btn-selected");
		$(id+"-yes").removeClassName("btn-yes-no");
		$(id+"-no").addClassName("btn-yes-no");
		$(id+"-no").removeClassName("btn-selected");		
	}else{
		$(id+"-no").addClassName("btn-selected");
		$(id+"-no").removeClassName("btn-yes-no");
		$(id+"-yes").addClassName("btn-yes-no");
		$(id+"-yes").removeClassName("btn-selected");		
	}
	
	$(id).setValue(val);
}

function addFolder(def,slist){
	hs_overlay({href:"admin.php?pg=ajax_gateway&action=addfolder&default="+eq(def)+"&folder="+eq(slist),onComplete:function(){$jq("#new_folder").focus();}});
}

function add_folder_action(val,slist){
		foldername = val;
		folders   = $(slist).options;
		folderlen = folders.length;
		newoption = folderlen;

		$(slist).options[newoption]= new Option(foldername,foldername);
		$(slist).selectedIndex = newoption;
		
		$jq.colorbox.close();
}

function ttm_tip(id, txt){
	new Tip(id, txt, {
			title: "",
			style: "darkgrey",
			className: "hstinytip",
			border: 0, 
			radius: 0,
			showOn: "mouseover",
			hideOn: "mouseout",
			stem: "topMiddle",
			width: "auto",
			hook: { target: "bottomMiddle", tip: "topMiddle" }
		});	
}

function ttm_tip_fat(id, txt){
	new Tip(id, txt, {
			title: "",
			style: "darkgrey",
			className: "hstinytip",
			border: 0, 
			radius: 0,
			showOn: "mouseover",
			hideOn: "mouseout",
			stem: "topMiddle",
			width: "160px",
			hook: { target: "bottomMiddle", tip: "topMiddle" }
		});	
}

function showOverflow(reqid, mode){
	Tips.hideAll();

  // Set a flag to hide the prev/next if on the sidebar search.
  if ($jq("#colorbox #rsgroup_1").length === 1) {
    mode = "sidebarsearch"
  }
  
	streamViewInit(reqid, mode);

	//Insert reqid link

	var menubody = new Template('<a href="admin.php?pg=request&reqid=#{id}" id="streamViewReqLink" class="reqid-link" style="display: inline-block;">#{id}</a>');
	$("streamViewTop_reqid").update(menubody.evaluate({id:reqid}));	
	
	var url = "admin.php?pg=request.static&from_streamview=1&reqid=" + reqid + "&rand=" + ajaxRandomString();

	if ($jq("#" + parseInt(reqid) + "_checkbox").is(':checked')) {
		$jq(".js-select-request").addClass("checked");
	} else {
		$jq(".js-select-request").removeClass("checked").prop( "checked", false );
	}
	$jq(".js-select-request").on("click", function(e){
		$jq(".js-select-request").toggleClass("checked");
		$jq("#" + parseInt(reqid) + "_checkbox").trigger("click");
		return false;
	});

	//Do ajax call and update content div
	new Ajax.Updater('streamViewBody',url,{
		evalScripts:true
	});
}

function showHistoryEmailAndHeaders(reqhistid, field, title){
	if(field == "emailheaders"){
		var url = "admin.php?pg=ajax_gateway&action=emailheaders&reqhisid=" + reqhistid + "&rand=" + ajaxRandomString();
	}else{
		var url = "admin.php?pg=ajax_gateway&action=emailsource&reqhisid=" + reqhistid + "&rand=" + ajaxRandomString();
	}
	
	//Show content overlay
	hs_overlay({href:url,title:title});	
}

function simplemenu_action(action, id, mode){
	mode = typeof(mode) != 'undefined' ? mode : "menu";
	
	//Hide tips & quick menu icon
	if(mode != "triage") document.fire("hs_overlay:closed");
	
	//Perform action
	if(action == 'unread'){
		
		$("replied_img_"+id).onclick();
		
		new Effect.Highlight("tr-"+id,{duration:2.0, startcolor:'#ffffff', endcolor:'#ffff99'});
		
	}else if(action == 'trash'){
		
		$("tr-"+id).addClassName("tablerow-trash");
		
		new Ajax.Request(
		'admin.php?pg=ajax_gateway&action=simplemenu_trash', 
		{
			method: 	 "post", 
			parameters:  {reqid:id},
			onComplete: function(r){ 
				if(r.responseText != ""){ 
					hs_alert(r.responseText);  
				}else{
					new Effect.Highlight("tr-"+id,{duration:1.0, startcolor:'#FDDFD7', endcolor:'#D8B3AE', afterFinish:function(){$("tr-"+id).remove();}});
				
					//Move triage to next
					if(mode == "triage") triage_next();					
				}
			}
		});			
		
	}else if(action == 'spam'){
	
		$("tr-"+id).addClassName("tablerow-spam");
		
		new Ajax.Request(
		'admin.php?pg=ajax_gateway&action=simplemenu_spam', 
		{
			method: 	 "post", 
			parameters:  {reqid:id},
			onComplete: function(r){ 
				if(r.responseText != ""){
					hs_alert(r.responseText); 
					$("tr-"+id).removeClassName("tablerow-spam");
				}else{
					new Effect.Highlight("tr-"+id,{duration:1.0, startcolor:'#FDDFD7', endcolor:'#D8B3AE', afterFinish:function(){$("tr-"+id).remove();}});
				
					//Move triage to next
					if(mode == "triage") triage_next();				
				}
			}
		});		
		
	}
}

person_status_update_details_flag=false;
function person_status_update_details(xperson,spage,ftype,sdetails){
	if(!person_status_update_details_flag){
		var pars = "xPersonStatus=" + eq(xperson) + "&sPage=" + eq(spage) + "&fType=" + eq(ftype) + "&sDetails=" + eq(sdetails) + "&rand=" + ajaxRandomString();
		
		var call = new Ajax.Request(
			'admin.php?pg=ajax_gateway&action=person_status_details', 
			{
				method: 	 "post", 
				parameters:  pars
			});	
			
		person_status_update_details_flag = true;
	}
}

function showPersonStatusWorkspace(id,reqid){

	var call = new Ajax.Request(
		'admin.php?pg=ajax_gateway&action=person_status_workspace', 
		{
			method: 	 "get", 
			parameters:  {rand:ajaxRandomString(),reqid:reqid}, 
			onComplete:  function(){ 

							new Tip(id, arguments[0].responseText,{
									title: reqid,
									style: "darkgrey",
									showOn: "click",
                                    hideOn: { element: 'closeButton', event: 'click' },
									hideOthers: true,
									stem: "leftMiddle",
									width: 250,
									hook: { target: "rightMiddle", tip: "leftMiddle" },
									offset: { x: -5, y: 0 }
								});	
								
							$(id).prototip.show();
						 }
		});				
				
}

//Overlay window
function hs_overlay(){
	//Accept 1 arg with just options array or 2 with a body element ID plus options
	if($jq.type(arguments[0]) == "string"){
		var body = arguments[0];
		var options = arguments[1];
	}else{
		var body = false;
		var options = arguments[0];	
	}
	
	var options = Object.extend({
	  width:	false,
	  height:	false,
	  maxWidth:	"90%",
	  maxHeight:"90%",
	  innerWidth: false,
	  innerHeight: false,
	  onHide: 	false,
	  onComplete: false,
	  close: button_close,
	  href: false,
	  iframe: false,
	  html: (body ? $jq("#"+body).html() : false),
	  title:	""
	}, options || { });

	Tips.hideAll();	

	$jq.colorbox({title: options.title,
				  width: (options.innerWidth ? false : options.width),
				  height: (options.innerHeight ? false : options.height),
				  minWidth: "550", //3.0.5 added patched version of colorbox which supports this
				  maxWidth: options.maxWidth,
				  maxHeight: options.maxHeight,
				  innerWidth: options.innerWidth,
				  innerHeight: options.innerHeight,				  
				  opacity: 0.80, 
				  close: options.close,
				  href: options.href,
				  html: options.html,
				  iframe: options.iframe,
				  onComplete: options.onComplete,
				  onCleanup: options.onHide});
				  
	return false;	
}

function insertTemplates(tpl){
	//text
	if($("ta_"+tpl)) $(tpl).value = $F("ta_"+tpl);
	
	//html
	if($("ta_"+tpl+"_html")) $(tpl+"_html").value = $F("ta_"+tpl+"_html");
	if($("ta_"+tpl+"_HTML")) $(tpl+"_HTML").value = $F("ta_"+tpl+"_HTML"); //AUTO RESPONSE TEMPLATE
	
	//subject
	if($("ta_"+tpl+"_subject")) $(tpl+"_subject").value = $F("ta_"+tpl+"_subject");

	//Show save message
	$(tpl+"_savemsg").show();

	$jq.colorbox.close();
}

function rsQuickMenu(elem,reqid){
	var menubody = new Template($("menubtn_tmpl").innerHTML);
	var html = menubody.evaluate({id:reqid});				

	new Tip(elem, html, {
			title: "",
			style: "darkgrey",
			delay: 0,
			showOn: "click",
			hideOn: false,
			hideAfter: 1,
			stem: "topMiddle",
			width: "auto",
			hook: { target: "bottomMiddle", tip: "topMiddle" },
			offset: { x: 0, y: 0 }
		});		
}

function hs_hover(element,newclass){
	if(Element.hasClassName(element,newclass)){
		//Swap to old class
		Element.removeClassName(element,newclass);
	}else{
		//Swap to new class
		Element.addClassName(element,newclass);		
	}
}

function getElementPosition(elemID) {
    var offsetTrail = document.getElementById(elemID);
    var offsetLeft = 0;
    var offsetTop = 0;
    while (offsetTrail) {
        offsetLeft += offsetTrail.offsetLeft;
        offsetTop += offsetTrail.offsetTop;
        offsetTrail = offsetTrail.offsetParent;
    }
    if (navigator.userAgent.indexOf("Mac") != -1 && 
        typeof document.body.leftMargin != "undefined") {
        offsetLeft += document.body.leftMargin;
        offsetTop += document.body.topMargin;
    }
    return {left:offsetLeft, top:offsetTop};
}

function innerWinSize() {
  var myWidth = 0, myHeight = 0;
  if( typeof( window.innerWidth ) == 'number' ) {
    //Non-IE
    myWidth = window.innerWidth;
    myHeight = window.innerHeight;
  } else if( document.documentElement &&
      ( document.documentElement.clientWidth || document.documentElement.clientHeight ) ) {
    //IE 6+ in 'standards compliant mode'
    myWidth = document.documentElement.clientWidth;
    myHeight = document.documentElement.clientHeight;
  } else if( document.body && ( document.body.clientWidth || document.body.clientHeight ) ) {
    //IE 4 compatible
    myWidth = document.body.clientWidth;
    myHeight = document.body.clientHeight;
  }
  return {width:myWidth, height:myHeight};
  
}

// Do lookup for ajax custom fields
function custom_ajax_field_lookup(div,url,calling,loading){
	//Get request fields
	query = getRequestFields();
	
	//Adding calling field id
	query.set('callingField', calling);
	
	var pars = "pg=ajax_gateway&action=ajax_field_lookup&url=" + eq(url)+ "&" + query.toQueryString() + "&rand=" + ajaxRandomString();
	
	$(div).innerHTML = loading;
	$(div).show();	
	
	var call = new Ajax.Request(
		'admin.php', 
		{
			method: 	 "get", 
			parameters:  pars, 
			onComplete:  function(){ 
							$(div).innerHTML = arguments[0].responseText;
						 }
		});	
}

//Popup a LL result
function ll_popup(base){
	Tips.hideAll();	

	$jq.colorbox({minWidth: "550",		  
				  opacity: 0.80, 
				  close: button_close,
				  html: $jq(base).next().html()});
}

function ll_popup_move(num,end){
	if($jq('#ll_popup_'+num).length){
		$jq('#ll_popup_'+num).click();
	}else{
		hs_alert(end);
	}
}

// Get field values for all fields on the request page
function getRequestFields(){
	var req = $H();
	
	//Find any requests fields that may be available and send along, if no customer ID present we"re in an automation rule so send back empty
	if($("sUserId")){
		var req = $H({sUserId: eq($F("sUserId")),
				   sFirstName: eq($F("sFirstName")),
				   sLastName: eq($F("sLastName")),
				   sEmail: eq($F("sEmail")),
				   sPhone: eq($F("sPhone")),
				   xStatus: eq($F("xStatus")),
				   xCategory: eq($F("xCategory")),
				   xPersonAssignedTo: eq($F("xPersonAssignedTo"))});
		
		//Check for custom fields and send in available
		var forms = document.getElementsByTagName("form");
		for(i=0;i < forms.length;i++){
			var f = Form.getElements(document.forms[i]);
			for(e=0;e < f.length;e++){
				if(f[e].id.indexOf("Custom") !== -1 && f[e].id.indexOf("_") === -1){ 
					req.set(f[e].id, eq($F(f[e].id)) );
				}
			}
		}
	}
	
	return req;
}

// HELPSPOT SPECIAL EFFECTS
HS_Effects = {	
	RsSetOrder: function(table,sortdiv){
		Element.hide(table);
		Element.show(sortdiv);
	},
	
	RsReturnSetOrder: function(url){
		goPage(url);
	}
};
// HELPSPOT SPECIAL EFFECTS

// AJAX HELPERS
function ajaxError(){

}

function ajaxLoadingImg(){
	return '<img src="'+static_path+'/css/shared/general/big-loader.gif" />';
}

function ajaxLoading(loading){
	return '<div class="inline_loading">'+ajaxLoadingImg()+'</div>';
}

//IE seems to cache ajax calls, this makes the URL unique
function ajaxRandomString(){
	var chars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXTZabcdefghiklmnopqrstuvwxyz";
	var string_length = 8;
	var randomstring = '';
	for (var i=0; i<string_length; i++) {
			var rnum = Math.floor(Math.random() * chars.length);
			randomstring += chars.substring(rnum,rnum+1);
	}
	
	return randomstring.toString();
}

//Show spinning thingy for ajax requests
var login_box_active = false;
var ajaxHandlers = {
	onCreate: function(){
		//new Effect.Appear('ajaxFeedback');
	},
	
	onComplete: function(response, transport){
		//if(!Ajax || Ajax.activeRequestCount <= 0){
		//	Element.hide('ajaxFeedback');
		//}
		
		//Handle session timeout
		if(response.getHeader("X-HelpSpot-Session") == "Expired" && !$("colorbox").visible()){
			hs_overlay("login-box", {title:lg_sessionexpired,width: '500px'});
			login_box_active = true;
		}		
	}
};

//Add a selected item from a drop down list to a sortable div list
function addSortableColumn(select_list,sortable_vars,hidden_var,editable,colorselect){
	var listObj = $(select_list);
	
	if(listObj.options){
		if(listObj.selectedIndex != 0){
			var txt = listObj.options[listObj.selectedIndex].text;
			//Sometimes a width value is passed in as well
			if(listObj.options[listObj.selectedIndex].value.indexOf('@@@') !== -1){
				var item = listObj.options[listObj.selectedIndex].value.split('@@@');
				var val = item[0];
				var width = (item[1] ? item[1] : "");
				var hideflow = (item[2] == 'hideflow' ? 'overflowMsg' : 'setColumnWidth');
			}else{
				var val = $F(select_list);
			}		
			var selected = listObj.selectedIndex;
			
			listObj.selectedIndex = 0;
			listObj.options[selected] = null;
		}
	}else{
		var txt = listObj.value;
		var val = eq(listObj.value); //URL encode for placement in hidden field
	}

	var colorid = Math.floor(Math.random() * 2000000000);
	
	var newDiv = Builder.node("div", {id: select_list + "_" + val, className: "sortable_filter", style: "display:none;"}, 
								[Builder.node("img", {src: static_path+"/img/remove2.gif", onClick: "return confirmRemove(\'"+select_list+"_"+val+"\', confirmListDelete);", style: "vertical-align: middle;cursor:pointer;"}),
								" ",
								Builder.node("img", {src: static_path+"/img/drag.gif", className: "drag_handle", style: "vertical-align: middle;cursor:move;"}),
								" ",
								(editable ? Builder.node("img", {src: static_path+"/img/space.gif", width:"16px", height:"16px", style: "vertical-align: middle;cursor:pointer;"}) : ""),
								" - ",
								Builder.node("span", {id: select_list + "_" + val + "_text"}, txt),
								(typeof(width) !== "undefined" ? Builder.node("span", {id: "column_width_" + val, className: "hand filter_width_text", onclick: hideflow+"('column_width_"+val+"');"}, (width !== "" ? width : Builder.node("img", {src:static_path+"/img/fillcol.gif"}))) : "" ),
								(typeof(width) !== "undefined" ? Builder.node("input", {type: "hidden", name: "column_width_" + val + "_value", id: "column_width_" + val + "_value", value: width}) : ""),
								Builder.node("input", {type: "hidden", name: hidden_var, value: val}),
								(typeof(colorselect) !== "undefined" ? Builder.node("input", {"class": "jscolor jscolor-small jscolor-right", "data-jscolor": "{required:false,hash:true}", name: "sListItemsColors[]", value: "", id:colorid}) : ""), //jscolor accepts values in the class attribute
								]
							);
	$(sortable_vars).appendChild(newDiv);
	Effect.Appear(newDiv.id);	

	//Setup JSColor if needed
	if(typeof(colorselect) !== "undefined"){
		var picker = new jscolor(document.getElementById(colorid),{required:false,hash:true,value:null});
	}	
	
	//Destroy original sortable and rebuild with new element
	Sortable.destroy(sortable_vars);
	Sortable.create(sortable_vars ,{tag:"div", constraint: "vertical"});	
}

//Helper for column width JS
function insertColumnWidth(id){
	var value = trim($F(id + "_textbox"));
	
	$(id).update( (value == "" ? "<img src=\""+static_path+"/img/fillcol.gif\" />" : value) );
	$(id + "_value").value = value;
	
	$(id).prototip.remove();
}	

//Fix safari bug where hidden form fields are not sent in reordered order
//Only for use in onsubmit
function safari_order_fix(fieldname, form){
	//Safari only
	if(navigator.appVersion.match(/Konqueror|Safari|KHTML/)){
		
		//Prototype knows correct order of hidden fields so get and create new set of fields
		var inputs = Form.getInputs(form, "hidden", fieldname);
		for(i=0;i<inputs.length;i++){
			new_fields = Builder.node("input", {type: "hidden", name: fieldname, value: inputs[i].value});
			$(form).appendChild(new_fields);
		}			
		
		//Find and remove all hidden form fields
		for(i=0;i<inputs.length;i++){
			Element.remove(inputs[i]);
		}	
	}
	
	return false;
}

//Stop a form entry if a particular form elment is not empty
function stopFormEnter(field){
	if($F(field) == ''){
		return true;
	}else{
		document.getElementById(field).focus();
		return false;	
	}			
}

//Encode string
function eq(string){
	return encodeURIComponent(string);
}

function confirmRemove(id, text){
	return hs_confirm(text,function(){Element.remove(id);});
}

//Insert in text area at cursor position - Copyright Alex King - Licensed LGPL
function insertAtCursor(myField, myValue) {
//IE support
if (document.selection) {
myField.focus();
sel = document.selection.createRange();
sel.text = myValue;
}
//MOZILLA/NETSCAPE support
else if (myField.selectionStart || myField.selectionStart == '0') {
var startPos = myField.selectionStart;
var endPos = myField.selectionEnd;
myField.value = myField.value.substring(0, startPos)
+ myValue
+ myField.value.substring(endPos, myField.value.length);
} else {
myField.value += myValue;
}
}

//Auto grow text areas 
function resize_all_textareas(){
	//If iPhone or iPod Touch then don't resize
	if(!RegExp("iPhone").test(navigator.userAgent) && !RegExp("iPod").test(navigator.userAgent)){
		var textareas=document.getElementsByTagName('textarea');
		for (var i=0;i<textareas.length;i++)
		{	
			//Apply resizing to all areas except the tbody type
			if(textareas[i].id != 'tBody') new ResizeableTextarea(textareas[i]);
		}
	}
}

ResizeableTextarea = Class.create();
ResizeableTextarea.prototype = {
    initialize: function(element, options) {
        this.element = $(element);
        this.size = parseFloat(this.element.getStyle('height') || '100');
        this.options = Object.extend({
            inScreen: true,
            resizeStep: 10,
            minHeight: this.size
        }, options || {});
        Event.observe(this.element, "keyup", this.resize.bindAsEventListener(this));
        if ( !this.options.inScreen ) {
            this.element.style.overflow = 'hidden';
        }
        this.element.setAttribute("wrap","virtual");
        this.resize();
    },
    resize : function(){
        this.shrink();
        this.grow();
    },
    shrink : function(){
        if ( this.size <= this.options.minHeight ){
            return;
        }
        if ( this.element.scrollHeight <= this.element.clientHeight) {
            this.size -= this.options.resizeStep;
            this.element.style.height = this.size+'px';
            this.shrink();
        }
    },
    grow : function(){
        if ( this.element.scrollHeight > this.element.clientHeight ) {
            if ( this.options.inScreen && (20 + this.element.offsetTop + this.element.clientHeight) > document.body.clientHeight ) {
                return;
            }
            this.size += (this.element.scrollHeight - this.element.clientHeight) + this.options.resizeStep;
            this.element.style.height = this.size+'px';
            this.grow();
        }
    }
}

//Cleans the timestamp for date (not datetime) fields
//An identical function is used in the portal helper for date fields
function calendar_clean_date(calendar){
	var id = calendar.params.inputField.id;
	
	//Create javscript date object of selected time
	var odate = new Date($(id).value * 1000);

	//Create a new date starting at midnight
	var ndate = new Date(odate.getFullYear(),odate.getMonth(),odate.getDate(),12,0,0); 

	//Set the modified date back to the ID
	$(id).value = (ndate.getTime()/1000);
}

//Show/hide a date field
function showhide_datefield(rowid){
	if($F(rowid + "_2") == "is" || $F(rowid + "_2") == "less_than" || $F(rowid + "_2") == "greater_than"){
		if($(rowid + "_3")) $(rowid + "_3").show();
		if($("calendar_date_" + rowid)) $("calendar_date_" + rowid).show();
		if($("datepick_" + rowid)) $("datepick_" + rowid).show();	
		if($("datepick_datetime_" + rowid)) $("datepick_datetime_" + rowid).show();	
	}else{
		if($(rowid + "_3")) $(rowid + "_3").hide();
		if($("calendar_date_" + rowid)) $("calendar_date_" + rowid).hide();
		if($("datepick_" + rowid)) $("datepick_" + rowid).hide();	
		if($("datepick_datetime_" + rowid)) $("datepick_datetime_" + rowid).hide();	
	}
}

var calc_row;
function do_min_calc() {
	var min;
	min=$("calc_days").value*60*24;
	min=min+($("calc_hours").value*60);
	$(calc_row).value=min;
}

//Note options table - request and merge request
var note_option_string = '<div id="@tabid"><table cellpadding="0" cellspacing="0" border="0" class="noteoptiontable"><tr class="noteoptionrow"><td class="noteoptiontab" width="145">@tabtext</td><td class="noteoptiontabexp" align="right">@tabexp</td></tr></table><table cellpadding="0" cellspacing="0" border="0" style="margin-bottom:0px;"><tr><td colspan="2" class="noteoptioninner" id="noteoptioninner_@tabid">@bodytext</td></tr></table></div>';

function validate_email(email) {
  // Regex from parsley.js
  var regExp = /^((([a-z]|\d|[!#\$%&'\*\+\-\/=\?\^_`{\|}~]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])+(\.([a-z]|\d|[!#\$%&'\*\+\-\/=\?\^_`{\|}~]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])+)*)|((\x22)((((\x20|\x09)*(\x0d\x0a))?(\x20|\x09)+)?(([\x01-\x08\x0b\x0c\x0e-\x1f\x7f]|\x21|[\x23-\x5b]|[\x5d-\x7e]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(\\([\x01-\x09\x0b\x0c\x0d-\x7f]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]))))*(((\x20|\x09)*(\x0d\x0a))?(\x20|\x09)+)?(\x22)))@((([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])*([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])))\.)+(([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])*([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])))$/i;
  if ( ! email) {
    return false;
  } else {
    return regExp.test(email);
  }
}

function showViewers(){

    $jq.get('admin.php?pg=ajax_gateway&action=get_request_viewers', function(data){
        var viewers = [];

        // list of all dom ID's with viewers
        $jq.each(data, function(index, value){
            viewers.push('viewing-'+index);
        });

        $jq.each(data, function(index, value){
            $jq("#viewing-"+index)
                .addClass('viewing-'+value.fType)
                .attr('onclick',"showPersonStatusWorkspace('viewing-"+index+"',"+index+");");
        });

        // Remove classes from any that weren't in result set
        $jq(".viewing").each(function(){
            if($jq.inArray(this.id,viewers) == -1){
                $jq(this).removeClass('viewing-2 viewing-1').removeAttr('onclick');
            }
        });
    },"json");
}

$jq(document).ready(function(){
	var checked = ($jq("input.canCheck:checked").length == $jq("input.canCheck").length);
	$jq(".check-all").prop("checked", checked);
	$jq(".check-all").on("change", function(e){
		$jq(".canCheck").prop("checked", $jq(this).prop("checked"));
	});
	$jq(".canCheck").on("change", function(e) {
		var checked = ($jq(".canCheck:checked").length == $jq(".canCheck").length);
		$jq(".check-all").prop("checked", checked);
	});
	$jq(".js-check-all").on("click", function(e){
		var checked = ! ($jq(".canCheck:checked").length == $jq(".canCheck").length);
		$jq(".canCheck").prop("checked", checked);
		return false;
	});
	$jq('.color-label').contrastColor();
});

// Request Pinning
$jq(document).on("click", "a.note-stream-item-pin", function(e){
	var id = $jq(this).data("id");
	$jq.ajax({
		method: "GET",
		url: "admin.php?pg=ajax_gateway&action=request_history_pin",
		data: { "xRequestHistory": id }
	})
		.done(function( msg ) {
			initRequestHistory();
		});
});

$jq.fn.contrastColor = function() {
	return this.each(function() {
		var bg = $jq(this).css('background-color');
		//use first opaque parent bg if element is transparent
		if(bg == 'transparent' || bg == 'rgba(0, 0, 0, 0)') {
			$jq(this).parents().each(function(){
				bg = $jq(this).css('background-color')
				if(bg != 'transparent' && bg != 'rgba(0, 0, 0, 0)') return false;
			});
			//exit if all parents are transparent
			if(bg == 'transparent' || bg == 'rgba(0, 0, 0, 0)') return false;
		}
		//get r,g,b and decide
		var rgb = bg.replace(/^(rgb|rgba)\(/,'').replace(/\)$/,'').replace(/\s/g,'').split(',');
		var yiq = ((rgb[0]*299)+(rgb[1]*587)+(rgb[2]*114))/1000;
		if(yiq >= 128) $jq(this).removeClass('light-color');
		else $jq(this).addClass('light-color');
	});
};

function addSlashes(str)
{
	return str.replace(/'/g, "\\'");
}
function removeSlashes(str)
{
	return str.replace(/\'/g, "'");
}
// script.aculo.us builder.js v1.9.0, Thu Dec 23 16:54:48 -0500 2010

// Copyright (c) 2005-2010 Thomas Fuchs (http://script.aculo.us, http://mir.aculo.us)
//
// script.aculo.us is freely distributable under the terms of an MIT-style license.
// For details, see the script.aculo.us web site: http://script.aculo.us/

var Builder = {
  NODEMAP: {
    AREA: 'map',
    CAPTION: 'table',
    COL: 'table',
    COLGROUP: 'table',
    LEGEND: 'fieldset',
    OPTGROUP: 'select',
    OPTION: 'select',
    PARAM: 'object',
    TBODY: 'table',
    TD: 'table',
    TFOOT: 'table',
    TH: 'table',
    THEAD: 'table',
    TR: 'table'
  },
  // note: For Firefox < 1.5, OPTION and OPTGROUP tags are currently broken,
  //       due to a Firefox bug
  node: function(elementName) {
    elementName = elementName.toUpperCase();

    // try innerHTML approach
    var parentTag = this.NODEMAP[elementName] || 'div';
    var parentElement = document.createElement(parentTag);
    try { // prevent IE "feature": http://dev.rubyonrails.org/ticket/2707
      parentElement.innerHTML = "<" + elementName + "></" + elementName + ">";
    } catch(e) {}
    var element = parentElement.firstChild || null;

    // see if browser added wrapping tags
    if(element && (element.tagName.toUpperCase() != elementName))
      element = element.getElementsByTagName(elementName)[0];

    // fallback to createElement approach
    if(!element) element = document.createElement(elementName);

    // abort if nothing could be created
    if(!element) return;

    // attributes (or text)
    if(arguments[1])
      if(this._isStringOrNumber(arguments[1]) ||
        (arguments[1] instanceof Array) ||
        arguments[1].tagName) {
          this._children(element, arguments[1]);
        } else {
          var attrs = this._attributes(arguments[1]);
          if(attrs.length) {
            try { // prevent IE "feature": http://dev.rubyonrails.org/ticket/2707
              parentElement.innerHTML = "<" +elementName + " " +
                attrs + "></" + elementName + ">";
            } catch(e) {}
            element = parentElement.firstChild || null;
            // workaround firefox 1.0.X bug
            if(!element) {
              element = document.createElement(elementName);
              for(attr in arguments[1])
                element[attr == 'class' ? 'className' : attr] = arguments[1][attr];
            }
            if(element.tagName.toUpperCase() != elementName)
              element = parentElement.getElementsByTagName(elementName)[0];
          }
        }

    // text, or array of children
    if(arguments[2])
      this._children(element, arguments[2]);

     return $(element);
  },
  _text: function(text) {
     return document.createTextNode(text);
  },

  ATTR_MAP: {
    'className': 'class',
    'htmlFor': 'for'
  },

  _attributes: function(attributes) {
    var attrs = [];
    for(attribute in attributes)
      attrs.push((attribute in this.ATTR_MAP ? this.ATTR_MAP[attribute] : attribute) +
          '="' + attributes[attribute].toString().escapeHTML().gsub(/"/,'&quot;') + '"');
    return attrs.join(" ");
  },
  _children: function(element, children) {
    if(children.tagName) {
      element.appendChild(children);
      return;
    }
    if(typeof children=='object') { // array can hold nodes and text
      children.flatten().each( function(e) {
        if(typeof e=='object')
          element.appendChild(e);
        else
          if(Builder._isStringOrNumber(e))
            element.appendChild(Builder._text(e));
      });
    } else
      if(Builder._isStringOrNumber(children))
        element.appendChild(Builder._text(children));
  },
  _isStringOrNumber: function(param) {
    return(typeof param=='string' || typeof param=='number');
  },
  build: function(html) {
    var element = this.node('div');
    $(element).update(html.strip());
    return element.down();
  },
  dump: function(scope) {
    if(typeof scope != 'object' && typeof scope != 'function') scope = window; //global scope

    var tags = ("A ABBR ACRONYM ADDRESS APPLET AREA B BASE BASEFONT BDO BIG BLOCKQUOTE BODY " +
      "BR BUTTON CAPTION CENTER CITE CODE COL COLGROUP DD DEL DFN DIR DIV DL DT EM FIELDSET " +
      "FONT FORM FRAME FRAMESET H1 H2 H3 H4 H5 H6 HEAD HR HTML I IFRAME IMG INPUT INS ISINDEX "+
      "KBD LABEL LEGEND LI LINK MAP MENU META NOFRAMES NOSCRIPT OBJECT OL OPTGROUP OPTION P "+
      "PARAM PRE Q S SAMP SCRIPT SELECT SMALL SPAN STRIKE STRONG STYLE SUB SUP TABLE TBODY TD "+
      "TEXTAREA TFOOT TH THEAD TITLE TR TT U UL VAR").split(/\s+/);

    tags.each( function(tag){
      scope[tag] = function() {
        return Builder.node.apply(Builder, [tag].concat($A(arguments)));
      };
    });
  }
};
// script.aculo.us effects.js v1.9.0, Thu Dec 23 16:54:48 -0500 2010

// Copyright (c) 2005-2010 Thomas Fuchs (http://script.aculo.us, http://mir.aculo.us)
// Contributors:
//  Justin Palmer (http://encytemedia.com/)
//  Mark Pilgrim (http://diveintomark.org/)
//  Martin Bialasinki
//
// script.aculo.us is freely distributable under the terms of an MIT-style license.
// For details, see the script.aculo.us web site: http://script.aculo.us/

// converts rgb() and #xxx to #xxxxxx format,
// returns self (or first argument) if not convertable
String.prototype.parseColor = function() {
  var color = '#';
  if (this.slice(0,4) == 'rgb(') {
    var cols = this.slice(4,this.length-1).split(',');
    var i=0; do { color += parseInt(cols[i]).toColorPart() } while (++i<3);
  } else {
    if (this.slice(0,1) == '#') {
      if (this.length==4) for(var i=1;i<4;i++) color += (this.charAt(i) + this.charAt(i)).toLowerCase();
      if (this.length==7) color = this.toLowerCase();
    }
  }
  return (color.length==7 ? color : (arguments[0] || this));
};

/*--------------------------------------------------------------------------*/

Element.collectTextNodes = function(element) {
  return $A($(element).childNodes).collect( function(node) {
    return (node.nodeType==3 ? node.nodeValue :
      (node.hasChildNodes() ? Element.collectTextNodes(node) : ''));
  }).flatten().join('');
};

Element.collectTextNodesIgnoreClass = function(element, className) {
  return $A($(element).childNodes).collect( function(node) {
    return (node.nodeType==3 ? node.nodeValue :
      ((node.hasChildNodes() && !Element.hasClassName(node,className)) ?
        Element.collectTextNodesIgnoreClass(node, className) : ''));
  }).flatten().join('');
};

Element.setContentZoom = function(element, percent) {
  element = $(element);
  element.setStyle({fontSize: (percent/100) + 'em'});
  if (Prototype.Browser.WebKit) window.scrollBy(0,0);
  return element;
};

Element.getInlineOpacity = function(element){
  return $(element).style.opacity || '';
};

Element.forceRerendering = function(element) {
  try {
    element = $(element);
    var n = document.createTextNode(' ');
    element.appendChild(n);
    element.removeChild(n);
  } catch(e) { }
};

/*--------------------------------------------------------------------------*/

var Effect = {
  _elementDoesNotExistError: {
    name: 'ElementDoesNotExistError',
    message: 'The specified DOM element does not exist, but is required for this effect to operate'
  },
  Transitions: {
    linear: Prototype.K,
    sinoidal: function(pos) {
      return (-Math.cos(pos*Math.PI)/2) + .5;
    },
    reverse: function(pos) {
      return 1-pos;
    },
    flicker: function(pos) {
      var pos = ((-Math.cos(pos*Math.PI)/4) + .75) + Math.random()/4;
      return pos > 1 ? 1 : pos;
    },
    wobble: function(pos) {
      return (-Math.cos(pos*Math.PI*(9*pos))/2) + .5;
    },
    pulse: function(pos, pulses) {
      return (-Math.cos((pos*((pulses||5)-.5)*2)*Math.PI)/2) + .5;
    },
    spring: function(pos) {
      return 1 - (Math.cos(pos * 4.5 * Math.PI) * Math.exp(-pos * 6));
    },
    none: function(pos) {
      return 0;
    },
    full: function(pos) {
      return 1;
    }
  },
  DefaultOptions: {
    duration:   1.0,   // seconds
    fps:        100,   // 100= assume 66fps max.
    sync:       false, // true for combining
    from:       0.0,
    to:         1.0,
    delay:      0.0,
    queue:      'parallel'
  },
  tagifyText: function(element) {
    var tagifyStyle = 'position:relative';
    if (Prototype.Browser.IE) tagifyStyle += ';zoom:1';

    element = $(element);
    $A(element.childNodes).each( function(child) {
      if (child.nodeType==3) {
        child.nodeValue.toArray().each( function(character) {
          element.insertBefore(
            new Element('span', {style: tagifyStyle}).update(
              character == ' ' ? String.fromCharCode(160) : character),
              child);
        });
        Element.remove(child);
      }
    });
  },
  multiple: function(element, effect) {
    var elements;
    if (((typeof element == 'object') ||
        Object.isFunction(element)) &&
       (element.length))
      elements = element;
    else
      elements = $(element).childNodes;

    var options = Object.extend({
      speed: 0.1,
      delay: 0.0
    }, arguments[2] || { });
    var masterDelay = options.delay;

    $A(elements).each( function(element, index) {
      new effect(element, Object.extend(options, { delay: index * options.speed + masterDelay }));
    });
  },
  PAIRS: {
    'slide':  ['SlideDown','SlideUp'],
    'blind':  ['BlindDown','BlindUp'],
    'appear': ['Appear','Fade']
  },
  toggle: function(element, effect, options) {
    element = $(element);
    effect  = (effect || 'appear').toLowerCase();
    
    return Effect[ Effect.PAIRS[ effect ][ element.visible() ? 1 : 0 ] ](element, Object.extend({
      queue: { position:'end', scope:(element.id || 'global'), limit: 1 }
    }, options || {}));
  }
};

Effect.DefaultOptions.transition = Effect.Transitions.sinoidal;

/* ------------- core effects ------------- */

Effect.ScopedQueue = Class.create(Enumerable, {
  initialize: function() {
    this.effects  = [];
    this.interval = null;
  },
  _each: function(iterator) {
    this.effects._each(iterator);
  },
  add: function(effect) {
    var timestamp = new Date().getTime();

    var position = Object.isString(effect.options.queue) ?
      effect.options.queue : effect.options.queue.position;

    switch(position) {
      case 'front':
        // move unstarted effects after this effect
        this.effects.findAll(function(e){ return e.state=='idle' }).each( function(e) {
            e.startOn  += effect.finishOn;
            e.finishOn += effect.finishOn;
          });
        break;
      case 'with-last':
        timestamp = this.effects.pluck('startOn').max() || timestamp;
        break;
      case 'end':
        // start effect after last queued effect has finished
        timestamp = this.effects.pluck('finishOn').max() || timestamp;
        break;
    }

    effect.startOn  += timestamp;
    effect.finishOn += timestamp;

    if (!effect.options.queue.limit || (this.effects.length < effect.options.queue.limit))
      this.effects.push(effect);

    if (!this.interval)
      this.interval = setInterval(this.loop.bind(this), 15);
  },
  remove: function(effect) {
    this.effects = this.effects.reject(function(e) { return e==effect });
    if (this.effects.length == 0) {
      clearInterval(this.interval);
      this.interval = null;
    }
  },
  loop: function() {
    var timePos = new Date().getTime();
    for(var i=0, len=this.effects.length;i<len;i++)
      this.effects[i] && this.effects[i].loop(timePos);
  }
});

Effect.Queues = {
  instances: $H(),
  get: function(queueName) {
    if (!Object.isString(queueName)) return queueName;

    return this.instances.get(queueName) ||
      this.instances.set(queueName, new Effect.ScopedQueue());
  }
};
Effect.Queue = Effect.Queues.get('global');

Effect.Base = Class.create({
  position: null,
  start: function(options) {
    if (options && options.transition === false) options.transition = Effect.Transitions.linear;
    this.options      = Object.extend(Object.extend({ },Effect.DefaultOptions), options || { });
    this.currentFrame = 0;
    this.state        = 'idle';
    this.startOn      = this.options.delay*1000;
    this.finishOn     = this.startOn+(this.options.duration*1000);
    this.fromToDelta  = this.options.to-this.options.from;
    this.totalTime    = this.finishOn-this.startOn;
    this.totalFrames  = this.options.fps*this.options.duration;

    this.render = (function() {
      function dispatch(effect, eventName) {
        if (effect.options[eventName + 'Internal'])
          effect.options[eventName + 'Internal'](effect);
        if (effect.options[eventName])
          effect.options[eventName](effect);
      }

      return function(pos) {
        if (this.state === "idle") {
          this.state = "running";
          dispatch(this, 'beforeSetup');
          if (this.setup) this.setup();
          dispatch(this, 'afterSetup');
        }
        if (this.state === "running") {
          pos = (this.options.transition(pos) * this.fromToDelta) + this.options.from;
          this.position = pos;
          dispatch(this, 'beforeUpdate');
          if (this.update) this.update(pos);
          dispatch(this, 'afterUpdate');
        }
      };
    })();

    this.event('beforeStart');
    if (!this.options.sync)
      Effect.Queues.get(Object.isString(this.options.queue) ?
        'global' : this.options.queue.scope).add(this);
  },
  loop: function(timePos) {
    if (timePos >= this.startOn) {
      if (timePos >= this.finishOn) {
        this.render(1.0);
        this.cancel();
        this.event('beforeFinish');
        if (this.finish) this.finish();
        this.event('afterFinish');
        return;
      }
      var pos   = (timePos - this.startOn) / this.totalTime,
          frame = (pos * this.totalFrames).round();
      if (frame > this.currentFrame) {
        this.render(pos);
        this.currentFrame = frame;
      }
    }
  },
  cancel: function() {
    if (!this.options.sync)
      Effect.Queues.get(Object.isString(this.options.queue) ?
        'global' : this.options.queue.scope).remove(this);
    this.state = 'finished';
  },
  event: function(eventName) {
    if (this.options[eventName + 'Internal']) this.options[eventName + 'Internal'](this);
    if (this.options[eventName]) this.options[eventName](this);
  },
  inspect: function() {
    var data = $H();
    for(property in this)
      if (!Object.isFunction(this[property])) data.set(property, this[property]);
    return '#<Effect:' + data.inspect() + ',options:' + $H(this.options).inspect() + '>';
  }
});

Effect.Parallel = Class.create(Effect.Base, {
  initialize: function(effects) {
    this.effects = effects || [];
    this.start(arguments[1]);
  },
  update: function(position) {
    this.effects.invoke('render', position);
  },
  finish: function(position) {
    this.effects.each( function(effect) {
      effect.render(1.0);
      effect.cancel();
      effect.event('beforeFinish');
      if (effect.finish) effect.finish(position);
      effect.event('afterFinish');
    });
  }
});

Effect.Tween = Class.create(Effect.Base, {
  initialize: function(object, from, to) {
    object = Object.isString(object) ? $(object) : object;
    var args = $A(arguments), method = args.last(),
      options = args.length == 5 ? args[3] : null;
    this.method = Object.isFunction(method) ? method.bind(object) :
      Object.isFunction(object[method]) ? object[method].bind(object) :
      function(value) { object[method] = value };
    this.start(Object.extend({ from: from, to: to }, options || { }));
  },
  update: function(position) {
    this.method(position);
  }
});

Effect.Event = Class.create(Effect.Base, {
  initialize: function() {
    this.start(Object.extend({ duration: 0 }, arguments[0] || { }));
  },
  update: Prototype.emptyFunction
});

Effect.Opacity = Class.create(Effect.Base, {
  initialize: function(element) {
    this.element = $(element);
    if (!this.element) throw(Effect._elementDoesNotExistError);
    // make this work on IE on elements without 'layout'
    if (Prototype.Browser.IE && (!this.element.currentStyle.hasLayout))
      this.element.setStyle({zoom: 1});
    var options = Object.extend({
      from: this.element.getOpacity() || 0.0,
      to:   1.0
    }, arguments[1] || { });
    this.start(options);
  },
  update: function(position) {
    this.element.setOpacity(position);
  }
});

Effect.Move = Class.create(Effect.Base, {
  initialize: function(element) {
    this.element = $(element);
    if (!this.element) throw(Effect._elementDoesNotExistError);
    var options = Object.extend({
      x:    0,
      y:    0,
      mode: 'relative'
    }, arguments[1] || { });
    this.start(options);
  },
  setup: function() {
    this.element.makePositioned();
    this.originalLeft = parseFloat(this.element.getStyle('left') || '0');
    this.originalTop  = parseFloat(this.element.getStyle('top')  || '0');
    if (this.options.mode == 'absolute') {
      this.options.x = this.options.x - this.originalLeft;
      this.options.y = this.options.y - this.originalTop;
    }
  },
  update: function(position) {
    this.element.setStyle({
      left: (this.options.x  * position + this.originalLeft).round() + 'px',
      top:  (this.options.y  * position + this.originalTop).round()  + 'px'
    });
  }
});

// for backwards compatibility
Effect.MoveBy = function(element, toTop, toLeft) {
  return new Effect.Move(element,
    Object.extend({ x: toLeft, y: toTop }, arguments[3] || { }));
};

Effect.Scale = Class.create(Effect.Base, {
  initialize: function(element, percent) {
    this.element = $(element);
    if (!this.element) throw(Effect._elementDoesNotExistError);
    var options = Object.extend({
      scaleX: true,
      scaleY: true,
      scaleContent: true,
      scaleFromCenter: false,
      scaleMode: 'box',        // 'box' or 'contents' or { } with provided values
      scaleFrom: 100.0,
      scaleTo:   percent
    }, arguments[2] || { });
    this.start(options);
  },
  setup: function() {
    this.restoreAfterFinish = this.options.restoreAfterFinish || false;
    this.elementPositioning = this.element.getStyle('position');

    this.originalStyle = { };
    ['top','left','width','height','fontSize'].each( function(k) {
      this.originalStyle[k] = this.element.style[k];
    }.bind(this));

    this.originalTop  = this.element.offsetTop;
    this.originalLeft = this.element.offsetLeft;

    var fontSize = this.element.getStyle('font-size') || '100%';
    ['em','px','%','pt'].each( function(fontSizeType) {
      if (fontSize.indexOf(fontSizeType)>0) {
        this.fontSize     = parseFloat(fontSize);
        this.fontSizeType = fontSizeType;
      }
    }.bind(this));

    this.factor = (this.options.scaleTo - this.options.scaleFrom)/100;

    this.dims = null;
    if (this.options.scaleMode=='box')
      this.dims = [this.element.offsetHeight, this.element.offsetWidth];
    if (/^content/.test(this.options.scaleMode))
      this.dims = [this.element.scrollHeight, this.element.scrollWidth];
    if (!this.dims)
      this.dims = [this.options.scaleMode.originalHeight,
                   this.options.scaleMode.originalWidth];
  },
  update: function(position) {
    var currentScale = (this.options.scaleFrom/100.0) + (this.factor * position);
    if (this.options.scaleContent && this.fontSize)
      this.element.setStyle({fontSize: this.fontSize * currentScale + this.fontSizeType });
    this.setDimensions(this.dims[0] * currentScale, this.dims[1] * currentScale);
  },
  finish: function(position) {
    if (this.restoreAfterFinish) this.element.setStyle(this.originalStyle);
  },
  setDimensions: function(height, width) {
    var d = { };
    if (this.options.scaleX) d.width = width.round() + 'px';
    if (this.options.scaleY) d.height = height.round() + 'px';
    if (this.options.scaleFromCenter) {
      var topd  = (height - this.dims[0])/2;
      var leftd = (width  - this.dims[1])/2;
      if (this.elementPositioning == 'absolute') {
        if (this.options.scaleY) d.top = this.originalTop-topd + 'px';
        if (this.options.scaleX) d.left = this.originalLeft-leftd + 'px';
      } else {
        if (this.options.scaleY) d.top = -topd + 'px';
        if (this.options.scaleX) d.left = -leftd + 'px';
      }
    }
    this.element.setStyle(d);
  }
});

Effect.Highlight = Class.create(Effect.Base, {
  initialize: function(element) {
    this.element = $(element);
    if (!this.element) throw(Effect._elementDoesNotExistError);
    var options = Object.extend({ startcolor: '#ffff99' }, arguments[1] || { });
    this.start(options);
  },
  setup: function() {
    // Prevent executing on elements not in the layout flow
    if (this.element.getStyle('display')=='none') { this.cancel(); return; }
    // Disable background image during the effect
    this.oldStyle = { };
    if (!this.options.keepBackgroundImage) {
      this.oldStyle.backgroundImage = this.element.getStyle('background-image');
      this.element.setStyle({backgroundImage: 'none'});
    }
    if (!this.options.endcolor)
      this.options.endcolor = this.element.getStyle('background-color').parseColor('#ffffff');
    if (!this.options.restorecolor)
      this.options.restorecolor = this.element.getStyle('background-color');
    // init color calculations
    this._base  = $R(0,2).map(function(i){ return parseInt(this.options.startcolor.slice(i*2+1,i*2+3),16) }.bind(this));
    this._delta = $R(0,2).map(function(i){ return parseInt(this.options.endcolor.slice(i*2+1,i*2+3),16)-this._base[i] }.bind(this));
  },
  update: function(position) {
    this.element.setStyle({backgroundColor: $R(0,2).inject('#',function(m,v,i){
      return m+((this._base[i]+(this._delta[i]*position)).round().toColorPart()); }.bind(this)) });
  },
  finish: function() {
    this.element.setStyle(Object.extend(this.oldStyle, {
      backgroundColor: this.options.restorecolor
    }));
  }
});

Effect.ScrollTo = function(element) {
  var options = arguments[1] || { },
  scrollOffsets = document.viewport.getScrollOffsets(),
  elementOffsets = $(element).cumulativeOffset();

  if (options.offset) elementOffsets[1] += options.offset;

  return new Effect.Tween(null,
    scrollOffsets.top,
    elementOffsets[1],
    options,
    function(p){ scrollTo(scrollOffsets.left, p.round()); }
  );
};

/* ------------- combination effects ------------- */

Effect.Fade = function(element) {
  element = $(element);
  var oldOpacity = element.getInlineOpacity();
  var options = Object.extend({
    from: element.getOpacity() || 1.0,
    to:   0.0,
    afterFinishInternal: function(effect) {
      if (effect.options.to!=0) return;
      effect.element.hide().setStyle({opacity: oldOpacity});
    }
  }, arguments[1] || { });
  return new Effect.Opacity(element,options);
};

Effect.Appear = function(element) {
  element = $(element);
  var options = Object.extend({
  from: (element.getStyle('display') == 'none' ? 0.0 : element.getOpacity() || 0.0),
  to:   1.0,
  // force Safari to render floated elements properly
  afterFinishInternal: function(effect) {
    effect.element.forceRerendering();
  },
  beforeSetup: function(effect) {
    effect.element.setOpacity(effect.options.from).show();
  }}, arguments[1] || { });
  return new Effect.Opacity(element,options);
};

Effect.Puff = function(element) {
  element = $(element);
  var oldStyle = {
    opacity: element.getInlineOpacity(),
    position: element.getStyle('position'),
    top:  element.style.top,
    left: element.style.left,
    width: element.style.width,
    height: element.style.height
  };
  return new Effect.Parallel(
   [ new Effect.Scale(element, 200,
      { sync: true, scaleFromCenter: true, scaleContent: true, restoreAfterFinish: true }),
     new Effect.Opacity(element, { sync: true, to: 0.0 } ) ],
     Object.extend({ duration: 1.0,
      beforeSetupInternal: function(effect) {
        Position.absolutize(effect.effects[0].element);
      },
      afterFinishInternal: function(effect) {
         effect.effects[0].element.hide().setStyle(oldStyle); }
     }, arguments[1] || { })
   );
};

Effect.BlindUp = function(element) {
  element = $(element);
  element.makeClipping();
  return new Effect.Scale(element, 0,
    Object.extend({ scaleContent: false,
      scaleX: false,
      restoreAfterFinish: true,
      afterFinishInternal: function(effect) {
        effect.element.hide().undoClipping();
      }
    }, arguments[1] || { })
  );
};

Effect.BlindDown = function(element) {
  element = $(element);
  var elementDimensions = element.getDimensions();
  return new Effect.Scale(element, 100, Object.extend({
    scaleContent: false,
    scaleX: false,
    scaleFrom: 0,
    scaleMode: {originalHeight: elementDimensions.height, originalWidth: elementDimensions.width},
    restoreAfterFinish: true,
    afterSetup: function(effect) {
      effect.element.makeClipping().setStyle({height: '0px'}).show();
    },
    afterFinishInternal: function(effect) {
      effect.element.undoClipping();
    }
  }, arguments[1] || { }));
};

Effect.SwitchOff = function(element) {
  element = $(element);
  var oldOpacity = element.getInlineOpacity();
  return new Effect.Appear(element, Object.extend({
    duration: 0.4,
    from: 0,
    transition: Effect.Transitions.flicker,
    afterFinishInternal: function(effect) {
      new Effect.Scale(effect.element, 1, {
        duration: 0.3, scaleFromCenter: true,
        scaleX: false, scaleContent: false, restoreAfterFinish: true,
        beforeSetup: function(effect) {
          effect.element.makePositioned().makeClipping();
        },
        afterFinishInternal: function(effect) {
          effect.element.hide().undoClipping().undoPositioned().setStyle({opacity: oldOpacity});
        }
      });
    }
  }, arguments[1] || { }));
};

Effect.DropOut = function(element) {
  element = $(element);
  var oldStyle = {
    top: element.getStyle('top'),
    left: element.getStyle('left'),
    opacity: element.getInlineOpacity() };
  return new Effect.Parallel(
    [ new Effect.Move(element, {x: 0, y: 100, sync: true }),
      new Effect.Opacity(element, { sync: true, to: 0.0 }) ],
    Object.extend(
      { duration: 0.5,
        beforeSetup: function(effect) {
          effect.effects[0].element.makePositioned();
        },
        afterFinishInternal: function(effect) {
          effect.effects[0].element.hide().undoPositioned().setStyle(oldStyle);
        }
      }, arguments[1] || { }));
};

Effect.Shake = function(element) {
  element = $(element);
  var options = Object.extend({
    distance: 20,
    duration: 0.5
  }, arguments[1] || {});
  var distance = parseFloat(options.distance);
  var split = parseFloat(options.duration) / 10.0;
  var oldStyle = {
    top: element.getStyle('top'),
    left: element.getStyle('left') };
    return new Effect.Move(element,
      { x:  distance, y: 0, duration: split, afterFinishInternal: function(effect) {
    new Effect.Move(effect.element,
      { x: -distance*2, y: 0, duration: split*2,  afterFinishInternal: function(effect) {
    new Effect.Move(effect.element,
      { x:  distance*2, y: 0, duration: split*2,  afterFinishInternal: function(effect) {
    new Effect.Move(effect.element,
      { x: -distance*2, y: 0, duration: split*2,  afterFinishInternal: function(effect) {
    new Effect.Move(effect.element,
      { x:  distance*2, y: 0, duration: split*2,  afterFinishInternal: function(effect) {
    new Effect.Move(effect.element,
      { x: -distance, y: 0, duration: split, afterFinishInternal: function(effect) {
        effect.element.undoPositioned().setStyle(oldStyle);
  }}); }}); }}); }}); }}); }});
};

Effect.SlideDown = function(element) {
  element = $(element).cleanWhitespace();
  // SlideDown need to have the content of the element wrapped in a container element with fixed height!
  var oldInnerBottom = element.down().getStyle('bottom');
  var elementDimensions = element.getDimensions();
  return new Effect.Scale(element, 100, Object.extend({
    scaleContent: false,
    scaleX: false,
    scaleFrom: window.opera ? 0 : 1,
    scaleMode: {originalHeight: elementDimensions.height, originalWidth: elementDimensions.width},
    restoreAfterFinish: true,
    afterSetup: function(effect) {
      effect.element.makePositioned();
      effect.element.down().makePositioned();
      if (window.opera) effect.element.setStyle({top: ''});
      effect.element.makeClipping().setStyle({height: '0px'}).show();
    },
    afterUpdateInternal: function(effect) {
      effect.element.down().setStyle({bottom:
        (effect.dims[0] - effect.element.clientHeight) + 'px' });
    },
    afterFinishInternal: function(effect) {
      effect.element.undoClipping().undoPositioned();
      effect.element.down().undoPositioned().setStyle({bottom: oldInnerBottom}); }
    }, arguments[1] || { })
  );
};

Effect.SlideUp = function(element) {
  element = $(element).cleanWhitespace();
  var oldInnerBottom = element.down().getStyle('bottom');
  var elementDimensions = element.getDimensions();
  return new Effect.Scale(element, window.opera ? 0 : 1,
   Object.extend({ scaleContent: false,
    scaleX: false,
    scaleMode: 'box',
    scaleFrom: 100,
    scaleMode: {originalHeight: elementDimensions.height, originalWidth: elementDimensions.width},
    restoreAfterFinish: true,
    afterSetup: function(effect) {
      effect.element.makePositioned();
      effect.element.down().makePositioned();
      if (window.opera) effect.element.setStyle({top: ''});
      effect.element.makeClipping().show();
    },
    afterUpdateInternal: function(effect) {
      effect.element.down().setStyle({bottom:
        (effect.dims[0] - effect.element.clientHeight) + 'px' });
    },
    afterFinishInternal: function(effect) {
      effect.element.hide().undoClipping().undoPositioned();
      effect.element.down().undoPositioned().setStyle({bottom: oldInnerBottom});
    }
   }, arguments[1] || { })
  );
};

// Bug in opera makes the TD containing this element expand for a instance after finish
Effect.Squish = function(element) {
  return new Effect.Scale(element, window.opera ? 1 : 0, {
    restoreAfterFinish: true,
    beforeSetup: function(effect) {
      effect.element.makeClipping();
    },
    afterFinishInternal: function(effect) {
      effect.element.hide().undoClipping();
    }
  });
};

Effect.Grow = function(element) {
  element = $(element);
  var options = Object.extend({
    direction: 'center',
    moveTransition: Effect.Transitions.sinoidal,
    scaleTransition: Effect.Transitions.sinoidal,
    opacityTransition: Effect.Transitions.full
  }, arguments[1] || { });
  var oldStyle = {
    top: element.style.top,
    left: element.style.left,
    height: element.style.height,
    width: element.style.width,
    opacity: element.getInlineOpacity() };

  var dims = element.getDimensions();
  var initialMoveX, initialMoveY;
  var moveX, moveY;

  switch (options.direction) {
    case 'top-left':
      initialMoveX = initialMoveY = moveX = moveY = 0;
      break;
    case 'top-right':
      initialMoveX = dims.width;
      initialMoveY = moveY = 0;
      moveX = -dims.width;
      break;
    case 'bottom-left':
      initialMoveX = moveX = 0;
      initialMoveY = dims.height;
      moveY = -dims.height;
      break;
    case 'bottom-right':
      initialMoveX = dims.width;
      initialMoveY = dims.height;
      moveX = -dims.width;
      moveY = -dims.height;
      break;
    case 'center':
      initialMoveX = dims.width / 2;
      initialMoveY = dims.height / 2;
      moveX = -dims.width / 2;
      moveY = -dims.height / 2;
      break;
  }

  return new Effect.Move(element, {
    x: initialMoveX,
    y: initialMoveY,
    duration: 0.01,
    beforeSetup: function(effect) {
      effect.element.hide().makeClipping().makePositioned();
    },
    afterFinishInternal: function(effect) {
      new Effect.Parallel(
        [ new Effect.Opacity(effect.element, { sync: true, to: 1.0, from: 0.0, transition: options.opacityTransition }),
          new Effect.Move(effect.element, { x: moveX, y: moveY, sync: true, transition: options.moveTransition }),
          new Effect.Scale(effect.element, 100, {
            scaleMode: { originalHeight: dims.height, originalWidth: dims.width },
            sync: true, scaleFrom: window.opera ? 1 : 0, transition: options.scaleTransition, restoreAfterFinish: true})
        ], Object.extend({
             beforeSetup: function(effect) {
               effect.effects[0].element.setStyle({height: '0px'}).show();
             },
             afterFinishInternal: function(effect) {
               effect.effects[0].element.undoClipping().undoPositioned().setStyle(oldStyle);
             }
           }, options)
      );
    }
  });
};

Effect.Shrink = function(element) {
  element = $(element);
  var options = Object.extend({
    direction: 'center',
    moveTransition: Effect.Transitions.sinoidal,
    scaleTransition: Effect.Transitions.sinoidal,
    opacityTransition: Effect.Transitions.none
  }, arguments[1] || { });
  var oldStyle = {
    top: element.style.top,
    left: element.style.left,
    height: element.style.height,
    width: element.style.width,
    opacity: element.getInlineOpacity() };

  var dims = element.getDimensions();
  var moveX, moveY;

  switch (options.direction) {
    case 'top-left':
      moveX = moveY = 0;
      break;
    case 'top-right':
      moveX = dims.width;
      moveY = 0;
      break;
    case 'bottom-left':
      moveX = 0;
      moveY = dims.height;
      break;
    case 'bottom-right':
      moveX = dims.width;
      moveY = dims.height;
      break;
    case 'center':
      moveX = dims.width / 2;
      moveY = dims.height / 2;
      break;
  }

  return new Effect.Parallel(
    [ new Effect.Opacity(element, { sync: true, to: 0.0, from: 1.0, transition: options.opacityTransition }),
      new Effect.Scale(element, window.opera ? 1 : 0, { sync: true, transition: options.scaleTransition, restoreAfterFinish: true}),
      new Effect.Move(element, { x: moveX, y: moveY, sync: true, transition: options.moveTransition })
    ], Object.extend({
         beforeStartInternal: function(effect) {
           effect.effects[0].element.makePositioned().makeClipping();
         },
         afterFinishInternal: function(effect) {
           effect.effects[0].element.hide().undoClipping().undoPositioned().setStyle(oldStyle); }
       }, options)
  );
};

Effect.Pulsate = function(element) {
  element = $(element);
  var options    = arguments[1] || { },
    oldOpacity = element.getInlineOpacity(),
    transition = options.transition || Effect.Transitions.linear,
    reverser   = function(pos){
      return 1 - transition((-Math.cos((pos*(options.pulses||5)*2)*Math.PI)/2) + .5);
    };

  return new Effect.Opacity(element,
    Object.extend(Object.extend({  duration: 2.0, from: 0,
      afterFinishInternal: function(effect) { effect.element.setStyle({opacity: oldOpacity}); }
    }, options), {transition: reverser}));
};

Effect.Fold = function(element) {
  element = $(element);
  var oldStyle = {
    top: element.style.top,
    left: element.style.left,
    width: element.style.width,
    height: element.style.height };
  element.makeClipping();
  return new Effect.Scale(element, 5, Object.extend({
    scaleContent: false,
    scaleX: false,
    afterFinishInternal: function(effect) {
    new Effect.Scale(element, 1, {
      scaleContent: false,
      scaleY: false,
      afterFinishInternal: function(effect) {
        effect.element.hide().undoClipping().setStyle(oldStyle);
      } });
  }}, arguments[1] || { }));
};

Effect.Morph = Class.create(Effect.Base, {
  initialize: function(element) {
    this.element = $(element);
    if (!this.element) throw(Effect._elementDoesNotExistError);
    var options = Object.extend({
      style: { }
    }, arguments[1] || { });

    if (!Object.isString(options.style)) this.style = $H(options.style);
    else {
      if (options.style.include(':'))
        this.style = options.style.parseStyle();
      else {
        this.element.addClassName(options.style);
        this.style = $H(this.element.getStyles());
        this.element.removeClassName(options.style);
        var css = this.element.getStyles();
        this.style = this.style.reject(function(style) {
          return style.value == css[style.key];
        });
        options.afterFinishInternal = function(effect) {
          effect.element.addClassName(effect.options.style);
          effect.transforms.each(function(transform) {
            effect.element.style[transform.style] = '';
          });
        };
      }
    }
    this.start(options);
  },

  setup: function(){
    function parseColor(color){
      if (!color || ['rgba(0, 0, 0, 0)','transparent'].include(color)) color = '#ffffff';
      color = color.parseColor();
      return $R(0,2).map(function(i){
        return parseInt( color.slice(i*2+1,i*2+3), 16 );
      });
    }
    this.transforms = this.style.map(function(pair){
      var property = pair[0], value = pair[1], unit = null;

      if (value.parseColor('#zzzzzz') != '#zzzzzz') {
        value = value.parseColor();
        unit  = 'color';
      } else if (property == 'opacity') {
        value = parseFloat(value);
        if (Prototype.Browser.IE && (!this.element.currentStyle.hasLayout))
          this.element.setStyle({zoom: 1});
      } else if (Element.CSS_LENGTH.test(value)) {
          var components = value.match(/^([\+\-]?[0-9\.]+)(.*)$/);
          value = parseFloat(components[1]);
          unit = (components.length == 3) ? components[2] : null;
      }

      var originalValue = this.element.getStyle(property);
      return {
        style: property.camelize(),
        originalValue: unit=='color' ? parseColor(originalValue) : parseFloat(originalValue || 0),
        targetValue: unit=='color' ? parseColor(value) : value,
        unit: unit
      };
    }.bind(this)).reject(function(transform){
      return (
        (transform.originalValue == transform.targetValue) ||
        (
          transform.unit != 'color' &&
          (isNaN(transform.originalValue) || isNaN(transform.targetValue))
        )
      );
    });
  },
  update: function(position) {
    var style = { }, transform, i = this.transforms.length;
    while(i--)
      style[(transform = this.transforms[i]).style] =
        transform.unit=='color' ? '#'+
          (Math.round(transform.originalValue[0]+
            (transform.targetValue[0]-transform.originalValue[0])*position)).toColorPart() +
          (Math.round(transform.originalValue[1]+
            (transform.targetValue[1]-transform.originalValue[1])*position)).toColorPart() +
          (Math.round(transform.originalValue[2]+
            (transform.targetValue[2]-transform.originalValue[2])*position)).toColorPart() :
        (transform.originalValue +
          (transform.targetValue - transform.originalValue) * position).toFixed(3) +
            (transform.unit === null ? '' : transform.unit);
    this.element.setStyle(style, true);
  }
});

Effect.Transform = Class.create({
  initialize: function(tracks){
    this.tracks  = [];
    this.options = arguments[1] || { };
    this.addTracks(tracks);
  },
  addTracks: function(tracks){
    tracks.each(function(track){
      track = $H(track);
      var data = track.values().first();
      this.tracks.push($H({
        ids:     track.keys().first(),
        effect:  Effect.Morph,
        options: { style: data }
      }));
    }.bind(this));
    return this;
  },
  play: function(){
    return new Effect.Parallel(
      this.tracks.map(function(track){
        var ids = track.get('ids'), effect = track.get('effect'), options = track.get('options');
        var elements = [$(ids) || $$(ids)].flatten();
        return elements.map(function(e){ return new effect(e, Object.extend({ sync:true }, options)) });
      }).flatten(),
      this.options
    );
  }
});

Element.CSS_PROPERTIES = $w(
  'backgroundColor backgroundPosition borderBottomColor borderBottomStyle ' +
  'borderBottomWidth borderLeftColor borderLeftStyle borderLeftWidth ' +
  'borderRightColor borderRightStyle borderRightWidth borderSpacing ' +
  'borderTopColor borderTopStyle borderTopWidth bottom clip color ' +
  'fontSize fontWeight height left letterSpacing lineHeight ' +
  'marginBottom marginLeft marginRight marginTop markerOffset maxHeight '+
  'maxWidth minHeight minWidth opacity outlineColor outlineOffset ' +
  'outlineWidth paddingBottom paddingLeft paddingRight paddingTop ' +
  'right textIndent top width wordSpacing zIndex');

Element.CSS_LENGTH = /^(([\+\-]?[0-9\.]+)(em|ex|px|in|cm|mm|pt|pc|\%))|0$/;

String.__parseStyleElement = document.createElement('div');
String.prototype.parseStyle = function(){
  var style, styleRules = $H();
  if (Prototype.Browser.WebKit)
    style = new Element('div',{style:this}).style;
  else {
    String.__parseStyleElement.innerHTML = '<div style="' + this + '"></div>';
    style = String.__parseStyleElement.childNodes[0].style;
  }

  Element.CSS_PROPERTIES.each(function(property){
    if (style[property]) styleRules.set(property, style[property]);
  });

  if (Prototype.Browser.IE && this.include('opacity'))
    styleRules.set('opacity', this.match(/opacity:\s*((?:0|1)?(?:\.\d*)?)/)[1]);

  return styleRules;
};

if (document.defaultView && document.defaultView.getComputedStyle) {
  Element.getStyles = function(element) {
    var css = document.defaultView.getComputedStyle($(element), null);
    return Element.CSS_PROPERTIES.inject({ }, function(styles, property) {
      styles[property] = css[property];
      return styles;
    });
  };
} else {
  Element.getStyles = function(element) {
    element = $(element);
    var css = element.currentStyle, styles;
    styles = Element.CSS_PROPERTIES.inject({ }, function(results, property) {
      results[property] = css[property];
      return results;
    });
    if (!styles.opacity) styles.opacity = element.getOpacity();
    return styles;
  };
}

Effect.Methods = {
  morph: function(element, style) {
    element = $(element);
    new Effect.Morph(element, Object.extend({ style: style }, arguments[2] || { }));
    return element;
  },
  visualEffect: function(element, effect, options) {
    element = $(element);
    var s = effect.dasherize().camelize(), klass = s.charAt(0).toUpperCase() + s.substring(1);
    new Effect[klass](element, options);
    return element;
  },
  highlight: function(element, options) {
    element = $(element);
    new Effect.Highlight(element, options);
    return element;
  }
};

$w('fade appear grow shrink fold blindUp blindDown slideUp slideDown '+
  'pulsate shake puff squish switchOff dropOut').each(
  function(effect) {
    Effect.Methods[effect] = function(element, options){
      element = $(element);
      Effect[effect.charAt(0).toUpperCase() + effect.substring(1)](element, options);
      return element;
    };
  }
);

$w('getInlineOpacity forceRerendering setContentZoom collectTextNodes collectTextNodesIgnoreClass getStyles').each(
  function(f) { Effect.Methods[f] = Element[f]; }
);

Element.addMethods(Effect.Methods);
// script.aculo.us dragdrop.js v1.9.0, Thu Dec 23 16:54:48 -0500 2010

// Copyright (c) 2005-2010 Thomas Fuchs (http://script.aculo.us, http://mir.aculo.us)
//
// script.aculo.us is freely distributable under the terms of an MIT-style license.
// For details, see the script.aculo.us web site: http://script.aculo.us/

if(Object.isUndefined(Effect))
  throw("dragdrop.js requires including script.aculo.us' effects.js library");

var Droppables = {
  drops: [],

  remove: function(element) {
    this.drops = this.drops.reject(function(d) { return d.element==$(element) });
  },

  add: function(element) {
    element = $(element);
    var options = Object.extend({
      greedy:     true,
      hoverclass: null,
      tree:       false
    }, arguments[1] || { });

    // cache containers
    if(options.containment) {
      options._containers = [];
      var containment = options.containment;
      if(Object.isArray(containment)) {
        containment.each( function(c) { options._containers.push($(c)) });
      } else {
        options._containers.push($(containment));
      }
    }

    if(options.accept) options.accept = [options.accept].flatten();

    Element.makePositioned(element); // fix IE
    options.element = element;

    this.drops.push(options);
  },

  findDeepestChild: function(drops) {
    deepest = drops[0];

    for (i = 1; i < drops.length; ++i)
      if (Element.isParent(drops[i].element, deepest.element))
        deepest = drops[i];

    return deepest;
  },

  isContained: function(element, drop) {
    var containmentNode;
    if(drop.tree) {
      containmentNode = element.treeNode;
    } else {
      containmentNode = element.parentNode;
    }
    return drop._containers.detect(function(c) { return containmentNode == c });
  },

  isAffected: function(point, element, drop) {
    return (
      (drop.element!=element) &&
      ((!drop._containers) ||
        this.isContained(element, drop)) &&
      ((!drop.accept) ||
        (Element.classNames(element).detect(
          function(v) { return drop.accept.include(v) } ) )) &&
      Position.within(drop.element, point[0], point[1]) );
  },

  deactivate: function(drop) {
    if(drop.hoverclass)
      Element.removeClassName(drop.element, drop.hoverclass);
    this.last_active = null;
  },

  activate: function(drop) {
    if(drop.hoverclass)
      Element.addClassName(drop.element, drop.hoverclass);
    this.last_active = drop;
  },

  show: function(point, element) {
    if(!this.drops.length) return;
    var drop, affected = [];

    this.drops.each( function(drop) {
      if(Droppables.isAffected(point, element, drop))
        affected.push(drop);
    });

    if(affected.length>0)
      drop = Droppables.findDeepestChild(affected);

    if(this.last_active && this.last_active != drop) this.deactivate(this.last_active);
    if (drop) {
      Position.within(drop.element, point[0], point[1]);
      if(drop.onHover)
        drop.onHover(element, drop.element, Position.overlap(drop.overlap, drop.element));

      if (drop != this.last_active) Droppables.activate(drop);
    }
  },

  fire: function(event, element) {
    if(!this.last_active) return;
    Position.prepare();

    if (this.isAffected([Event.pointerX(event), Event.pointerY(event)], element, this.last_active))
      if (this.last_active.onDrop) {
        this.last_active.onDrop(element, this.last_active.element, event);
        return true;
      }
  },

  reset: function() {
    if(this.last_active)
      this.deactivate(this.last_active);
  }
};

var Draggables = {
  drags: [],
  observers: [],

  register: function(draggable) {
    if(this.drags.length == 0) {
      this.eventMouseUp   = this.endDrag.bindAsEventListener(this);
      this.eventMouseMove = this.updateDrag.bindAsEventListener(this);
      this.eventKeypress  = this.keyPress.bindAsEventListener(this);

      Event.observe(document, "mouseup", this.eventMouseUp);
      Event.observe(document, "mousemove", this.eventMouseMove);
      Event.observe(document, "keypress", this.eventKeypress);
    }
    this.drags.push(draggable);
  },

  unregister: function(draggable) {
    this.drags = this.drags.reject(function(d) { return d==draggable });
    if(this.drags.length == 0) {
      Event.stopObserving(document, "mouseup", this.eventMouseUp);
      Event.stopObserving(document, "mousemove", this.eventMouseMove);
      Event.stopObserving(document, "keypress", this.eventKeypress);
    }
  },

  activate: function(draggable) {
    if(draggable.options.delay) {
      this._timeout = setTimeout(function() {
        Draggables._timeout = null;
        window.focus();
        Draggables.activeDraggable = draggable;
      }.bind(this), draggable.options.delay);
    } else {
      window.focus(); // allows keypress events if window isn't currently focused, fails for Safari
      this.activeDraggable = draggable;
    }
  },

  deactivate: function() {
    this.activeDraggable = null;
  },

  updateDrag: function(event) {
    if(!this.activeDraggable) return;
    var pointer = [Event.pointerX(event), Event.pointerY(event)];
    // Mozilla-based browsers fire successive mousemove events with
    // the same coordinates, prevent needless redrawing (moz bug?)
    if(this._lastPointer && (this._lastPointer.inspect() == pointer.inspect())) return;
    this._lastPointer = pointer;

    this.activeDraggable.updateDrag(event, pointer);
  },

  endDrag: function(event) {
    if(this._timeout) {
      clearTimeout(this._timeout);
      this._timeout = null;
    }
    if(!this.activeDraggable) return;
    this._lastPointer = null;
    this.activeDraggable.endDrag(event);
    this.activeDraggable = null;
  },

  keyPress: function(event) {
    if(this.activeDraggable)
      this.activeDraggable.keyPress(event);
  },

  addObserver: function(observer) {
    this.observers.push(observer);
    this._cacheObserverCallbacks();
  },

  removeObserver: function(element) {  // element instead of observer fixes mem leaks
    this.observers = this.observers.reject( function(o) { return o.element==element });
    this._cacheObserverCallbacks();
  },

  notify: function(eventName, draggable, event) {  // 'onStart', 'onEnd', 'onDrag'
    if(this[eventName+'Count'] > 0)
      this.observers.each( function(o) {
        if(o[eventName]) o[eventName](eventName, draggable, event);
      });
    if(draggable.options[eventName]) draggable.options[eventName](draggable, event);
  },

  _cacheObserverCallbacks: function() {
    ['onStart','onEnd','onDrag'].each( function(eventName) {
      Draggables[eventName+'Count'] = Draggables.observers.select(
        function(o) { return o[eventName]; }
      ).length;
    });
  }
};

/*--------------------------------------------------------------------------*/

var Draggable = Class.create({
  initialize: function(element) {
    var defaults = {
      handle: false,
      reverteffect: function(element, top_offset, left_offset) {
        var dur = Math.sqrt(Math.abs(top_offset^2)+Math.abs(left_offset^2))*0.02;
        new Effect.Move(element, { x: -left_offset, y: -top_offset, duration: dur,
          queue: {scope:'_draggable', position:'end'}
        });
      },
      endeffect: function(element) {
        var toOpacity = Object.isNumber(element._opacity) ? element._opacity : 1.0;
        new Effect.Opacity(element, {duration:0.2, from:0.7, to:toOpacity,
          queue: {scope:'_draggable', position:'end'},
          afterFinish: function(){
            Draggable._dragging[element] = false
          }
        });
      },
      zindex: 1000,
      revert: false,
      quiet: false,
      scroll: false,
      scrollSensitivity: 20,
      scrollSpeed: 15,
      snap: false,  // false, or xy or [x,y] or function(x,y){ return [x,y] }
      delay: 0
    };

    if(!arguments[1] || Object.isUndefined(arguments[1].endeffect))
      Object.extend(defaults, {
        starteffect: function(element) {
          element._opacity = Element.getOpacity(element);
          Draggable._dragging[element] = true;
          new Effect.Opacity(element, {duration:0.2, from:element._opacity, to:0.7});
        }
      });

    var options = Object.extend(defaults, arguments[1] || { });

    this.element = $(element);

    if(options.handle && Object.isString(options.handle))
      this.handle = this.element.down('.'+options.handle, 0);

    if(!this.handle) this.handle = $(options.handle);
    if(!this.handle) this.handle = this.element;

    if(options.scroll && !options.scroll.scrollTo && !options.scroll.outerHTML) {
      options.scroll = $(options.scroll);
      this._isScrollChild = Element.childOf(this.element, options.scroll);
    }

    Element.makePositioned(this.element); // fix IE

    this.options  = options;
    this.dragging = false;

    this.eventMouseDown = this.initDrag.bindAsEventListener(this);
    Event.observe(this.handle, "mousedown", this.eventMouseDown);

    Draggables.register(this);
  },

  destroy: function() {
    Event.stopObserving(this.handle, "mousedown", this.eventMouseDown);
    Draggables.unregister(this);
  },

  currentDelta: function() {
    return([
      parseInt(Element.getStyle(this.element,'left') || '0'),
      parseInt(Element.getStyle(this.element,'top') || '0')]);
  },

  initDrag: function(event) {
    if(!Object.isUndefined(Draggable._dragging[this.element]) &&
      Draggable._dragging[this.element]) return;
    if(Event.isLeftClick(event)) {
      // abort on form elements, fixes a Firefox issue
      var src = Event.element(event);
      if((tag_name = src.tagName.toUpperCase()) && (
        tag_name=='INPUT' ||
        tag_name=='SELECT' ||
        tag_name=='OPTION' ||
        tag_name=='BUTTON' ||
        tag_name=='TEXTAREA')) return;

      var pointer = [Event.pointerX(event), Event.pointerY(event)];
      var pos     = this.element.cumulativeOffset();
      this.offset = [0,1].map( function(i) { return (pointer[i] - pos[i]) });

      Draggables.activate(this);
      Event.stop(event);
    }
  },

  startDrag: function(event) {
    this.dragging = true;
    if(!this.delta)
      this.delta = this.currentDelta();

    if(this.options.zindex) {
      this.originalZ = parseInt(Element.getStyle(this.element,'z-index') || 0);
      this.element.style.zIndex = this.options.zindex;
    }

    if(this.options.ghosting) {
      this._clone = this.element.cloneNode(true);
      this._originallyAbsolute = (this.element.getStyle('position') == 'absolute');
      if (!this._originallyAbsolute)
        Position.absolutize(this.element);
      this.element.parentNode.insertBefore(this._clone, this.element);
    }

    if(this.options.scroll) {
      if (this.options.scroll == window) {
        var where = this._getWindowScroll(this.options.scroll);
        this.originalScrollLeft = where.left;
        this.originalScrollTop = where.top;
      } else {
        this.originalScrollLeft = this.options.scroll.scrollLeft;
        this.originalScrollTop = this.options.scroll.scrollTop;
      }
    }

    Draggables.notify('onStart', this, event);

    if(this.options.starteffect) this.options.starteffect(this.element);
  },

  updateDrag: function(event, pointer) {
    if(!this.dragging) this.startDrag(event);

    if(!this.options.quiet){
      Position.prepare();
      Droppables.show(pointer, this.element);
    }

    Draggables.notify('onDrag', this, event);

    this.draw(pointer);
    if(this.options.change) this.options.change(this);

    if(this.options.scroll) {
      this.stopScrolling();

      var p;
      if (this.options.scroll == window) {
        with(this._getWindowScroll(this.options.scroll)) { p = [ left, top, left+width, top+height ]; }
      } else {
        p = Position.page(this.options.scroll).toArray();
        p[0] += this.options.scroll.scrollLeft + Position.deltaX;
        p[1] += this.options.scroll.scrollTop + Position.deltaY;
        p.push(p[0]+this.options.scroll.offsetWidth);
        p.push(p[1]+this.options.scroll.offsetHeight);
      }
      var speed = [0,0];
      if(pointer[0] < (p[0]+this.options.scrollSensitivity)) speed[0] = pointer[0]-(p[0]+this.options.scrollSensitivity);
      if(pointer[1] < (p[1]+this.options.scrollSensitivity)) speed[1] = pointer[1]-(p[1]+this.options.scrollSensitivity);
      if(pointer[0] > (p[2]-this.options.scrollSensitivity)) speed[0] = pointer[0]-(p[2]-this.options.scrollSensitivity);
      if(pointer[1] > (p[3]-this.options.scrollSensitivity)) speed[1] = pointer[1]-(p[3]-this.options.scrollSensitivity);
      this.startScrolling(speed);
    }

    // fix AppleWebKit rendering
    if(Prototype.Browser.WebKit) window.scrollBy(0,0);

    Event.stop(event);
  },

  finishDrag: function(event, success) {
    this.dragging = false;

    if(this.options.quiet){
      Position.prepare();
      var pointer = [Event.pointerX(event), Event.pointerY(event)];
      Droppables.show(pointer, this.element);
    }

    if(this.options.ghosting) {
      if (!this._originallyAbsolute)
        Position.relativize(this.element);
      delete this._originallyAbsolute;
      Element.remove(this._clone);
      this._clone = null;
    }

    var dropped = false;
    if(success) {
      dropped = Droppables.fire(event, this.element);
      if (!dropped) dropped = false;
    }
    if(dropped && this.options.onDropped) this.options.onDropped(this.element);
    Draggables.notify('onEnd', this, event);

    var revert = this.options.revert;
    if(revert && Object.isFunction(revert)) revert = revert(this.element);

    var d = this.currentDelta();
    if(revert && this.options.reverteffect) {
      if (dropped == 0 || revert != 'failure')
        this.options.reverteffect(this.element,
          d[1]-this.delta[1], d[0]-this.delta[0]);
    } else {
      this.delta = d;
    }

    if(this.options.zindex)
      this.element.style.zIndex = this.originalZ;

    if(this.options.endeffect)
      this.options.endeffect(this.element);

    Draggables.deactivate(this);
    Droppables.reset();
  },

  keyPress: function(event) {
    if(event.keyCode!=Event.KEY_ESC) return;
    this.finishDrag(event, false);
    Event.stop(event);
  },

  endDrag: function(event) {
    if(!this.dragging) return;
    this.stopScrolling();
    this.finishDrag(event, true);
    Event.stop(event);
  },

  draw: function(point) {
    var pos = this.element.cumulativeOffset();
    if(this.options.ghosting) {
      var r   = Position.realOffset(this.element);
      pos[0] += r[0] - Position.deltaX; pos[1] += r[1] - Position.deltaY;
    }

    var d = this.currentDelta();
    pos[0] -= d[0]; pos[1] -= d[1];

    if(this.options.scroll && (this.options.scroll != window && this._isScrollChild)) {
      pos[0] -= this.options.scroll.scrollLeft-this.originalScrollLeft;
      pos[1] -= this.options.scroll.scrollTop-this.originalScrollTop;
    }

    var p = [0,1].map(function(i){
      return (point[i]-pos[i]-this.offset[i])
    }.bind(this));

    if(this.options.snap) {
      if(Object.isFunction(this.options.snap)) {
        p = this.options.snap(p[0],p[1],this);
      } else {
      if(Object.isArray(this.options.snap)) {
        p = p.map( function(v, i) {
          return (v/this.options.snap[i]).round()*this.options.snap[i] }.bind(this));
      } else {
        p = p.map( function(v) {
          return (v/this.options.snap).round()*this.options.snap }.bind(this));
      }
    }}

    var style = this.element.style;
    if((!this.options.constraint) || (this.options.constraint=='horizontal'))
      style.left = p[0] + "px";
    if((!this.options.constraint) || (this.options.constraint=='vertical'))
      style.top  = p[1] + "px";

    if(style.visibility=="hidden") style.visibility = ""; // fix gecko rendering
  },

  stopScrolling: function() {
    if(this.scrollInterval) {
      clearInterval(this.scrollInterval);
      this.scrollInterval = null;
      Draggables._lastScrollPointer = null;
    }
  },

  startScrolling: function(speed) {
    if(!(speed[0] || speed[1])) return;
    this.scrollSpeed = [speed[0]*this.options.scrollSpeed,speed[1]*this.options.scrollSpeed];
    this.lastScrolled = new Date();
    this.scrollInterval = setInterval(this.scroll.bind(this), 10);
  },

  scroll: function() {
    var current = new Date();
    var delta = current - this.lastScrolled;
    this.lastScrolled = current;
    if(this.options.scroll == window) {
      with (this._getWindowScroll(this.options.scroll)) {
        if (this.scrollSpeed[0] || this.scrollSpeed[1]) {
          var d = delta / 1000;
          this.options.scroll.scrollTo( left + d*this.scrollSpeed[0], top + d*this.scrollSpeed[1] );
        }
      }
    } else {
      this.options.scroll.scrollLeft += this.scrollSpeed[0] * delta / 1000;
      this.options.scroll.scrollTop  += this.scrollSpeed[1] * delta / 1000;
    }

    Position.prepare();
    Droppables.show(Draggables._lastPointer, this.element);
    Draggables.notify('onDrag', this);
    if (this._isScrollChild) {
      Draggables._lastScrollPointer = Draggables._lastScrollPointer || $A(Draggables._lastPointer);
      Draggables._lastScrollPointer[0] += this.scrollSpeed[0] * delta / 1000;
      Draggables._lastScrollPointer[1] += this.scrollSpeed[1] * delta / 1000;
      if (Draggables._lastScrollPointer[0] < 0)
        Draggables._lastScrollPointer[0] = 0;
      if (Draggables._lastScrollPointer[1] < 0)
        Draggables._lastScrollPointer[1] = 0;
      this.draw(Draggables._lastScrollPointer);
    }

    if(this.options.change) this.options.change(this);
  },

  _getWindowScroll: function(w) {
    var T, L, W, H;
    with (w.document) {
      if (w.document.documentElement && documentElement.scrollTop) {
        T = documentElement.scrollTop;
        L = documentElement.scrollLeft;
      } else if (w.document.body) {
        T = body.scrollTop;
        L = body.scrollLeft;
      }
      if (w.innerWidth) {
        W = w.innerWidth;
        H = w.innerHeight;
      } else if (w.document.documentElement && documentElement.clientWidth) {
        W = documentElement.clientWidth;
        H = documentElement.clientHeight;
      } else {
        W = body.offsetWidth;
        H = body.offsetHeight;
      }
    }
    return { top: T, left: L, width: W, height: H };
  }
});

Draggable._dragging = { };

/*--------------------------------------------------------------------------*/

var SortableObserver = Class.create({
  initialize: function(element, observer) {
    this.element   = $(element);
    this.observer  = observer;
    this.lastValue = Sortable.serialize(this.element);
  },

  onStart: function() {
    this.lastValue = Sortable.serialize(this.element);
  },

  onEnd: function() {
    Sortable.unmark();
    if(this.lastValue != Sortable.serialize(this.element))
      this.observer(this.element)
  }
});

var Sortable = {
  SERIALIZE_RULE: /^[^_\-](?:[A-Za-z0-9\-\_]*)[_](.*)$/,

  sortables: { },

  _findRootElement: function(element) {
    while (element.tagName.toUpperCase() != "BODY") {
      if(element.id && Sortable.sortables[element.id]) return element;
      element = element.parentNode;
    }
  },

  options: function(element) {
    element = Sortable._findRootElement($(element));
    if(!element) return;
    return Sortable.sortables[element.id];
  },

  destroy: function(element){
    element = $(element);
    var s = Sortable.sortables[element.id];

    if(s) {
      Draggables.removeObserver(s.element);
      s.droppables.each(function(d){ Droppables.remove(d) });
      s.draggables.invoke('destroy');

      delete Sortable.sortables[s.element.id];
    }
  },

  create: function(element) {
    element = $(element);
    var options = Object.extend({
      element:     element,
      tag:         'li',       // assumes li children, override with tag: 'tagname'
      dropOnEmpty: false,
      tree:        false,
      treeTag:     'ul',
      overlap:     'vertical', // one of 'vertical', 'horizontal'
      constraint:  'vertical', // one of 'vertical', 'horizontal', false
      containment: element,    // also takes array of elements (or id's); or false
      handle:      false,      // or a CSS class
      only:        false,
      delay:       0,
      hoverclass:  null,
      ghosting:    false,
      quiet:       false,
      scroll:      false,
      scrollSensitivity: 20,
      scrollSpeed: 15,
      format:      this.SERIALIZE_RULE,

      // these take arrays of elements or ids and can be
      // used for better initialization performance
      elements:    false,
      handles:     false,

      onChange:    Prototype.emptyFunction,
      onUpdate:    Prototype.emptyFunction
    }, arguments[1] || { });

    // clear any old sortable with same element
    this.destroy(element);

    // build options for the draggables
    var options_for_draggable = {
      revert:      true,
      quiet:       options.quiet,
      scroll:      options.scroll,
      scrollSpeed: options.scrollSpeed,
      scrollSensitivity: options.scrollSensitivity,
      delay:       options.delay,
      ghosting:    options.ghosting,
      constraint:  options.constraint,
      handle:      options.handle };

    if(options.starteffect)
      options_for_draggable.starteffect = options.starteffect;

    if(options.reverteffect)
      options_for_draggable.reverteffect = options.reverteffect;
    else
      if(options.ghosting) options_for_draggable.reverteffect = function(element) {
        element.style.top  = 0;
        element.style.left = 0;
      };

    if(options.endeffect)
      options_for_draggable.endeffect = options.endeffect;

    if(options.zindex)
      options_for_draggable.zindex = options.zindex;

    // build options for the droppables
    var options_for_droppable = {
      overlap:     options.overlap,
      containment: options.containment,
      tree:        options.tree,
      hoverclass:  options.hoverclass,
      onHover:     Sortable.onHover
    };

    var options_for_tree = {
      onHover:      Sortable.onEmptyHover,
      overlap:      options.overlap,
      containment:  options.containment,
      hoverclass:   options.hoverclass
    };

    // fix for gecko engine
    Element.cleanWhitespace(element);

    options.draggables = [];
    options.droppables = [];

    // drop on empty handling
    if(options.dropOnEmpty || options.tree) {
      Droppables.add(element, options_for_tree);
      options.droppables.push(element);
    }

    (options.elements || this.findElements(element, options) || []).each( function(e,i) {
      var handle = options.handles ? $(options.handles[i]) :
        (options.handle ? $(e).select('.' + options.handle)[0] : e);
      options.draggables.push(
        new Draggable(e, Object.extend(options_for_draggable, { handle: handle })));
      Droppables.add(e, options_for_droppable);
      if(options.tree) e.treeNode = element;
      options.droppables.push(e);
    });

    if(options.tree) {
      (Sortable.findTreeElements(element, options) || []).each( function(e) {
        Droppables.add(e, options_for_tree);
        e.treeNode = element;
        options.droppables.push(e);
      });
    }

    // keep reference
    this.sortables[element.identify()] = options;

    // for onupdate
    Draggables.addObserver(new SortableObserver(element, options.onUpdate));

  },

  // return all suitable-for-sortable elements in a guaranteed order
  findElements: function(element, options) {
    return Element.findChildren(
      element, options.only, options.tree ? true : false, options.tag);
  },

  findTreeElements: function(element, options) {
    return Element.findChildren(
      element, options.only, options.tree ? true : false, options.treeTag);
  },

  onHover: function(element, dropon, overlap) {
    if(Element.isParent(dropon, element)) return;

    if(overlap > .33 && overlap < .66 && Sortable.options(dropon).tree) {
      return;
    } else if(overlap>0.5) {
      Sortable.mark(dropon, 'before');
      if(dropon.previousSibling != element) {
        var oldParentNode = element.parentNode;
        element.style.visibility = "hidden"; // fix gecko rendering
        dropon.parentNode.insertBefore(element, dropon);
        if(dropon.parentNode!=oldParentNode)
          Sortable.options(oldParentNode).onChange(element);
        Sortable.options(dropon.parentNode).onChange(element);
      }
    } else {
      Sortable.mark(dropon, 'after');
      var nextElement = dropon.nextSibling || null;
      if(nextElement != element) {
        var oldParentNode = element.parentNode;
        element.style.visibility = "hidden"; // fix gecko rendering
        dropon.parentNode.insertBefore(element, nextElement);
        if(dropon.parentNode!=oldParentNode)
          Sortable.options(oldParentNode).onChange(element);
        Sortable.options(dropon.parentNode).onChange(element);
      }
    }
  },

  onEmptyHover: function(element, dropon, overlap) {
    var oldParentNode = element.parentNode;
    var droponOptions = Sortable.options(dropon);

    if(!Element.isParent(dropon, element)) {
      var index;

      var children = Sortable.findElements(dropon, {tag: droponOptions.tag, only: droponOptions.only});
      var child = null;

      if(children) {
        var offset = Element.offsetSize(dropon, droponOptions.overlap) * (1.0 - overlap);

        for (index = 0; index < children.length; index += 1) {
          if (offset - Element.offsetSize (children[index], droponOptions.overlap) >= 0) {
            offset -= Element.offsetSize (children[index], droponOptions.overlap);
          } else if (offset - (Element.offsetSize (children[index], droponOptions.overlap) / 2) >= 0) {
            child = index + 1 < children.length ? children[index + 1] : null;
            break;
          } else {
            child = children[index];
            break;
          }
        }
      }

      dropon.insertBefore(element, child);

      Sortable.options(oldParentNode).onChange(element);
      droponOptions.onChange(element);
    }
  },

  unmark: function() {
    if(Sortable._marker) Sortable._marker.hide();
  },

  mark: function(dropon, position) {
    // mark on ghosting only
    var sortable = Sortable.options(dropon.parentNode);
    if(sortable && !sortable.ghosting) return;

    if(!Sortable._marker) {
      Sortable._marker =
        ($('dropmarker') || Element.extend(document.createElement('DIV'))).
          hide().addClassName('dropmarker').setStyle({position:'absolute'});
      document.getElementsByTagName("body").item(0).appendChild(Sortable._marker);
    }
    var offsets = dropon.cumulativeOffset();
    Sortable._marker.setStyle({left: offsets[0]+'px', top: offsets[1] + 'px'});

    if(position=='after')
      if(sortable.overlap == 'horizontal')
        Sortable._marker.setStyle({left: (offsets[0]+dropon.clientWidth) + 'px'});
      else
        Sortable._marker.setStyle({top: (offsets[1]+dropon.clientHeight) + 'px'});

    Sortable._marker.show();
  },

  _tree: function(element, options, parent) {
    var children = Sortable.findElements(element, options) || [];

    for (var i = 0; i < children.length; ++i) {
      var match = children[i].id.match(options.format);

      if (!match) continue;

      var child = {
        id: encodeURIComponent(match ? match[1] : null),
        element: element,
        parent: parent,
        children: [],
        position: parent.children.length,
        container: $(children[i]).down(options.treeTag)
      };

      /* Get the element containing the children and recurse over it */
      if (child.container)
        this._tree(child.container, options, child);

      parent.children.push (child);
    }

    return parent;
  },

  tree: function(element) {
    element = $(element);
    var sortableOptions = this.options(element);
    var options = Object.extend({
      tag: sortableOptions.tag,
      treeTag: sortableOptions.treeTag,
      only: sortableOptions.only,
      name: element.id,
      format: sortableOptions.format
    }, arguments[1] || { });

    var root = {
      id: null,
      parent: null,
      children: [],
      container: element,
      position: 0
    };

    return Sortable._tree(element, options, root);
  },

  /* Construct a [i] index for a particular node */
  _constructIndex: function(node) {
    var index = '';
    do {
      if (node.id) index = '[' + node.position + ']' + index;
    } while ((node = node.parent) != null);
    return index;
  },

  sequence: function(element) {
    element = $(element);
    var options = Object.extend(this.options(element), arguments[1] || { });

    return $(this.findElements(element, options) || []).map( function(item) {
      return item.id.match(options.format) ? item.id.match(options.format)[1] : '';
    });
  },

  setSequence: function(element, new_sequence) {
    element = $(element);
    var options = Object.extend(this.options(element), arguments[2] || { });

    var nodeMap = { };
    this.findElements(element, options).each( function(n) {
        if (n.id.match(options.format))
            nodeMap[n.id.match(options.format)[1]] = [n, n.parentNode];
        n.parentNode.removeChild(n);
    });

    new_sequence.each(function(ident) {
      var n = nodeMap[ident];
      if (n) {
        n[1].appendChild(n[0]);
        delete nodeMap[ident];
      }
    });
  },

  serialize: function(element) {
    element = $(element);
    var options = Object.extend(Sortable.options(element), arguments[1] || { });
    var name = encodeURIComponent(
      (arguments[1] && arguments[1].name) ? arguments[1].name : element.id);

    if (options.tree) {
      return Sortable.tree(element, arguments[1]).children.map( function (item) {
        return [name + Sortable._constructIndex(item) + "[id]=" +
                encodeURIComponent(item.id)].concat(item.children.map(arguments.callee));
      }).flatten().join('&');
    } else {
      return Sortable.sequence(element, arguments[1]).map( function(item) {
        return name + "[]=" + encodeURIComponent(item);
      }).join('&');
    }
  }
};

// Returns true if child is contained within element
Element.isParent = function(child, element) {
  if (!child.parentNode || child == element) return false;
  if (child.parentNode == element) return true;
  return Element.isParent(child.parentNode, element);
};

Element.findChildren = function(element, only, recursive, tagName) {
  if(!element.hasChildNodes()) return null;
  tagName = tagName.toUpperCase();
  if(only) only = [only].flatten();
  var elements = [];
  $A(element.childNodes).each( function(e) {
    if(e.tagName && e.tagName.toUpperCase()==tagName &&
      (!only || (Element.classNames(e).detect(function(v) { return only.include(v) }))))
        elements.push(e);
    if(recursive) {
      var grandchildren = Element.findChildren(e, only, recursive, tagName);
      if(grandchildren) elements.push(grandchildren);
    }
  });

  return (elements.length>0 ? elements.flatten() : []);
};

Element.offsetSize = function (element, type) {
  return element['offset' + ((type=='vertical' || type=='height') ? 'Height' : 'Width')];
};
// script.aculo.us controls.js v1.9.0, Thu Dec 23 16:54:48 -0500 2010

// Copyright (c) 2005-2010 Thomas Fuchs (http://script.aculo.us, http://mir.aculo.us)
//           (c) 2005-2010 Ivan Krstic (http://blogs.law.harvard.edu/ivan)
//           (c) 2005-2010 Jon Tirsen (http://www.tirsen.com)
// Contributors:
//  Richard Livsey
//  Rahul Bhargava
//  Rob Wills
//
// script.aculo.us is freely distributable under the terms of an MIT-style license.
// For details, see the script.aculo.us web site: http://script.aculo.us/

// Autocompleter.Base handles all the autocompletion functionality
// that's independent of the data source for autocompletion. This
// includes drawing the autocompletion menu, observing keyboard
// and mouse events, and similar.
//
// Specific autocompleters need to provide, at the very least,
// a getUpdatedChoices function that will be invoked every time
// the text inside the monitored textbox changes. This method
// should get the text for which to provide autocompletion by
// invoking this.getToken(), NOT by directly accessing
// this.element.value. This is to allow incremental tokenized
// autocompletion. Specific auto-completion logic (AJAX, etc)
// belongs in getUpdatedChoices.
//
// Tokenized incremental autocompletion is enabled automatically
// when an autocompleter is instantiated with the 'tokens' option
// in the options parameter, e.g.:
// new Ajax.Autocompleter('id','upd', '/url/', { tokens: ',' });
// will incrementally autocomplete with a comma as the token.
// Additionally, ',' in the above example can be replaced with
// a token array, e.g. { tokens: [',', '\n'] } which
// enables autocompletion on multiple tokens. This is most
// useful when one of the tokens is \n (a newline), as it
// allows smart autocompletion after linebreaks.

if(typeof Effect == 'undefined')
  throw("controls.js requires including script.aculo.us' effects.js library");

var Autocompleter = { };
Autocompleter.Base = Class.create({
  baseInitialize: function(element, update, options) {
    element          = $(element);
    this.element     = element;
    this.update      = $(update);
    this.hasFocus    = false;
    this.changed     = false;
    this.active      = false;
    this.index       = 0;
    this.entryCount  = 0;
    this.oldElementValue = this.element.value;

    if(this.setOptions)
      this.setOptions(options);
    else
      this.options = options || { };

    this.options.paramName    = this.options.paramName || this.element.name;
    this.options.tokens       = this.options.tokens || [];
    this.options.frequency    = this.options.frequency || 0.4;
    this.options.minChars     = this.options.minChars || 1;
    this.options.onShow       = this.options.onShow ||
      function(element, update){
        if(!update.style.position || update.style.position=='absolute') {
          update.style.position = 'absolute';
          Position.clone(element, update, {
            setHeight: false,
            offsetTop: element.offsetHeight
          });
        }
        Effect.Appear(update,{duration:0.15});
      };
    this.options.onHide = this.options.onHide ||
      function(element, update){ new Effect.Fade(update,{duration:0.15}) };

    if(typeof(this.options.tokens) == 'string')
      this.options.tokens = new Array(this.options.tokens);
    // Force carriage returns as token delimiters anyway
    if (!this.options.tokens.include('\n'))
      this.options.tokens.push('\n');

    this.observer = null;

    this.element.setAttribute('autocomplete','off');

    Element.hide(this.update);

    Event.observe(this.element, 'blur', this.onBlur.bindAsEventListener(this));
    Event.observe(this.element, 'keydown', this.onKeyPress.bindAsEventListener(this));
  },

  show: function() {
    if(Element.getStyle(this.update, 'display')=='none') this.options.onShow(this.element, this.update);
    if(!this.iefix &&
      (Prototype.Browser.IE) &&
      (Element.getStyle(this.update, 'position')=='absolute')) {
      new Insertion.After(this.update,
       '<iframe id="' + this.update.id + '_iefix" '+
       'style="display:none;position:absolute;filter:progid:DXImageTransform.Microsoft.Alpha(opacity=0);" ' +
       'src="javascript:false;" frameborder="0" scrolling="no"></iframe>');
      this.iefix = $(this.update.id+'_iefix');
    }
    if(this.iefix) setTimeout(this.fixIEOverlapping.bind(this), 50);
  },

  fixIEOverlapping: function() {
    Position.clone(this.update, this.iefix, {setTop:(!this.update.style.height)});
    this.iefix.style.zIndex = 1;
    this.update.style.zIndex = 2;
    Element.show(this.iefix);
  },

  hide: function() {
    this.stopIndicator();
    if(Element.getStyle(this.update, 'display')!='none') this.options.onHide(this.element, this.update);
    if(this.iefix) Element.hide(this.iefix);
  },

  startIndicator: function() {
    if(this.options.indicator) Element.show(this.options.indicator);
  },

  stopIndicator: function() {
    if(this.options.indicator) Element.hide(this.options.indicator);
  },

  onKeyPress: function(event) {
    if(this.active)
      switch(event.keyCode) {
       case Event.KEY_TAB:
       case Event.KEY_RETURN:
         this.selectEntry();
         Event.stop(event);
       case Event.KEY_ESC:
         this.hide();
         this.active = false;
         Event.stop(event);
         return;
       case Event.KEY_LEFT:
       case Event.KEY_RIGHT:
         return;
       case Event.KEY_UP:
         this.markPrevious();
         this.render();
         Event.stop(event);
         return;
       case Event.KEY_DOWN:
         this.markNext();
         this.render();
         Event.stop(event);
         return;
      }
     else
       if(event.keyCode==Event.KEY_TAB || event.keyCode==Event.KEY_RETURN ||
         (Prototype.Browser.WebKit > 0 && event.keyCode == 0)) return;

    this.changed = true;
    this.hasFocus = true;

    if(this.observer) clearTimeout(this.observer);
      this.observer =
        setTimeout(this.onObserverEvent.bind(this), this.options.frequency*1000);
  },

  activate: function() {
    this.changed = false;
    this.hasFocus = true;
    this.getUpdatedChoices();
  },

  onHover: function(event) {
    var element = Event.findElement(event, 'LI');
    if(this.index != element.autocompleteIndex)
    {
        this.index = element.autocompleteIndex;
        this.render();
    }
    Event.stop(event);
  },

  onClick: function(event) {
    var element = Event.findElement(event, 'LI');
    this.index = element.autocompleteIndex;
    this.selectEntry();
    this.hide();
  },

  onBlur: function(event) {
    // needed to make click events working
    setTimeout(this.hide.bind(this), 250);
    this.hasFocus = false;
    this.active = false;
  },

  render: function() {
    if(this.entryCount > 0) {
      for (var i = 0; i < this.entryCount; i++)
        this.index==i ?
          Element.addClassName(this.getEntry(i),"selected") :
          Element.removeClassName(this.getEntry(i),"selected");
      if(this.hasFocus) {
        this.show();
        this.active = true;
      }
    } else {
      this.active = false;
      this.hide();
    }
  },

  markPrevious: function() {
    if(this.index > 0) this.index--;
      else this.index = this.entryCount-1;
    this.getEntry(this.index).scrollIntoView(true);
  },

  markNext: function() {
    if(this.index < this.entryCount-1) this.index++;
      else this.index = 0;
    this.getEntry(this.index).scrollIntoView(false);
  },

  getEntry: function(index) {
    return this.update.firstChild.childNodes[index];
  },

  getCurrentEntry: function() {
    return this.getEntry(this.index);
  },

  selectEntry: function() {
    this.active = false;
    this.updateElement(this.getCurrentEntry());
  },

  updateElement: function(selectedElement) {
    if (this.options.updateElement) {
      this.options.updateElement(selectedElement);
      return;
    }
    var value = '';
    if (this.options.select) {
      var nodes = $(selectedElement).select('.' + this.options.select) || [];
      if(nodes.length>0) value = Element.collectTextNodes(nodes[0], this.options.select);
    } else
      value = Element.collectTextNodesIgnoreClass(selectedElement, 'informal');

    var bounds = this.getTokenBounds();
    if (bounds[0] != -1) {
      var newValue = this.element.value.substr(0, bounds[0]);
      var whitespace = this.element.value.substr(bounds[0]).match(/^\s+/);
      if (whitespace)
        newValue += whitespace[0];
      this.element.value = newValue + value + this.element.value.substr(bounds[1]);
    } else {
      this.element.value = value;
    }
    this.oldElementValue = this.element.value;
    this.element.focus();

    if (this.options.afterUpdateElement)
      this.options.afterUpdateElement(this.element, selectedElement);
  },

  updateChoices: function(choices) {
    if(!this.changed && this.hasFocus) {
      this.update.innerHTML = choices;
      Element.cleanWhitespace(this.update);
      Element.cleanWhitespace(this.update.down());

      if(this.update.firstChild && this.update.down().childNodes) {
        this.entryCount =
          this.update.down().childNodes.length;
        for (var i = 0; i < this.entryCount; i++) {
          var entry = this.getEntry(i);
          entry.autocompleteIndex = i;
          this.addObservers(entry);
        }
      } else {
        this.entryCount = 0;
      }

      this.stopIndicator();
      this.index = 0;

      if(this.entryCount==1 && this.options.autoSelect) {
        this.selectEntry();
        this.hide();
      } else {
        this.render();
      }
    }
  },

  addObservers: function(element) {
    Event.observe(element, "mouseover", this.onHover.bindAsEventListener(this));
    Event.observe(element, "click", this.onClick.bindAsEventListener(this));
  },

  onObserverEvent: function() {
    this.changed = false;
    this.tokenBounds = null;
    if(this.getToken().length>=this.options.minChars) {
      this.getUpdatedChoices();
    } else {
      this.active = false;
      this.hide();
    }
    this.oldElementValue = this.element.value;
  },

  getToken: function() {
    var bounds = this.getTokenBounds();
    return this.element.value.substring(bounds[0], bounds[1]).strip();
  },

  getTokenBounds: function() {
    if (null != this.tokenBounds) return this.tokenBounds;
    var value = this.element.value;
    if (value.strip().empty()) return [-1, 0];
    var diff = arguments.callee.getFirstDifferencePos(value, this.oldElementValue);
    var offset = (diff == this.oldElementValue.length ? 1 : 0);
    var prevTokenPos = -1, nextTokenPos = value.length;
    var tp;
    for (var index = 0, l = this.options.tokens.length; index < l; ++index) {
      tp = value.lastIndexOf(this.options.tokens[index], diff + offset - 1);
      if (tp > prevTokenPos) prevTokenPos = tp;
      tp = value.indexOf(this.options.tokens[index], diff + offset);
      if (-1 != tp && tp < nextTokenPos) nextTokenPos = tp;
    }
    return (this.tokenBounds = [prevTokenPos + 1, nextTokenPos]);
  }
});

Autocompleter.Base.prototype.getTokenBounds.getFirstDifferencePos = function(newS, oldS) {
  var boundary = Math.min(newS.length, oldS.length);
  for (var index = 0; index < boundary; ++index)
    if (newS[index] != oldS[index])
      return index;
  return boundary;
};

Ajax.Autocompleter = Class.create(Autocompleter.Base, {
  initialize: function(element, update, url, options) {
    this.baseInitialize(element, update, options);
    this.options.asynchronous  = true;
    this.options.onComplete    = this.onComplete.bind(this);
    this.options.defaultParams = this.options.parameters || null;
    this.url                   = url;
  },

  getUpdatedChoices: function() {
    this.startIndicator();

    var entry = encodeURIComponent(this.options.paramName) + '=' +
      encodeURIComponent(this.getToken());

    this.options.parameters = this.options.callback ?
      this.options.callback(this.element, entry) : entry;

    if(this.options.defaultParams)
      this.options.parameters += '&' + this.options.defaultParams;

    new Ajax.Request(this.url, this.options);
  },

  onComplete: function(request) {
    this.updateChoices(request.responseText);
  }
});

// The local array autocompleter. Used when you'd prefer to
// inject an array of autocompletion options into the page, rather
// than sending out Ajax queries, which can be quite slow sometimes.
//
// The constructor takes four parameters. The first two are, as usual,
// the id of the monitored textbox, and id of the autocompletion menu.
// The third is the array you want to autocomplete from, and the fourth
// is the options block.
//
// Extra local autocompletion options:
// - choices - How many autocompletion choices to offer
//
// - partialSearch - If false, the autocompleter will match entered
//                    text only at the beginning of strings in the
//                    autocomplete array. Defaults to true, which will
//                    match text at the beginning of any *word* in the
//                    strings in the autocomplete array. If you want to
//                    search anywhere in the string, additionally set
//                    the option fullSearch to true (default: off).
//
// - fullSsearch - Search anywhere in autocomplete array strings.
//
// - partialChars - How many characters to enter before triggering
//                   a partial match (unlike minChars, which defines
//                   how many characters are required to do any match
//                   at all). Defaults to 2.
//
// - ignoreCase - Whether to ignore case when autocompleting.
//                 Defaults to true.
//
// It's possible to pass in a custom function as the 'selector'
// option, if you prefer to write your own autocompletion logic.
// In that case, the other options above will not apply unless
// you support them.

Autocompleter.Local = Class.create(Autocompleter.Base, {
  initialize: function(element, update, array, options) {
    this.baseInitialize(element, update, options);
    this.options.array = array;
  },

  getUpdatedChoices: function() {
    this.updateChoices(this.options.selector(this));
  },

  setOptions: function(options) {
    this.options = Object.extend({
      choices: 10,
      partialSearch: true,
      partialChars: 2,
      ignoreCase: true,
      fullSearch: false,
      selector: function(instance) {
        var ret       = []; // Beginning matches
        var partial   = []; // Inside matches
        var entry     = instance.getToken();
        var count     = 0;

        for (var i = 0; i < instance.options.array.length &&
          ret.length < instance.options.choices ; i++) {

          var elem = instance.options.array[i];
          var foundPos = instance.options.ignoreCase ?
            elem.toLowerCase().indexOf(entry.toLowerCase()) :
            elem.indexOf(entry);

          while (foundPos != -1) {
            if (foundPos == 0 && elem.length != entry.length) {
              ret.push("<li><strong>" + elem.substr(0, entry.length) + "</strong>" +
                elem.substr(entry.length) + "</li>");
              break;
            } else if (entry.length >= instance.options.partialChars &&
              instance.options.partialSearch && foundPos != -1) {
              if (instance.options.fullSearch || /\s/.test(elem.substr(foundPos-1,1))) {
                partial.push("<li>" + elem.substr(0, foundPos) + "<strong>" +
                  elem.substr(foundPos, entry.length) + "</strong>" + elem.substr(
                  foundPos + entry.length) + "</li>");
                break;
              }
            }

            foundPos = instance.options.ignoreCase ?
              elem.toLowerCase().indexOf(entry.toLowerCase(), foundPos + 1) :
              elem.indexOf(entry, foundPos + 1);

          }
        }
        if (partial.length)
          ret = ret.concat(partial.slice(0, instance.options.choices - ret.length));
        return "<ul>" + ret.join('') + "</ul>";
      }
    }, options || { });
  }
});

// AJAX in-place editor and collection editor
// Full rewrite by Christophe Porteneuve <tdd@tddsworld.com> (April 2007).

// Use this if you notice weird scrolling problems on some browsers,
// the DOM might be a bit confused when this gets called so do this
// waits 1 ms (with setTimeout) until it does the activation
Field.scrollFreeActivate = function(field) {
  setTimeout(function() {
    Field.activate(field);
  }, 1);
};

Ajax.InPlaceEditor = Class.create({
  initialize: function(element, url, options) {
    this.url = url;
    this.element = element = $(element);
    this.prepareOptions();
    this._controls = { };
    arguments.callee.dealWithDeprecatedOptions(options); // DEPRECATION LAYER!!!
    Object.extend(this.options, options || { });
    if (!this.options.formId && this.element.id) {
      this.options.formId = this.element.id + '-inplaceeditor';
      if ($(this.options.formId))
        this.options.formId = '';
    }
    if (this.options.externalControl)
      this.options.externalControl = $(this.options.externalControl);
    if (!this.options.externalControl)
      this.options.externalControlOnly = false;
    this._originalBackground = this.element.getStyle('background-color') || 'transparent';
    this.element.title = this.options.clickToEditText;
    this._boundCancelHandler = this.handleFormCancellation.bind(this);
    this._boundComplete = (this.options.onComplete || Prototype.emptyFunction).bind(this);
    this._boundFailureHandler = this.handleAJAXFailure.bind(this);
    this._boundSubmitHandler = this.handleFormSubmission.bind(this);
    this._boundWrapperHandler = this.wrapUp.bind(this);
    this.registerListeners();
  },
  checkForEscapeOrReturn: function(e) {
    if (!this._editing || e.ctrlKey || e.altKey || e.shiftKey) return;
    if (Event.KEY_ESC == e.keyCode)
      this.handleFormCancellation(e);
    else if (Event.KEY_RETURN == e.keyCode)
      this.handleFormSubmission(e);
  },
  createControl: function(mode, handler, extraClasses) {
    var control = this.options[mode + 'Control'];
    var text = this.options[mode + 'Text'];
    if ('button' == control) {
      var btn = document.createElement('input');
      btn.type = 'submit';
      btn.value = text;
      btn.className = 'editor_' + mode + '_button';
      if ('cancel' == mode)
        btn.onclick = this._boundCancelHandler;
      this._form.appendChild(btn);
      this._controls[mode] = btn;
    } else if ('link' == control) {
      var link = document.createElement('a');
      link.href = '#';
      link.appendChild(document.createTextNode(text));
      link.onclick = 'cancel' == mode ? this._boundCancelHandler : this._boundSubmitHandler;
      link.className = 'editor_' + mode + '_link';
      if (extraClasses)
        link.className += ' ' + extraClasses;
      this._form.appendChild(link);
      this._controls[mode] = link;
    }
  },
  createEditField: function() {
    var text = (this.options.loadTextURL ? this.options.loadingText : this.getText());
    var fld;
    if (1 >= this.options.rows && !/\r|\n/.test(this.getText())) {
      fld = document.createElement('input');
      fld.type = 'text';
      var size = this.options.size || this.options.cols || 0;
      if (0 < size) fld.size = size;
    } else {
      fld = document.createElement('textarea');
      fld.rows = (1 >= this.options.rows ? this.options.autoRows : this.options.rows);
      fld.cols = this.options.cols || 40;
    }
    fld.name = this.options.paramName;
    fld.value = text; // No HTML breaks conversion anymore
    fld.className = 'editor_field';
    if (this.options.submitOnBlur)
      fld.onblur = this._boundSubmitHandler;
    this._controls.editor = fld;
    if (this.options.loadTextURL)
      this.loadExternalText();
    this._form.appendChild(this._controls.editor);
  },
  createForm: function() {
    var ipe = this;
    function addText(mode, condition) {
      var text = ipe.options['text' + mode + 'Controls'];
      if (!text || condition === false) return;
      ipe._form.appendChild(document.createTextNode(text));
    };
    this._form = $(document.createElement('form'));
    this._form.id = this.options.formId;
    this._form.addClassName(this.options.formClassName);
    this._form.onsubmit = this._boundSubmitHandler;
    this.createEditField();
    if ('textarea' == this._controls.editor.tagName.toLowerCase())
      this._form.appendChild(document.createElement('br'));
    if (this.options.onFormCustomization)
      this.options.onFormCustomization(this, this._form);
    addText('Before', this.options.okControl || this.options.cancelControl);
    this.createControl('ok', this._boundSubmitHandler);
    addText('Between', this.options.okControl && this.options.cancelControl);
    this.createControl('cancel', this._boundCancelHandler, 'editor_cancel');
    addText('After', this.options.okControl || this.options.cancelControl);
  },
  destroy: function() {
    if (this._oldInnerHTML)
      this.element.innerHTML = this._oldInnerHTML;
    this.leaveEditMode();
    this.unregisterListeners();
  },
  enterEditMode: function(e) {
    if (this._saving || this._editing) return;
    this._editing = true;
    this.triggerCallback('onEnterEditMode');
    if (this.options.externalControl)
      this.options.externalControl.hide();
    this.element.hide();
    this.createForm();
    this.element.parentNode.insertBefore(this._form, this.element);
    if (!this.options.loadTextURL)
      this.postProcessEditField();
    if (e) Event.stop(e);
  },
  enterHover: function(e) {
    if (this.options.hoverClassName)
      this.element.addClassName(this.options.hoverClassName);
    if (this._saving) return;
    this.triggerCallback('onEnterHover');
  },
  getText: function() {
    return this.element.innerHTML.unescapeHTML();
  },
  handleAJAXFailure: function(transport) {
    this.triggerCallback('onFailure', transport);
    if (this._oldInnerHTML) {
      this.element.innerHTML = this._oldInnerHTML;
      this._oldInnerHTML = null;
    }
  },
  handleFormCancellation: function(e) {
    this.wrapUp();
    if (e) Event.stop(e);
  },
  handleFormSubmission: function(e) {
    var form = this._form;
    var value = $F(this._controls.editor);
    this.prepareSubmission();
    var params = this.options.callback(form, value) || '';
    if (Object.isString(params))
      params = params.toQueryParams();
    params.editorId = this.element.id;
    if (this.options.htmlResponse) {
      var options = Object.extend({ evalScripts: true }, this.options.ajaxOptions);
      Object.extend(options, {
        parameters: params,
        onComplete: this._boundWrapperHandler,
        onFailure: this._boundFailureHandler
      });
      new Ajax.Updater({ success: this.element }, this.url, options);
    } else {
      var options = Object.extend({ method: 'get' }, this.options.ajaxOptions);
      Object.extend(options, {
        parameters: params,
        onComplete: this._boundWrapperHandler,
        onFailure: this._boundFailureHandler
      });
      new Ajax.Request(this.url, options);
    }
    if (e) Event.stop(e);
  },
  leaveEditMode: function() {
    this.element.removeClassName(this.options.savingClassName);
    this.removeForm();
    this.leaveHover();
    this.element.style.backgroundColor = this._originalBackground;
    this.element.show();
    if (this.options.externalControl)
      this.options.externalControl.show();
    this._saving = false;
    this._editing = false;
    this._oldInnerHTML = null;
    this.triggerCallback('onLeaveEditMode');
  },
  leaveHover: function(e) {
    if (this.options.hoverClassName)
      this.element.removeClassName(this.options.hoverClassName);
    if (this._saving) return;
    this.triggerCallback('onLeaveHover');
  },
  loadExternalText: function() {
    this._form.addClassName(this.options.loadingClassName);
    this._controls.editor.disabled = true;
    var options = Object.extend({ method: 'get' }, this.options.ajaxOptions);
    Object.extend(options, {
      parameters: 'editorId=' + encodeURIComponent(this.element.id),
      onComplete: Prototype.emptyFunction,
      onSuccess: function(transport) {
        this._form.removeClassName(this.options.loadingClassName);
        var text = transport.responseText;
        if (this.options.stripLoadedTextTags)
          text = text.stripTags();
        this._controls.editor.value = text;
        this._controls.editor.disabled = false;
        this.postProcessEditField();
      }.bind(this),
      onFailure: this._boundFailureHandler
    });
    new Ajax.Request(this.options.loadTextURL, options);
  },
  postProcessEditField: function() {
    var fpc = this.options.fieldPostCreation;
    if (fpc)
      $(this._controls.editor)['focus' == fpc ? 'focus' : 'activate']();
  },
  prepareOptions: function() {
    this.options = Object.clone(Ajax.InPlaceEditor.DefaultOptions);
    Object.extend(this.options, Ajax.InPlaceEditor.DefaultCallbacks);
    [this._extraDefaultOptions].flatten().compact().each(function(defs) {
      Object.extend(this.options, defs);
    }.bind(this));
  },
  prepareSubmission: function() {
    this._saving = true;
    this.removeForm();
    this.leaveHover();
    this.showSaving();
  },
  registerListeners: function() {
    this._listeners = { };
    var listener;
    $H(Ajax.InPlaceEditor.Listeners).each(function(pair) {
      listener = this[pair.value].bind(this);
      this._listeners[pair.key] = listener;
      if (!this.options.externalControlOnly)
        this.element.observe(pair.key, listener);
      if (this.options.externalControl)
        this.options.externalControl.observe(pair.key, listener);
    }.bind(this));
  },
  removeForm: function() {
    if (!this._form) return;
    this._form.remove();
    this._form = null;
    this._controls = { };
  },
  showSaving: function() {
    this._oldInnerHTML = this.element.innerHTML;
    this.element.innerHTML = this.options.savingText;
    this.element.addClassName(this.options.savingClassName);
    this.element.style.backgroundColor = this._originalBackground;
    this.element.show();
  },
  triggerCallback: function(cbName, arg) {
    if ('function' == typeof this.options[cbName]) {
      this.options[cbName](this, arg);
    }
  },
  unregisterListeners: function() {
    $H(this._listeners).each(function(pair) {
      if (!this.options.externalControlOnly)
        this.element.stopObserving(pair.key, pair.value);
      if (this.options.externalControl)
        this.options.externalControl.stopObserving(pair.key, pair.value);
    }.bind(this));
  },
  wrapUp: function(transport) {
    this.leaveEditMode();
    // Can't use triggerCallback due to backward compatibility: requires
    // binding + direct element
    this._boundComplete(transport, this.element);
  }
});

Object.extend(Ajax.InPlaceEditor.prototype, {
  dispose: Ajax.InPlaceEditor.prototype.destroy
});

Ajax.InPlaceCollectionEditor = Class.create(Ajax.InPlaceEditor, {
  initialize: function($super, element, url, options) {
    this._extraDefaultOptions = Ajax.InPlaceCollectionEditor.DefaultOptions;
    $super(element, url, options);
  },

  createEditField: function() {
    var list = document.createElement('select');
    list.name = this.options.paramName;
    list.size = 1;
    this._controls.editor = list;
    this._collection = this.options.collection || [];
    if (this.options.loadCollectionURL)
      this.loadCollection();
    else
      this.checkForExternalText();
    this._form.appendChild(this._controls.editor);
  },

  loadCollection: function() {
    this._form.addClassName(this.options.loadingClassName);
    this.showLoadingText(this.options.loadingCollectionText);
    var options = Object.extend({ method: 'get' }, this.options.ajaxOptions);
    Object.extend(options, {
      parameters: 'editorId=' + encodeURIComponent(this.element.id),
      onComplete: Prototype.emptyFunction,
      onSuccess: function(transport) {
        var js = transport.responseText.strip();
        if (!/^\[.*\]$/.test(js)) // TODO: improve sanity check
          throw('Server returned an invalid collection representation.');
        this._collection = eval(js);
        this.checkForExternalText();
      }.bind(this),
      onFailure: this.onFailure
    });
    new Ajax.Request(this.options.loadCollectionURL, options);
  },

  showLoadingText: function(text) {
    this._controls.editor.disabled = true;
    var tempOption = this._controls.editor.firstChild;
    if (!tempOption) {
      tempOption = document.createElement('option');
      tempOption.value = '';
      this._controls.editor.appendChild(tempOption);
      tempOption.selected = true;
    }
    tempOption.update((text || '').stripScripts().stripTags());
  },

  checkForExternalText: function() {
    this._text = this.getText();
    if (this.options.loadTextURL)
      this.loadExternalText();
    else
      this.buildOptionList();
  },

  loadExternalText: function() {
    this.showLoadingText(this.options.loadingText);
    var options = Object.extend({ method: 'get' }, this.options.ajaxOptions);
    Object.extend(options, {
      parameters: 'editorId=' + encodeURIComponent(this.element.id),
      onComplete: Prototype.emptyFunction,
      onSuccess: function(transport) {
        this._text = transport.responseText.strip();
        this.buildOptionList();
      }.bind(this),
      onFailure: this.onFailure
    });
    new Ajax.Request(this.options.loadTextURL, options);
  },

  buildOptionList: function() {
    this._form.removeClassName(this.options.loadingClassName);
    this._collection = this._collection.map(function(entry) {
      return 2 === entry.length ? entry : [entry, entry].flatten();
    });
    var marker = ('value' in this.options) ? this.options.value : this._text;
    var textFound = this._collection.any(function(entry) {
      return entry[0] == marker;
    }.bind(this));
    this._controls.editor.update('');
    var option;
    this._collection.each(function(entry, index) {
      option = document.createElement('option');
      option.value = entry[0];
      option.selected = textFound ? entry[0] == marker : 0 == index;
      option.appendChild(document.createTextNode(entry[1]));
      this._controls.editor.appendChild(option);
    }.bind(this));
    this._controls.editor.disabled = false;
    Field.scrollFreeActivate(this._controls.editor);
  }
});

//**** DEPRECATION LAYER FOR InPlace[Collection]Editor! ****
//**** This only  exists for a while,  in order to  let ****
//**** users adapt to  the new API.  Read up on the new ****
//**** API and convert your code to it ASAP!            ****

Ajax.InPlaceEditor.prototype.initialize.dealWithDeprecatedOptions = function(options) {
  if (!options) return;
  function fallback(name, expr) {
    if (name in options || expr === undefined) return;
    options[name] = expr;
  };
  fallback('cancelControl', (options.cancelLink ? 'link' : (options.cancelButton ? 'button' :
    options.cancelLink == options.cancelButton == false ? false : undefined)));
  fallback('okControl', (options.okLink ? 'link' : (options.okButton ? 'button' :
    options.okLink == options.okButton == false ? false : undefined)));
  fallback('highlightColor', options.highlightcolor);
  fallback('highlightEndColor', options.highlightendcolor);
};

Object.extend(Ajax.InPlaceEditor, {
  DefaultOptions: {
    ajaxOptions: { },
    autoRows: 3,                                // Use when multi-line w/ rows == 1
    cancelControl: 'link',                      // 'link'|'button'|false
    cancelText: 'cancel',
    clickToEditText: 'Click to edit',
    externalControl: null,                      // id|elt
    externalControlOnly: false,
    fieldPostCreation: 'activate',              // 'activate'|'focus'|false
    formClassName: 'inplaceeditor-form',
    formId: null,                               // id|elt
    highlightColor: '#ffff99',
    highlightEndColor: '#ffffff',
    hoverClassName: '',
    htmlResponse: true,
    loadingClassName: 'inplaceeditor-loading',
    loadingText: 'Loading...',
    okControl: 'button',                        // 'link'|'button'|false
    okText: 'ok',
    paramName: 'value',
    rows: 1,                                    // If 1 and multi-line, uses autoRows
    savingClassName: 'inplaceeditor-saving',
    savingText: 'Saving...',
    size: 0,
    stripLoadedTextTags: false,
    submitOnBlur: false,
    textAfterControls: '',
    textBeforeControls: '',
    textBetweenControls: ''
  },
  DefaultCallbacks: {
    callback: function(form) {
      return Form.serialize(form);
    },
    onComplete: function(transport, element) {
      // For backward compatibility, this one is bound to the IPE, and passes
      // the element directly.  It was too often customized, so we don't break it.
      new Effect.Highlight(element, {
        startcolor: this.options.highlightColor, keepBackgroundImage: true });
    },
    onEnterEditMode: null,
    onEnterHover: function(ipe) {
      ipe.element.style.backgroundColor = ipe.options.highlightColor;
      if (ipe._effect)
        ipe._effect.cancel();
    },
    onFailure: function(transport, ipe) {
      alert('Error communication with the server: ' + transport.responseText.stripTags());
    },
    onFormCustomization: null, // Takes the IPE and its generated form, after editor, before controls.
    onLeaveEditMode: null,
    onLeaveHover: function(ipe) {
      ipe._effect = new Effect.Highlight(ipe.element, {
        startcolor: ipe.options.highlightColor, endcolor: ipe.options.highlightEndColor,
        restorecolor: ipe._originalBackground, keepBackgroundImage: true
      });
    }
  },
  Listeners: {
    click: 'enterEditMode',
    keydown: 'checkForEscapeOrReturn',
    mouseover: 'enterHover',
    mouseout: 'leaveHover'
  }
});

Ajax.InPlaceCollectionEditor.DefaultOptions = {
  loadingCollectionText: 'Loading options...'
};

// Delayed observer, like Form.Element.Observer,
// but waits for delay after last key input
// Ideal for live-search fields

Form.Element.DelayedObserver = Class.create({
  initialize: function(element, delay, callback) {
    this.delay     = delay || 0.5;
    this.element   = $(element);
    this.callback  = callback;
    this.timer     = null;
    this.lastValue = $F(this.element);
    Event.observe(this.element,'keyup',this.delayedListener.bindAsEventListener(this));
  },
  delayedListener: function(event) {
    if(this.lastValue == $F(this.element)) return;
    if(this.timer) clearTimeout(this.timer);
    this.timer = setTimeout(this.onTimerEvent.bind(this), this.delay * 1000);
    this.lastValue = $F(this.element);
  },
  onTimerEvent: function() {
    this.timer = null;
    this.callback(this.element, $F(this.element));
  }
});
// script.aculo.us slider.js v1.9.0, Thu Dec 23 16:54:48 -0500 2010

// Copyright (c) 2005-2010 Marty Haught, Thomas Fuchs
//
// script.aculo.us is freely distributable under the terms of an MIT-style license.
// For details, see the script.aculo.us web site: http://script.aculo.us/

if (!Control) var Control = { };

// options:
//  axis: 'vertical', or 'horizontal' (default)
//
// callbacks:
//  onChange(value)
//  onSlide(value)
Control.Slider = Class.create({
  initialize: function(handle, track, options) {
    var slider = this;

    if (Object.isArray(handle)) {
      this.handles = handle.collect( function(e) { return $(e) });
    } else {
      this.handles = [$(handle)];
    }

    this.track   = $(track);
    this.options = options || { };

    this.axis      = this.options.axis || 'horizontal';
    this.increment = this.options.increment || 1;
    this.step      = parseInt(this.options.step || '1');
    this.range     = this.options.range || $R(0,1);

    this.value     = 0; // assure backwards compat
    this.values    = this.handles.map( function() { return 0 });
    this.spans     = this.options.spans ? this.options.spans.map(function(s){ return $(s) }) : false;
    this.options.startSpan = $(this.options.startSpan || null);
    this.options.endSpan   = $(this.options.endSpan || null);

    this.restricted = this.options.restricted || false;

    this.maximum   = this.options.maximum || this.range.end;
    this.minimum   = this.options.minimum || this.range.start;

    // Will be used to align the handle onto the track, if necessary
    this.alignX = parseInt(this.options.alignX || '0');
    this.alignY = parseInt(this.options.alignY || '0');

    this.trackLength = this.maximumOffset() - this.minimumOffset();

    this.handleLength = this.isVertical() ?
      (this.handles[0].offsetHeight != 0 ?
        this.handles[0].offsetHeight : this.handles[0].style.height.replace(/px$/,"")) :
      (this.handles[0].offsetWidth != 0 ? this.handles[0].offsetWidth :
        this.handles[0].style.width.replace(/px$/,""));

    this.active   = false;
    this.dragging = false;
    this.disabled = false;

    if (this.options.disabled) this.setDisabled();

    // Allowed values array
    this.allowedValues = this.options.values ? this.options.values.sortBy(Prototype.K) : false;
    if (this.allowedValues) {
      this.minimum = this.allowedValues.min();
      this.maximum = this.allowedValues.max();
    }

    this.eventMouseDown = this.startDrag.bindAsEventListener(this);
    this.eventMouseUp   = this.endDrag.bindAsEventListener(this);
    this.eventMouseMove = this.update.bindAsEventListener(this);

    // Initialize handles in reverse (make sure first handle is active)
    this.handles.each( function(h,i) {
      i = slider.handles.length-1-i;
      slider.setValue(parseFloat(
        (Object.isArray(slider.options.sliderValue) ?
          slider.options.sliderValue[i] : slider.options.sliderValue) ||
         slider.range.start), i);
      h.makePositioned().observe("mousedown", slider.eventMouseDown);
    });

    this.track.observe("mousedown", this.eventMouseDown);
    document.observe("mouseup", this.eventMouseUp);
    document.observe("mousemove", this.eventMouseMove);

    this.initialized = true;
  },
  dispose: function() {
    var slider = this;
    Event.stopObserving(this.track, "mousedown", this.eventMouseDown);
    Event.stopObserving(document, "mouseup", this.eventMouseUp);
    Event.stopObserving(document, "mousemove", this.eventMouseMove);
    this.handles.each( function(h) {
      Event.stopObserving(h, "mousedown", slider.eventMouseDown);
    });
  },
  setDisabled: function(){
    this.disabled = true;
  },
  setEnabled: function(){
    this.disabled = false;
  },
  getNearestValue: function(value){
    if (this.allowedValues){
      if (value >= this.allowedValues.max()) return(this.allowedValues.max());
      if (value <= this.allowedValues.min()) return(this.allowedValues.min());

      var offset = Math.abs(this.allowedValues[0] - value);
      var newValue = this.allowedValues[0];
      this.allowedValues.each( function(v) {
        var currentOffset = Math.abs(v - value);
        if (currentOffset <= offset){
          newValue = v;
          offset = currentOffset;
        }
      });
      return newValue;
    }
    if (value > this.range.end) return this.range.end;
    if (value < this.range.start) return this.range.start;
    return value;
  },
  setValue: function(sliderValue, handleIdx){
    if (!this.active) {
      this.activeHandleIdx = handleIdx || 0;
      this.activeHandle    = this.handles[this.activeHandleIdx];
      this.updateStyles();
    }
    handleIdx = handleIdx || this.activeHandleIdx || 0;
    if (this.initialized && this.restricted) {
      if ((handleIdx>0) && (sliderValue<this.values[handleIdx-1]))
        sliderValue = this.values[handleIdx-1];
      if ((handleIdx < (this.handles.length-1)) && (sliderValue>this.values[handleIdx+1]))
        sliderValue = this.values[handleIdx+1];
    }
    sliderValue = this.getNearestValue(sliderValue);
    this.values[handleIdx] = sliderValue;
    this.value = this.values[0]; // assure backwards compat

    this.handles[handleIdx].style[this.isVertical() ? 'top' : 'left'] =
      this.translateToPx(sliderValue);

    this.drawSpans();
    if (!this.dragging || !this.event) this.updateFinished();
  },
  setValueBy: function(delta, handleIdx) {
    this.setValue(this.values[handleIdx || this.activeHandleIdx || 0] + delta,
      handleIdx || this.activeHandleIdx || 0);
  },
  translateToPx: function(value) {
    return Math.round(
      ((this.trackLength-this.handleLength)/(this.range.end-this.range.start)) *
      (value - this.range.start)) + "px";
  },
  translateToValue: function(offset) {
    return ((offset/(this.trackLength-this.handleLength) *
      (this.range.end-this.range.start)) + this.range.start);
  },
  getRange: function(range) {
    var v = this.values.sortBy(Prototype.K);
    range = range || 0;
    return $R(v[range],v[range+1]);
  },
  minimumOffset: function(){
    return(this.isVertical() ? this.alignY : this.alignX);
  },
  maximumOffset: function(){
    return(this.isVertical() ?
      (this.track.offsetHeight != 0 ? this.track.offsetHeight :
        this.track.style.height.replace(/px$/,"")) - this.alignY :
      (this.track.offsetWidth != 0 ? this.track.offsetWidth :
        this.track.style.width.replace(/px$/,"")) - this.alignX);
  },
  isVertical:  function(){
    return (this.axis == 'vertical');
  },
  drawSpans: function() {
    var slider = this;
    if (this.spans)
      $R(0, this.spans.length-1).each(function(r) { slider.setSpan(slider.spans[r], slider.getRange(r)) });
    if (this.options.startSpan)
      this.setSpan(this.options.startSpan,
        $R(0, this.values.length>1 ? this.getRange(0).min() : this.value ));
    if (this.options.endSpan)
      this.setSpan(this.options.endSpan,
        $R(this.values.length>1 ? this.getRange(this.spans.length-1).max() : this.value, this.maximum));
  },
  setSpan: function(span, range) {
    if (this.isVertical()) {
      span.style.top = this.translateToPx(range.start);
      span.style.height = this.translateToPx(range.end - range.start + this.range.start);
    } else {
      span.style.left = this.translateToPx(range.start);
      span.style.width = this.translateToPx(range.end - range.start + this.range.start);
    }
  },
  updateStyles: function() {
    this.handles.each( function(h){ Element.removeClassName(h, 'selected') });
    Element.addClassName(this.activeHandle, 'selected');
  },
  startDrag: function(event) {
    if (Event.isLeftClick(event)) {
      if (!this.disabled){
        this.active = true;

        var handle = Event.element(event);
        var pointer  = [Event.pointerX(event), Event.pointerY(event)];
        var track = handle;
        if (track==this.track) {
          var offsets  = this.track.cumulativeOffset();
          this.event = event;
          this.setValue(this.translateToValue(
           (this.isVertical() ? pointer[1]-offsets[1] : pointer[0]-offsets[0])-(this.handleLength/2)
          ));
          var offsets  = this.activeHandle.cumulativeOffset();
          this.offsetX = (pointer[0] - offsets[0]);
          this.offsetY = (pointer[1] - offsets[1]);
        } else {
          // find the handle (prevents issues with Safari)
          while((this.handles.indexOf(handle) == -1) && handle.parentNode)
            handle = handle.parentNode;

          if (this.handles.indexOf(handle)!=-1) {
            this.activeHandle    = handle;
            this.activeHandleIdx = this.handles.indexOf(this.activeHandle);
            this.updateStyles();

            var offsets  = this.activeHandle.cumulativeOffset();
            this.offsetX = (pointer[0] - offsets[0]);
            this.offsetY = (pointer[1] - offsets[1]);
          }
        }
      }
      Event.stop(event);
    }
  },
  update: function(event) {
   if (this.active) {
      if (!this.dragging) this.dragging = true;
      this.draw(event);
      if (Prototype.Browser.WebKit) window.scrollBy(0,0);
      Event.stop(event);
   }
  },
  draw: function(event) {
    var pointer = [Event.pointerX(event), Event.pointerY(event)];
    var offsets = this.track.cumulativeOffset();
    pointer[0] -= this.offsetX + offsets[0];
    pointer[1] -= this.offsetY + offsets[1];
    this.event = event;
    this.setValue(this.translateToValue( this.isVertical() ? pointer[1] : pointer[0] ));
    if (this.initialized && this.options.onSlide)
      this.options.onSlide(this.values.length>1 ? this.values : this.value, this);
  },
  endDrag: function(event) {
    if (this.active && this.dragging) {
      this.finishDrag(event, true);
      Event.stop(event);
    }
    this.active = false;
    this.dragging = false;
  },
  finishDrag: function(event, success) {
    this.active = false;
    this.dragging = false;
    this.updateFinished();
  },
  updateFinished: function() {
    if (this.initialized && this.options.onChange)
      this.options.onChange(this.values.length>1 ? this.values : this.value, this);
    this.event = null;
  }
});
var Prototip = {
  Version: '2.2.2'
};

Object.extend(Prototip, {
    REQUIRED_Prototype: "1.7",
    support: {
        canvas: !! document.createElement("canvas").getContext
    },
    insertScript: function (a) {
        try {
            document.write("<script type='text/javascript' src='" + a + "'><\/script>")
        } catch (b) {
            $$("head")[0].insert(new Element("script", {
                src: a,
                type: "text/javascript"
            }))
        }
    },
    start: function () {
        this.require("Prototype");
        var a = /prototip([\w\d-_.]+)?\.js(.*)/;
        this.path = (($$("script[src]").find(function (b) {
            return b.src.match(a)
        }) || {}).src || "").replace(a, "");
        Tips.paths = (function (b) {
            return {
                images: (/^(https?:\/\/|\/)/.test(b.images)) ? b.images : this.path + b.images,
                javascript: (/^(https?:\/\/|\/)/.test(b.javascript)) ? b.javascript : this.path + b.javascript
            }
        }.bind(this))(Tips.options.paths);
        if (!Prototip.Styles) {
            this.insertScript(Tips.paths.javascript + "styles.js")
        }
        if (!this.support.canvas) {
            if (document.documentMode >= 8 && !document.namespaces.ns_vml) {
                document.namespaces.add("ns_vml", "urn:schemas-microsoft-com:vml", "#default#VML")
            } else {
                document.observe("dom:loaded", function () {
                    var b = document.createStyleSheet();
                    b.cssText = "ns_vml\\:*{behavior:url(#default#VML)}"
                })
            }
        }
        Tips.initialize();
        Element.observe(window, "unload", this.unload)
    },
    require: function (a) {
        if ((typeof window[a] == "undefined") || (this.convertVersionString(window[a].Version) < this.convertVersionString(this["REQUIRED_" + a]))) {
            throw ("Prototip requires " + a + " >= " + this["REQUIRED_" + a])
        }
    },
    convertVersionString: function (a) {
        var b = a.replace(/_.*|\./g, "");
        b = parseInt(b + "0".times(4 - b.length));
        return a.indexOf("_") > -1 ? b - 1 : b
    },
    toggleInt: function (a) {
        return (a > 0) ? (-1 * a) : (a).abs()
    },
    unload: function () {
        Tips.removeAll()
    }
});
Object.extend(Tips, (function () {
    function a(b) {
        if (!b) {
            return
        }
        b.deactivate();
        if (b.tooltip) {
            b.wrapper.remove();
            if (Tips.fixIE) {
                b.iframeShim.remove()
            }
        }
        Tips.tips = Tips.tips.without(b)
    }
    return {
        tips: [],
        visible: [],
        initialize: function () {
            this.zIndexTop = this.zIndex
        },
        _inverse: {
            left: "right",
            right: "left",
            top: "bottom",
            bottom: "top",
            middle: "middle",
            horizontal: "vertical",
            vertical: "horizontal"
        },
        _stemTranslation: {
            width: "horizontal",
            height: "vertical"
        },
        inverseStem: function (b) {
            return !!arguments[1] ? this._inverse[b] : b
        },
        fixIE: (function (c) {
            var b = new RegExp("MSIE ([\\d.]+)").exec(c);
            return b ? (parseFloat(b[1]) < 7) : false
        })(navigator.userAgent),
        WebKit419: (Prototype.Browser.WebKit && !document.evaluate),
        add: function (b) {
            this.tips.push(b)
        },
        remove: function (d) {
            var g, e = [];
            for (var c = 0, b = this.tips.length; c < b; c++) {
                var f = this.tips[c];
                if (!g && f.element == $(d)) {
                    g = f
                } else {
                    if (!f.element.parentNode) {
                        e.push(f)
                    }
                }
            }
            a(g);
            for (var c = 0, b = e.length; c < b; c++) {
                var f = e[c];
                a(f)
            }
            d.prototip = null
        },
        removeAll: function () {
            for (var c = 0, b = this.tips.length; c < b; c++) {
                a(this.tips[c])
            }
        },
        raise: function (d) {
            if (d == this._highest) {
                return
            }
            if (this.visible.length === 0) {
                this.zIndexTop = this.options.zIndex;
                for (var c = 0, b = this.tips.length; c < b; c++) {
                    this.tips[c].wrapper.setStyle({
                        zIndex: this.options.zIndex
                    })
                }
            }
            d.wrapper.setStyle({
                zIndex: this.zIndexTop++
            });
            if (d.loader) {
                d.loader.setStyle({
                    zIndex: this.zIndexTop
                })
            }
            this._highest = d
        },
        addVisibile: function (b) {
            this.removeVisible(b);
            this.visible.push(b)
        },
        removeVisible: function (b) {
            this.visible = this.visible.without(b)
        },
        hideAll: function () {
            Tips.visible.invoke("hide")
        },
        isChrome: function(version) {
            if( ! version )
            {
                version = 32;
            }

            return (navigator.userAgent.toLowerCase().indexOf('chrome/'+version) > -1);
        },
        hook: function (c, g) {
            c = $(c), g = $(g);
            var l = Object.extend({
                offset: {
                    x: 0,
                    y: 0
                },
                position: false
            }, arguments[2] || {});
            var e = l.mouse || g.cumulativeOffset();
            e.left += l.offset.x;
            e.top += l.offset.y;
            var d = l.mouse ? [0, 0] : g.cumulativeScrollOffset(),
                b = document.viewport.getScrollOffsets(),
                h = l.mouse ? "mouseHook" : "target";
            e.left += (-1 * (d[0] - b[0]));

            // Only conditionally run if not Chrome 32
            // See GitHub bug #403
            if( ! this.isChrome('32') )
            {
                e.top += (-1 * (d[1] - b[1]));
            }

            if (l.mouse) {
                var f = [0, 0];
                f.width = 0;
                f.height = 0
            }
            var j = {
                element: c.getDimensions()
            }, k = {
                    element: Object.clone(e)
                };
            j[h] = l.mouse ? f : g.getDimensions();
            k[h] = Object.clone(e);
            for (var i in k) {
                switch (l[i]) {
                case "topRight":
                case "rightTop":
                    k[i].left += j[i].width;
                    break;
                case "topMiddle":
                    k[i].left += (j[i].width / 2);
                    break;
                case "rightMiddle":
                    k[i].left += j[i].width;
                    k[i].top += (j[i].height / 2);
                    break;
                case "bottomLeft":
                case "leftBottom":
                    k[i].top += j[i].height;
                    break;
                case "bottomRight":
                case "rightBottom":
                    k[i].left += j[i].width;
                    k[i].top += j[i].height;
                    break;
                case "bottomMiddle":
                    k[i].left += (j[i].width / 2);
                    k[i].top += j[i].height;
                    break;
                case "leftMiddle":
                    k[i].top += (j[i].height / 2);
                    break
                }
            }
            e.left += -1 * (k.element.left - k[h].left);
            e.top += -1 * (k.element.top - k[h].top);
            if (l.position) {
                c.setStyle({
                    left: e.left + "px",
                    top: e.top + "px"
                })
            }
            return e
        }
    }
})());
Tips.initialize();
var Tip = Class.create({
    initialize: function (c, e) {
        this.element = $(c);
        if (!this.element) {
            throw ("Prototip: Element not available, cannot create a tooltip.");
            return
        }
        Tips.remove(this.element);
        var a = (Object.isString(e) || Object.isElement(e)),
            b = a ? arguments[2] || [] : e;
        this.content = a ? e : null;
        if (b.style) {
            b = Object.extend(Object.clone(Prototip.Styles[b.style]), b)
        }
        this.options = Object.extend(Object.extend({
            ajax: false,
            border: 0,
            borderColor: "#000000",
            radius: 0,
            className: Tips.options.className,
            closeButton: Tips.options.closeButtons,
            delay: !(b.showOn && b.showOn == "click") ? 0.14 : false,
            hideAfter: false,
            hideOn: "mouseleave",
            hideOthers: false,
            hook: b.hook,
            offset: b.hook ? {
                x: 0,
                y: 0
            } : {
                x: 16,
                y: 16
            },
            fixed: (b.hook && !b.hook.mouse) ? true : false,
            showOn: "mousemove",
            stem: false,
            style: "default",
            target: this.element,
            title: false,
            viewport: (b.hook && !b.hook.mouse) ? false : true,
            width: false
        }, Prototip.Styles["default"]), b);
        this.target = $(this.options.target);
        this.radius = this.options.radius;
        this.border = (this.radius > this.options.border) ? this.radius : this.options.border;
        if (this.options.images) {
            this.images = this.options.images.include("://") ? this.options.images : Tips.paths.images + this.options.images
        } else {
            this.images = Tips.paths.images + "styles/" + (this.options.style || "") + "/"
        } if (!this.images.endsWith("/")) {
            this.images += "/"
        }
        if (Object.isString(this.options.stem)) {
            this.options.stem = {
                position: this.options.stem
            }
        }
        if (this.options.stem.position) {
            this.options.stem = Object.extend(Object.clone(Prototip.Styles[this.options.style].stem) || {}, this.options.stem);
            this.options.stem.position = [this.options.stem.position.match(/[a-z]+/)[0].toLowerCase(), this.options.stem.position.match(/[A-Z][a-z]+/)[0].toLowerCase()];
            this.options.stem.orientation = ["left", "right"].member(this.options.stem.position[0]) ? "horizontal" : "vertical";
            this.stemInverse = {
                horizontal: false,
                vertical: false
            }
        }
        if (this.options.ajax) {
            this.options.ajax.options = Object.extend({
                onComplete: Prototype.emptyFunction
            }, this.options.ajax.options || {})
        }
        if (this.options.hook.mouse) {
            var d = this.options.hook.tip.match(/[a-z]+/)[0].toLowerCase();
            this.mouseHook = Tips._inverse[d] + Tips._inverse[this.options.hook.tip.match(/[A-Z][a-z]+/)[0].toLowerCase()].capitalize()
        }
        this.fixSafari2 = (Tips.WebKit419 && this.radius);
        this.setup();
        Tips.add(this);
        this.activate();
        Prototip.extend(this)
    },
    setup: function () {
        this.wrapper = new Element("div", {
            className: "prototip"
        }).setStyle({
            zIndex: Tips.options.zIndex
        });
        if (this.fixSafari2) {
            this.wrapper.hide = function () {
                this.setStyle("left:-9500px;top:-9500px;visibility:hidden;");
                return this
            };
            this.wrapper.show = function () {
                this.setStyle("visibility:visible");
                return this
            };
            this.wrapper.visible = function () {
                return (this.getStyle("visibility") == "visible" && parseFloat(this.getStyle("top").replace("px", "")) > -9500)
            }
        }
        this.wrapper.hide();
        if (Tips.fixIE) {
            this.iframeShim = new Element("iframe", {
                className: "iframeShim",
                src: "javascript:false;",
                frameBorder: 0
            }).setStyle({
                display: "none",
                zIndex: Tips.options.zIndex - 1,
                opacity: 0
            })
        }
        if (this.options.ajax) {
            this.showDelayed = this.showDelayed.wrap(this.ajaxShow)
        }
        this.tip = new Element("div", {
            className: "content"
        });
        this.title = new Element("div", {
            className: "title"
        }).hide();
        if (this.options.closeButton || (this.options.hideOn.element && this.options.hideOn.element == "closeButton")) {
            this.closeButton = new Element("div", {
                className: "close"
            }).setPngBackground(this.images + "close.png")
        }
    },
    build: function () {
        if (document.loaded) {
            this._build();
            this._isBuilding = true;
            return true
        } else {
            if (!this._isBuilding) {
                document.observe("dom:loaded", this._build);
                return false
            }
        }
    },
    _build: function () {
        $(document.body).insert(this.wrapper);
        if (Tips.fixIE) {
            $(document.body).insert(this.iframeShim)
        }
        if (this.options.ajax) {
            $(document.body).insert(this.loader = new Element("div", {
                className: "prototipLoader"
            }).setPngBackground(this.images + "loader.gif").hide())
        }
        var g = "wrapper";
        if (this.options.stem.position) {
            this.stem = new Element("div", {
                className: "prototip_Stem"
            }).setStyle({
                height: this.options.stem[this.options.stem.orientation == "vertical" ? "height" : "width"] + "px"
            });
            var b = this.options.stem.orientation == "horizontal";
            this[g].insert(this.stemWrapper = new Element("div", {
                className: "prototip_StemWrapper clearfix"
            }).insert(this.stemBox = new Element("div", {
                className: "prototip_StemBox clearfix"
            })));
            this.stem.insert(this.stemImage = new Element("div", {
                className: "prototip_StemImage"
            }).setStyle({
                height: this.options.stem[b ? "width" : "height"] + "px",
                width: this.options.stem[b ? "height" : "width"] + "px"
            }));
            if (Tips.fixIE && !this.options.stem.position[1].toUpperCase().include("MIDDLE")) {
                this.stemImage.setStyle({
                    display: "inline"
                })
            }
            g = "stemBox"
        }
        if (this.border) {
            var d = this.border,
                f;
            this[g].insert(this.borderFrame = new Element("ul", {
                className: "borderFrame"
            }).insert(this.borderTop = new Element("li", {
                className: "borderTop borderRow"
            }).setStyle("height: " + d + "px").insert(new Element("div", {
                className: "prototip_CornerWrapper prototip_CornerWrapperTopLeft"
            }).insert(new Element("div", {
                className: "prototip_Corner"
            }))).insert(f = new Element("div", {
                className: "prototip_BetweenCorners"
            }).setStyle({
                height: d + "px"
            }).insert(new Element("div", {
                className: "prototip_Between"
            }).setStyle({
                margin: "0 " + d + "px",
                height: d + "px"
            }))).insert(new Element("div", {
                className: "prototip_CornerWrapper prototip_CornerWrapperTopRight"
            }).insert(new Element("div", {
                className: "prototip_Corner"
            })))).insert(this.borderMiddle = new Element("li", {
                className: "borderMiddle borderRow"
            }).insert(this.borderCenter = new Element("div", {
                className: "borderCenter"
            }).setStyle("padding: 0 " + d + "px"))).insert(this.borderBottom = new Element("li", {
                className: "borderBottom borderRow"
            }).setStyle("height: " + d + "px").insert(new Element("div", {
                className: "prototip_CornerWrapper prototip_CornerWrapperBottomLeft"
            }).insert(new Element("div", {
                className: "prototip_Corner"
            }))).insert(f.cloneNode(true)).insert(new Element("div", {
                className: "prototip_CornerWrapper prototip_CornerWrapperBottomRight"
            }).insert(new Element("div", {
                className: "prototip_Corner"
            })))));
            g = "borderCenter";
            var c = this.borderFrame.select(".prototip_Corner");
            $w("tl tr bl br").each(function (j, h) {
                if (this.radius > 0) {
                    Prototip.createCorner(c[h], j, {
                        backgroundColor: this.options.borderColor,
                        border: d,
                        radius: this.options.radius
                    })
                } else {
                    c[h].addClassName("prototip_Fill")
                }
                c[h].setStyle({
                    width: d + "px",
                    height: d + "px"
                }).addClassName("prototip_Corner" + j.capitalize())
            }.bind(this));
            this.borderFrame.select(".prototip_Between", ".borderMiddle", ".prototip_Fill").invoke("setStyle", {
                backgroundColor: this.options.borderColor
            })
        }
        this[g].insert(this.tooltip = new Element("div", {
            className: "tooltip " + this.options.className
        }).insert(this.toolbar = new Element("div", {
            className: "toolbar"
        }).insert(this.title)));
        if (this.options.width) {
            var e = this.options.width;
            if (Object.isNumber(e)) {
                e += "px"
            }
            this.tooltip.setStyle("width:" + e)
        }
        if (this.stem) {
            var a = {};
            a[this.options.stem.orientation == "horizontal" ? "top" : "bottom"] = this.stem;
            this.wrapper.insert(a);
            this.positionStem()
        }
        this.tooltip.insert(this.tip);
        if (!this.options.ajax) {
            this._update({
                title: this.options.title,
                content: this.content
            })
        }
    },
    _update: function (e) {
        var a = this.wrapper.getStyle("visibility");
        this.wrapper.setStyle("height:auto;width:auto;visibility:hidden").show();
        if (this.border) {
            this.borderTop.setStyle("height:0");
            this.borderTop.setStyle("height:0")
        }
        if (e.title) {
            this.title.show().update(e.title);
            this.toolbar.show()
        } else {
            if (!this.closeButton) {
                this.title.hide();
                this.toolbar.hide()
            }
        } if (Object.isElement(e.content)) {
            e.content.show()
        }
        if (Object.isString(e.content) || Object.isElement(e.content)) {
            this.tip.update(e.content)
        }
        this.tooltip.setStyle({
            width: this.tooltip.getWidth() + "px"
        });
        this.wrapper.setStyle("visibility:visible").show();
        this.tooltip.show();
        var c = this.tooltip.getDimensions(),
            b = {
                width: c.width + "px"
            }, d = [this.wrapper];
        if (Tips.fixIE) {
            d.push(this.iframeShim)
        }
        if (this.closeButton) {
            this.title.show().insert({
                top: this.closeButton
            });
            this.toolbar.show()
        }
        if (e.title || this.closeButton) {
            this.toolbar.setStyle("width: 100%")
        }
        b.height = null;
        this.wrapper.setStyle({
            visibility: a
        });
        this.tip.addClassName("clearfix");
        if (e.title || this.closeButton) {
            this.title.addClassName("clearfix")
        }
        if (this.border) {
            this.borderTop.setStyle("height:" + this.border + "px");
            this.borderTop.setStyle("height:" + this.border + "px");
            b = "width: " + (c.width + 2 * this.border) + "px";
            d.push(this.borderFrame)
        }
        d.invoke("setStyle", b);
        if (this.stem) {
            this.positionStem();
            if (this.options.stem.orientation == "horizontal") {
                this.wrapper.setStyle({
                    width: this.wrapper.getWidth() + this.options.stem.height + "px"
                })
            }
        }
        this.wrapper.hide()
    },
    activate: function () {
        this.eventShow = this.showDelayed.bindAsEventListener(this);
        this.eventHide = this.hide.bindAsEventListener(this);
        if (this.options.fixed && this.options.showOn == "mousemove") {
            this.options.showOn = "mouseover"
        }
        if (this.options.showOn && this.options.showOn == this.options.hideOn) {
            this.eventToggle = this.toggle.bindAsEventListener(this);
            this.element.observe(this.options.showOn, this.eventToggle)
        }
        if (this.closeButton) {
            this.closeButton.observe("mouseover", function (d) {
                d.setPngBackground(this.images + "close_hover.png")
            }.bind(this, this.closeButton)).observe("mouseout", function (d) {
                d.setPngBackground(this.images + "close.png")
            }.bind(this, this.closeButton))
        }
        var c = {
            element: this.eventToggle ? [] : [this.element],
            target: this.eventToggle ? [] : [this.target],
            tip: this.eventToggle ? [] : [this.wrapper],
            closeButton: [],
            none: []
        }, a = this.options.hideOn.element;
        this.hideElement = a || (!this.options.hideOn ? "none" : "element");
        this.hideTargets = c[this.hideElement];
        if (!this.hideTargets && a && Object.isString(a)) {
            this.hideTargets = this.tip.select(a)
        }
        $w("show hide").each(function (g) {
            var f = g.capitalize(),
                d = (this.options[g + "On"].event || this.options[g + "On"]);
            if (d == "mouseover") {
                d == "mouseenter"
            } else {
                if (d == "mouseout") {
                    d == "mouseleave"
                }
            }
            this[g + "Action"] = d
        }.bind(this));
        if (!this.eventToggle && this.options.showOn) {
            this.element.observe(this.options.showOn, this.eventShow)
        }
        if (this.hideTargets && this.options.hideOn) {
            this.hideTargets.invoke("observe", this.hideAction, this.eventHide)
        }
        if (!this.options.fixed && this.options.showOn == "click") {
            this.eventPosition = this.position.bindAsEventListener(this);
            this.element.observe("mousemove", this.eventPosition)
        }
        this.buttonEvent = this.hide.wrap(function (f, e) {
            var d = e.findElement(".close");
            if (d) {
                d.blur();
                e.stop();
                f(e)
            }
        }).bindAsEventListener(this);
        if (this.closeButton || (this.options.hideOn && (this.options.hideOn.element == ".close"))) {
            this.wrapper.observe("click", this.buttonEvent)
        }
        if (this.options.showOn != "click" && (this.hideElement != "element")) {
            this.eventCheckDelay = function () {
                this.clearTimer("show")
            }.bindAsEventListener(this);
            this.element.observe("mouseleave", this.eventCheckDelay)
        }
        if (this.options.hideOn || this.options.hideAfter) {
            var b = [this.element, this.wrapper];
            this.activityEnter = function () {
                Tips.raise(this);
                this.cancelHideAfter()
            }.bindAsEventListener(this);
            this.activityLeave = this.hideAfter.bindAsEventListener(this);
            b.invoke("observe", "mouseenter", this.activityEnter).invoke("observe", "mouseleave", this.activityLeave)
        }
        if (this.options.ajax && this.options.showOn != "click") {
            this.ajaxHideEvent = this.ajaxHide.bindAsEventListener(this);
            this.element.observe("mouseleave", this.ajaxHideEvent)
        }
    },
    deactivate: function () {
        if (this.options.showOn && this.options.showOn == this.options.hideOn) {
            this.element.stopObserving(this.options.showOn, this.eventToggle)
        } else {
            if (this.options.showOn) {
                this.element.stopObserving(this.options.showOn, this.eventShow)
            }
            if (this.hideTargets && this.options.hideOn) {
                this.hideTargets.invoke("stopObserving")
            }
        } if (this.eventPosition) {
            this.element.stopObserving("mousemove", this.eventPosition)
        }
        if (this.eventCheckDelay) {
            this.element.stopObserving("mouseout", this.eventCheckDelay)
        }
        this.wrapper.stopObserving();
        if (this.options.hideOn || this.options.hideAfter) {
            this.element.stopObserving("mouseenter", this.activityEnter).stopObserving("mouseleave", this.activityLeave)
        }
        if (this.ajaxHideEvent) {
            this.element.stopObserving("mouseleave", this.ajaxHideEvent)
        }
    },
    ajaxShow: function (c, b) {
        if (!this.tooltip) {
            if (!this.build()) {
                return
            }
        }
        this.position(b);
        if (this.ajaxContentLoading) {
            return
        } else {
            if (this.ajaxContentLoaded) {
                c(b);
                return
            }
        }
        this.ajaxContentLoading = true;
        var d = {
            fakePointer: {
                pointerX: 0,
                pointerY: 0
            }
        };
        if (b.pointer) {
            var e = b.pointer(),
                d = {
                    fakePointer: {
                        pointerX: e.x,
                        pointerY: e.y
                    }
                }
        } else {
            if (b.fakePointer) {
                d.fakePointer = b.fakePointer
            }
        }
        var a = Object.clone(this.options.ajax.options);
        a.onComplete = a.onComplete.wrap(function (g, f) {
            this._update({
                title: this.options.title,
                content: f.responseText
            });
            this.position(d);
            (function () {
                g(f);
                var h = (this.loader && this.loader.visible());
                if (this.loader) {
                    this.clearTimer("loader");
                    this.loader.remove();
                    this.loader = null
                }
                if (h) {
                    this.show()
                }
                this.ajaxContentLoaded = true;
                this.ajaxContentLoading = null
            }.bind(this)).delay(0.6)
        }.bind(this));
        this.loaderTimer = Element.show.delay(this.options.delay, this.loader);
        this.wrapper.hide();
        this.ajaxContentLoading = true;
        this.loader.show();
        this.ajaxTimer = (function () {
            new Ajax.Request(this.options.ajax.url, a)
        }.bind(this)).delay(this.options.delay);
        return false
    },
    ajaxHide: function () {
        this.clearTimer("loader")
    },
    showDelayed: function (a) {
        if (!this.tooltip) {
            if (!this.build()) {
                return
            }
        }
        this.position(a);
        if (this.wrapper.visible()) {
            return
        }
        this.clearTimer("show");
        this.showTimer = this.show.bind(this).delay(this.options.delay)
    },
    clearTimer: function (a) {
        if (this[a + "Timer"]) {
            clearTimeout(this[a + "Timer"])
        }
    },
    show: function () {
        if (this.wrapper.visible()) {
            return
        }
        if (Tips.fixIE) {
            this.iframeShim.show()
        }
        if (this.options.hideOthers) {
            Tips.hideAll()
        }
        Tips.addVisibile(this);
        this.tooltip.show();
        this.wrapper.show();
        if (this.stem) {
            this.stem.show()
        }
        this.element.fire("prototip:shown")
    },
    hideAfter: function (a) {
        if (this.options.ajax) {
            if (this.loader && this.options.showOn != "click") {
                this.loader.hide()
            }
        }
        if (!this.options.hideAfter) {
            return
        }
        this.cancelHideAfter();
        this.hideAfterTimer = this.hide.bind(this).delay(this.options.hideAfter)
    },
    cancelHideAfter: function () {
        if (this.options.hideAfter) {
            this.clearTimer("hideAfter")
        }
    },
    hide: function () {
        this.clearTimer("show");
        this.clearTimer("loader");
        if (!this.wrapper.visible()) {
            return
        }
        this.afterHide()
    },
    afterHide: function () {
        if (Tips.fixIE) {
            this.iframeShim.hide()
        }
        if (this.loader) {
            this.loader.hide()
        }
        this.wrapper.hide();
        (this.borderFrame || this.tooltip).show();
        Tips.removeVisible(this);
        this.element.fire("prototip:hidden")
    },
    toggle: function (a) {
        if (this.wrapper && this.wrapper.visible()) {
            this.hide(a)
        } else {
            this.showDelayed(a)
        }
    },
    positionStem: function () {
        var c = this.options.stem,
            b = arguments[0] || this.stemInverse,
            d = Tips.inverseStem(c.position[0], b[c.orientation]),
            f = Tips.inverseStem(c.position[1], b[Tips._inverse[c.orientation]]),
            a = this.radius || 0;
        this.stemImage.setPngBackground(this.images + d + f + ".png");
        if (c.orientation == "horizontal") {
            var e = (d == "left") ? c.height : 0;
            this.stemWrapper.setStyle("left: " + e + "px;");
            this.stemImage.setStyle({
                "float": d
            });
            this.stem.setStyle({
                left: 0,
                top: (f == "bottom" ? "100%" : f == "middle" ? "50%" : 0),
                marginTop: (f == "bottom" ? -1 * c.width : f == "middle" ? -0.5 * c.width : 0) + (f == "bottom" ? -1 * a : f == "top" ? a : 0) + "px"
            })
        } else {
            this.stemWrapper.setStyle(d == "top" ? "margin: 0; padding: " + c.height + "px 0 0 0;" : "padding: 0; margin: 0 0 " + c.height + "px 0;");
            this.stem.setStyle(d == "top" ? "top: 0; bottom: auto;" : "top: auto; bottom: 0;");
            this.stemImage.setStyle({
                margin: 0,
                "float": f != "middle" ? f : "none"
            });
            if (f == "middle") {
                this.stemImage.setStyle("margin: 0 auto;")
            } else {
                this.stemImage.setStyle("margin-" + f + ": " + a + "px;")
            } if (Tips.WebKit419) {
                if (d == "bottom") {
                    this.stem.setStyle({
                        position: "relative",
                        clear: "both",
                        top: "auto",
                        bottom: "auto",
                        "float": "left",
                        width: "100%",
                        margin: (-1 * c.height) + "px 0 0 0"
                    });
                    this.stem.style.display = "block"
                } else {
                    this.stem.setStyle({
                        position: "absolute",
                        "float": "none",
                        margin: 0
                    })
                }
            }
        }
        this.stemInverse = b
    },
    position: function (b) {
        if (!this.tooltip) {
            if (!this.build()) {
                return
            }
        }
        Tips.raise(this);
        if (Tips.fixIE) {
            var a = this.wrapper.getDimensions();
            if (!this.iframeShimDimensions || this.iframeShimDimensions.height != a.height || this.iframeShimDimensions.width != a.width) {
                this.iframeShim.setStyle({
                    width: a.width + "px",
                    height: a.height + "px"
                })
            }
            this.iframeShimDimensions = a
        }
        if (this.options.hook) {
            var j, h;
            if (this.mouseHook) {
                var k = document.viewport.getScrollOffsets(),
                    c = b.fakePointer || {};
                var g, i = 2;
                switch (this.mouseHook.toUpperCase()) {
                case "LEFTTOP":
                case "TOPLEFT":
                    g = {
                        x: 0 - i,
                        y: 0 - i
                    };
                    break;
                case "TOPMIDDLE":
                    g = {
                        x: 0,
                        y: 0 - i
                    };
                    break;
                case "TOPRIGHT":
                case "RIGHTTOP":
                    g = {
                        x: i,
                        y: 0 - i
                    };
                    break;
                case "RIGHTMIDDLE":
                    g = {
                        x: i,
                        y: 0
                    };
                    break;
                case "RIGHTBOTTOM":
                case "BOTTOMRIGHT":
                    g = {
                        x: i,
                        y: i
                    };
                    break;
                case "BOTTOMMIDDLE":
                    g = {
                        x: 0,
                        y: i
                    };
                    break;
                case "BOTTOMLEFT":
                case "LEFTBOTTOM":
                    g = {
                        x: 0 - i,
                        y: i
                    };
                    break;
                case "LEFTMIDDLE":
                    g = {
                        x: 0 - i,
                        y: 0
                    };
                    break
                }
                g.x += this.options.offset.x;
                g.y += this.options.offset.y;
                j = Object.extend({
                    offset: g
                }, {
                    element: this.options.hook.tip,
                    mouseHook: this.mouseHook,
                    mouse: {
                        top: c.pointerY || Event.pointerY(b) - k.top,
                        left: c.pointerX || Event.pointerX(b) - k.left
                    }
                });
                h = Tips.hook(this.wrapper, this.target, j);
                if (this.options.viewport) {
                    var n = this.getPositionWithinViewport(h),
                        m = n.stemInverse;
                    h = n.position;
                    h.left += m.vertical ? 2 * Prototip.toggleInt(g.x - this.options.offset.x) : 0;
                    h.top += m.vertical ? 2 * Prototip.toggleInt(g.y - this.options.offset.y) : 0;
                    if (this.stem && (this.stemInverse.horizontal != m.horizontal || this.stemInverse.vertical != m.vertical)) {
                        this.positionStem(m)
                    }
                }
                h = {
                    left: h.left + "px",
                    top: h.top + "px"
                };
                this.wrapper.setStyle(h)
            } else {
                j = Object.extend({
                    offset: this.options.offset
                }, {
                    element: this.options.hook.tip,
                    target: this.options.hook.target
                });
                h = Tips.hook(this.wrapper, this.target, Object.extend({
                    position: true
                }, j));
                h = {
                    left: h.left + "px",
                    top: h.top + "px"
                }
            } if (this.loader) {
                var e = Tips.hook(this.loader, this.target, Object.extend({
                    position: true
                }, j))
            }
            if (Tips.fixIE) {
                this.iframeShim.setStyle(h)
            }
        } else {
            var f = this.target.cumulativeOffset(),
                c = b.fakePointer || {}, h = {
                    left: ((this.options.fixed) ? f[0] : c.pointerX || Event.pointerX(b)) + this.options.offset.x,
                    top: ((this.options.fixed) ? f[1] : c.pointerY || Event.pointerY(b)) + this.options.offset.y
                };
            if (!this.options.fixed && this.element !== this.target) {
                var d = this.element.cumulativeOffset();
                h.left += -1 * (d[0] - f[0]);
                h.top += -1 * (d[1] - f[1])
            }
            if (!this.options.fixed && this.options.viewport) {
                var n = this.getPositionWithinViewport(h),
                    m = n.stemInverse;
                h = n.position;
                if (this.stem && (this.stemInverse.horizontal != m.horizontal || this.stemInverse.vertical != m.vertical)) {
                    this.positionStem(m)
                }
            }
            h = {
                left: h.left + "px",
                top: h.top + "px"
            };
            this.wrapper.setStyle(h);
            if (this.loader) {
                this.loader.setStyle(h)
            }
            if (Tips.fixIE) {
                this.iframeShim.setStyle(h)
            }
        }
    },
    getPositionWithinViewport: function (c) {
        var e = {
            horizontal: false,
            vertical: false
        }, d = this.wrapper.getDimensions(),
            b = document.viewport.getScrollOffsets(),
            a = document.viewport.getDimensions(),
            g = {
                left: "width",
                top: "height"
            };
        for (var f in g) {
            if ((c[f] + d[g[f]] - b[f]) > a[g[f]]) {
                c[f] = c[f] - (d[g[f]] + (2 * this.options.offset[f == "left" ? "x" : "y"]));
                if (this.stem) {
                    e[Tips._stemTranslation[g[f]]] = true
                }
            }
        }
        return {
            position: c,
            stemInverse: e
        }
    }
});
Object.extend(Prototip, {
    createCorner: function (d, g) {
        var j = arguments[2] || this.options,
            f = j.radius,
            c = j.border,
            e = {
                top: (g.charAt(0) == "t"),
                left: (g.charAt(1) == "l")
            };
        if (this.support.canvas) {
            var b = new Element("canvas", {
                className: "cornerCanvas" + g.capitalize(),
                width: c + "px",
                height: c + "px"
            });
            d.insert(b);
            var i = b.getContext("2d");
            i.fillStyle = j.backgroundColor;
            i.arc((e.left ? f : c - f), (e.top ? f : c - f), f, 0, Math.PI * 2, true);
            i.fill();
            i.fillRect((e.left ? f : 0), 0, c - f, c);
            i.fillRect(0, (e.top ? f : 0), c, c - f)
        } else {
            var h;
            d.insert(h = new Element("div").setStyle({
                width: c + "px",
                height: c + "px",
                margin: 0,
                padding: 0,
                display: "block",
                position: "relative",
                overflow: "hidden"
            }));
            var a = new Element("ns_vml:roundrect", {
                fillcolor: j.backgroundColor,
                strokeWeight: "1px",
                strokeColor: j.backgroundColor,
                arcSize: (f / c * 0.5).toFixed(2)
            }).setStyle({
                width: 2 * c - 1 + "px",
                height: 2 * c - 1 + "px",
                position: "absolute",
                left: (e.left ? 0 : (-1 * c)) + "px",
                top: (e.top ? 0 : (-1 * c)) + "px"
            });
            h.insert(a);
            a.outerHTML = a.outerHTML
        }
    }
});
Element.addMethods({
    setPngBackground: function (c, b) {
        c = $(c);
        var a = Object.extend({
            align: "top left",
            repeat: "no-repeat",
            sizingMethod: "scale",
            backgroundColor: ""
        }, arguments[2] || {});
        c.setStyle(Tips.fixIE ? {
            filter: "progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + b + "'', sizingMethod='" + a.sizingMethod + "')"
        } : {
            background: a.backgroundColor + " url(" + b + ") " + a.align + " " + a.repeat
        });
        return c
    }
});
Prototip.Methods = {
    hold: function (a) {
        if (a.element && !a.element.parentNode) {
            return true
        }
        return false
    },
    show: function () {
        if (Prototip.Methods.hold(this)) {
            return
        }
        Tips.raise(this);
        this.cancelHideAfter();
        var d = {};
        if (this.options.hook && !this.options.hook.mouse) {
            d.fakePointer = {
                pointerX: 0,
                pointerY: 0
            }
        } else {
            var a = this.target.cumulativeOffset(),
                c = this.target.cumulativeScrollOffset(),
                b = document.viewport.getScrollOffsets();
            a.left += (-1 * (c[0] - b[0]));
            a.top += (-1 * (c[1] - b[1]));
            d.fakePointer = {
                pointerX: a.left,
                pointerY: a.top
            }
        } if (this.options.ajax && !this.ajaxContentLoaded) {
            this.ajaxShow(this.showDelayed, d)
        } else {
            this.showDelayed(d)
        }
        this.hideAfter()
    }
};
Prototip.extend = function (a) {
    a.element.prototip = {};
    Object.extend(a.element.prototip, {
        show: Prototip.Methods.show.bind(a),
        hide: a.hide.bind(a),
        remove: Tips.remove.bind(Tips, a.element)
    })
};
Prototip.start();
/*
* Really easy field validation with Prototype
* http://tetlaw.id.au/view/javascript/really-easy-field-validation
* Andrew Tetlaw
* Version 1.5.4.1 (2007-01-05)
* 
* Copyright (c) 2007 Andrew Tetlaw
* Permission is hereby granted, free of charge, to any person
* obtaining a copy of this software and associated documentation
* files (the "Software"), to deal in the Software without
* restriction, including without limitation the rights to use, copy,
* modify, merge, publish, distribute, sublicense, and/or sell copies
* of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
* 
* The above copyright notice and this permission notice shall be
* included in all copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
* NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
* BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
* ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
* CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
* 
*/
var Validator = Class.create();

Validator.prototype = {
	initialize : function(className, error, test, options) {
		if(typeof test == 'function'){
			this.options = $H(options);
			this._test = test;
		} else {
			this.options = $H(test);
			this._test = function(){return true};
		}
		this.error = error || 'Validation failed.';
		this.className = className;
	},
	test : function(v, elm) {
		return (this._test(v,elm) && this.options.all(function(p){
			return Validator.methods[p.key] ? Validator.methods[p.key](v,elm,p.value) : true;
		}));
	}
}
Validator.methods = {
	pattern : function(v,elm,opt) {return Validation.get('IsEmpty').test(v) || opt.test(v)},
	minLength : function(v,elm,opt) {return v.length >= opt},
	maxLength : function(v,elm,opt) {return v.length <= opt},
	min : function(v,elm,opt) {return v >= parseFloat(opt)}, 
	max : function(v,elm,opt) {return v <= parseFloat(opt)},
	notOneOf : function(v,elm,opt) {return $A(opt).all(function(value) {
		return v != value;
	})},
	oneOf : function(v,elm,opt) {return $A(opt).any(function(value) {
		return v == value;
	})},
	is : function(v,elm,opt) {return v == opt},
	isNot : function(v,elm,opt) {return v != opt},
	equalToField : function(v,elm,opt) {return v == $F(opt)},
	notEqualToField : function(v,elm,opt) {return v != $F(opt)},
	include : function(v,elm,opt) {return $A(opt).all(function(value) {
		return Validation.get(value).test(v,elm);
	})}
}

var Validation = Class.create();

Validation.prototype = {
	initialize : function(form, options){
		this.options = Object.extend({
			onSubmit : true,
			stopOnFirst : false,
			immediate : false,
			focusOnError : true,
			useTitles : false,
			onFormValidate : function(result, form) {},
			onElementValidate : function(result, elm) {}
		}, options || {});
		this.form = $(form);
		if(this.options.onSubmit) Event.observe(this.form,'submit',this.onSubmit.bind(this),false);
		if(this.options.immediate) {
			var useTitles = this.options.useTitles;
			var callback = this.options.onElementValidate;
			Form.getElements(this.form).each(function(input) { // Thanks Mike!
				Event.observe(input, 'blur', function(ev) { Validation.validate(Event.element(ev),{useTitle : useTitles, onElementValidate : callback}); });
			});
		}
	},
	onSubmit :  function(ev){
		if(!this.validate()) Event.stop(ev);
	},
	validate : function() {
		var result = false;
		var useTitles = this.options.useTitles;
		var callback = this.options.onElementValidate;
		if(this.options.stopOnFirst) {
			result = Form.getElements(this.form).all(function(elm) { return Validation.validate(elm,{useTitle : useTitles, onElementValidate : callback}); });
		} else {
			result = Form.getElements(this.form).collect(function(elm) { return Validation.validate(elm,{useTitle : useTitles, onElementValidate : callback}); }).all();
		}
		if(!result && this.options.focusOnError) {
			Form.getElements(this.form).findAll(function(elm){return $(elm).hasClassName('validation-failed')}).first().focus()
		}
		this.options.onFormValidate(result, this.form);
		return result;
	},
	reset : function() {
		Form.getElements(this.form).each(Validation.reset);
	}
}

Object.extend(Validation, {
	validate : function(elm, options){
		options = Object.extend({
			useTitle : false,
			onElementValidate : function(result, elm) {}
		}, options || {});
		elm = $(elm);
		var cn = elm.classNames();
		return result = cn.all(function(value) {
			var test = Validation.test(value,elm,options.useTitle);
			options.onElementValidate(test, elm);
			return test;
		});
	},
	test : function(name, elm, useTitle) {
		var v = Validation.get(name);
		var prop = '__advice'+name.camelize();
		try {
		if(Validation.isVisible(elm) && !v.test($F(elm), elm)) {
			if(!elm[prop]) {
				var advice = Validation.getAdvice(name, elm);
				if(advice == null) {
					var errorMsg = useTitle ? ((elm && elm.title) ? elm.title : v.error) : v.error;
					advice = '<div class="validation-advice" id="advice-' + name + '-' + Validation.getElmID(elm) +'" style="display:none">' + errorMsg + '</div>'
					switch (elm.type.toLowerCase()) {
						case 'checkbox':
						case 'radio':
							var p = elm.parentNode;
							if(p) {
								new Insertion.Bottom(p, advice);
							} else {
								new Insertion.After(elm, advice);
							}
							break;
						default:
							new Insertion.After(elm, advice);
				    }
					advice = Validation.getAdvice(name, elm);
				}
				if(typeof Effect == 'undefined') {
					advice.style.display = 'block';
				} else {
					new Effect.Appear(advice, {duration : 1 });
				}
			}
			elm[prop] = true;
			elm.removeClassName('validation-passed');
			elm.addClassName('validation-failed');
			return false;
		} else {
			var advice = Validation.getAdvice(name, elm);
			if(advice != null) advice.hide();
			elm[prop] = '';
			elm.removeClassName('validation-failed');
			elm.addClassName('validation-passed');
			return true;
		}
		} catch(e) {
			throw(e)
		}
	},
	isVisible : function(elm) {
		while(elm.tagName != 'BODY') {
			if(!$(elm).visible()) return false;
			elm = elm.parentNode;
		}
		return true;
	},
	getAdvice : function(name, elm) {
		return $('advice-' + name + '-' + Validation.getElmID(elm)) || $('advice-' + Validation.getElmID(elm));
	},
	getElmID : function(elm) {
		return elm.id ? elm.id : elm.name;
	},
	reset : function(elm) {
		elm = $(elm);
		var cn = elm.classNames();
		cn.each(function(value) {
			var prop = '__advice'+value.camelize();
			if(elm[prop]) {
				var advice = Validation.getAdvice(value, elm);
				advice.hide();
				elm[prop] = '';
			}
			elm.removeClassName('validation-failed');
			elm.removeClassName('validation-passed');
		});
	},
	add : function(className, error, test, options) {
		var nv = {};
		nv[className] = new Validator(className, error, test, options);
		Object.extend(Validation.methods, nv);
	},
	addAllThese : function(validators) {
		var nv = {};
		$A(validators).each(function(value) {
				nv[value[0]] = new Validator(value[0], value[1], value[2], (value.length > 3 ? value[3] : {}));
			});
		Object.extend(Validation.methods, nv);
	},
	get : function(name) {
		return  Validation.methods[name] ? Validation.methods[name] : Validation.methods['_LikeNoIDIEverSaw_'];
	},
	methods : {
		'_LikeNoIDIEverSaw_' : new Validator('_LikeNoIDIEverSaw_','',{})
	}
});

Validation.add('IsEmpty', '', function(v) {
				return  ((v == null) || (v.length == 0)); // || /^\s+$/.test(v));
			});

Validation.addAllThese([
	['required', 'This is a required field.', function(v) {
				return !Validation.get('IsEmpty').test(v);
			}],
	['validate-number', 'Please enter a valid number in this field.', function(v) {
				return Validation.get('IsEmpty').test(v) || (!isNaN(v) && !/^\s+$/.test(v));
			}],
	['validate-digits', 'Please use numbers only in this field. please avoid spaces or other characters such as dots or commas.', function(v) {
				return Validation.get('IsEmpty').test(v) ||  !/[^\d]/.test(v);
			}],
	['validate-alpha', 'Please use letters only (a-z) in this field.', function (v) {
				return Validation.get('IsEmpty').test(v) ||  /^[a-zA-Z]+$/.test(v)
			}],
	['validate-alphanum', 'Please use only letters (a-z) or numbers (0-9) only in this field. No spaces or other characters are allowed.', function(v) {
				return Validation.get('IsEmpty').test(v) ||  !/\W/.test(v)
			}],
	['validate-date', 'Please enter a valid date.', function(v) {
				var test = new Date(v);
				return Validation.get('IsEmpty').test(v) || !isNaN(test);
			}],
	['validate-email', 'Please enter a valid email address. For example fred@domain.com .', function (v) {
				return Validation.get('IsEmpty').test(v) || /\w{1,}[@][\w\-]{1,}([.]([\w\-]{1,})){1,3}$/.test(v)
			}],
	['validate-url', 'Please enter a valid URL.', function (v) {
				return Validation.get('IsEmpty').test(v) || /^(http|https|ftp):\/\/(([A-Z0-9][A-Z0-9_-]*)(\.[A-Z0-9][A-Z0-9_-]*)+)(:(\d+))?\/?/i.test(v)
			}],
	['validate-date-au', 'Please use this date format: dd/mm/yyyy. For example 17/03/2006 for the 17th of March, 2006.', function(v) {
				if(Validation.get('IsEmpty').test(v)) return true;
				var regex = /^(\d{2})\/(\d{2})\/(\d{4})$/;
				if(!regex.test(v)) return false;
				var d = new Date(v.replace(regex, '$2/$1/$3'));
				return ( parseInt(RegExp.$2, 10) == (1+d.getMonth()) ) && 
							(parseInt(RegExp.$1, 10) == d.getDate()) && 
							(parseInt(RegExp.$3, 10) == d.getFullYear() );
			}],
	['validate-currency-dollar', 'Please enter a valid $ amount. For example $100.00 .', function(v) {
				// [$]1[##][,###]+[.##]
				// [$]1###+[.##]
				// [$]0.##
				// [$].##
				return Validation.get('IsEmpty').test(v) ||  /^\$?\-?([1-9]{1}[0-9]{0,2}(\,[0-9]{3})*(\.[0-9]{0,2})?|[1-9]{1}\d*(\.[0-9]{0,2})?|0(\.[0-9]{0,2})?|(\.[0-9]{1,2})?)$/.test(v)
			}],
	['validate-selection', 'Please make a selection', function(v,elm){
				return elm.options ? elm.selectedIndex > 0 : !Validation.get('IsEmpty').test(v);
			}],
	['validate-one-required', 'Please select one of the above options.', function (v,elm) {
				var p = elm.parentNode;
				var options = p.getElementsByTagName('INPUT');
				return $A(options).any(function(elm) {
					return $F(elm);
				});
			}]
]);
/**
 * @author Ryan Johnson <http://syntacticx.com/>
 * @copyright 2008 PersonalGrid Corporation <http://personalgrid.com/>
 * @package LivePipe UI
 * @license MIT
 * @url http://livepipe.net/core
 * @require prototype.js
 */

if(typeof(Control) == 'undefined')
    Control = {};
    
var $proc = function(proc){
    return typeof(proc) == 'function' ? proc : function(){return proc};
};

var $value = function(value){
    return typeof(value) == 'function' ? value() : value;
};

Object.Event = {
    extend: function(object){
        object._objectEventSetup = function(event_name){
            this._observers = this._observers || {};
            this._observers[event_name] = this._observers[event_name] || [];
        };
        object.observe = function(event_name,observer){
            if(typeof(event_name) == 'string' && typeof(observer) != 'undefined'){
                this._objectEventSetup(event_name);
                if(!this._observers[event_name].include(observer))
                    this._observers[event_name].push(observer);
            }else
                for(var e in event_name)
                    this.observe(e,event_name[e]);
        };
        object.stopObserving = function(event_name,observer){
            this._objectEventSetup(event_name);
            if(event_name && observer)
                this._observers[event_name] = this._observers[event_name].without(observer);
            else if(event_name)
                this._observers[event_name] = [];
            else
                this._observers = {};
        };
        object.observeOnce = function(event_name,outer_observer){
            var inner_observer = function(){
                outer_observer.apply(this,arguments);
                this.stopObserving(event_name,inner_observer);
            }.bind(this);
            this._objectEventSetup(event_name);
            this._observers[event_name].push(inner_observer);
        };
        object.notify = function(event_name){
            this._objectEventSetup(event_name);
            var collected_return_values = [];
            var args = $A(arguments).slice(1);
            try{
                for(var i = 0; i < this._observers[event_name].length; ++i)
                    collected_return_values.push(this._observers[event_name][i].apply(this._observers[event_name][i],args) || null);
            }catch(e){
                if(e == $break)
                    return false;
                else
                    throw e;
            }
            return collected_return_values;
        };
        if(object.prototype){
            object.prototype._objectEventSetup = object._objectEventSetup;
            object.prototype.observe = object.observe;
            object.prototype.stopObserving = object.stopObserving;
            object.prototype.observeOnce = object.observeOnce;
            object.prototype.notify = function(event_name){
                if(object.notify){
                    var args = $A(arguments).slice(1);
                    args.unshift(this);
                    args.unshift(event_name);
                    object.notify.apply(object,args);
                }
                this._objectEventSetup(event_name);
                var args = $A(arguments).slice(1);
                var collected_return_values = [];
                try{
                    if(this.options && this.options[event_name] && typeof(this.options[event_name]) == 'function')
                        collected_return_values.push(this.options[event_name].apply(this,args) || null);
                    var callbacks_copy = this._observers[event_name]; // since original array will be modified after observeOnce calls
                    for(var i = 0; i < callbacks_copy.length; ++i)
                        collected_return_values.push(callbacks_copy[i].apply(callbacks_copy[i],args) || null);
                }catch(e){
                    if(e == $break)
                        return false;
                    else
                        throw e;
                }
                return collected_return_values;
            };
        }
    }
};

/* Begin Core Extensions */

//Element.observeOnce
Element.addMethods({
    observeOnce: function(element,event_name,outer_callback){
        var inner_callback = function(){
            outer_callback.apply(this,arguments);
            Element.stopObserving(element,event_name,inner_callback);
        };
        Element.observe(element,event_name,inner_callback);
    }
});

//mouse:wheel
(function(){
    function wheel(event){
        var delta, element, custom_event;
        // normalize the delta
        if (event.wheelDelta) { // IE & Opera
            delta = event.wheelDelta / 120;
        } else if (event.detail) { // W3C
            delta =- event.detail / 3;
        }
        if (!delta) { return; }
        element = Event.extend(event).target;
        element = Element.extend(element.nodeType === Node.TEXT_NODE ? element.parentNode : element);
        custom_event = element.fire('mouse:wheel',{ delta: delta });
        if (custom_event.stopped) {
            Event.stop(event);
            return false;
        }
    }
    document.observe('mousewheel',wheel);
    document.observe('DOMMouseScroll',wheel);
})();

/* End Core Extensions */

//from PrototypeUI
var IframeShim = Class.create({
    initialize: function() {
        this.element = new Element('iframe',{
            style: 'position:absolute;filter:progid:DXImageTransform.Microsoft.Alpha(opacity=0);display:none',
            src: 'javascript:void(0);',
            frameborder: 0 
        });
        $(document.body).insert(this.element);
    },
    hide: function() {
        this.element.hide();
        return this;
    },
    show: function() {
        this.element.show();
        return this;
    },
    positionUnder: function(element) {
        var element = $(element);
        var offset = element.cumulativeOffset();
        var dimensions = element.getDimensions();
        this.element.setStyle({
            left: offset[0] + 'px',
            top: offset[1] + 'px',
            width: dimensions.width + 'px',
            height: dimensions.height + 'px',
            zIndex: element.getStyle('zIndex') - 1
        }).show();
        return this;
    },
    setBounds: function(bounds) {
        for(prop in bounds)
            bounds[prop] += 'px';
        this.element.setStyle(bounds);
        return this;
    },
    destroy: function() {
        if(this.element)
            this.element.remove();
        return this;
    }
});

/**
 * @author Ryan Johnson <http://syntacticx.com/>
 * @copyright 2008 PersonalGrid Corporation <http://personalgrid.com/>
 * @package LivePipe UI
 * @license MIT
 * @url http://livepipe.net/control/tabs
 * @require prototype.js, livepipe.js
 */

/*global window, document, Prototype, $, $A, $H, $break, Class, Element, Event, Control */

if(typeof(Prototype) == "undefined") {
    throw "Control.Tabs requires Prototype to be loaded."; }
if(typeof(Object.Event) == "undefined") {
    throw "Control.Tabs requires Object.Event to be loaded."; }

Control.Tabs = Class.create({
    initialize: function(tab_list_container,options){
        if(!$(tab_list_container)) {
            throw "Control.Tabs could not find the element: " + tab_list_container; }
        this.activeContainer = false;
        this.activeLink = false;
        this.containers = $H({});
        this.links = [];
        Control.Tabs.instances.push(this);
        this.options = {
            beforeChange: Prototype.emptyFunction,
            afterChange: Prototype.emptyFunction,
            hover: false,
            linkSelector: 'li a',
            setClassOnContainer: false,
            activeClassName: 'active',
            defaultTab: 'first',
            autoLinkExternal: true,
            targetRegExp: /#(.+)$/,
            showFunction: Element.show,
            hideFunction: Element.hide
        };
        Object.extend(this.options,options || {});
        (typeof(this.options.linkSelector) == 'string' ? 
            $(tab_list_container).select(this.options.linkSelector) : 
            this.options.linkSelector($(tab_list_container))
        ).findAll(function(link){
            return (/^#/).exec(link.href.replace(window.location.href.split('#')[0],''));
        }).each(function(link){
            this.addTab(link);
        }.bind(this));
        this.containers.values().each(Element.hide);
        if(this.options.defaultTab == 'first') {
            this.setActiveTab(this.links.first());
        } else if(this.options.defaultTab == 'last') {
            this.setActiveTab(this.links.last());
        } else {
            this.setActiveTab(this.options.defaultTab); }
        var targets = this.options.targetRegExp.exec(window.location);
        if(targets && targets[1]){
            targets[1].split(',').each(function(target){
                this.setActiveTab(this.links.find(function(link){
                    return link.key == target;
                }));
            }.bind(this));
        }
        if(this.options.autoLinkExternal){
            $A(document.getElementsByTagName('a')).each(function(a){
                if(!this.links.include(a)){
                    var clean_href = a.href.replace(window.location.href.split('#')[0],'');
                    if(clean_href.substring(0,1) == '#'){
                        if(this.containers.keys().include(clean_href.substring(1))){
                            $(a).observe('click',function(event,clean_href){
                                this.setActiveTab(clean_href.substring(1));
                            }.bindAsEventListener(this,clean_href));
                        }
                    }
                }
            }.bind(this));
        }
    },
    addTab: function(link){
        this.links.push(link);
        link.key = link.getAttribute('href').replace(window.location.href.split('#')[0],'').split('#').last().replace(/#/,'');
        var container = $(link.key);
        if(!container) {
            throw "Control.Tabs: #" + link.key + " was not found on the page."; }
        this.containers.set(link.key,container);
        link[this.options.hover ? 'onmouseover' : 'onclick'] = function(link){
            if(window.event) {
                Event.stop(window.event); }
            this.setActiveTab(link);
            return false;
        }.bind(this,link);
    },
    setActiveTab: function(link){
        if(!link && typeof(link) == 'undefined') {
            return; }
        if(typeof(link) == 'string'){
            this.setActiveTab(this.links.find(function(_link){
                return _link.key == link;
            }));
        }else if(typeof(link) == 'number'){
            this.setActiveTab(this.links[link]);
        }else{
            if(this.notify('beforeChange',this.activeContainer,this.containers.get(link.key)) === false) {
                return; }
            if(this.activeContainer) {
                this.options.hideFunction(this.activeContainer); }
            this.links.each(function(item){
                (this.options.setClassOnContainer ? $(item.parentNode) : item).removeClassName(this.options.activeClassName);
            }.bind(this));
            (this.options.setClassOnContainer ? $(link.parentNode) : link).addClassName(this.options.activeClassName);
            this.activeContainer = this.containers.get(link.key);
            this.activeLink = link;
            this.options.showFunction(this.containers.get(link.key));
            this.notify('afterChange',this.containers.get(link.key));
        }
    },
    next: function(){
        this.links.each(function(link,i){
            if(this.activeLink == link && this.links[i + 1]){
                this.setActiveTab(this.links[i + 1]);
                throw $break;
            }
        }.bind(this));
    },
    previous: function(){
        this.links.each(function(link,i){
            if(this.activeLink == link && this.links[i - 1]){
                this.setActiveTab(this.links[i - 1]);
                throw $break;
            }
        }.bind(this));
    },
    first: function(){
        this.setActiveTab(this.links.first());
    },
    last: function(){
        this.setActiveTab(this.links.last());
    }
});
Object.extend(Control.Tabs,{
    instances: [],
    findByTabId: function(id){
        return Control.Tabs.instances.find(function(tab){
            return tab.links.find(function(link){
                return link.key == id;
            });
        });
    }
});
Object.Event.extend(Control.Tabs);

/**
 * Copyright (c)2005-2007 Matt Kruse (javascripttoolbox.com)
 * 
 * Dual licensed under the MIT and GPL licenses. 
 * This basically means you can use this code however you want for
 * free, but don't claim to have written it yourself!
 * Donations always accepted: http://www.JavascriptToolbox.com/donate/
 * 
 * Please do not link to the .js files on javascripttoolbox.com from
 * your site. Copy the files locally to your server instead.
 * 
 */
// Global objects to keep track of DynamicOptionList objects created on the page
var dynamicOptionListCount=0;
var dynamicOptionListObjects = new Array();

// Init call to setup lists after page load. One call to this function sets up all lists.
function initDynamicOptionLists() {
	// init each DynamicOptionList object
	for (var i=0; i<dynamicOptionListObjects.length; i++) {
		var dol = dynamicOptionListObjects[i];

		// Find the form associated with this list
		if (dol.formName!=null) { 
			dol.form = document.forms[dol.formName];
		}
		else if (dol.formIndex!=null) {
			dol.form = document.forms[dol.formIndex];
		}
		else {
			// Form wasn't set manually, so go find it!
			// Search for the first form element name in the lists
			var name = dol.fieldNames[0][0];
			for (var f=0; f<document.forms.length; f++) {
				if (typeof(document.forms[f][name])!="undefined") {
					dol.form = document.forms[f];
					break;
				}
			}
			if (dol.form==null) {
				alert("ERROR: Couldn't find form element "+name+" in any form on the page! Init aborted"); return;
			}
		}

		// Form is found, now set the onchange attributes of each dependent select box
		for (var j=0; j<dol.fieldNames.length; j++) {
			// For each set of field names...
			for (var k=0; k<dol.fieldNames[j].length-1; k++) {
				// For each field in the set...
				var selObj = dol.form[dol.fieldNames[j][k]];
				if (typeof(selObj)=="undefined") { alert("Select box named "+dol.fieldNames[j][k]+" could not be found in the form. Init aborted"); return; }
				// Map the HTML options in the first select into the options we created
				if (k==0) {
					if (selObj.options!=null) {
						for (l=0; l<selObj.options.length; l++) {
							var sopt = selObj.options[l];
							var m = dol.findMatchingOptionInArray(dol.options,sopt.text,sopt.value,false);
							if (m!=null) {
								var reselectForNN6 = sopt.selected;
								var m2 = new Option(sopt.text, sopt.value, sopt.defaultSelected, sopt.selected);
								m2.selected = sopt.selected; // For some reason I need to do this to make NN4 happy
								m2.defaultSelected = sopt.defaultSelected;
								m2.DOLOption = m;
								selObj.options[l] = m2;
								selObj.options[l].selected = reselectForNN6; // Reselect this option for NN6 to be happy. Yuck.
							}
						}
					}
				}
				if (selObj.onchange==null) {
					// We only modify the onChange attribute if it's empty! Otherwise do it yourself in your source!
					selObj.onchange = new Function("dynamicOptionListObjects["+dol.index+"].change(this)");
				}
			}
		}
	}
	// Set the preselectd options on page load 
	resetDynamicOptionLists();
}

// This function populates lists with the preselected values. 
// It's pulled out into a separate function so it can be hooked into a 'reset' button on a form
// Optionally passed a form object which should be the only form reset
function resetDynamicOptionLists(theform) {
	// reset each DynamicOptionList object
	for (var i=0; i<dynamicOptionListObjects.length; i++) {
		var dol = dynamicOptionListObjects[i];
		if (typeof(theform)=="undefined" || theform==null || theform==dol.form) {
			for (var j=0; j<dol.fieldNames.length; j++) {
				dol.change(dol.form[dol.fieldNames[j][0]],true); // Second argument says to use preselected values rather than default values
			}
		}
	}
}

// An object to represent an Option() but just for data-holding
function DOLOption(text,value,defaultSelected,selected) {
	this.text = text;
	this.value = value;
	this.defaultSelected = defaultSelected;
	this.selected = selected;
	this.options = new Array(); // To hold sub-options
	return this;
}

// DynamicOptionList CONSTRUCTOR
function DynamicOptionList() {
	this.form = null;// The form this list belongs to
	this.options = new Array();// Holds the options of dependent lists
	this.longestString = new Array();// Longest string that is currently a potential option (for Netscape)
	this.numberOfOptions = new Array();// The total number of options that might be displayed, to build dummy options (for Netscape)
	this.currentNode = null;// The current node that has been selected with forValue() or forText()
	this.currentField = null;// The current field that is selected to be used for setValue()
	this.currentNodeDepth = 0;// How far down the tree the currentNode is
	this.fieldNames = new Array();// Lists of dependent fields which use this object
	this.formIndex = null;// The index of the form to associate with this list
	this.formName = null;// The name of the form to associate with this list
	this.fieldListIndexes = new Object();// Hold the field lists index where fields exist
	this.fieldIndexes = new Object();// Hold the index within the list where fields exist
	this.selectFirstOption = true;// Whether or not to select the first option by default if no options are default or preselected, otherwise set the selectedIndex = -1
	this.numberOfOptions = new Array();// Store the max number of options for a given option list
	this.longestString = new Array();// Store the longest possible string 
	this.values = new Object(); // Will hold the preselected values for fields, by field name
	
	// Method mappings
	this.forValue = DOL_forValue;
	this.forText = DOL_forText;
	this.forField = DOL_forField;
	this.forX = DOL_forX;
	this.addOptions = DOL_addOptions;
	this.addOptionsTextValue = DOL_addOptionsTextValue;
	this.setDefaultOptions = DOL_setDefaultOptions;
	this.setValues = DOL_setValues;
	this.setValue = DOL_setValues;
	this.setFormIndex = DOL_setFormIndex;
	this.setFormName = DOL_setFormName;
	this.printOptions = DOL_printOptions;
	this.addDependentFields = DOL_addDependentFields;
	this.change = DOL_change;
	this.child = DOL_child;
	this.selectChildOptions = DOL_selectChildOptions;
	this.populateChild = DOL_populateChild;
	this.change = DOL_change;
	this.addNewOptionToList = DOL_addNewOptionToList;
	this.findMatchingOptionInArray = DOL_findMatchingOptionInArray;

	// Optionally pass in the dependent field names
	if (arguments.length > 0) {
		// Process arguments and add dependency groups
		for (var i=0; i<arguments.length; i++) {
			this.fieldListIndexes[arguments[i].toString()] = this.fieldNames.length;
			this.fieldIndexes[arguments[i].toString()] = i;
		}
		this.fieldNames[this.fieldNames.length] = arguments;
	}
	
	// Add this object to the global array of dynamicoptionlist objects
	this.index = window.dynamicOptionListCount++;
	window["dynamicOptionListObjects"][this.index] = this;
}

// Given an array of Option objects, search for an existing option that matches value, text, or both
function DOL_findMatchingOptionInArray(a,text,value,exactMatchRequired) {
	if (a==null || typeof(a)=="undefined") { return null; }
	var value_match = null; // Whether or not a value has been matched
	var text_match = null; // Whether or not a text has been matched
	for (var i=0; i<a.length; i++) {
		var opt = a[i];
		// If both value and text match, return it right away
		if (opt.value==value && opt.text==text) { return opt; }
		if (!exactMatchRequired) {
			// If value matches, store it until we complete scanning the list
			if (value_match==null && value!=null && opt.value==value) {
				value_match = opt;
			}
			// If text matches, store it for later
			if (text_match==null && text!=null && opt.text==text) {
				text_match = opt;
			}
		}
	}
	return (value_match!=null)?value_match:text_match;
}

// Util function used by forValue and forText
function DOL_forX(s,type) {
	if (this.currentNode==null) { this.currentNodeDepth=0; }
	var useNode = (this.currentNode==null)?this:this.currentNode;
	var o = this.findMatchingOptionInArray(useNode["options"],(type=="text")?s:null,(type=="value")?s:null,false);
	if (o==null) {
		o = new DOLOption(null,null,false,false);
		o[type] = s;
		useNode.options[useNode.options.length] = o;
	}
	this.currentNode = o;
	this.currentNodeDepth++;
	return this;
}

// Set the portion of the list structure that is to be used by a later operation like addOptions
function DOL_forValue(s) { return this.forX(s,"value"); }

// Set the portion of the list structure that is to be used by a later operation like addOptions
function DOL_forText(s) { return this.forX(s,"text"); }

// Set the field to be used for setValue() calls
function DOL_forField(f) { this.currentField = f; return this; }

// Create and add an option to a list, avoiding duplicates
function DOL_addNewOptionToList(a, text, value, defaultSelected) {
	var o = new DOLOption(text,value,defaultSelected,false);
	// Add the option to the array
	if (a==null) { a = new Array(); }
	for (var i=0; i<a.length; i++) {
		if (a[i].text==o.text && a[i].value==o.value) {
			if (o.selected) { 
				a[i].selected=true;
			}
			if (o.defaultSelected) {
				a[i].defaultSelected = true;
			}
			return a;
		}
	}
	a[a.length] = o;
}

// Add sub-options to the currently-selected node, with the same text and value for each option
function DOL_addOptions() {
	if (this.currentNode==null) { this.currentNode = this; }
	if (this.currentNode["options"] == null) { this.currentNode["options"] = new Array(); }
	for (var i=0; i<arguments.length; i++) {
		var text = arguments[i];
		this.addNewOptionToList(this.currentNode.options,text,text,false);
		if (typeof(this.numberOfOptions[this.currentNodeDepth])=="undefined") {
			this.numberOfOptions[this.currentNodeDepth]=0;
		}
		if (this.currentNode.options.length > this.numberOfOptions[this.currentNodeDepth]) {
			this.numberOfOptions[this.currentNodeDepth] = this.currentNode.options.length;
		}
		if (typeof(this.longestString[this.currentNodeDepth])=="undefined" || (text.length > this.longestString[this.currentNodeDepth].length)) {
			this.longestString[this.currentNodeDepth] = text;
		}
	}
	this.currentNode = null;
	this.currentNodeDepth = 0;
}

// Add sub-options to the currently-selected node, specifying separate text and values for each option
function DOL_addOptionsTextValue() {
	if (this.currentNode==null) { this.currentNode = this; }
	if (this.currentNode["options"] == null) { this.currentNode["options"] = new Array(); }
	for (var i=0; i<arguments.length; i++) {
		var text = arguments[i++];
		var value = arguments[i];
		this.addNewOptionToList(this.currentNode.options,text,value,false);
		if (typeof(this.numberOfOptions[this.currentNodeDepth])=="undefined") {
			this.numberOfOptions[this.currentNodeDepth]=0;
		}
		if (this.currentNode.options.length > this.numberOfOptions[this.currentNodeDepth]) {
			this.numberOfOptions[this.currentNodeDepth] = this.currentNode.options.length;
		}
		if (typeof(this.longestString[this.currentNodeDepth])=="undefined" || (text.length > this.longestString[this.currentNodeDepth].length)) {
			this.longestString[this.currentNodeDepth] = text;
		}
	}
	this.currentNode = null;
	this.currentNodeDepth = 0;
}

// Find the first dependent list of a select box
// If it's the last list in a chain, return null because there are no children
function DOL_child(obj) {
	var listIndex = this.fieldListIndexes[obj.name];
	var index = this.fieldIndexes[obj.name];
	if (index < (this.fieldNames[listIndex].length-1)) {
		return this.form[this.fieldNames[listIndex][index+1]];
	}
	return null;
}

// Set the options which should be selected by default for a certain value in the parent
function DOL_setDefaultOptions() {
	if (this.currentNode==null) { this.currentNode = this; }
	for (var i=0; i<arguments.length; i++) {
		var o = this.findMatchingOptionInArray(this.currentNode.options,null,arguments[i],false);
		if (o!=null) {
			o.defaultSelected = true;
		}
	}
	this.currentNode = null;
}

// Set the options which should be selected when the page loads. This is different than the default value and ONLY applies when the page LOADS
function DOL_setValues() {
	if (this.currentField==null) { 
		alert("Can't call setValues() without using forField() first!");
		return;
	}
	if (typeof(this.values[this.currentField])=="undefined") {
		this.values[this.currentField] = new Object();
	}
	for (var i=0; i<arguments.length; i++) {
		this.values[this.currentField][arguments[i]] = true;
	}
	this.currentField = null;
}

// Manually set the form for the object using an index
function DOL_setFormIndex(i) {
	this.formIndex = i;
}

// Manually set the form for the object using a form name
function DOL_setFormName(n) {
	this.formName = n;
}

// Print blank <option> objects for Netscape4, since it refuses to grow or shrink select boxes for new options
function DOL_printOptions(name) {
	// Only need to write out "dummy" options for Netscape4
    if ((navigator.appName == 'Netscape') && (parseInt(navigator.appVersion) <= 4)){
		var index = this.fieldIndexes[name];
		var ret = "";
		if (typeof(this.numberOfOptions[index])!="undefined") {
			for (var i=0; i<this.numberOfOptions[index]; i++) { 
				ret += "<OPTION>";
			}
		}
		ret += "<OPTION>";
		if (typeof(this.longestString[index])!="undefined") {
			for (var i=0; i<this.longestString[index].length; i++) {
				ret += "_";
			}
		}
		document.writeln(ret);
	}
}

// Add a list of field names which use this option-mapping object.
// A single mapping object may be used by multiple sets of fields
function DOL_addDependentFields() {
	for (var i=0; i<arguments.length; i++) {
		this.fieldListIndexes[arguments[i].toString()] = this.fieldNames.length;
		this.fieldIndexes[arguments[i].toString()] = i;
	}
	this.fieldNames[this.fieldNames.length] = arguments;
}

// Called when a parent select box is changed. It populates its direct child, then calls change on the child object to continue the population.
function DOL_change(obj, usePreselected) {
	if (usePreselected==null || typeof(usePreselected)=="undefined") { usePreselected = false; }
	var changedListIndex = this.fieldListIndexes[obj.name];
	var changedIndex = this.fieldIndexes[obj.name];
	var child = this.child(obj);
	if (child == null) { return; } // No child, no need to continue
	if (obj.type == "select-one") {
		// Treat single-select differently so we don't have to scan the entire select list, which could potentially speed things up
		if (child.options!=null) {
			child.options.length=0; // Erase all the options from the child so we can re-populate
		}
		if (obj.options!=null && obj.options.length>0 && obj.selectedIndex>=0) {
			var o = obj.options[obj.selectedIndex];
			this.populateChild(o.DOLOption,child,usePreselected);
			this.selectChildOptions(child,usePreselected);
		}
	}
	else if (obj.type == "select-multiple") {
		// For each selected value in the parent, find the options to fill in for this list
		// Loop through the child list and keep track of options that are currently selected
		var currentlySelectedOptions = new Array();
		if (!usePreselected) {
			for (var i=0; i<child.options.length; i++) {
				var co = child.options[i];
				if (co.selected) {
					this.addNewOptionToList(currentlySelectedOptions, co.text, co.value, co.defaultSelected);
				}
			}
		}
		child.options.length=0;
		if (obj.options!=null) {
			var obj_o = obj.options;
			// For each selected option in the parent...
			for (var i=0; i<obj_o.length; i++) {
				if (obj_o[i].selected) {
					// if option is selected, add its children to the list
 					this.populateChild(obj_o[i].DOLOption,child,usePreselected);
				}
			}
			// Now go through and re-select any options which were selected before
			var atLeastOneSelected = false;
			if (!usePreselected) {
				for (var i=0; i<child.options.length; i++) {
					var m = this.findMatchingOptionInArray(currentlySelectedOptions,child.options[i].text,child.options[i].value,true);
					if (m!=null) {
						child.options[i].selected = true;
						atLeastOneSelected = true;
					}
				}
			}
			if (!atLeastOneSelected) {	
				this.selectChildOptions(child,usePreselected);
			}
		}
	}
	// Change all the way down the chain
	this.change(child,usePreselected);
}
function DOL_populateChild(dolOption,childSelectObj,usePreselected) {
	// If this opton has sub-options, populate the child list with them
	if (dolOption!=null && dolOption.options!=null) {
		for (var j=0; j<dolOption.options.length; j++) {
			var srcOpt = dolOption.options[j];
			if (childSelectObj.options==null) { childSelectObj.options = new Array(); }
			// Put option into select list
			var duplicate = false;
			var preSelectedExists = false;
			for (var k=0; k<childSelectObj.options.length; k++) {
				var csi = childSelectObj.options[k];
				if (csi.text==srcOpt.text && csi.value==srcOpt.value) {
					duplicate = true;
					break;
				}
			}
			if (!duplicate) {
				var newopt = new Option(srcOpt.text, srcOpt.value, false, false);
				newopt.selected = false; // Again, we have to do these two statements for NN4 to work
				newopt.defaultSelected = false;
				newopt.DOLOption = srcOpt;
				childSelectObj.options[childSelectObj.options.length] = newopt;
			}
		}
	}
}

// Once a child select is populated, go back over it to select options which should be selected
function DOL_selectChildOptions(obj,usePreselected) {
	// Look to see if any options are preselected=true. If so, then set then selected if usePreselected=true, otherwise set defaults
	var values = this.values[obj.name];
	var preselectedExists = false;
	if (usePreselected && values!=null && typeof(values)!="undefined") {
		for (var i=0; i<obj.options.length; i++) {
			var v = obj.options[i].value;
			if (v!=null && values[v]!=null && typeof(values[v])!="undefined") {
				preselectedExists = true;
				break;
			}
		}
	}
	// Go back over all the options to do the selection
	var atLeastOneSelected = false;
	for (var i=0; i<obj.options.length; i++) {
		var o = obj.options[i];
		//if(o.value == 'pages'){alert(preselectedExists)}
		if (preselectedExists && o.value!=null && values[o.value]!=null && typeof(values[o.value])!="undefined") {
			o.selected = true;
			atLeastOneSelected = true;
		}
		else if (!preselectedExists && o.DOLOption!=null && o.DOLOption.defaultSelected) {
			o.selected = true;
			atLeastOneSelected = true;
		}
		else {
			//o.selected = false;
		}
	}
	// If nothing else was selected, select the first one by default
	if (this.selectFirstOption && !atLeastOneSelected && obj.options.length>0) {
		obj.options[0].selected = true;
	}
	else if (!atLeastOneSelected &&  obj.type=="select-one") {
		obj.selectedIndex = -1;
	}
}
/**
 * jscolor - JavaScript Color Picker
 *
 * @link    http://jscolor.com
 * @license For open source use: GPLv3
 *          For commercial use: JSColor Commercial License
 * @author  Jan Odvarko
 *
 * See usage examples at http://jscolor.com/examples/
 */"use strict";window.jscolor||(window.jscolor=function(){var e={register:function(){e.attachDOMReadyEvent(e.init),e.attachEvent(document,"mousedown",e.onDocumentMouseDown),e.attachEvent(document,"touchstart",e.onDocumentTouchStart),e.attachEvent(window,"resize",e.onWindowResize)},init:function(){e.jscolor.lookupClass&&e.jscolor.installByClassName(e.jscolor.lookupClass)},tryInstallOnElements:function(t,n){var r=new RegExp("(^|\\s)("+n+")(\\s*(\\{[^}]*\\})|\\s|$)","i");for(var i=0;i<t.length;i+=1){if(t[i].type!==undefined&&t[i].type.toLowerCase()=="color"&&e.isColorAttrSupported)continue;var s;if(!t[i].jscolor&&t[i].className&&(s=t[i].className.match(r))){var o=t[i],u=null,a=e.getDataAttr(o,"jscolor");a!==null?u=a:s[4]&&(u=s[4]);var f={};if(u)try{f=(new Function("return ("+u+")"))()}catch(l){e.warn("Error parsing jscolor options: "+l+":\n"+u)}o.jscolor=new e.jscolor(o,f)}}},isColorAttrSupported:function(){var e=document.createElement("input");if(e.setAttribute){e.setAttribute("type","color");if(e.type.toLowerCase()=="color")return!0}return!1}(),isCanvasSupported:function(){var e=document.createElement("canvas");return!!e.getContext&&!!e.getContext("2d")}(),fetchElement:function(e){return typeof e=="string"?document.getElementById(e):e},isElementType:function(e,t){return e.nodeName.toLowerCase()===t.toLowerCase()},getDataAttr:function(e,t){var n="data-"+t,r=e.getAttribute(n);return r!==null?r:null},attachEvent:function(e,t,n){e.addEventListener?e.addEventListener(t,n,!1):e.attachEvent&&e.attachEvent("on"+t,n)},detachEvent:function(e,t,n){e.removeEventListener?e.removeEventListener(t,n,!1):e.detachEvent&&e.detachEvent("on"+t,n)},_attachedGroupEvents:{},attachGroupEvent:function(t,n,r,i){e._attachedGroupEvents.hasOwnProperty(t)||(e._attachedGroupEvents[t]=[]),e._attachedGroupEvents[t].push([n,r,i]),e.attachEvent(n,r,i)},detachGroupEvents:function(t){if(e._attachedGroupEvents.hasOwnProperty(t)){for(var n=0;n<e._attachedGroupEvents[t].length;n+=1){var r=e._attachedGroupEvents[t][n];e.detachEvent(r[0],r[1],r[2])}delete e._attachedGroupEvents[t]}},attachDOMReadyEvent:function(e){var t=!1,n=function(){t||(t=!0,e())};if(document.readyState==="complete"){setTimeout(n,1);return}if(document.addEventListener)document.addEventListener("DOMContentLoaded",n,!1),window.addEventListener("load",n,!1);else if(document.attachEvent){document.attachEvent("onreadystatechange",function(){document.readyState==="complete"&&(document.detachEvent("onreadystatechange",arguments.callee),n())}),window.attachEvent("onload",n);if(document.documentElement.doScroll&&window==window.top){var r=function(){if(!document.body)return;try{document.documentElement.doScroll("left"),n()}catch(e){setTimeout(r,1)}};r()}}},warn:function(e){window.console&&window.console.warn&&window.console.warn(e)},preventDefault:function(e){e.preventDefault&&e.preventDefault(),e.returnValue=!1},captureTarget:function(t){t.setCapture&&(e._capturedTarget=t,e._capturedTarget.setCapture())},releaseTarget:function(){e._capturedTarget&&(e._capturedTarget.releaseCapture(),e._capturedTarget=null)},fireEvent:function(e,t){if(!e)return;if(document.createEvent){var n=document.createEvent("HTMLEvents");n.initEvent(t,!0,!0),e.dispatchEvent(n)}else if(document.createEventObject){var n=document.createEventObject();e.fireEvent("on"+t,n)}else e["on"+t]&&e["on"+t]()},classNameToList:function(e){return e.replace(/^\s+|\s+$/g,"").split(/\s+/)},hasClass:function(e,t){return t?-1!=(" "+e.className.replace(/\s+/g," ")+" ").indexOf(" "+t+" "):!1},setClass:function(t,n){var r=e.classNameToList(n);for(var i=0;i<r.length;i+=1)e.hasClass(t,r[i])||(t.className+=(t.className?" ":"")+r[i])},unsetClass:function(t,n){var r=e.classNameToList(n);for(var i=0;i<r.length;i+=1){var s=new RegExp("^\\s*"+r[i]+"\\s*|"+"\\s*"+r[i]+"\\s*$|"+"\\s+"+r[i]+"(\\s+)","g");t.className=t.className.replace(s,"$1")}},getStyle:function(e){return window.getComputedStyle?window.getComputedStyle(e):e.currentStyle},setStyle:function(){var e=document.createElement("div"),t=function(t){for(var n=0;n<t.length;n+=1)if(t[n]in e.style)return t[n]},n={borderRadius:t(["borderRadius","MozBorderRadius","webkitBorderRadius"]),boxShadow:t(["boxShadow","MozBoxShadow","webkitBoxShadow"])};return function(e,t,r){switch(t.toLowerCase()){case"opacity":var i=Math.round(parseFloat(r)*100);e.style.opacity=r,e.style.filter="alpha(opacity="+i+")";break;default:e.style[n[t]]=r}}}(),setBorderRadius:function(t,n){e.setStyle(t,"borderRadius",n||"0")},setBoxShadow:function(t,n){e.setStyle(t,"boxShadow",n||"none")},getElementPos:function(t,n){var r=0,i=0,s=t.getBoundingClientRect();r=s.left,i=s.top;if(!n){var o=e.getViewPos();r+=o[0],i+=o[1]}return[r,i]},getElementSize:function(e){return[e.offsetWidth,e.offsetHeight]},getAbsPointerPos:function(e){e||(e=window.event);var t=0,n=0;return typeof e.changedTouches!="undefined"&&e.changedTouches.length?(t=e.changedTouches[0].clientX,n=e.changedTouches[0].clientY):typeof e.clientX=="number"&&(t=e.clientX,n=e.clientY),{x:t,y:n}},getRelPointerPos:function(e){e||(e=window.event);var t=e.target||e.srcElement,n=t.getBoundingClientRect(),r=0,i=0,s=0,o=0;return typeof e.changedTouches!="undefined"&&e.changedTouches.length?(s=e.changedTouches[0].clientX,o=e.changedTouches[0].clientY):typeof e.clientX=="number"&&(s=e.clientX,o=e.clientY),r=s-n.left,i=o-n.top,{x:r,y:i}},getViewPos:function(){var e=document.documentElement;return[(window.pageXOffset||e.scrollLeft)-(e.clientLeft||0),(window.pageYOffset||e.scrollTop)-(e.clientTop||0)]},getViewSize:function(){var e=document.documentElement;return[window.innerWidth||e.clientWidth,window.innerHeight||e.clientHeight]},redrawPosition:function(){if(e.picker&&e.picker.owner){var t=e.picker.owner,n,r;t.fixed?(n=e.getElementPos(t.targetElement,!0),r=[0,0]):(n=e.getElementPos(t.targetElement),r=e.getViewPos());var i=e.getElementSize(t.targetElement),s=e.getViewSize(),o=e.getPickerOuterDims(t),u,a,f;switch(t.position.toLowerCase()){case"left":u=1,a=0,f=-1;break;case"right":u=1,a=0,f=1;break;case"top":u=0,a=1,f=-1;break;default:u=0,a=1,f=1}var l=(i[a]+o[a])/2;if(!t.smartPosition)var c=[n[u],n[a]+i[a]-l+l*f];else var c=[-r[u]+n[u]+o[u]>s[u]?-r[u]+n[u]+i[u]/2>s[u]/2&&n[u]+i[u]-o[u]>=0?n[u]+i[u]-o[u]:n[u]:n[u],-r[a]+n[a]+i[a]+o[a]-l+l*f>s[a]?-r[a]+n[a]+i[a]/2>s[a]/2&&n[a]+i[a]-l-l*f>=0?n[a]+i[a]-l-l*f:n[a]+i[a]-l+l*f:n[a]+i[a]-l+l*f>=0?n[a]+i[a]-l+l*f:n[a]+i[a]-l-l*f];var h=c[u],p=c[a],d=t.fixed?"fixed":"absolute",v=(c[0]+o[0]>n[0]||c[0]<n[0]+i[0])&&c[1]+o[1]<n[1]+i[1];e._drawPosition(t,h,p,d,v)}},_drawPosition:function(t,n,r,i,s){var o=s?0:t.shadowBlur;e.picker.wrap.style.position=i,e.picker.wrap.style.left=n+"px",e.picker.wrap.style.top=r+"px",e.setBoxShadow(e.picker.boxS,t.shadow?new e.BoxShadow(0,o,t.shadowBlur,0,t.shadowColor):null)},getPickerDims:function(t){var n=!!e.getSliderComponent(t),r=[2*t.insetWidth+2*t.padding+t.width+(n?2*t.insetWidth+e.getPadToSliderPadding(t)+t.sliderSize:0),2*t.insetWidth+2*t.padding+t.height+(t.closable?2*t.insetWidth+t.padding+t.buttonHeight:0)];return r},getPickerOuterDims:function(t){var n=e.getPickerDims(t);return[n[0]+2*t.borderWidth,n[1]+2*t.borderWidth]},getPadToSliderPadding:function(e){return Math.max(e.padding,1.5*(2*e.pointerBorderWidth+e.pointerThickness))},getPadYComponent:function(e){switch(e.mode.charAt(1).toLowerCase()){case"v":return"v"}return"s"},getSliderComponent:function(e){if(e.mode.length>2)switch(e.mode.charAt(2).toLowerCase()){case"s":return"s";case"v":return"v"}return null},onDocumentMouseDown:function(t){t||(t=window.event);var n=t.target||t.srcElement;n._jscLinkedInstance?n._jscLinkedInstance.showOnClick&&n._jscLinkedInstance.show():n._jscControlName?e.onControlPointerStart(t,n,n._jscControlName,"mouse"):e.picker&&e.picker.owner&&e.picker.owner.hide()},onDocumentTouchStart:function(t){t||(t=window.event);var n=t.target||t.srcElement;n._jscLinkedInstance?n._jscLinkedInstance.showOnClick&&n._jscLinkedInstance.show():n._jscControlName?e.onControlPointerStart(t,n,n._jscControlName,"touch"):e.picker&&e.picker.owner&&e.picker.owner.hide()},onWindowResize:function(t){e.redrawPosition()},onParentScroll:function(t){e.picker&&e.picker.owner&&e.picker.owner.hide()},_pointerMoveEvent:{mouse:"mousemove",touch:"touchmove"},_pointerEndEvent:{mouse:"mouseup",touch:"touchend"},_pointerOrigin:null,_capturedTarget:null,onControlPointerStart:function(t,n,r,i){var s=n._jscInstance;e.preventDefault(t),e.captureTarget(n);var o=function(s,o){e.attachGroupEvent("drag",s,e._pointerMoveEvent[i],e.onDocumentPointerMove(t,n,r,i,o)),e.attachGroupEvent("drag",s,e._pointerEndEvent[i],e.onDocumentPointerEnd(t,n,r,i))};o(document,[0,0]);if(window.parent&&window.frameElement){var u=window.frameElement.getBoundingClientRect(),a=[-u.left,-u.top];o(window.parent.window.document,a)}var f=e.getAbsPointerPos(t),l=e.getRelPointerPos(t);e._pointerOrigin={x:f.x-l.x,y:f.y-l.y};switch(r){case"pad":switch(e.getSliderComponent(s)){case"s":s.hsv[1]===0&&s.fromHSV(null,100,null);break;case"v":s.hsv[2]===0&&s.fromHSV(null,null,100)}e.setPad(s,t,0,0);break;case"sld":e.setSld(s,t,0)}e.dispatchFineChange(s)},onDocumentPointerMove:function(t,n,r,i,s){return function(t){var i=n._jscInstance;switch(r){case"pad":t||(t=window.event),e.setPad(i,t,s[0],s[1]),e.dispatchFineChange(i);break;case"sld":t||(t=window.event),e.setSld(i,t,s[1]),e.dispatchFineChange(i)}}},onDocumentPointerEnd:function(t,n,r,i){return function(t){var r=n._jscInstance;e.detachGroupEvents("drag"),e.releaseTarget(),e.dispatchChange(r)}},dispatchChange:function(t){t.valueElement&&e.isElementType(t.valueElement,"input")&&e.fireEvent(t.valueElement,"change")},dispatchFineChange:function(e){if(e.onFineChange){var t;typeof e.onFineChange=="string"?t=new Function(e.onFineChange):t=e.onFineChange,t.call(e)}},setPad:function(t,n,r,i){var s=e.getAbsPointerPos(n),o=r+s.x-e._pointerOrigin.x-t.padding-t.insetWidth,u=i+s.y-e._pointerOrigin.y-t.padding-t.insetWidth,a=o*(360/(t.width-1)),f=100-u*(100/(t.height-1));switch(e.getPadYComponent(t)){case"s":t.fromHSV(a,f,null,e.leaveSld);break;case"v":t.fromHSV(a,null,f,e.leaveSld)}},setSld:function(t,n,r){var i=e.getAbsPointerPos(n),s=r+i.y-e._pointerOrigin.y-t.padding-t.insetWidth,o=100-s*(100/(t.height-1));switch(e.getSliderComponent(t)){case"s":t.fromHSV(null,o,null,e.leavePad);break;case"v":t.fromHSV(null,null,o,e.leavePad)}},_vmlNS:"jsc_vml_",_vmlCSS:"jsc_vml_css_",_vmlReady:!1,initVML:function(){if(!e._vmlReady){var t=document;t.namespaces[e._vmlNS]||t.namespaces.add(e._vmlNS,"urn:schemas-microsoft-com:vml");if(!t.styleSheets[e._vmlCSS]){var n=["shape","shapetype","group","background","path","formulas","handles","fill","stroke","shadow","textbox","textpath","imagedata","line","polyline","curve","rect","roundrect","oval","arc","image"],r=t.createStyleSheet();r.owningElement.id=e._vmlCSS;for(var i=0;i<n.length;i+=1)r.addRule(e._vmlNS+"\\:"+n[i],"behavior:url(#default#VML);")}e._vmlReady=!0}},createPalette:function(){var t={elm:null,draw:null};if(e.isCanvasSupported){var n=document.createElement("canvas"),r=n.getContext("2d"),i=function(e,t,i){n.width=e,n.height=t,r.clearRect(0,0,n.width,n.height);var s=r.createLinearGradient(0,0,n.width,0);s.addColorStop(0,"#F00"),s.addColorStop(1/6,"#FF0"),s.addColorStop(2/6,"#0F0"),s.addColorStop(.5,"#0FF"),s.addColorStop(4/6,"#00F"),s.addColorStop(5/6,"#F0F"),s.addColorStop(1,"#F00"),r.fillStyle=s,r.fillRect(0,0,n.width,n.height);var o=r.createLinearGradient(0,0,0,n.height);switch(i.toLowerCase()){case"s":o.addColorStop(0,"rgba(255,255,255,0)"),o.addColorStop(1,"rgba(255,255,255,1)");break;case"v":o.addColorStop(0,"rgba(0,0,0,0)"),o.addColorStop(1,"rgba(0,0,0,1)")}r.fillStyle=o,r.fillRect(0,0,n.width,n.height)};t.elm=n,t.draw=i}else{e.initVML();var s=document.createElement("div");s.style.position="relative",s.style.overflow="hidden";var o=document.createElement(e._vmlNS+":fill");o.type="gradient",o.method="linear",o.angle="90",o.colors="16.67% #F0F, 33.33% #00F, 50% #0FF, 66.67% #0F0, 83.33% #FF0";var u=document.createElement(e._vmlNS+":rect");u.style.position="absolute",u.style.left="-1px",u.style.top="-1px",u.stroked=!1,u.appendChild(o),s.appendChild(u);var a=document.createElement(e._vmlNS+":fill");a.type="gradient",a.method="linear",a.angle="180",a.opacity="0";var f=document.createElement(e._vmlNS+":rect");f.style.position="absolute",f.style.left="-1px",f.style.top="-1px",f.stroked=!1,f.appendChild(a),s.appendChild(f);var i=function(e,t,n){s.style.width=e+"px",s.style.height=t+"px",u.style.width=f.style.width=e+1+"px",u.style.height=f.style.height=t+1+"px",o.color="#F00",o.color2="#F00";switch(n.toLowerCase()){case"s":a.color=a.color2="#FFF";break;case"v":a.color=a.color2="#000"}};t.elm=s,t.draw=i}return t},createSliderGradient:function(){var t={elm:null,draw:null};if(e.isCanvasSupported){var n=document.createElement("canvas"),r=n.getContext("2d"),i=function(e,t,i,s){n.width=e,n.height=t,r.clearRect(0,0,n.width,n.height);var o=r.createLinearGradient(0,0,0,n.height);o.addColorStop(0,i),o.addColorStop(1,s),r.fillStyle=o,r.fillRect(0,0,n.width,n.height)};t.elm=n,t.draw=i}else{e.initVML();var s=document.createElement("div");s.style.position="relative",s.style.overflow="hidden";var o=document.createElement(e._vmlNS+":fill");o.type="gradient",o.method="linear",o.angle="180";var u=document.createElement(e._vmlNS+":rect");u.style.position="absolute",u.style.left="-1px",u.style.top="-1px",u.stroked=!1,u.appendChild(o),s.appendChild(u);var i=function(e,t,n,r){s.style.width=e+"px",s.style.height=t+"px",u.style.width=e+1+"px",u.style.height=t+1+"px",o.color=n,o.color2=r};t.elm=s,t.draw=i}return t},leaveValue:1,leaveStyle:2,leavePad:4,leaveSld:8,BoxShadow:function(){var e=function(e,t,n,r,i,s){this.hShadow=e,this.vShadow=t,this.blur=n,this.spread=r,this.color=i,this.inset=!!s};return e.prototype.toString=function(){var e=[Math.round(this.hShadow)+"px",Math.round(this.vShadow)+"px",Math.round(this.blur)+"px",Math.round(this.spread)+"px",this.color];return this.inset&&e.push("inset"),e.join(" ")},e}(),jscolor:function(t,n){function i(e,t,n){e/=255,t/=255,n/=255;var r=Math.min(Math.min(e,t),n),i=Math.max(Math.max(e,t),n),s=i-r;if(s===0)return[null,0,100*i];var o=e===r?3+(n-t)/s:t===r?5+(e-n)/s:1+(t-e)/s;return[60*(o===6?0:o),100*(s/i),100*i]}function s(e,t,n){var r=255*(n/100);if(e===null)return[r,r,r];e/=60,t/=100;var i=Math.floor(e),s=i%2?e-i:1-(e-i),o=r*(1-t),u=r*(1-t*s);switch(i){case 6:case 0:return[r,u,o];case 1:return[u,r,o];case 2:return[o,r,u];case 3:return[o,u,r];case 4:return[u,o,r];case 5:return[r,o,u]}}function o(){e.unsetClass(d.targetElement,d.activeClass),e.picker.wrap.parentNode.removeChild(e.picker.wrap),delete e.picker.owner}function u(){function l(){var e=d.insetColor.split(/\s+/),n=e.length<2?e[0]:e[1]+" "+e[0]+" "+e[0]+" "+e[1];t.btn.style.borderColor=n}d._processParentElementsInDOM(),e.picker||(e.picker={owner:null,wrap:document.createElement("div"),box:document.createElement("div"),boxS:document.createElement("div"),boxB:document.createElement("div"),pad:document.createElement("div"),padB:document.createElement("div"),padM:document.createElement("div"),padPal:e.createPalette(),cross:document.createElement("div"),crossBY:document.createElement("div"),crossBX:document.createElement("div"),crossLY:document.createElement("div"),crossLX:document.createElement("div"),sld:document.createElement("div"),sldB:document.createElement("div"),sldM:document.createElement("div"),sldGrad:e.createSliderGradient(),sldPtrS:document.createElement("div"),sldPtrIB:document.createElement("div"),sldPtrMB:document.createElement("div"),sldPtrOB:document.createElement("div"),btn:document.createElement("div"),btnT:document.createElement("span")},e.picker.pad.appendChild(e.picker.padPal.elm),e.picker.padB.appendChild(e.picker.pad),e.picker.cross.appendChild(e.picker.crossBY),e.picker.cross.appendChild(e.picker.crossBX),e.picker.cross.appendChild(e.picker.crossLY),e.picker.cross.appendChild(e.picker.crossLX),e.picker.padB.appendChild(e.picker.cross),e.picker.box.appendChild(e.picker.padB),e.picker.box.appendChild(e.picker.padM),e.picker.sld.appendChild(e.picker.sldGrad.elm),e.picker.sldB.appendChild(e.picker.sld),e.picker.sldB.appendChild(e.picker.sldPtrOB),e.picker.sldPtrOB.appendChild(e.picker.sldPtrMB),e.picker.sldPtrMB.appendChild(e.picker.sldPtrIB),e.picker.sldPtrIB.appendChild(e.picker.sldPtrS),e.picker.box.appendChild(e.picker.sldB),e.picker.box.appendChild(e.picker.sldM),e.picker.btn.appendChild(e.picker.btnT),e.picker.box.appendChild(e.picker.btn),e.picker.boxB.appendChild(e.picker.box),e.picker.wrap.appendChild(e.picker.boxS),e.picker.wrap.appendChild(e.picker.boxB));var t=e.picker,n=!!e.getSliderComponent(d),r=e.getPickerDims(d),i=2*d.pointerBorderWidth+d.pointerThickness+2*d.crossSize,s=e.getPadToSliderPadding(d),o=Math.min(d.borderRadius,Math.round(d.padding*Math.PI)),u="crosshair";t.wrap.style.clear="both",t.wrap.style.width=r[0]+2*d.borderWidth+"px",t.wrap.style.height=r[1]+2*d.borderWidth+"px",t.wrap.style.zIndex=d.zIndex,t.box.style.width=r[0]+"px",t.box.style.height=r[1]+"px",t.boxS.style.position="absolute",t.boxS.style.left="0",t.boxS.style.top="0",t.boxS.style.width="100%",t.boxS.style.height="100%",e.setBorderRadius(t.boxS,o+"px"),t.boxB.style.position="relative",t.boxB.style.border=d.borderWidth+"px solid",t.boxB.style.borderColor=d.borderColor,t.boxB.style.background=d.backgroundColor,e.setBorderRadius(t.boxB,o+"px"),t.padM.style.background=t.sldM.style.background="#FFF",e.setStyle(t.padM,"opacity","0"),e.setStyle(t.sldM,"opacity","0"),t.pad.style.position="relative",t.pad.style.width=d.width+"px",t.pad.style.height=d.height+"px",t.padPal.draw(d.width,d.height,e.getPadYComponent(d)),t.padB.style.position="absolute",t.padB.style.left=d.padding+"px",t.padB.style.top=d.padding+"px",t.padB.style.border=d.insetWidth+"px solid",t.padB.style.borderColor=d.insetColor,t.padM._jscInstance=d,t.padM._jscControlName="pad",t.padM.style.position="absolute",t.padM.style.left="0",t.padM.style.top="0",t.padM.style.width=d.padding+2*d.insetWidth+d.width+s/2+"px",t.padM.style.height=r[1]+"px",t.padM.style.cursor=u,t.cross.style.position="absolute",t.cross.style.left=t.cross.style.top="0",t.cross.style.width=t.cross.style.height=i+"px",t.crossBY.style.position=t.crossBX.style.position="absolute",t.crossBY.style.background=t.crossBX.style.background=d.pointerBorderColor,t.crossBY.style.width=t.crossBX.style.height=2*d.pointerBorderWidth+d.pointerThickness+"px",t.crossBY.style.height=t.crossBX.style.width=i+"px",t.crossBY.style.left=t.crossBX.style.top=Math.floor(i/2)-Math.floor(d.pointerThickness/2)-d.pointerBorderWidth+"px",t.crossBY.style.top=t.crossBX.style.left="0",t.crossLY.style.position=t.crossLX.style.position="absolute",t.crossLY.style.background=t.crossLX.style.background=d.pointerColor,t.crossLY.style.height=t.crossLX.style.width=i-2*d.pointerBorderWidth+"px",t.crossLY.style.width=t.crossLX.style.height=d.pointerThickness+"px",t.crossLY.style.left=t.crossLX.style.top=Math.floor(i/2)-Math.floor(d.pointerThickness/2)+"px",t.crossLY.style.top=t.crossLX.style.left=d.pointerBorderWidth+"px",t.sld.style.overflow="hidden",t.sld.style.width=d.sliderSize+"px",t.sld.style.height=d.height+"px",t.sldGrad.draw(d.sliderSize,d.height,"#000","#000"),t.sldB.style.display=n?"block":"none",t.sldB.style.position="absolute",t.sldB.style.right=d.padding+"px",t.sldB.style.top=d.padding+"px",t.sldB.style.border=d.insetWidth+"px solid",t.sldB.style.borderColor=d.insetColor,t.sldM._jscInstance=d,t.sldM._jscControlName="sld",t.sldM.style.display=n?"block":"none",t.sldM.style.position="absolute",t.sldM.style.right="0",t.sldM.style.top="0",t.sldM.style.width=d.sliderSize+s/2+d.padding+2*d.insetWidth+"px",t.sldM.style.height=r[1]+"px",t.sldM.style.cursor="default",t.sldPtrIB.style.border=t.sldPtrOB.style.border=d.pointerBorderWidth+"px solid "+d.pointerBorderColor,t.sldPtrOB.style.position="absolute",t.sldPtrOB.style.left=-(2*d.pointerBorderWidth+d.pointerThickness)+"px",t.sldPtrOB.style.top="0",t.sldPtrMB.style.border=d.pointerThickness+"px solid "+d.pointerColor,t.sldPtrS.style.width=d.sliderSize+"px",t.sldPtrS.style.height=m+"px",t.btn.style.display=d.closable?"block":"none",t.btn.style.position="absolute",t.btn.style.left=d.padding+"px",t.btn.style.bottom=d.padding+"px",t.btn.style.padding="0 15px",t.btn.style.height=d.buttonHeight+"px",t.btn.style.border=d.insetWidth+"px solid",l(),t.btn.style.color=d.buttonColor,t.btn.style.font="12px sans-serif",t.btn.style.textAlign="center";try{t.btn.style.cursor="pointer"}catch(c){t.btn.style.cursor="hand"}t.btn.onmousedown=function(){d.hide()},t.btnT.style.lineHeight=d.buttonHeight+"px",t.btnT.innerHTML="",t.btnT.appendChild(document.createTextNode(d.closeText)),a(),f(),e.picker.owner&&e.picker.owner!==d&&e.unsetClass(e.picker.owner.targetElement,d.activeClass),e.picker.owner=d,e.isElementType(v,"body")?e.redrawPosition():e._drawPosition(d,0,0,"relative",!1),t.wrap.parentNode!=v&&v.appendChild(t.wrap),e.setClass(d.targetElement,d.activeClass)}function a(){switch(e.getPadYComponent(d)){case"s":var t=1;break;case"v":var t=2}var n=Math.round(d.hsv[0]/360*(d.width-1)),r=Math.round((1-d.hsv[t]/100)*(d.height-1)),i=2*d.pointerBorderWidth+d.pointerThickness+2*d.crossSize,o=-Math.floor(i/2);e.picker.cross.style.left=n+o+"px",e.picker.cross.style.top=r+o+"px";switch(e.getSliderComponent(d)){case"s":var u=s(d.hsv[0],100,d.hsv[2]),a=s(d.hsv[0],0,d.hsv[2]),f="rgb("+Math.round(u[0])+","+Math.round(u[1])+","+Math.round(u[2])+")",l="rgb("+Math.round(a[0])+","+Math.round(a[1])+","+Math.round(a[2])+")";e.picker.sldGrad.draw(d.sliderSize,d.height,f,l);break;case"v":var c=s(d.hsv[0],d.hsv[1],100),f="rgb("+Math.round(c[0])+","+Math.round(c[1])+","+Math.round(c[2])+")",l="#000";e.picker.sldGrad.draw(d.sliderSize,d.height,f,l)}}function f(){var t=e.getSliderComponent(d);if(t){switch(t){case"s":var n=1;break;case"v":var n=2}var r=Math.round((1-d.hsv[n]/100)*(d.height-1));e.picker.sldPtrOB.style.top=r-(2*d.pointerBorderWidth+d.pointerThickness)-Math.floor(m/2)+"px"}}function l(){return e.picker&&e.picker.owner===d}function c(){d.importColor()}this.value=null,this.valueElement=t,this.styleElement=t,this.required=!0,this.refine=!0,this.hash=!1,this.uppercase=!0,this.onFineChange=null,this.activeClass="jscolor-active",this.minS=0,this.maxS=100,this.minV=0,this.maxV=100,this.hsv=[0,0,100],this.rgb=[255,255,255],this.width=181,this.height=101,this.showOnClick=!0,this.mode="HSV",this.position="bottom",this.smartPosition=!0,this.sliderSize=16,this.crossSize=8,this.closable=!1,this.closeText="Close",this.buttonColor="#000000",this.buttonHeight=18,this.padding=12,this.backgroundColor="#FFFFFF",this.borderWidth=1,this.borderColor="#BBBBBB",this.borderRadius=8,this.insetWidth=1,this.insetColor="#BBBBBB",this.shadow=!0,this.shadowBlur=15,this.shadowColor="rgba(0,0,0,0.2)",this.pointerColor="#4C4C4C",this.pointerBorderColor="#FFFFFF",this.pointerBorderWidth=1,this.pointerThickness=2,this.zIndex=1e3,this.container=null;for(var r in n)n.hasOwnProperty(r)&&(this[r]=n[r]);this.hide=function(){l()&&o()},this.show=function(){u()},this.redraw=function(){l()&&u()},this.importColor=function(){this.valueElement?e.isElementType(this.valueElement,"input")?this.refine?!this.required&&/^\s*$/.test(this.valueElement.value)?(this.valueElement.value="",this.styleElement&&(this.styleElement.style.backgroundImage=this.styleElement._jscOrigStyle.backgroundImage,this.styleElement.style.backgroundColor=this.styleElement._jscOrigStyle.backgroundColor,this.styleElement.style.color=this.styleElement._jscOrigStyle.color),this.exportColor(e.leaveValue|e.leaveStyle)):this.fromString(this.valueElement.value)||this.exportColor():this.fromString(this.valueElement.value,e.leaveValue)||(this.styleElement&&(this.styleElement.style.backgroundImage=this.styleElement._jscOrigStyle.backgroundImage,this.styleElement.style.backgroundColor=this.styleElement._jscOrigStyle.backgroundColor,this.styleElement.style.color=this.styleElement._jscOrigStyle.color),this.exportColor(e.leaveValue|e.leaveStyle)):this.exportColor():this.exportColor()},this.exportColor=function(t){if(!(t&e.leaveValue)&&this.valueElement){var n=this.toString();this.uppercase&&(n=n.toUpperCase()),this.hash&&(n="#"+n),e.isElementType(this.valueElement,"input")?this.valueElement.value=n:this.valueElement.innerHTML=n}t&e.leaveStyle||this.styleElement&&(this.styleElement.style.backgroundImage="none",this.styleElement.style.backgroundColor="#"+this.toString(),this.styleElement.style.color=this.isLight()?"#000":"#FFF"),!(t&e.leavePad)&&l()&&a(),!(t&e.leaveSld)&&l()&&f()},this.fromHSV=function(e,t,n,r){if(e!==null){if(isNaN(e))return!1;e=Math.max(0,Math.min(360,e))}if(t!==null){if(isNaN(t))return!1;t=Math.max(0,Math.min(100,this.maxS,t),this.minS)}if(n!==null){if(isNaN(n))return!1;n=Math.max(0,Math.min(100,this.maxV,n),this.minV)}this.rgb=s(e===null?this.hsv[0]:this.hsv[0]=e,t===null?this.hsv[1]:this.hsv[1]=t,n===null?this.hsv[2]:this.hsv[2]=n),this.exportColor(r)},this.fromRGB=function(e,t,n,r){if(e!==null){if(isNaN(e))return!1;e=Math.max(0,Math.min(255,e))}if(t!==null){if(isNaN(t))return!1;t=Math.max(0,Math.min(255,t))}if(n!==null){if(isNaN(n))return!1;n=Math.max(0,Math.min(255,n))}var o=i(e===null?this.rgb[0]:e,t===null?this.rgb[1]:t,n===null?this.rgb[2]:n);o[0]!==null&&(this.hsv[0]=Math.max(0,Math.min(360,o[0]))),o[2]!==0&&(this.hsv[1]=o[1]===null?null:Math.max(0,this.minS,Math.min(100,this.maxS,o[1]))),this.hsv[2]=o[2]===null?null:Math.max(0,this.minV,Math.min(100,this.maxV,o[2]));var u=s(this.hsv[0],this.hsv[1],this.hsv[2]);this.rgb[0]=u[0],this.rgb[1]=u[1],this.rgb[2]=u[2],this.exportColor(r)},this.fromString=function(e,t){var n;if(n=e.match(/^\W*([0-9A-F]{3}([0-9A-F]{3})?)\W*$/i))return n[1].length===6?this.fromRGB(parseInt(n[1].substr(0,2),16),parseInt(n[1].substr(2,2),16),parseInt(n[1].substr(4,2),16),t):this.fromRGB(parseInt(n[1].charAt(0)+n[1].charAt(0),16),parseInt(n[1].charAt(1)+n[1].charAt(1),16),parseInt(n[1].charAt(2)+n[1].charAt(2),16),t),!0;if(n=e.match(/^\W*rgba?\(([^)]*)\)\W*$/i)){var r=n[1].split(","),i=/^\s*(\d*)(\.\d+)?\s*$/,s,o,u;if(r.length>=3&&(s=r[0].match(i))&&(o=r[1].match(i))&&(u=r[2].match(i))){var a=parseFloat((s[1]||"0")+(s[2]||"")),f=parseFloat((o[1]||"0")+(o[2]||"")),l=parseFloat((u[1]||"0")+(u[2]||""));return this.fromRGB(a,f,l,t),!0}}return!1},this.toString=function(){return(256|Math.round(this.rgb[0])).toString(16).substr(1)+(256|Math.round(this.rgb[1])).toString(16).substr(1)+(256|Math.round(this.rgb[2])).toString(16).substr(1)},this.toHEXString=function(){return"#"+this.toString().toUpperCase()},this.toRGBString=function(){return"rgb("+Math.round(this.rgb[0])+","+Math.round(this.rgb[1])+","+Math.round(this.rgb[2])+")"},this.isLight=function(){return.213*this.rgb[0]+.715*this.rgb[1]+.072*this.rgb[2]>127.5},this._processParentElementsInDOM=function(){if(this._linkedElementsProcessed)return;this._linkedElementsProcessed=!0;var t=this.targetElement;do{var n=e.getStyle(t);n&&n.position.toLowerCase()==="fixed"&&(this.fixed=!0),t!==this.targetElement&&(t._jscEventsAttached||(e.attachEvent(t,"scroll",e.onParentScroll),t._jscEventsAttached=!0))}while((t=t.parentNode)&&!e.isElementType(t,"body"))};if(typeof t=="string"){var h=t,p=document.getElementById(h);p?this.targetElement=p:e.warn("Could not find target element with ID '"+h+"'")}else t?this.targetElement=t:e.warn("Invalid target element: '"+t+"'");if(this.targetElement._jscLinkedInstance){e.warn("Cannot link jscolor twice to the same element. Skipping.");return}this.targetElement._jscLinkedInstance=this,this.valueElement=e.fetchElement(this.valueElement),this.styleElement=e.fetchElement(this.styleElement);var d=this,v=this.container?e.fetchElement(this.container):document.getElementsByTagName("body")[0],m=3;if(e.isElementType(this.targetElement,"button"))if(this.targetElement.onclick){var g=this.targetElement.onclick;this.targetElement.onclick=function(e){return g.call(this,e),!1}}else this.targetElement.onclick=function(){return!1};if(this.valueElement&&e.isElementType(this.valueElement,"input")){var y=function(){d.fromString(d.valueElement.value,e.leaveValue),e.dispatchFineChange(d)};e.attachEvent(this.valueElement,"keyup",y),e.attachEvent(this.valueElement,"input",y),e.attachEvent(this.valueElement,"blur",c),this.valueElement.setAttribute("autocomplete","off")}this.styleElement&&(this.styleElement._jscOrigStyle={backgroundImage:this.styleElement.style.backgroundImage,backgroundColor:this.styleElement.style.backgroundColor,color:this.styleElement.style.color}),this.value?this.fromString(this.value)||this.exportColor():this.importColor()}};return e.jscolor.lookupClass="jscolor",e.jscolor.installByClassName=function(t){var n=document.getElementsByTagName("input"),r=document.getElementsByTagName("button");e.tryInstallOnElements(n,t),e.tryInstallOnElements(r,t)},e.register(),e.jscolor}());
/**
 * SyntaxHighlighter
 * http://alexgorbatchev.com/SyntaxHighlighter
 *
 * SyntaxHighlighter is donationware. If you are using it, please donate.
 * http://alexgorbatchev.com/SyntaxHighlighter/donate.html
 *
 * @version
 * 3.0.83 (July 02 2010)
 * 
 * @copyright
 * Copyright (C) 2004-2010 Alex Gorbatchev.
 *
 * @license
 * Dual licensed under the MIT and GPL licenses.
 */
eval(function(p,a,c,k,e,d){e=function(c){return(c<a?'':e(parseInt(c/a)))+((c=c%a)>35?String.fromCharCode(c+29):c.toString(36))};if(!''.replace(/^/,String)){while(c--){d[e(c)]=k[c]||e(c)}k=[function(e){return d[e]}];e=function(){return'\\w+'};c=1};while(c--){if(k[c]){p=p.replace(new RegExp('\\b'+e(c)+'\\b','g'),k[c])}}return p}('K M;I(M)1S 2U("2a\'t 4k M 4K 2g 3l 4G 4H");(6(){6 r(f,e){I(!M.1R(f))1S 3m("3s 15 4R");K a=f.1w;f=M(f.1m,t(f)+(e||""));I(a)f.1w={1m:a.1m,19:a.19?a.19.1a(0):N};H f}6 t(f){H(f.1J?"g":"")+(f.4s?"i":"")+(f.4p?"m":"")+(f.4v?"x":"")+(f.3n?"y":"")}6 B(f,e,a,b){K c=u.L,d,h,g;v=R;5K{O(;c--;){g=u[c];I(a&g.3r&&(!g.2p||g.2p.W(b))){g.2q.12=e;I((h=g.2q.X(f))&&h.P===e){d={3k:g.2b.W(b,h,a),1C:h};1N}}}}5v(i){1S i}5q{v=11}H d}6 p(f,e,a){I(3b.Z.1i)H f.1i(e,a);O(a=a||0;a<f.L;a++)I(f[a]===e)H a;H-1}M=6(f,e){K a=[],b=M.1B,c=0,d,h;I(M.1R(f)){I(e!==1d)1S 3m("2a\'t 5r 5I 5F 5B 5C 15 5E 5p");H r(f)}I(v)1S 2U("2a\'t W 3l M 59 5m 5g 5x 5i");e=e||"";O(d={2N:11,19:[],2K:6(g){H e.1i(g)>-1},3d:6(g){e+=g}};c<f.L;)I(h=B(f,c,b,d)){a.U(h.3k);c+=h.1C[0].L||1}Y I(h=n.X.W(z[b],f.1a(c))){a.U(h[0]);c+=h[0].L}Y{h=f.3a(c);I(h==="[")b=M.2I;Y I(h==="]")b=M.1B;a.U(h);c++}a=15(a.1K(""),n.Q.W(e,w,""));a.1w={1m:f,19:d.2N?d.19:N};H a};M.3v="1.5.0";M.2I=1;M.1B=2;K C=/\\$(?:(\\d\\d?|[$&`\'])|{([$\\w]+)})/g,w=/[^5h]+|([\\s\\S])(?=[\\s\\S]*\\1)/g,A=/^(?:[?*+]|{\\d+(?:,\\d*)?})\\??/,v=11,u=[],n={X:15.Z.X,1A:15.Z.1A,1C:1r.Z.1C,Q:1r.Z.Q,1e:1r.Z.1e},x=n.X.W(/()??/,"")[1]===1d,D=6(){K f=/^/g;n.1A.W(f,"");H!f.12}(),y=6(){K f=/x/g;n.Q.W("x",f,"");H!f.12}(),E=15.Z.3n!==1d,z={};z[M.2I]=/^(?:\\\\(?:[0-3][0-7]{0,2}|[4-7][0-7]?|x[\\29-26-f]{2}|u[\\29-26-f]{4}|c[A-3o-z]|[\\s\\S]))/;z[M.1B]=/^(?:\\\\(?:0(?:[0-3][0-7]{0,2}|[4-7][0-7]?)?|[1-9]\\d*|x[\\29-26-f]{2}|u[\\29-26-f]{4}|c[A-3o-z]|[\\s\\S])|\\(\\?[:=!]|[?*+]\\?|{\\d+(?:,\\d*)?}\\??)/;M.1h=6(f,e,a,b){u.U({2q:r(f,"g"+(E?"y":"")),2b:e,3r:a||M.1B,2p:b||N})};M.2n=6(f,e){K a=f+"/"+(e||"");H M.2n[a]||(M.2n[a]=M(f,e))};M.3c=6(f){H r(f,"g")};M.5l=6(f){H f.Q(/[-[\\]{}()*+?.,\\\\^$|#\\s]/g,"\\\\$&")};M.5e=6(f,e,a,b){e=r(e,"g"+(b&&E?"y":""));e.12=a=a||0;f=e.X(f);H b?f&&f.P===a?f:N:f};M.3q=6(){M.1h=6(){1S 2U("2a\'t 55 1h 54 3q")}};M.1R=6(f){H 53.Z.1q.W(f)==="[2m 15]"};M.3p=6(f,e,a,b){O(K c=r(e,"g"),d=-1,h;h=c.X(f);){a.W(b,h,++d,f,c);c.12===h.P&&c.12++}I(e.1J)e.12=0};M.57=6(f,e){H 6 a(b,c){K d=e[c].1I?e[c]:{1I:e[c]},h=r(d.1I,"g"),g=[],i;O(i=0;i<b.L;i++)M.3p(b[i],h,6(k){g.U(d.3j?k[d.3j]||"":k[0])});H c===e.L-1||!g.L?g:a(g,c+1)}([f],0)};15.Z.1p=6(f,e){H J.X(e[0])};15.Z.W=6(f,e){H J.X(e)};15.Z.X=6(f){K e=n.X.1p(J,14),a;I(e){I(!x&&e.L>1&&p(e,"")>-1){a=15(J.1m,n.Q.W(t(J),"g",""));n.Q.W(f.1a(e.P),a,6(){O(K c=1;c<14.L-2;c++)I(14[c]===1d)e[c]=1d})}I(J.1w&&J.1w.19)O(K b=1;b<e.L;b++)I(a=J.1w.19[b-1])e[a]=e[b];!D&&J.1J&&!e[0].L&&J.12>e.P&&J.12--}H e};I(!D)15.Z.1A=6(f){(f=n.X.W(J,f))&&J.1J&&!f[0].L&&J.12>f.P&&J.12--;H!!f};1r.Z.1C=6(f){M.1R(f)||(f=15(f));I(f.1J){K e=n.1C.1p(J,14);f.12=0;H e}H f.X(J)};1r.Z.Q=6(f,e){K a=M.1R(f),b,c;I(a&&1j e.58()==="3f"&&e.1i("${")===-1&&y)H n.Q.1p(J,14);I(a){I(f.1w)b=f.1w.19}Y f+="";I(1j e==="6")c=n.Q.W(J,f,6(){I(b){14[0]=1f 1r(14[0]);O(K d=0;d<b.L;d++)I(b[d])14[0][b[d]]=14[d+1]}I(a&&f.1J)f.12=14[14.L-2]+14[0].L;H e.1p(N,14)});Y{c=J+"";c=n.Q.W(c,f,6(){K d=14;H n.Q.W(e,C,6(h,g,i){I(g)5b(g){24"$":H"$";24"&":H d[0];24"`":H d[d.L-1].1a(0,d[d.L-2]);24"\'":H d[d.L-1].1a(d[d.L-2]+d[0].L);5a:i="";g=+g;I(!g)H h;O(;g>d.L-3;){i=1r.Z.1a.W(g,-1)+i;g=1Q.3i(g/10)}H(g?d[g]||"":"$")+i}Y{g=+i;I(g<=d.L-3)H d[g];g=b?p(b,i):-1;H g>-1?d[g+1]:h}})})}I(a&&f.1J)f.12=0;H c};1r.Z.1e=6(f,e){I(!M.1R(f))H n.1e.1p(J,14);K a=J+"",b=[],c=0,d,h;I(e===1d||+e<0)e=5D;Y{e=1Q.3i(+e);I(!e)H[]}O(f=M.3c(f);d=f.X(a);){I(f.12>c){b.U(a.1a(c,d.P));d.L>1&&d.P<a.L&&3b.Z.U.1p(b,d.1a(1));h=d[0].L;c=f.12;I(b.L>=e)1N}f.12===d.P&&f.12++}I(c===a.L){I(!n.1A.W(f,"")||h)b.U("")}Y b.U(a.1a(c));H b.L>e?b.1a(0,e):b};M.1h(/\\(\\?#[^)]*\\)/,6(f){H n.1A.W(A,f.2S.1a(f.P+f[0].L))?"":"(?:)"});M.1h(/\\((?!\\?)/,6(){J.19.U(N);H"("});M.1h(/\\(\\?<([$\\w]+)>/,6(f){J.19.U(f[1]);J.2N=R;H"("});M.1h(/\\\\k<([\\w$]+)>/,6(f){K e=p(J.19,f[1]);H e>-1?"\\\\"+(e+1)+(3R(f.2S.3a(f.P+f[0].L))?"":"(?:)"):f[0]});M.1h(/\\[\\^?]/,6(f){H f[0]==="[]"?"\\\\b\\\\B":"[\\\\s\\\\S]"});M.1h(/^\\(\\?([5A]+)\\)/,6(f){J.3d(f[1]);H""});M.1h(/(?:\\s+|#.*)+/,6(f){H n.1A.W(A,f.2S.1a(f.P+f[0].L))?"":"(?:)"},M.1B,6(){H J.2K("x")});M.1h(/\\./,6(){H"[\\\\s\\\\S]"},M.1B,6(){H J.2K("s")})})();1j 2e!="1d"&&(2e.M=M);K 1v=6(){6 r(a,b){a.1l.1i(b)!=-1||(a.1l+=" "+b)}6 t(a){H a.1i("3e")==0?a:"3e"+a}6 B(a){H e.1Y.2A[t(a)]}6 p(a,b,c){I(a==N)H N;K d=c!=R?a.3G:[a.2G],h={"#":"1c",".":"1l"}[b.1o(0,1)]||"3h",g,i;g=h!="3h"?b.1o(1):b.5u();I((a[h]||"").1i(g)!=-1)H a;O(a=0;d&&a<d.L&&i==N;a++)i=p(d[a],b,c);H i}6 C(a,b){K c={},d;O(d 2g a)c[d]=a[d];O(d 2g b)c[d]=b[d];H c}6 w(a,b,c,d){6 h(g){g=g||1P.5y;I(!g.1F){g.1F=g.52;g.3N=6(){J.5w=11}}c.W(d||1P,g)}a.3g?a.3g("4U"+b,h):a.4y(b,h,11)}6 A(a,b){K c=e.1Y.2j,d=N;I(c==N){c={};O(K h 2g e.1U){K g=e.1U[h];d=g.4x;I(d!=N){g.1V=h.4w();O(g=0;g<d.L;g++)c[d[g]]=h}}e.1Y.2j=c}d=e.1U[c[a]];d==N&&b!=11&&1P.1X(e.13.1x.1X+(e.13.1x.3E+a));H d}6 v(a,b){O(K c=a.1e("\\n"),d=0;d<c.L;d++)c[d]=b(c[d],d);H c.1K("\\n")}6 u(a,b){I(a==N||a.L==0||a=="\\n")H a;a=a.Q(/</g,"&1y;");a=a.Q(/ {2,}/g,6(c){O(K d="",h=0;h<c.L-1;h++)d+=e.13.1W;H d+" "});I(b!=N)a=v(a,6(c){I(c.L==0)H"";K d="";c=c.Q(/^(&2s;| )+/,6(h){d=h;H""});I(c.L==0)H d;H d+\'<17 1g="\'+b+\'">\'+c+"</17>"});H a}6 n(a,b){a.1e("\\n");O(K c="",d=0;d<50;d++)c+="                    ";H a=v(a,6(h){I(h.1i("\\t")==-1)H h;O(K g=0;(g=h.1i("\\t"))!=-1;)h=h.1o(0,g)+c.1o(0,b-g%b)+h.1o(g+1,h.L);H h})}6 x(a){H a.Q(/^\\s+|\\s+$/g,"")}6 D(a,b){I(a.P<b.P)H-1;Y I(a.P>b.P)H 1;Y I(a.L<b.L)H-1;Y I(a.L>b.L)H 1;H 0}6 y(a,b){6 c(k){H k[0]}O(K d=N,h=[],g=b.2D?b.2D:c;(d=b.1I.X(a))!=N;){K i=g(d,b);I(1j i=="3f")i=[1f e.2L(i,d.P,b.23)];h=h.1O(i)}H h}6 E(a){K b=/(.*)((&1G;|&1y;).*)/;H a.Q(e.3A.3M,6(c){K d="",h=N;I(h=b.X(c)){c=h[1];d=h[2]}H\'<a 2h="\'+c+\'">\'+c+"</a>"+d})}6 z(){O(K a=1E.36("1k"),b=[],c=0;c<a.L;c++)a[c].3s=="20"&&b.U(a[c]);H b}6 f(a){a=a.1F;K b=p(a,".20",R);a=p(a,".3O",R);K c=1E.4i("3t");I(!(!a||!b||p(a,"3t"))){B(b.1c);r(b,"1m");O(K d=a.3G,h=[],g=0;g<d.L;g++)h.U(d[g].4z||d[g].4A);h=h.1K("\\r");c.39(1E.4D(h));a.39(c);c.2C();c.4C();w(c,"4u",6(){c.2G.4E(c);b.1l=b.1l.Q("1m","")})}}I(1j 3F!="1d"&&1j M=="1d")M=3F("M").M;K e={2v:{"1g-27":"","2i-1s":1,"2z-1s-2t":11,1M:N,1t:N,"42-45":R,"43-22":4,1u:R,16:R,"3V-17":R,2l:11,"41-40":R,2k:11,"1z-1k":11},13:{1W:"&2s;",2M:R,46:11,44:11,34:"4n",1x:{21:"4o 1m",2P:"?",1X:"1v\\n\\n",3E:"4r\'t 4t 1D O: ",4g:"4m 4B\'t 51 O 1z-1k 4F: ",37:\'<!4T 1z 4S "-//4V//3H 4W 1.0 4Z//4Y" "1Z://2y.3L.3K/4X/3I/3H/3I-4P.4J"><1z 4I="1Z://2y.3L.3K/4L/5L"><3J><4N 1Z-4M="5G-5M" 6K="2O/1z; 6J=6I-8" /><1t>6L 1v</1t></3J><3B 1L="25-6M:6Q,6P,6O,6N-6F;6y-2f:#6x;2f:#6w;25-22:6v;2O-3D:3C;"><T 1L="2O-3D:3C;3w-32:1.6z;"><T 1L="25-22:6A-6E;">1v</T><T 1L="25-22:.6C;3w-6B:6R;"><T>3v 3.0.76 (72 73 3x)</T><T><a 2h="1Z://3u.2w/1v" 1F="38" 1L="2f:#3y">1Z://3u.2w/1v</a></T><T>70 17 6U 71.</T><T>6T 6X-3x 6Y 6D.</T></T><T>6t 61 60 J 1k, 5Z <a 2h="6u://2y.62.2w/63-66/65?64=5X-5W&5P=5O" 1L="2f:#3y">5R</a> 5V <2R/>5U 5T 5S!</T></T></3B></1z>\'}},1Y:{2j:N,2A:{}},1U:{},3A:{6n:/\\/\\*[\\s\\S]*?\\*\\//2c,6m:/\\/\\/.*$/2c,6l:/#.*$/2c,6k:/"([^\\\\"\\n]|\\\\.)*"/g,6o:/\'([^\\\\\'\\n]|\\\\.)*\'/g,6p:1f M(\'"([^\\\\\\\\"]|\\\\\\\\.)*"\',"3z"),6s:1f M("\'([^\\\\\\\\\']|\\\\\\\\.)*\'","3z"),6q:/(&1y;|<)!--[\\s\\S]*?--(&1G;|>)/2c,3M:/\\w+:\\/\\/[\\w-.\\/?%&=:@;]*/g,6a:{18:/(&1y;|<)\\?=?/g,1b:/\\?(&1G;|>)/g},69:{18:/(&1y;|<)%=?/g,1b:/%(&1G;|>)/g},6d:{18:/(&1y;|<)\\s*1k.*?(&1G;|>)/2T,1b:/(&1y;|<)\\/\\s*1k\\s*(&1G;|>)/2T}},16:{1H:6(a){6 b(i,k){H e.16.2o(i,k,e.13.1x[k])}O(K c=\'<T 1g="16">\',d=e.16.2x,h=d.2X,g=0;g<h.L;g++)c+=(d[h[g]].1H||b)(a,h[g]);c+="</T>";H c},2o:6(a,b,c){H\'<2W><a 2h="#" 1g="6e 6h\'+b+" "+b+\'">\'+c+"</a></2W>"},2b:6(a){K b=a.1F,c=b.1l||"";b=B(p(b,".20",R).1c);K d=6(h){H(h=15(h+"6f(\\\\w+)").X(c))?h[1]:N}("6g");b&&d&&e.16.2x[d].2B(b);a.3N()},2x:{2X:["21","2P"],21:{1H:6(a){I(a.V("2l")!=R)H"";K b=a.V("1t");H e.16.2o(a,"21",b?b:e.13.1x.21)},2B:6(a){a=1E.6j(t(a.1c));a.1l=a.1l.Q("47","")}},2P:{2B:6(){K a="68=0";a+=", 18="+(31.30-33)/2+", 32="+(31.2Z-2Y)/2+", 30=33, 2Z=2Y";a=a.Q(/^,/,"");a=1P.6Z("","38",a);a.2C();K b=a.1E;b.6W(e.13.1x.37);b.6V();a.2C()}}}},35:6(a,b){K c;I(b)c=[b];Y{c=1E.36(e.13.34);O(K d=[],h=0;h<c.L;h++)d.U(c[h]);c=d}c=c;d=[];I(e.13.2M)c=c.1O(z());I(c.L===0)H d;O(h=0;h<c.L;h++){O(K g=c[h],i=a,k=c[h].1l,j=3W 0,l={},m=1f M("^\\\\[(?<2V>(.*?))\\\\]$"),s=1f M("(?<27>[\\\\w-]+)\\\\s*:\\\\s*(?<1T>[\\\\w-%#]+|\\\\[.*?\\\\]|\\".*?\\"|\'.*?\')\\\\s*;?","g");(j=s.X(k))!=N;){K o=j.1T.Q(/^[\'"]|[\'"]$/g,"");I(o!=N&&m.1A(o)){o=m.X(o);o=o.2V.L>0?o.2V.1e(/\\s*,\\s*/):[]}l[j.27]=o}g={1F:g,1n:C(i,l)};g.1n.1D!=N&&d.U(g)}H d},1M:6(a,b){K c=J.35(a,b),d=N,h=e.13;I(c.L!==0)O(K g=0;g<c.L;g++){b=c[g];K i=b.1F,k=b.1n,j=k.1D,l;I(j!=N){I(k["1z-1k"]=="R"||e.2v["1z-1k"]==R){d=1f e.4l(j);j="4O"}Y I(d=A(j))d=1f d;Y 6H;l=i.3X;I(h.2M){l=l;K m=x(l),s=11;I(m.1i("<![6G[")==0){m=m.4h(9);s=R}K o=m.L;I(m.1i("]]\\>")==o-3){m=m.4h(0,o-3);s=R}l=s?m:l}I((i.1t||"")!="")k.1t=i.1t;k.1D=j;d.2Q(k);b=d.2F(l);I((i.1c||"")!="")b.1c=i.1c;i.2G.74(b,i)}}},2E:6(a){w(1P,"4k",6(){e.1M(a)})}};e.2E=e.2E;e.1M=e.1M;e.2L=6(a,b,c){J.1T=a;J.P=b;J.L=a.L;J.23=c;J.1V=N};e.2L.Z.1q=6(){H J.1T};e.4l=6(a){6 b(j,l){O(K m=0;m<j.L;m++)j[m].P+=l}K c=A(a),d,h=1f e.1U.5Y,g=J,i="2F 1H 2Q".1e(" ");I(c!=N){d=1f c;O(K k=0;k<i.L;k++)(6(){K j=i[k];g[j]=6(){H h[j].1p(h,14)}})();d.28==N?1P.1X(e.13.1x.1X+(e.13.1x.4g+a)):h.2J.U({1I:d.28.17,2D:6(j){O(K l=j.17,m=[],s=d.2J,o=j.P+j.18.L,F=d.28,q,G=0;G<s.L;G++){q=y(l,s[G]);b(q,o);m=m.1O(q)}I(F.18!=N&&j.18!=N){q=y(j.18,F.18);b(q,j.P);m=m.1O(q)}I(F.1b!=N&&j.1b!=N){q=y(j.1b,F.1b);b(q,j.P+j[0].5Q(j.1b));m=m.1O(q)}O(j=0;j<m.L;j++)m[j].1V=c.1V;H m}})}};e.4j=6(){};e.4j.Z={V:6(a,b){K c=J.1n[a];c=c==N?b:c;K d={"R":R,"11":11}[c];H d==N?c:d},3Y:6(a){H 1E.4i(a)},4c:6(a,b){K c=[];I(a!=N)O(K d=0;d<a.L;d++)I(1j a[d]=="2m")c=c.1O(y(b,a[d]));H J.4e(c.6b(D))},4e:6(a){O(K b=0;b<a.L;b++)I(a[b]!==N)O(K c=a[b],d=c.P+c.L,h=b+1;h<a.L&&a[b]!==N;h++){K g=a[h];I(g!==N)I(g.P>d)1N;Y I(g.P==c.P&&g.L>c.L)a[b]=N;Y I(g.P>=c.P&&g.P<d)a[h]=N}H a},4d:6(a){K b=[],c=2u(J.V("2i-1s"));v(a,6(d,h){b.U(h+c)});H b},3U:6(a){K b=J.V("1M",[]);I(1j b!="2m"&&b.U==N)b=[b];a:{a=a.1q();K c=3W 0;O(c=c=1Q.6c(c||0,0);c<b.L;c++)I(b[c]==a){b=c;1N a}b=-1}H b!=-1},2r:6(a,b,c){a=["1s","6i"+b,"P"+a,"6r"+(b%2==0?1:2).1q()];J.3U(b)&&a.U("67");b==0&&a.U("1N");H\'<T 1g="\'+a.1K(" ")+\'">\'+c+"</T>"},3Q:6(a,b){K c="",d=a.1e("\\n").L,h=2u(J.V("2i-1s")),g=J.V("2z-1s-2t");I(g==R)g=(h+d-1).1q().L;Y I(3R(g)==R)g=0;O(K i=0;i<d;i++){K k=b?b[i]:h+i,j;I(k==0)j=e.13.1W;Y{j=g;O(K l=k.1q();l.L<j;)l="0"+l;j=l}a=j;c+=J.2r(i,k,a)}H c},49:6(a,b){a=x(a);K c=a.1e("\\n");J.V("2z-1s-2t");K d=2u(J.V("2i-1s"));a="";O(K h=J.V("1D"),g=0;g<c.L;g++){K i=c[g],k=/^(&2s;|\\s)+/.X(i),j=N,l=b?b[g]:d+g;I(k!=N){j=k[0].1q();i=i.1o(j.L);j=j.Q(" ",e.13.1W)}i=x(i);I(i.L==0)i=e.13.1W;a+=J.2r(g,l,(j!=N?\'<17 1g="\'+h+\' 5N">\'+j+"</17>":"")+i)}H a},4f:6(a){H a?"<4a>"+a+"</4a>":""},4b:6(a,b){6 c(l){H(l=l?l.1V||g:g)?l+" ":""}O(K d=0,h="",g=J.V("1D",""),i=0;i<b.L;i++){K k=b[i],j;I(!(k===N||k.L===0)){j=c(k);h+=u(a.1o(d,k.P-d),j+"48")+u(k.1T,j+k.23);d=k.P+k.L+(k.75||0)}}h+=u(a.1o(d),c()+"48");H h},1H:6(a){K b="",c=["20"],d;I(J.V("2k")==R)J.1n.16=J.1n.1u=11;1l="20";J.V("2l")==R&&c.U("47");I((1u=J.V("1u"))==11)c.U("6S");c.U(J.V("1g-27"));c.U(J.V("1D"));a=a.Q(/^[ ]*[\\n]+|[\\n]*[ ]*$/g,"").Q(/\\r/g," ");b=J.V("43-22");I(J.V("42-45")==R)a=n(a,b);Y{O(K h="",g=0;g<b;g++)h+=" ";a=a.Q(/\\t/g,h)}a=a;a:{b=a=a;h=/<2R\\s*\\/?>|&1y;2R\\s*\\/?&1G;/2T;I(e.13.46==R)b=b.Q(h,"\\n");I(e.13.44==R)b=b.Q(h,"");b=b.1e("\\n");h=/^\\s*/;g=4Q;O(K i=0;i<b.L&&g>0;i++){K k=b[i];I(x(k).L!=0){k=h.X(k);I(k==N){a=a;1N a}g=1Q.4q(k[0].L,g)}}I(g>0)O(i=0;i<b.L;i++)b[i]=b[i].1o(g);a=b.1K("\\n")}I(1u)d=J.4d(a);b=J.4c(J.2J,a);b=J.4b(a,b);b=J.49(b,d);I(J.V("41-40"))b=E(b);1j 2H!="1d"&&2H.3S&&2H.3S.1C(/5s/)&&c.U("5t");H b=\'<T 1c="\'+t(J.1c)+\'" 1g="\'+c.1K(" ")+\'">\'+(J.V("16")?e.16.1H(J):"")+\'<3Z 5z="0" 5H="0" 5J="0">\'+J.4f(J.V("1t"))+"<3T><3P>"+(1u?\'<2d 1g="1u">\'+J.3Q(a)+"</2d>":"")+\'<2d 1g="17"><T 1g="3O">\'+b+"</T></2d></3P></3T></3Z></T>"},2F:6(a){I(a===N)a="";J.17=a;K b=J.3Y("T");b.3X=J.1H(a);J.V("16")&&w(p(b,".16"),"5c",e.16.2b);J.V("3V-17")&&w(p(b,".17"),"56",f);H b},2Q:6(a){J.1c=""+1Q.5d(1Q.5n()*5k).1q();e.1Y.2A[t(J.1c)]=J;J.1n=C(e.2v,a||{});I(J.V("2k")==R)J.1n.16=J.1n.1u=11},5j:6(a){a=a.Q(/^\\s+|\\s+$/g,"").Q(/\\s+/g,"|");H"\\\\b(?:"+a+")\\\\b"},5f:6(a){J.28={18:{1I:a.18,23:"1k"},1b:{1I:a.1b,23:"1k"},17:1f M("(?<18>"+a.18.1m+")(?<17>.*?)(?<1b>"+a.1b.1m+")","5o")}}};H e}();1j 2e!="1d"&&(2e.1v=1v);',62,441,'||||||function|||||||||||||||||||||||||||||||||||||return|if|this|var|length|XRegExp|null|for|index|replace|true||div|push|getParam|call|exec|else|prototype||false|lastIndex|config|arguments|RegExp|toolbar|code|left|captureNames|slice|right|id|undefined|split|new|class|addToken|indexOf|typeof|script|className|source|params|substr|apply|toString|String|line|title|gutter|SyntaxHighlighter|_xregexp|strings|lt|html|test|OUTSIDE_CLASS|match|brush|document|target|gt|getHtml|regex|global|join|style|highlight|break|concat|window|Math|isRegExp|throw|value|brushes|brushName|space|alert|vars|http|syntaxhighlighter|expandSource|size|css|case|font|Fa|name|htmlScript|dA|can|handler|gm|td|exports|color|in|href|first|discoveredBrushes|light|collapse|object|cache|getButtonHtml|trigger|pattern|getLineHtml|nbsp|numbers|parseInt|defaults|com|items|www|pad|highlighters|execute|focus|func|all|getDiv|parentNode|navigator|INSIDE_CLASS|regexList|hasFlag|Match|useScriptTags|hasNamedCapture|text|help|init|br|input|gi|Error|values|span|list|250|height|width|screen|top|500|tagName|findElements|getElementsByTagName|aboutDialog|_blank|appendChild|charAt|Array|copyAsGlobal|setFlag|highlighter_|string|attachEvent|nodeName|floor|backref|output|the|TypeError|sticky|Za|iterate|freezeTokens|scope|type|textarea|alexgorbatchev|version|margin|2010|005896|gs|regexLib|body|center|align|noBrush|require|childNodes|DTD|xhtml1|head|org|w3|url|preventDefault|container|tr|getLineNumbersHtml|isNaN|userAgent|tbody|isLineHighlighted|quick|void|innerHTML|create|table|links|auto|smart|tab|stripBrs|tabs|bloggerMode|collapsed|plain|getCodeLinesHtml|caption|getMatchesHtml|findMatches|figureOutLineNumbers|removeNestedMatches|getTitleHtml|brushNotHtmlScript|substring|createElement|Highlighter|load|HtmlScript|Brush|pre|expand|multiline|min|Can|ignoreCase|find|blur|extended|toLowerCase|aliases|addEventListener|innerText|textContent|wasn|select|createTextNode|removeChild|option|same|frame|xmlns|dtd|twice|1999|equiv|meta|htmlscript|transitional|1E3|expected|PUBLIC|DOCTYPE|on|W3C|XHTML|TR|EN|Transitional||configured|srcElement|Object|after|run|dblclick|matchChain|valueOf|constructor|default|switch|click|round|execAt|forHtmlScript|token|gimy|functions|getKeywords|1E6|escape|within|random|sgi|another|finally|supply|MSIE|ie|toUpperCase|catch|returnValue|definition|event|border|imsx|constructing|one|Infinity|from|when|Content|cellpadding|flags|cellspacing|try|xhtml|Type|spaces|2930402|hosted_button_id|lastIndexOf|donate|active|development|keep|to|xclick|_s|Xml|please|like|you|paypal|cgi|cmd|webscr|bin|highlighted|scrollbars|aspScriptTags|phpScriptTags|sort|max|scriptScriptTags|toolbar_item|_|command|command_|number|getElementById|doubleQuotedString|singleLinePerlComments|singleLineCComments|multiLineCComments|singleQuotedString|multiLineDoubleQuotedString|xmlComments|alt|multiLineSingleQuotedString|If|https|1em|000|fff|background|5em|xx|bottom|75em|Gorbatchev|large|serif|CDATA|continue|utf|charset|content|About|family|sans|Helvetica|Arial|Geneva|3em|nogutter|Copyright|syntax|close|write|2004|Alex|open|JavaScript|highlighter|July|02|replaceChild|offset|83'.split('|'),0,{}))

/**
 * SyntaxHighlighter
 * http://alexgorbatchev.com/SyntaxHighlighter
 *
 * SyntaxHighlighter is donationware. If you are using it, please donate.
 * http://alexgorbatchev.com/SyntaxHighlighter/donate.html
 *
 * @version
 * 3.0.83 (July 02 2010)
 * 
 * @copyright
 * Copyright (C) 2004-2010 Alex Gorbatchev.
 *
 * @license
 * Dual licensed under the MIT and GPL licenses.
 */
;(function()
{
	// CommonJS
	typeof(require) != 'undefined' ? SyntaxHighlighter = require('shCore').SyntaxHighlighter : null;

	function Brush()
	{
		function getKeywordsCSS(str)
		{
			return '\\b([a-z_]|)' + str.replace(/ /g, '(?=:)\\b|\\b([a-z_\\*]|\\*|)') + '(?=:)\\b';
		};
	
		function getValuesCSS(str)
		{
			return '\\b' + str.replace(/ /g, '(?!-)(?!:)\\b|\\b()') + '\:\\b';
		};

		var keywords =	'ascent azimuth background-attachment background-color background-image background-position ' +
						'background-repeat background baseline bbox border-collapse border-color border-spacing border-style border-top ' +
						'border-right border-bottom border-left border-top-color border-right-color border-bottom-color border-left-color ' +
						'border-top-style border-right-style border-bottom-style border-left-style border-top-width border-right-width ' +
						'border-bottom-width border-left-width border-width border bottom cap-height caption-side centerline clear clip color ' +
						'content counter-increment counter-reset cue-after cue-before cue cursor definition-src descent direction display ' +
						'elevation empty-cells float font-size-adjust font-family font-size font-stretch font-style font-variant font-weight font ' +
						'height left letter-spacing line-height list-style-image list-style-position list-style-type list-style margin-top ' +
						'margin-right margin-bottom margin-left margin marker-offset marks mathline max-height max-width min-height min-width orphans ' +
						'outline-color outline-style outline-width outline overflow padding-top padding-right padding-bottom padding-left padding page ' +
						'page-break-after page-break-before page-break-inside pause pause-after pause-before pitch pitch-range play-during position ' +
						'quotes right richness size slope src speak-header speak-numeral speak-punctuation speak speech-rate stemh stemv stress ' +
						'table-layout text-align top text-decoration text-indent text-shadow text-transform unicode-bidi unicode-range units-per-em ' +
						'vertical-align visibility voice-family volume white-space widows width widths word-spacing x-height z-index';

		var values =	'above absolute all always aqua armenian attr aural auto avoid baseline behind below bidi-override black blink block blue bold bolder '+
						'both bottom braille capitalize caption center center-left center-right circle close-quote code collapse compact condensed '+
						'continuous counter counters crop cross crosshair cursive dashed decimal decimal-leading-zero default digits disc dotted double '+
						'embed embossed e-resize expanded extra-condensed extra-expanded fantasy far-left far-right fast faster fixed format fuchsia '+
						'gray green groove handheld hebrew help hidden hide high higher icon inline-table inline inset inside invert italic '+
						'justify landscape large larger left-side left leftwards level lighter lime line-through list-item local loud lower-alpha '+
						'lowercase lower-greek lower-latin lower-roman lower low ltr marker maroon medium message-box middle mix move narrower '+
						'navy ne-resize no-close-quote none no-open-quote no-repeat normal nowrap n-resize nw-resize oblique olive once open-quote outset '+
						'outside overline pointer portrait pre print projection purple red relative repeat repeat-x repeat-y rgb ridge right right-side '+
						'rightwards rtl run-in screen scroll semi-condensed semi-expanded separate se-resize show silent silver slower slow '+
						'small small-caps small-caption smaller soft solid speech spell-out square s-resize static status-bar sub super sw-resize '+
						'table-caption table-cell table-column table-column-group table-footer-group table-header-group table-row table-row-group teal '+
						'text-bottom text-top thick thin top transparent tty tv ultra-condensed ultra-expanded underline upper-alpha uppercase upper-latin '+
						'upper-roman url visible wait white wider w-resize x-fast x-high x-large x-loud x-low x-slow x-small x-soft xx-large xx-small yellow';

		var fonts =		'[mM]onospace [tT]ahoma [vV]erdana [aA]rial [hH]elvetica [sS]ans-serif [sS]erif [cC]ourier mono sans serif';
	
		this.regexList = [
			{ regex: SyntaxHighlighter.regexLib.multiLineCComments,		css: 'comments' },	// multiline comments
			{ regex: SyntaxHighlighter.regexLib.doubleQuotedString,		css: 'string' },	// double quoted strings
			{ regex: SyntaxHighlighter.regexLib.singleQuotedString,		css: 'string' },	// single quoted strings
			{ regex: /\#[a-fA-F0-9]{3,6}/g,								css: 'value' },		// html colors
			{ regex: /(-?\d+)(\.\d+)?(px|em|pt|\:|\%|)/g,				css: 'value' },		// sizes
			{ regex: /!important/g,										css: 'color3' },	// !important
			{ regex: new RegExp(getKeywordsCSS(keywords), 'gm'),		css: 'keyword' },	// keywords
			{ regex: new RegExp(getValuesCSS(values), 'g'),				css: 'value' },		// values
			{ regex: new RegExp(this.getKeywords(fonts), 'g'),			css: 'color1' }		// fonts
			];

		this.forHtmlScript({ 
			left: /(&lt;|<)\s*style.*?(&gt;|>)/gi, 
			right: /(&lt;|<)\/\s*style\s*(&gt;|>)/gi 
			});
	};

	Brush.prototype	= new SyntaxHighlighter.Highlighter();
	Brush.aliases	= ['css'];

	SyntaxHighlighter.brushes.CSS = Brush;

	// CommonJS
	typeof(exports) != 'undefined' ? exports.Brush = Brush : null;
})();

/**
 * SyntaxHighlighter
 * http://alexgorbatchev.com/SyntaxHighlighter
 *
 * SyntaxHighlighter is donationware. If you are using it, please donate.
 * http://alexgorbatchev.com/SyntaxHighlighter/donate.html
 *
 * @version
 * 3.0.83 (July 02 2010)
 * 
 * @copyright
 * Copyright (C) 2004-2010 Alex Gorbatchev.
 *
 * @license
 * Dual licensed under the MIT and GPL licenses.
 */
;(function()
{
	// CommonJS
	typeof(require) != 'undefined' ? SyntaxHighlighter = require('shCore').SyntaxHighlighter : null;

	function Brush()
	{
		var keywords =	'break case catch continue ' +
						'default delete do else false  ' +
						'for function if in instanceof ' +
						'new null return super switch ' +
						'this throw true try typeof var while with'
						;

		var r = SyntaxHighlighter.regexLib;
		
		this.regexList = [
			{ regex: r.multiLineDoubleQuotedString,					css: 'string' },			// double quoted strings
			{ regex: r.multiLineSingleQuotedString,					css: 'string' },			// single quoted strings
			{ regex: r.singleLineCComments,							css: 'comments' },			// one line comments
			{ regex: r.multiLineCComments,							css: 'comments' },			// multiline comments
			{ regex: /\s*#.*/gm,									css: 'preprocessor' },		// preprocessor tags like #region and #endregion
			{ regex: new RegExp(this.getKeywords(keywords), 'gm'),	css: 'keyword' }			// keywords
			];
	
		this.forHtmlScript(r.scriptScriptTags);
	};

	Brush.prototype	= new SyntaxHighlighter.Highlighter();
	Brush.aliases	= ['js', 'jscript', 'javascript'];

	SyntaxHighlighter.brushes.JScript = Brush;

	// CommonJS
	typeof(exports) != 'undefined' ? exports.Brush = Brush : null;
})();

/**
 * SyntaxHighlighter
 * http://alexgorbatchev.com/SyntaxHighlighter
 *
 * SyntaxHighlighter is donationware. If you are using it, please donate.
 * http://alexgorbatchev.com/SyntaxHighlighter/donate.html
 *
 * @version
 * 3.0.83 (July 02 2010)
 * 
 * @copyright
 * Copyright (C) 2004-2010 Alex Gorbatchev.
 *
 * @license
 * Dual licensed under the MIT and GPL licenses.
 */
;(function()
{
	// CommonJS
	typeof(require) != 'undefined' ? SyntaxHighlighter = require('shCore').SyntaxHighlighter : null;

	function Brush()
	{
		var funcs	=	'abs acos acosh addcslashes addslashes ' +
						'array_change_key_case array_chunk array_combine array_count_values array_diff '+
						'array_diff_assoc array_diff_key array_diff_uassoc array_diff_ukey array_fill '+
						'array_filter array_flip array_intersect array_intersect_assoc array_intersect_key '+
						'array_intersect_uassoc array_intersect_ukey array_key_exists array_keys array_map '+
						'array_merge array_merge_recursive array_multisort array_pad array_pop array_product '+
						'array_push array_rand array_reduce array_reverse array_search array_shift '+
						'array_slice array_splice array_sum array_udiff array_udiff_assoc '+
						'array_udiff_uassoc array_uintersect array_uintersect_assoc '+
						'array_uintersect_uassoc array_unique array_unshift array_values array_walk '+
						'array_walk_recursive atan atan2 atanh base64_decode base64_encode base_convert '+
						'basename bcadd bccomp bcdiv bcmod bcmul bindec bindtextdomain bzclose bzcompress '+
						'bzdecompress bzerrno bzerror bzerrstr bzflush bzopen bzread bzwrite ceil chdir '+
						'checkdate checkdnsrr chgrp chmod chop chown chr chroot chunk_split class_exists '+
						'closedir closelog copy cos cosh count count_chars date decbin dechex decoct '+
						'deg2rad delete ebcdic2ascii echo empty end ereg ereg_replace eregi eregi_replace error_log '+
						'error_reporting escapeshellarg escapeshellcmd eval exec exit exp explode extension_loaded '+
						'feof fflush fgetc fgetcsv fgets fgetss file_exists file_get_contents file_put_contents '+
						'fileatime filectime filegroup fileinode filemtime fileowner fileperms filesize filetype '+
						'floatval flock floor flush fmod fnmatch fopen fpassthru fprintf fputcsv fputs fread fscanf '+
						'fseek fsockopen fstat ftell ftok getallheaders getcwd getdate getenv gethostbyaddr gethostbyname '+
						'gethostbynamel getimagesize getlastmod getmxrr getmygid getmyinode getmypid getmyuid getopt '+
						'getprotobyname getprotobynumber getrandmax getrusage getservbyname getservbyport gettext '+
						'gettimeofday gettype glob gmdate gmmktime ini_alter ini_get ini_get_all ini_restore ini_set '+
						'interface_exists intval ip2long is_a is_array is_bool is_callable is_dir is_double '+
						'is_executable is_file is_finite is_float is_infinite is_int is_integer is_link is_long '+
						'is_nan is_null is_numeric is_object is_readable is_real is_resource is_scalar is_soap_fault '+
						'is_string is_subclass_of is_uploaded_file is_writable is_writeable mkdir mktime nl2br '+
						'parse_ini_file parse_str parse_url passthru pathinfo print readlink realpath rewind rewinddir rmdir '+
						'round str_ireplace str_pad str_repeat str_replace str_rot13 str_shuffle str_split '+
						'str_word_count strcasecmp strchr strcmp strcoll strcspn strftime strip_tags stripcslashes '+
						'stripos stripslashes stristr strlen strnatcasecmp strnatcmp strncasecmp strncmp strpbrk '+
						'strpos strptime strrchr strrev strripos strrpos strspn strstr strtok strtolower strtotime '+
						'strtoupper strtr strval substr substr_compare';

		var keywords =	'abstract and array as break case catch cfunction class clone const continue declare default die do ' +
						'else elseif enddeclare endfor endforeach endif endswitch endwhile extends final for foreach ' +
						'function include include_once global goto if implements interface instanceof namespace new ' +
						'old_function or private protected public return require require_once static switch ' +
						'throw try use var while xor ';
		
		var constants	= '__FILE__ __LINE__ __METHOD__ __FUNCTION__ __CLASS__';

		this.regexList = [
			{ regex: SyntaxHighlighter.regexLib.singleLineCComments,	css: 'comments' },			// one line comments
			{ regex: SyntaxHighlighter.regexLib.multiLineCComments,		css: 'comments' },			// multiline comments
			{ regex: SyntaxHighlighter.regexLib.doubleQuotedString,		css: 'string' },			// double quoted strings
			{ regex: SyntaxHighlighter.regexLib.singleQuotedString,		css: 'string' },			// single quoted strings
			{ regex: /\$\w+/g,											css: 'variable' },			// variables
			{ regex: new RegExp(this.getKeywords(funcs), 'gmi'),		css: 'functions' },			// common functions
			{ regex: new RegExp(this.getKeywords(constants), 'gmi'),	css: 'constants' },			// constants
			{ regex: new RegExp(this.getKeywords(keywords), 'gm'),		css: 'keyword' }			// keyword
			];

		this.forHtmlScript(SyntaxHighlighter.regexLib.phpScriptTags);
	};

	Brush.prototype	= new SyntaxHighlighter.Highlighter();
	Brush.aliases	= ['php'];

	SyntaxHighlighter.brushes.Php = Brush;

	// CommonJS
	typeof(exports) != 'undefined' ? exports.Brush = Brush : null;
})();

/**
 * SyntaxHighlighter
 * http://alexgorbatchev.com/SyntaxHighlighter
 *
 * SyntaxHighlighter is donationware. If you are using it, please donate.
 * http://alexgorbatchev.com/SyntaxHighlighter/donate.html
 *
 * @version
 * 3.0.83 (July 02 2010)
 * 
 * @copyright
 * Copyright (C) 2004-2010 Alex Gorbatchev.
 *
 * @license
 * Dual licensed under the MIT and GPL licenses.
 */
;(function()
{
	// CommonJS
	typeof(require) != 'undefined' ? SyntaxHighlighter = require('shCore').SyntaxHighlighter : null;

	function Brush()
	{
		function process(match, regexInfo)
		{
			var constructor = SyntaxHighlighter.Match,
				code = match[0],
				tag = new XRegExp('(&lt;|<)[\\s\\/\\?]*(?<name>[:\\w-\\.]+)', 'xg').exec(code),
				result = []
				;
		
			if (match.attributes != null) 
			{
				var attributes,
					regex = new XRegExp('(?<name> [\\w:\\-\\.]+)' +
										'\\s*=\\s*' +
										'(?<value> ".*?"|\'.*?\'|\\w+)',
										'xg');

				while ((attributes = regex.exec(code)) != null) 
				{
					result.push(new constructor(attributes.name, match.index + attributes.index, 'color1'));
					result.push(new constructor(attributes.value, match.index + attributes.index + attributes[0].indexOf(attributes.value), 'string'));
				}
			}

			if (tag != null)
				result.push(
					new constructor(tag.name, match.index + tag[0].indexOf(tag.name), 'keyword')
				);

			return result;
		}
	
		this.regexList = [
			{ regex: new XRegExp('(\\&lt;|<)\\!\\[[\\w\\s]*?\\[(.|\\s)*?\\]\\](\\&gt;|>)', 'gm'),			css: 'color2' },	// <![ ... [ ... ]]>
			{ regex: SyntaxHighlighter.regexLib.xmlComments,												css: 'comments' },	// <!-- ... -->
			{ regex: new XRegExp('(&lt;|<)[\\s\\/\\?]*(\\w+)(?<attributes>.*?)[\\s\\/\\?]*(&gt;|>)', 'sg'), func: process }
		];
	};

	Brush.prototype	= new SyntaxHighlighter.Highlighter();
	Brush.aliases	= ['xml', 'xhtml', 'xslt', 'html'];

	SyntaxHighlighter.brushes.Xml = Brush;

	// CommonJS
	typeof(exports) != 'undefined' ? exports.Brush = Brush : null;
})();

/**
 *                                                        ____   _____
 *  Dynarch Calendar -- JSCal2, version 1.9               \  /_  /   /
 *  Built at 2011/03/13 10:28 GMT                          \  / /   /
 *                                                          \/ /_  /
 *  (c) Dynarch.com 2009                                     \  / /
 *  All rights reserved.                                       / /
 *  Visit www.dynarch.com/projects/calendar for details        \/
 *
 */
Calendar=function(){function bm(a){typeof a=="string"&&(a=document.getElementById(a));return a}function bk(a,b,c){for(c=0;c<a.length;++c)b(a[c])}function bj(){var a=document.documentElement,b=document.body;return{x:a.scrollLeft||b.scrollLeft,y:a.scrollTop||b.scrollTop,w:a.clientWidth||window.innerWidth||b.clientWidth,h:a.clientHeight||window.innerHeight||b.clientHeight}}function bi(a){var b=0,c=0,d=/^div$/i.test(a.tagName),e,f;d&&a.scrollLeft&&(b=a.scrollLeft),d&&a.scrollTop&&(c=a.scrollTop),e={x:a.offsetLeft-b,y:a.offsetTop-c},a.offsetParent&&(f=bi(a.offsetParent),e.x+=f.x,e.y+=f.y);return e}function bh(a,b){var c=e?a.clientX+document.body.scrollLeft:a.pageX,d=e?a.clientY+document.body.scrollTop:a.pageY;b&&(c-=b.x,d-=b.y);return{x:c,y:d}}function bg(a,b){var c=a.style;b!=null&&(c.display=b?"":"none");return c.display!="none"}function bf(a,b){b===""?e?a.style.filter="":a.style.opacity="":b!=null?e?a.style.filter="alpha(opacity="+b*100+")":a.style.opacity=b:e?/alpha\(opacity=([0-9.])+\)/.test(a.style.opacity)&&(b=parseFloat(RegExp.$1)/100):b=parseFloat(a.style.opacity);return b}function bd(a,b,c){function h(){var b=a.len;a.onUpdate(c/b,d),c==b&&g(),++c}function g(){b&&(clearInterval(b),b=null),a.onStop(c/a.len,d)}function f(){b&&g(),c=0,b=setInterval(h,1e3/a.fps)}function d(a,b,c,d){return d?c+a*(b-c):b+a*(c-b)}a=U(a,{fps:50,len:15,onUpdate:bl,onStop:bl}),e&&(a.len=Math.round(a.len/2)),f();return{start:f,stop:g,update:h,args:a,map:d}}function bc(a,b){if(!b(a))for(var c=a.firstChild;c;c=c.nextSibling)c.nodeType==1&&bc(c,b)}function bb(a,b){var c=ba(arguments,2);return b==undefined?function(){return a.apply(this,c.concat(ba(arguments)))}:function(){return a.apply(b,c.concat(ba(arguments)))}}function ba(a,b){b==null&&(b=0);var c,d,e;try{c=Array.prototype.slice.call(a,b)}catch(f){c=Array(a.length-b);for(d=b,e=0;d<a.length;++d,++e)c[e]=a[d]}return c}function _(a,b,c){var d=null;document.createElementNS?d=document.createElementNS("http://www.w3.org/1999/xhtml",a):d=document.createElement(a),b&&(d.className=b),c&&c.appendChild(d);return d}function $(a,b,c){if(b instanceof Array)for(var d=b.length;--d>=0;)$(a,b[d],c);else Y(b,c,a?c:null);return a}function Z(a,b){return Y(a,b,b)}function Y(a,b,c){if(a){var d=a.className.replace(/^\s+|\s+$/,"").split(/\x20/),e=[],f;for(f=d.length;f>0;)d[--f]!=b&&e.push(d[f]);c&&e.push(c),a.className=e.join(" ")}return c}function X(a){a=a||window.event,e?(a.cancelBubble=!0,a.returnValue=!1):(a.preventDefault(),a.stopPropagation());return!1}function W(a,b,c,d){if(a instanceof Array)for(var f=a.length;--f>=0;)W(a[f],b,c);else if(typeof b=="object")for(var f in b)b.hasOwnProperty(f)&&W(a,f,b[f],c);else a.removeEventListener?a.removeEventListener(b,c,e?!0:!!d):a.detachEvent?a.detachEvent("on"+b,c):a["on"+b]=null}function V(a,b,c,d){if(a instanceof Array)for(var f=a.length;--f>=0;)V(a[f],b,c,d);else if(typeof b=="object")for(var f in b)b.hasOwnProperty(f)&&V(a,f,b[f],c);else a.addEventListener?a.addEventListener(b,c,e?!0:!!d):a.attachEvent?a.attachEvent("on"+b,c):a["on"+b]=c}function U(a,b,c,d){d={};for(c in b)b.hasOwnProperty(c)&&(d[c]=b[c]);for(c in a)a.hasOwnProperty(c)&&(d[c]=a[c]);return d}function T(a){if(/\S/.test(a)){a=a.toLowerCase();function b(b){for(var c=b.length;--c>=0;)if(b[c].toLowerCase().indexOf(a)==0)return c+1}return b(L("smn"))||b(L("mn"))}}function S(a){if(a){if(typeof a=="number")return P(a);if(!(a instanceof Date)){var b=a.split(/-/);return new Date(parseInt(b[0],10),parseInt(b[1],10)-1,parseInt(b[2],10),12,0,0,0)}}return a}function R(a,b){var c=a.getMonth(),d=a.getDate(),e=a.getFullYear(),f=M(a),g=a.getDay(),h=a.getHours(),i=h>=12,j=i?h-12:h,k=N(a),l=a.getMinutes(),m=a.getSeconds(),n=/%./g,o;j===0&&(j=12),o={"%a":L("sdn")[g],"%A":L("dn")[g],"%b":L("smn")[c],"%B":L("mn")[c],"%C":1+Math.floor(e/100),"%d":d<10?"0"+d:d,"%e":d,"%H":h<10?"0"+h:h,"%I":j<10?"0"+j:j,"%j":k<10?"00"+k:k<100?"0"+k:k,"%k":h,"%l":j,"%m":c<9?"0"+(1+c):1+c,"%o":1+c,"%M":l<10?"0"+l:l,"%n":"\n","%p":i?"PM":"AM","%P":i?"pm":"am","%s":Math.floor(a.getTime()/1e3),"%S":m<10?"0"+m:m,"%t":"\t","%U":f<10?"0"+f:f,"%W":f<10?"0"+f:f,"%V":f<10?"0"+f:f,"%u":g+1,"%w":g,"%y":(""+e).substr(2,2),"%Y":e,"%%":"%"};return b.replace(n,function(a){return o.hasOwnProperty(a)?o[a]:a})}function Q(a,b,c){var d=a.getFullYear(),e=a.getMonth(),f=a.getDate(),g=b.getFullYear(),h=b.getMonth(),i=b.getDate();return d<g?-3:d>g?3:e<h?-2:e>h?2:c?0:f<i?-1:f>i?1:0}function P(a,b,c,d,e){if(!(a instanceof Date)){a=parseInt(a,10);var f=Math.floor(a/1e4);a=a%1e4;var g=Math.floor(a/100);a=a%100,a=new Date(f,g-1,a,b==null?12:b,c==null?0:c,d==null?0:d,e==null?0:e)}return a}function O(a){if(a instanceof Date)return 1e4*a.getFullYear()+100*(a.getMonth()+1)+a.getDate();if(typeof a=="string")return parseInt(a,10);return a}function N(a){a=new Date(a.getFullYear(),a.getMonth(),a.getDate(),12,0,0);var b=new Date(a.getFullYear(),0,1,12,0,0),c=a-b;return Math.floor(c/864e5)}function M(a){a=new Date(a.getFullYear(),a.getMonth(),a.getDate(),12,0,0);var b=a.getDay();a.setDate(a.getDate()-(b+6)%7+3);var c=a.valueOf();a.setMonth(0),a.setDate(4);return Math.round((c-a.valueOf())/6048e5)+1}function L(a,b){var c=i.__.data[a];b&&typeof c=="string"&&(c=K(c,b));return c}function K(a,b){return a.replace(/\$\{([^:\}]+)(:[^\}]+)?\}/g,function(a,c,d){var e=b[c],f;d&&(f=d.substr(1).split(/\s*\|\s*/),e=(e>=f.length?f[f.length-1]:f[e]).replace(/##?/g,function(a){return a.length==2?"#":e}));return e})}function J(b){if(!this._menuAnim){b=b||window.event;var c=b.target||b.srcElement,d=c.getAttribute("dyc-btn"),e=b.keyCode,f=b.charCode||e,g=H[e];if("year"==d&&e==13){var h=new Date(this.date);h.setDate(1),h.setFullYear(this._getInputYear()),this.moveTo(h,!0),z(this,!1);return X(b)}if(this._menuVisible){if(e==27){z(this,!1);return X(b)}}else{b.ctrlKey||(g=null),g==null&&!b.ctrlKey&&(g=I[e]),e==36&&(g=0);if(g!=null){y(this,g);return X(b)}f=String.fromCharCode(f).toLowerCase();var i=this.els.yearInput,j=this.selection;if(f==" "){z(this,!0),this.focus(),i.focus(),i.select();return X(b)}if(f>="0"&&f<="9"){z(this,!0),this.focus(),i.value=f,i.focus();return X(b)}var k=L("mn"),l=b.shiftKey?-1:this.date.getMonth(),m=0,n;while(++m<12){n=k[(l+m)%12].toLowerCase();if(n.indexOf(f)==0){var h=new Date(this.date);h.setDate(1),h.setMonth((l+m)%12),this.moveTo(h,!0);return X(b)}}if(e>=37&&e<=40){var h=this._lastHoverDate;if(!h&&!j.isEmpty()){h=e<39?j.getFirstDate():j.getLastDate();if(h<this._firstDateVisible||h>this._lastDateVisible)h=null}if(!h)h=e<39?this._lastDateVisible:this._firstDateVisible;else{var o=h;h=P(h);var l=100;while(l-->0){switch(e){case 37:h.setDate(h.getDate()-1);break;case 38:h.setDate(h.getDate()-7);break;case 39:h.setDate(h.getDate()+1);break;case 40:h.setDate(h.getDate()+7)}if(!this.isDisabled(h))break}h=O(h),(h<this._firstDateVisible||h>this._lastDateVisible)&&this.moveTo(h)}Y(this._getDateDiv(o),Z(this._getDateDiv(h),"DynarchCalendar-hover-date")),this._lastHoverDate=h;return X(b)}if(e==13&&this._lastHoverDate){j.type==a.SEL_MULTIPLE&&(b.shiftKey||b.ctrlKey)?(b.shiftKey&&this._selRangeStart&&(j.clear(!0),j.selectRange(this._selRangeStart,this._lastHoverDate)),b.ctrlKey&&j.set(this._selRangeStart=this._lastHoverDate,!0)):j.reset(this._selRangeStart=this._lastHoverDate);return X(b)}e==27&&!this.args.cont&&this.hide()}}}function G(){this.refresh();var a=this.inputField,b=this.selection;if(a){var c=b.print(this.dateFormat);/input|textarea/i.test(a.tagName)?a.value=c:a.innerHTML=c}this.callHooks("onSelect",this,b)}function F(a){a=a||window.event;var b=C(a);if(b){var c=b.getAttribute("dyc-btn"),d=b.getAttribute("dyc-type"),e=a.wheelDelta?a.wheelDelta/120:-a.detail/3;e=e<0?-1:e>0?1:0,this.args.reverseWheel&&(e=-e);if(/^(time-(hour|min))/.test(d)){switch(RegExp.$1){case"time-hour":this.setHours(this.getHours()+e);break;case"time-min":this.setMinutes(this.getMinutes()+this.args.minuteStep*e)}X(a)}else/Y/i.test(c)&&(e*=2),y(this,-e),X(a)}}function E(a,b){b=b||window.event;var c=C(b);if(c){var d=c.getAttribute("dyc-type");if(d&&!c.getAttribute("disabled"))if(!a||!this._bodyAnim||d!="date"){var e=c.getAttribute("dyc-cls");e=e?D(e,0):"DynarchCalendar-hover-"+d,(d!="date"||this.selection.type)&&$(a,c,e),d=="date"&&($(a,c.parentNode.parentNode,"DynarchCalendar-hover-week"),this._showTooltip(c.getAttribute("dyc-date"))),/^time-hour/.test(d)&&$(a,this.els.timeHour,"DynarchCalendar-hover-time"),/^time-min/.test(d)&&$(a,this.els.timeMinute,"DynarchCalendar-hover-time"),Y(this._getDateDiv(this._lastHoverDate),"DynarchCalendar-hover-date"),this._lastHoverDate=null}}a||this._showTooltip()}function D(a,b){return"DynarchCalendar-"+a.split(/,/)[b]}function C(a){var b=a.target||a.srcElement,c=b;while(b&&b.getAttribute&&!b.getAttribute("dyc-type"))b=b.parentNode;return b.getAttribute&&b||c}function B(a){a=a||window.event;var b=this.els.topCont.style,c=bh(a,this._mouseDiff);b.left=c.x+"px",b.top=c.y+"px"}function A(b,c){c=c||window.event;var d=C(c);if(d&&!d.getAttribute("disabled")){var f=d.getAttribute("dyc-btn"),g=d.getAttribute("dyc-type"),h=d.getAttribute("dyc-date"),i=this.selection,j,k={mouseover:X,mousemove:X,mouseup:function(a){var b=d.getAttribute("dyc-cls");b&&Y(d,D(b,1)),clearTimeout(j),W(document,k,!0),k=null}};if(b){setTimeout(bb(this.focus,this),1);var l=d.getAttribute("dyc-cls");l&&Z(d,D(l,1));if("menu"==f)this.toggleMenu();else if(d&&/^[+-][MY]$/.test(f))if(y(this,f)){var m=bb(function(){y(this,f,!0)?j=setTimeout(m,40):(k.mouseup(),y(this,f))},this);j=setTimeout(m,350),V(document,k,!0)}else k.mouseup();else if("year"==f)this.els.yearInput.focus(),this.els.yearInput.select();else if(g=="time-am")V(document,k,!0);else if(/^time/.test(g)){var m=bb(function(a){w.call(this,a),j=setTimeout(m,100)},this,g);w.call(this,g),j=setTimeout(m,350),V(document,k,!0)}else h&&i.type&&(i.type==a.SEL_MULTIPLE?c.shiftKey&&this._selRangeStart?i.selectRange(this._selRangeStart,h):(!c.ctrlKey&&!i.isSelected(h)&&i.clear(!0),i.set(h,!0),this._selRangeStart=h):(i.set(h),this.moveTo(P(h),2)),d=this._getDateDiv(h),E.call(this,!0,{target:d})),V(document,k,!0);e&&k&&/dbl/i.test(c.type)&&k.mouseup(),!this.args.fixed&&/^(DynarchCalendar-(topBar|bottomBar|weekend|weekNumber|menu(-sep)?))?$/.test(d.className)&&!this.args.cont&&(k.mousemove=bb(B,this),this._mouseDiff=bh(c,bi(this.els.topCont)),V(document,k,!0))}else if("today"==f)!this._menuVisible&&i.type==a.SEL_SINGLE&&i.set(new Date),this.moveTo(new Date,!0),z(this,!1);else if(/^m([0-9]+)/.test(f)){var h=new Date(this.date);h.setDate(1),h.setMonth(RegExp.$1),h.setFullYear(this._getInputYear()),this.moveTo(h,!0),z(this,!1)}else g=="time-am"&&this.setHours(this.getHours()+12);e||X(c)}}function z(a,b){a._menuVisible=b,$(b,a.els.title,"DynarchCalendar-pressed-title");var c=a.els.menu;f&&(c.style.height=a.els.main.offsetHeight+"px");if(!a.args.animation)bg(c,b),a.focused&&a.focus();else{a._menuAnim&&a._menuAnim.stop();var d=a.els.main.offsetHeight;f&&(c.style.width=a.els.topBar.offsetWidth+"px"),b&&(c.firstChild.style.marginTop=-d+"px",a.args.opacity>0&&bf(c,0),bg(c,!0)),a._menuAnim=bd({onUpdate:function(e,f){c.firstChild.style.marginTop=f(be.accel_b(e),-d,0,!b)+"px",a.args.opacity>0&&bf(c,f(be.accel_b(e),0,.85,!b))},onStop:function(){a.args.opacity>0&&bf(c,.85),c.firstChild.style.marginTop="",a._menuAnim=null,b||(bg(c,!1),a.focused&&a.focus())}})}}function y(a,b,c){this._bodyAnim&&this._bodyAnim.stop();var d;if(b!=0){d=new Date(a.date),d.setDate(1);switch(b){case"-Y":case-2:d.setFullYear(d.getFullYear()-1);break;case"+Y":case 2:d.setFullYear(d.getFullYear()+1);break;case"-M":case-1:d.setMonth(d.getMonth()-1);break;case"+M":case 1:d.setMonth(d.getMonth()+1)}}else d=new Date;return a.moveTo(d,!c)}function w(a){switch(a){case"time-hour+":this.setHours(this.getHours()+1);break;case"time-hour-":this.setHours(this.getHours()-1);break;case"time-min+":this.setMinutes(this.getMinutes()+this.args.minuteStep);break;case"time-min-":this.setMinutes(this.getMinutes()-this.args.minuteStep);break;default:return}}function v(){this._bluringTimeout=setTimeout(bb(u,this),50)}function u(){this.focused=!1,Y(this.els.main,"DynarchCalendar-focused"),this._menuVisible&&z(this,!1),this.args.cont||this.hide(),this.callHooks("onBlur",this)}function t(){this._bluringTimeout&&clearTimeout(this._bluringTimeout),this.focused=!0,Z(this.els.main,"DynarchCalendar-focused"),this.callHooks("onFocus",this)}function s(a){var b=_("div"),c=a.els={},d={mousedown:bb(A,a,!0),mouseup:bb(A,a,!1),mouseover:bb(E,a,!0),mouseout:bb(E,a,!1),keypress:bb(J,a)};a.args.noScroll||(d[g?"DOMMouseScroll":"mousewheel"]=bb(F,a)),e&&(d.dblclick=d.mousedown,d.keydown=d.keypress),b.innerHTML=m(a),bc(b.firstChild,function(a){var b=r[a.className];b&&(c[b]=a),e&&a.setAttribute("unselectable","on")}),V(c.main,d),V([c.focusLink,c.yearInput],a._focusEvents={focus:bb(t,a),blur:bb(v,a)}),a.moveTo(a.date,!1),a.setTime(null,!0);return c.topCont}function q(a){function d(){c.showTime&&(b.push("<td>"),p(a,b),b.push("</td>"))}var b=[],c=a.args;b.push("<table",j," style='width:100%'><tr>"),c.timePos=="left"&&d(),c.bottomBar&&(b.push("<td>"),b.push("<table",j,"><tr><td>","<div dyc-btn='today' dyc-cls='hover-bottomBar-today,pressed-bottomBar-today' dyc-type='bottomBar-today' ","class='DynarchCalendar-bottomBar-today'>",L("today"),"</div>","</td></tr></table>"),b.push("</td>")),c.timePos=="right"&&d(),b.push("</tr></table>");return b.join("")}function p(a,b){b.push("<table class='DynarchCalendar-time'"+j+"><tr>","<td rowspan='2'><div dyc-type='time-hour' dyc-cls='hover-time,pressed-time' class='DynarchCalendar-time-hour'></div></td>","<td dyc-type='time-hour+' dyc-cls='hover-time,pressed-time' class='DynarchCalendar-time-up'></td>","<td rowspan='2' class='DynarchCalendar-time-sep'></td>","<td rowspan='2'><div dyc-type='time-min' dyc-cls='hover-time,pressed-time' class='DynarchCalendar-time-minute'></div></td>","<td dyc-type='time-min+' dyc-cls='hover-time,pressed-time' class='DynarchCalendar-time-up'></td>"),a.args.showTime==12&&b.push("<td rowspan='2' class='DynarchCalendar-time-sep'></td>","<td rowspan='2'><div class='DynarchCalendar-time-am' dyc-type='time-am' dyc-cls='hover-time,pressed-time'></div></td>"),b.push("</tr><tr>","<td dyc-type='time-hour-' dyc-cls='hover-time,pressed-time' class='DynarchCalendar-time-down'></td>","<td dyc-type='time-min-' dyc-cls='hover-time,pressed-time' class='DynarchCalendar-time-down'></td>","</tr></table>")}function o(a){var b=["<table height='100%'",j,"><tr><td>","<table style='margin-top: 1.5em'",j,">","<tr><td colspan='3'><input dyc-btn='year' class='DynarchCalendar-menu-year' size='6' value='",a.date.getFullYear(),"' /></td></tr>","<tr><td><div dyc-type='menubtn' dyc-cls='hover-navBtn,pressed-navBtn' dyc-btn='today'>",L("goToday"),"</div></td></tr>","</table>","<p class='DynarchCalendar-menu-sep'>&nbsp;</p>","<table class='DynarchCalendar-menu-mtable'",j,">"],c=L("smn"),d=0,e=b.length,f;while(d<12){b[e++]="<tr>";for(f=4;--f>0;)b[e++]="<td><div dyc-type='menubtn' dyc-cls='hover-navBtn,pressed-navBtn' dyc-btn='m"+d+"' class='DynarchCalendar-menu-month'>"+c[d++]+"</div></td>";b[e++]="</tr>"}b[e++]="</table></td></tr></table>";return b.join("")}function n(a){return"<div unselectable='on'>"+R(a.date,a.args.titleFormat)+"</div>"}function m(a){var b=["<table class='DynarchCalendar-topCont'",j,"><tr><td>","<div class='DynarchCalendar'>",e?"<a class='DynarchCalendar-focusLink' href='#'></a>":"<button class='DynarchCalendar-focusLink'></button>","<div class='DynarchCalendar-topBar'>","<div dyc-type='nav' dyc-btn='-Y' dyc-cls='hover-navBtn,pressed-navBtn' ","class='DynarchCalendar-navBtn DynarchCalendar-prevYear'><div></div></div>","<div dyc-type='nav' dyc-btn='+Y' dyc-cls='hover-navBtn,pressed-navBtn' ","class='DynarchCalendar-navBtn DynarchCalendar-nextYear'><div></div></div>","<div dyc-type='nav' dyc-btn='-M' dyc-cls='hover-navBtn,pressed-navBtn' ","class='DynarchCalendar-navBtn DynarchCalendar-prevMonth'><div></div></div>","<div dyc-type='nav' dyc-btn='+M' dyc-cls='hover-navBtn,pressed-navBtn' ","class='DynarchCalendar-navBtn DynarchCalendar-nextMonth'><div></div></div>","<table class='DynarchCalendar-titleCont'",j,"><tr><td>","<div dyc-type='title' dyc-btn='menu' dyc-cls='hover-title,pressed-title' class='DynarchCalendar-title'>",n(a),"</div></td></tr></table>","<div class='DynarchCalendar-dayNames'>",k(a),"</div>","</div>","<div class='DynarchCalendar-body'></div>"];(a.args.bottomBar||a.args.showTime)&&b.push("<div class='DynarchCalendar-bottomBar'>",q(a),"</div>"),b.push("<div class='DynarchCalendar-menu' style='display: none'>",o(a),"</div>","<div class='DynarchCalendar-tooltip'></div>","</div>","</td></tr></table>");return b.join("")}function l(a,b,c){b=b||a.date,c=c||a.fdow,b=new Date(b.getFullYear(),b.getMonth(),b.getDate(),12,0,0,0);var d=b.getMonth(),e=[],f=0,g=a.args.weekNumbers;b.setDate(1);var h=(b.getDay()-c)%7;h<0&&(h+=7),b.setDate(0-h),b.setDate(b.getDate()+1);var i=new Date,k=i.getDate(),l=i.getMonth(),m=i.getFullYear();e[f++]="<table class='DynarchCalendar-bodyTable'"+j+">";for(var n=0;n<6;++n){e[f++]="<tr class='DynarchCalendar-week",n==0&&(e[f++]=" DynarchCalendar-first-row"),n==5&&(e[f++]=" DynarchCalendar-last-row"),e[f++]="'>",g&&(e[f++]="<td class='DynarchCalendar-first-col'><div class='DynarchCalendar-weekNumber'>"+M(b)+"</div></td>");for(var o=0;o<7;++o){var p=b.getDate(),q=b.getMonth(),r=b.getFullYear(),s=1e4*r+100*(q+1)+p,t=a.selection.isSelected(s),u=a.isDisabled(b);e[f++]="<td class='",o==0&&!g&&(e[f++]=" DynarchCalendar-first-col"),o==0&&n==0&&(a._firstDateVisible=s),o==6&&(e[f++]=" DynarchCalendar-last-col",n==5&&(a._lastDateVisible=s)),t&&(e[f++]=" DynarchCalendar-td-selected"),e[f++]="'><div dyc-type='date' unselectable='on' dyc-date='"+s+"' ",u&&(e[f++]="disabled='1' "),e[f++]="class='DynarchCalendar-day",L("weekend").indexOf(b.getDay())>=0&&(e[f++]=" DynarchCalendar-weekend"),q!=d&&(e[f++]=" DynarchCalendar-day-othermonth"),p==k&&q==l&&r==m&&(e[f++]=" DynarchCalendar-day-today"),u&&(e[f++]=" DynarchCalendar-day-disabled"),t&&(e[f++]=" DynarchCalendar-day-selected"),u=a.args.dateInfo(b),u&&u.klass&&(e[f++]=" "+u.klass),e[f++]="'>"+p+"</div></td>",b=new Date(r,q,p+1,12,0,0,0)}e[f++]="</tr>"}e[f++]="</table>";return e.join("")}function k(a){var b=["<table",j,"><tr>"],c=0;a.args.weekNumbers&&b.push("<td><div class='DynarchCalendar-weekNumber'>",L("wk"),"</div></td>");while(c<7){var d=(c++ +a.fdow)%7;b.push("<td><div",L("weekend").indexOf(d)>=0?" class='DynarchCalendar-weekend'>":">",L("sdn")[d],"</div></td>")}b.push("</tr></table>");return b.join("")}function a(b){b=b||{},this.args=b=U(b,{animation:!f,cont:null,bottomBar:!0,date:!0,fdow:L("fdow"),min:null,max:null,reverseWheel:!1,selection:[],selectionType:a.SEL_SINGLE,weekNumbers:!1,align:"Bl/ / /T/r",inputField:null,trigger:null,dateFormat:"%Y-%m-%d",fixed:!1,opacity:e?1:3,titleFormat:"%b %Y",showTime:!1,timePos:"right",time:!0,minuteStep:5,noScroll:!1,disabled:bl,checkRange:!1,dateInfo:bl,onChange:bl,onSelect:bl,onTimeChange:bl,onFocus:bl,onBlur:bl}),this.handlers={};var c=this,d=new Date;b.min=S(b.min),b.max=S(b.max),b.date===!0&&(b.date=d),b.time===!0&&(b.time=d.getHours()*100+Math.floor(d.getMinutes()/b.minuteStep)*b.minuteStep),this.date=S(b.date),this.time=b.time,this.fdow=b.fdow,bk("onChange onSelect onTimeChange onFocus onBlur".split(/\s+/),function(a){var d=b[a];d instanceof Array||(d=[d]),c.handlers[a]=d}),this.selection=new a.Selection(b.selection,b.selectionType,G,this);var g=s(this);b.cont&&bm(b.cont).appendChild(g),b.trigger&&this.manageFields(b.trigger,b.inputField,b.dateFormat)}var b=navigator.userAgent,c=/opera/i.test(b),d=/Konqueror|Safari|KHTML/i.test(b),e=/msie/i.test(b)&&!c&&!/mac_powerpc/i.test(b),f=e&&/msie 6/i.test(b),g=/gecko/i.test(b)&&!d&&!c&&!e,h=a.prototype,i=a.I18N={};a.SEL_NONE=0,a.SEL_SINGLE=1,a.SEL_MULTIPLE=2,a.SEL_WEEK=3,a.dateToInt=O,a.intToDate=P,a.printDate=R,a.formatString=K,a.i18n=L,a.LANG=function(a,b,c){i.__=i[a]={name:b,data:c}},a.setup=function(b){return new a(b)},h.moveTo=function(a,b){var c=this;a=S(a);var d=Q(a,c.date,!0),e,f=c.args,g=f.min&&Q(a,f.min),h=f.max&&Q(a,f.max);f.animation||(b=!1),$(g!=null&&g<=1,[c.els.navPrevMonth,c.els.navPrevYear],"DynarchCalendar-navDisabled"),$(h!=null&&h>=-1,[c.els.navNextMonth,c.els.navNextYear],"DynarchCalendar-navDisabled"),g<-1&&(a=f.min,e=1,d=0),h>1&&(a=f.max,e=2,d=0),c.date=a,c.refresh(!!b),c.callHooks("onChange",c,a,b);if(b&&(d!=0||b!=2)){c._bodyAnim&&c._bodyAnim.stop();var i=c.els.body,j=_("div","DynarchCalendar-animBody-"+x[d],i),k=i.firstChild,m=bf(k)||.7,n=e?be.brakes:d==0?be.shake:be.accel_ab2,o=d*d>4,p=o?k.offsetTop:k.offsetLeft,q=j.style,r=o?i.offsetHeight:i.offsetWidth;d<0?r+=p:d>0?r=p-r:(r=Math.round(r/7),e==2&&(r=-r));if(!e&&d!=0){var s=j.cloneNode(!0),t=s.style,u=2*r;s.appendChild(k.cloneNode(!0)),t[o?"marginTop":"marginLeft"]=r+"px",i.appendChild(s)}k.style.visibility="hidden",j.innerHTML=l(c),c._bodyAnim=bd({onUpdate:function(a,b){var f=n(a);if(s)var g=b(f,r,u)+"px";if(e)q[o?"marginTop":"marginLeft"]=b(f,r,0)+"px";else{if(o||d==0)q.marginTop=b(d==0?n(a*a):f,0,r)+"px",d!=0&&(t.marginTop=g);if(!o||d==0)q.marginLeft=b(f,0,r)+"px",d!=0&&(t.marginLeft=g)}c.args.opacity>2&&s&&(bf(s,1-f),bf(j,f))},onStop:function(b){i.innerHTML=l(c,a),c._bodyAnim=null}})}c._lastHoverDate=null;return g>=-1&&h<=1},h.isDisabled=function(a){var b=this.args;return b.min&&Q(a,b.min)<0||b.max&&Q(a,b.max)>0||b.disabled(a)},h.toggleMenu=function(){z(this,!this._menuVisible)},h.refresh=function(a){var b=this.els;a||(b.body.innerHTML=l(this)),b.title.innerHTML=n(this),b.yearInput.value=this.date.getFullYear()},h.redraw=function(){var a=this,b=a.els;a.refresh(),b.dayNames.innerHTML=k(a),b.menu.innerHTML=o(a),b.bottomBar&&(b.bottomBar.innerHTML=q(a)),bc(b.topCont,function(c){var d=r[c.className];d&&(b[d]=c),c.className=="DynarchCalendar-menu-year"?(V(c,a._focusEvents),b.yearInput=c):e&&c.setAttribute("unselectable","on")}),a.setTime(null,!0)},h.setLanguage=function(b){var c=a.setLanguage(b);c&&(this.fdow=c.data.fdow,this.redraw())},a.setLanguage=function(a){var b=i[a];b&&(i.__=b);return b},h.focus=function(){try{this.els[this._menuVisible?"yearInput":"focusLink"].focus()}catch(a){}t.call(this)},h.blur=function(){this.els.focusLink.blur(),this.els.yearInput.blur(),u.call(this)},h.showAt=function(a,b,c){this._showAnim&&this._showAnim.stop(),c=c&&this.args.animation;var d=this.els.topCont,e=this,f=this.els.body.firstChild,g=f.offsetHeight,h=d.style;h.position="absolute",h.left=a+"px",h.top=b+"px",h.zIndex=1e4,h.display="",c&&(f.style.marginTop=-g+"px",this.args.opacity>1&&bf(d,0),this._showAnim=bd({onUpdate:function(a,b){f.style.marginTop=-b(be.accel_b(a),g,0)+"px",e.args.opacity>1&&bf(d,a)},onStop:function(){e.args.opacity>1&&bf(d,""),e._showAnim=null}}))},h.hide=function(){var a=this.els.topCont,b=this,c=this.els.body.firstChild,d=c.offsetHeight,e=bi(a).y;this.args.animation?(this._showAnim&&this._showAnim.stop(),this._showAnim=bd({onUpdate:function(f,g){b.args.opacity>1&&bf(a,1-f),c.style.marginTop=-g(be.accel_b(f),0,d)+"px",a.style.top=g(be.accel_ab(f),e,e-10)+"px"},onStop:function(){a.style.display="none",c.style.marginTop="",b.args.opacity>1&&bf(a,""),b._showAnim=null}})):a.style.display="none",this.inputField=null},h.popup=function(a,b){function h(b){var c={x:i.x,y:i.y};if(!b)return c;/B/.test(b)&&(c.y+=a.offsetHeight),/b/.test(b)&&(c.y+=a.offsetHeight-f.y),/T/.test(b)&&(c.y-=f.y),/l/.test(b)&&(c.x-=f.x-a.offsetWidth),/L/.test(b)&&(c.x-=f.x),/R/.test(b)&&(c.x+=a.offsetWidth),/c/i.test(b)&&(c.x+=(a.offsetWidth-f.x)/2),/m/i.test(b)&&(c.y+=(a.offsetHeight-f.y)/2);return c}a=bm(a),b||(b=this.args.align),b=b.split(/\x2f/);var c=bi(a),d=this.els.topCont,e=d.style,f,g=bj();e.visibility="hidden",e.display="",this.showAt(0,0),document.body.appendChild(d),f={x:d.offsetWidth,y:d.offsetHeight};var i=c;i=h(b[0]),i.y<g.y&&(i.y=c.y,i=h(b[1])),i.x+f.x>g.x+g.w&&(i.x=c.x,i=h(b[2])),i.y+f.y>g.y+g.h&&(i.y=c.y,i=h(b[3])),i.x<g.x&&(i.x=c.x,i=h(b[4])),this.showAt(i.x,i.y,!0),e.visibility="",this.focus()},h.manageFields=function(b,c,d){var e=this;c=bm(c),b=bm(b),/^button$/i.test(b.tagName)&&b.setAttribute("type","button"),V(b,"click",function(){e.inputField=c,e.dateFormat=d;if(e.selection.type==a.SEL_SINGLE){var f,g,h,i;f=/input|textarea/i.test(c.tagName)?c.value:c.innerText||c.textContent,f&&(g=/(^|[^%])%[bBmo]/.exec(d),h=/(^|[^%])%[de]/.exec(d),g&&h&&(i=g.index<h.index),f=Calendar.parseDate(f,i),f&&(e.selection.set(f,!1,!0),e.args.showTime&&(e.setHours(f.getHours()),e.setMinutes(f.getMinutes())),e.moveTo(f)))}e.popup(b)})},h.callHooks=function(a){var b=ba(arguments,1),c=this.handlers[a],d=0;for(;d<c.length;++d)c[d].apply(this,b)},h.addEventListener=function(a,b){this.handlers[a].push(b)},h.removeEventListener=function(a,b){var c=this.handlers[a],d=c.length;while(--d>=0)c[d]===b&&c.splice(d,1)},h.getTime=function(){return this.time},h.setTime=function(a,b){if(this.args.showTime){a=a!=null?a:this.time,this.time=a;var c=this.getHours(),d=this.getMinutes(),e=c<12;this.args.showTime==12&&(c==0&&(c=12),c>12&&(c-=12),this.els.timeAM.innerHTML=L(e?"AM":"PM")),c<10&&(c="0"+c),d<10&&(d="0"+d),this.els.timeHour.innerHTML=c,this.els.timeMinute.innerHTML=d,b||this.callHooks("onTimeChange",this,a)}},h.getHours=function(){return Math.floor(this.time/100)},h.getMinutes=function(){return this.time%100},h.setHours=function(a){a<0&&(a+=24),this.setTime(100*(a%24)+this.time%100)},h.setMinutes=function(a){a<0&&(a+=60),a=Math.floor(a/this.args.minuteStep)*this.args.minuteStep,this.setTime(100*this.getHours()+a%60)},h._getInputYear=function(){var a=parseInt(this.els.yearInput.value,10);isNaN(a)&&(a=this.date.getFullYear());return a},h._showTooltip=function(a){var b="",c,d=this.els.tooltip;a&&(a=P(a),c=this.args.dateInfo(a),c&&c.tooltip&&(b="<div class='DynarchCalendar-tooltipCont'>"+R(a,c.tooltip)+"</div>")),d.innerHTML=b};var j=" align='center' cellspacing='0' cellpadding='0'",r={"DynarchCalendar-topCont":"topCont","DynarchCalendar-focusLink":"focusLink",DynarchCalendar:"main","DynarchCalendar-topBar":"topBar","DynarchCalendar-title":"title","DynarchCalendar-dayNames":"dayNames","DynarchCalendar-body":"body","DynarchCalendar-menu":"menu","DynarchCalendar-menu-year":"yearInput","DynarchCalendar-bottomBar":"bottomBar","DynarchCalendar-tooltip":"tooltip","DynarchCalendar-time-hour":"timeHour","DynarchCalendar-time-minute":"timeMinute","DynarchCalendar-time-am":"timeAM","DynarchCalendar-navBtn DynarchCalendar-prevYear":"navPrevYear","DynarchCalendar-navBtn DynarchCalendar-nextYear":"navNextYear","DynarchCalendar-navBtn DynarchCalendar-prevMonth":"navPrevMonth","DynarchCalendar-navBtn DynarchCalendar-nextMonth":"navNextMonth"},x={"-3":"backYear","-2":"back",0:"now",2:"fwd",3:"fwdYear"},H={37:-1,38:-2,39:1,40:2},I={33:-1,34:1};h._getDateDiv=function(a){var b=null;if(a)try{bc(this.els.body,function(c){if(c.getAttribute("dyc-date")==a)throw b=c})}catch(c){}return b},(a.Selection=function(a,b,c,d){this.type=b,this.sel=a instanceof Array?a:[a],this.onChange=bb(c,d),this.cal=d}).prototype={get:function(){return this.type==a.SEL_SINGLE?this.sel[0]:this.sel},isEmpty:function(){return this.sel.length==0},set:function(b,c,d){var e=this.type==a.SEL_SINGLE;b instanceof Array?(this.sel=b,this.normalize(),d||this.onChange(this)):(b=O(b),e||!this.isSelected(b)?(e?this.sel=[b]:this.sel.splice(this.findInsertPos(b),0,b),this.normalize(),d||this.onChange(this)):c&&this.unselect(b,d))},reset:function(){this.sel=[],this.set.apply(this,arguments)},countDays:function(){var a=0,b=this.sel,c=b.length,d,e,f;while(--c>=0)d=b[c],d instanceof Array&&(e=P(d[0]),f=P(d[1]),a+=Math.round(Math.abs(f.getTime()-e.getTime())/864e5)),++a;return a},unselect:function(a,b){a=O(a);var c=!1;for(var d=this.sel,e=d.length,f;--e>=0;){f=d[e];if(f instanceof Array){if(a>=f[0]&&a<=f[1]){var g=P(a),h=g.getDate();if(a==f[0])g.setDate(h+1),f[0]=O(g),c=!0;else if(a==f[1])g.setDate(h-1),f[1]=O(g),c=!0;else{var i=new Date(g);i.setDate(h+1),g.setDate(h-1),d.splice(e+1,0,[O(i),f[1]]),f[1]=O(g),c=!0}}}else a==f&&(d.splice(e,1),c=!0)}c&&(this.normalize(),b||this.onChange(this))},normalize:function(){this.sel=this.sel.sort(function(a,b){a instanceof Array&&(a=a[0]),b instanceof Array&&(b=b[0]);return a-b});for(var a=this.sel,b=a.length,c,d;--b>=0;){c=a[b];if(c instanceof Array){if(c[0]>c[1]){a.splice(b,1);continue}c[0]==c[1]&&(c=a[b]=c[0])}if(d){var e=d,f=c instanceof Array?c[1]:c;f=P(f),f.setDate(f.getDate()+1),f=O(f);if(f>=e){var g=a[b+1];c instanceof Array&&g instanceof Array?(c[1]=g[1],a.splice(b+1,1)):c instanceof Array?(c[1]=d,a.splice(b+1,1)):g instanceof Array?(g[0]=c,a.splice(b,1)):(a[b]=[c,g],a.splice(b+1,1))}}d=c instanceof Array?c[0]:c}},findInsertPos:function(a){for(var b=this.sel,c=b.length,d;--c>=0;){d=b[c],d instanceof Array&&(d=d[0]);if(d<=a)break}return c+1},clear:function(a){this.sel=[],a||this.onChange(this)},selectRange:function(b,c){b=O(b),c=O(c);if(b>c){var d=b;b=c,c=d}var e=this.cal.args.checkRange;if(!e)return this._do_selectRange(b,c);try{bk((new a.Selection([[b,c]],a.SEL_MULTIPLE,bl)).getDates(),bb(function(a){if(this.isDisabled(a)){e instanceof Function&&e(a,this);throw"OUT"}},this.cal)),this._do_selectRange(b,c)}catch(f){}},_do_selectRange:function(a,b){this.sel.push([a,b]),this.normalize(),this.onChange(this)},isSelected:function(a){for(var b=this.sel.length,c;--b>=0;){c=this.sel[b];if(c instanceof Array&&a>=c[0]&&a<=c[1]||a==c)return!0}return!1},getFirstDate:function(){var a=this.sel[0];a&&a instanceof Array&&(a=a[0]);return a},getLastDate:function(){if(this.sel.length>0){var a=this.sel[this.sel.length-1];a&&a instanceof Array&&(a=a[1]);return a}},print:function(a,b){var c=[],d=0,e,f=this.cal.getHours(),g=this.cal.getMinutes();b||(b=" -> ");while(d<this.sel.length)e=this.sel[d++],e instanceof Array?c.push(R(P(e[0],f,g),a)+b+R(P(e[1],f,g),a)):c.push(R(P(e,f,g),a));return c},getDates:function(a){var b=[],c=0,d,e;while(c<this.sel.length){e=this.sel[c++];if(e instanceof Array){d=P(e[0]),e=e[1];while(O(d)<e)b.push(a?R(d,a):new Date(d)),d.setDate(d.getDate()+1)}else d=P(e);b.push(a?R(d,a):d)}return b}},a.isUnicodeLetter=function(a){return a.toUpperCase()!=a.toLowerCase()},a.parseDate=function(b,c,d){if(!/\S/.test(b))return"";b=b.replace(/^\s+/,"").replace(/\s+$/,""),d=d||new Date;var e=null,f=null,g=null,h=null,i=null,j=null,k=b.match(/([0-9]{1,2}):([0-9]{1,2})(:[0-9]{1,2})?\s*(am|pm)?/i);k&&(h=parseInt(k[1],10),i=parseInt(k[2],10),j=k[3]?parseInt(k[3].substr(1),10):0,b=b.substring(0,k.index)+b.substr(k.index+k[0].length),k[4]&&(k[4].toLowerCase()=="pm"&&h<12?h+=12:k[4].toLowerCase()=="am"&&h>=12&&(h-=12)));var l=function(){function k(a){d.push(a)}function j(){var a="";while(g()&&/[0-9]/.test(g()))a+=f();if(h(g()))return i(a);return parseInt(a,10)}function i(a){while(g()&&h(g()))a+=f();return a}function g(){return b.charAt(c)}function f(){return b.charAt(c++)}var c=0,d=[],e,h=a.isUnicodeLetter;while(c<b.length)e=g(),h(e)?k(i("")):/[0-9]/.test(e)?k(j()):f();return d}(),m=[];for(var n=0;n<l.length;++n){var o=l[n];/^[0-9]{4}$/.test(o)?(e=parseInt(o,10),f==null&&g==null&&c==null&&(c=!0)):/^[0-9]{1,2}$/.test(o)?(o=parseInt(o,10),o<60?o<0||o>12?o>=1&&o<=31&&(g=o):m.push(o):e=o):f==null&&(f=T(o))}m.length<2?m.length==1&&(g==null?g=m.shift():f==null&&(f=m.shift())):c?(f==null&&(f=m.shift()),g==null&&(g=m.shift())):(g==null&&(g=m.shift()),f==null&&(f=m.shift())),e==null&&(e=m.length>0?m.shift():d.getFullYear()),e<30?e+=2e3:e<99&&(e+=1900),f==null&&(f=d.getMonth()+1);return e!=null&&f!=null&&g!=null?new Date(e,f-1,g,h,i,j):null};var be={elastic_b:function(a){return 1-Math.cos(-a*5.5*Math.PI)/Math.pow(2,7*a)},magnetic:function(a){return 1-Math.cos(a*a*a*10.5*Math.PI)/Math.exp(4*a)},accel_b:function(a){a=1-a;return 1-a*a*a*a},accel_a:function(a){return a*a*a},accel_ab:function(a){a=1-a;return 1-Math.sin(a*a*Math.PI/2)},accel_ab2:function(a){return(a/=.5)<1?.5*a*a:-0.5*(--a*(a-2)-1)},brakes:function(a){a=1-a;return 1-Math.sin(a*a*Math.PI)},shake:function(a){return a<.5?-Math.cos(a*11*Math.PI)*a*a:(a=1-a,Math.cos(a*11*Math.PI)*a*a)}},bl=new Function;return a}()
Calendar.isUnicodeLetter = (function(){
        var rx = new RegExp("[\\u0041-\\u005A\\u0061-\\u007A\\u00AA\\u00B5\\u00BA\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02C1\\u02C6-\\u02D1\\u02E0-\\u02E4\\u02EC\\u02EE\\u0370-\\u0374\\u0376\\u0377\\u037A-\\u037D\\u0386\\u0388-\\u038A\\u038C\\u038E-\\u03A1\\u03A3-\\u03F5\\u03F7-\\u0481\\u048A-\\u0523\\u0531-\\u0556\\u0559\\u0561-\\u0587\\u05D0-\\u05EA\\u05F0-\\u05F2\\u0621-\\u064A\\u066E\\u066F\\u0671-\\u06D3\\u06D5\\u06E5\\u06E6\\u06EE\\u06EF\\u06FA-\\u06FC\\u06FF\\u0710\\u0712-\\u072F\\u074D-\\u07A5\\u07B1\\u07CA-\\u07EA\\u07F4\\u07F5\\u07FA\\u0904-\\u0939\\u093D\\u0950\\u0958-\\u0961\\u0971\\u0972\\u097B-\\u097F\\u0985-\\u098C\\u098F\\u0990\\u0993-\\u09A8\\u09AA-\\u09B0\\u09B2\\u09B6-\\u09B9\\u09BD\\u09CE\\u09DC\\u09DD\\u09DF-\\u09E1\\u09F0\\u09F1\\u0A05-\\u0A0A\\u0A0F\\u0A10\\u0A13-\\u0A28\\u0A2A-\\u0A30\\u0A32\\u0A33\\u0A35\\u0A36\\u0A38\\u0A39\\u0A59-\\u0A5C\\u0A5E\\u0A72-\\u0A74\\u0A85-\\u0A8D\\u0A8F-\\u0A91\\u0A93-\\u0AA8\\u0AAA-\\u0AB0\\u0AB2\\u0AB3\\u0AB5-\\u0AB9\\u0ABD\\u0AD0\\u0AE0\\u0AE1\\u0B05-\\u0B0C\\u0B0F\\u0B10\\u0B13-\\u0B28\\u0B2A-\\u0B30\\u0B32\\u0B33\\u0B35-\\u0B39\\u0B3D\\u0B5C\\u0B5D\\u0B5F-\\u0B61\\u0B71\\u0B83\\u0B85-\\u0B8A\\u0B8E-\\u0B90\\u0B92-\\u0B95\\u0B99\\u0B9A\\u0B9C\\u0B9E\\u0B9F\\u0BA3\\u0BA4\\u0BA8-\\u0BAA\\u0BAE-\\u0BB9\\u0BD0\\u0C05-\\u0C0C\\u0C0E-\\u0C10\\u0C12-\\u0C28\\u0C2A-\\u0C33\\u0C35-\\u0C39\\u0C3D\\u0C58\\u0C59\\u0C60\\u0C61\\u0C85-\\u0C8C\\u0C8E-\\u0C90\\u0C92-\\u0CA8\\u0CAA-\\u0CB3\\u0CB5-\\u0CB9\\u0CBD\\u0CDE\\u0CE0\\u0CE1\\u0D05-\\u0D0C\\u0D0E-\\u0D10\\u0D12-\\u0D28\\u0D2A-\\u0D39\\u0D3D\\u0D60\\u0D61\\u0D7A-\\u0D7F\\u0D85-\\u0D96\\u0D9A-\\u0DB1\\u0DB3-\\u0DBB\\u0DBD\\u0DC0-\\u0DC6\\u0E01-\\u0E30\\u0E32\\u0E33\\u0E40-\\u0E46\\u0E81\\u0E82\\u0E84\\u0E87\\u0E88\\u0E8A\\u0E8D\\u0E94-\\u0E97\\u0E99-\\u0E9F\\u0EA1-\\u0EA3\\u0EA5\\u0EA7\\u0EAA\\u0EAB\\u0EAD-\\u0EB0\\u0EB2\\u0EB3\\u0EBD\\u0EC0-\\u0EC4\\u0EC6\\u0EDC\\u0EDD\\u0F00\\u0F40-\\u0F47\\u0F49-\\u0F6C\\u0F88-\\u0F8B\\u1000-\\u102A\\u103F\\u1050-\\u1055\\u105A-\\u105D\\u1061\\u1065\\u1066\\u106E-\\u1070\\u1075-\\u1081\\u108E\\u10A0-\\u10C5\\u10D0-\\u10FA\\u10FC\\u1100-\\u1159\\u115F-\\u11A2\\u11A8-\\u11F9\\u1200-\\u1248\\u124A-\\u124D\\u1250-\\u1256\\u1258\\u125A-\\u125D\\u1260-\\u1288\\u128A-\\u128D\\u1290-\\u12B0\\u12B2-\\u12B5\\u12B8-\\u12BE\\u12C0\\u12C2-\\u12C5\\u12C8-\\u12D6\\u12D8-\\u1310\\u1312-\\u1315\\u1318-\\u135A\\u1380-\\u138F\\u13A0-\\u13F4\\u1401-\\u166C\\u166F-\\u1676\\u1681-\\u169A\\u16A0-\\u16EA\\u1700-\\u170C\\u170E-\\u1711\\u1720-\\u1731\\u1740-\\u1751\\u1760-\\u176C\\u176E-\\u1770\\u1780-\\u17B3\\u17D7\\u17DC\\u1820-\\u1877\\u1880-\\u18A8\\u18AA\\u1900-\\u191C\\u1950-\\u196D\\u1970-\\u1974\\u1980-\\u19A9\\u19C1-\\u19C7\\u1A00-\\u1A16\\u1B05-\\u1B33\\u1B45-\\u1B4B\\u1B83-\\u1BA0\\u1BAE\\u1BAF\\u1C00-\\u1C23\\u1C4D-\\u1C4F\\u1C5A-\\u1C7D\\u1D00-\\u1DBF\\u1E00-\\u1F15\\u1F18-\\u1F1D\\u1F20-\\u1F45\\u1F48-\\u1F4D\\u1F50-\\u1F57\\u1F59\\u1F5B\\u1F5D\\u1F5F-\\u1F7D\\u1F80-\\u1FB4\\u1FB6-\\u1FBC\\u1FBE\\u1FC2-\\u1FC4\\u1FC6-\\u1FCC\\u1FD0-\\u1FD3\\u1FD6-\\u1FDB\\u1FE0-\\u1FEC\\u1FF2-\\u1FF4\\u1FF6-\\u1FFC\\u2071\\u207F\\u2090-\\u2094\\u2102\\u2107\\u210A-\\u2113\\u2115\\u2119-\\u211D\\u2124\\u2126\\u2128\\u212A-\\u212D\\u212F-\\u2139\\u213C-\\u213F\\u2145-\\u2149\\u214E\\u2183\\u2184\\u2C00-\\u2C2E\\u2C30-\\u2C5E\\u2C60-\\u2C6F\\u2C71-\\u2C7D\\u2C80-\\u2CE4\\u2D00-\\u2D25\\u2D30-\\u2D65\\u2D6F\\u2D80-\\u2D96\\u2DA0-\\u2DA6\\u2DA8-\\u2DAE\\u2DB0-\\u2DB6\\u2DB8-\\u2DBE\\u2DC0-\\u2DC6\\u2DC8-\\u2DCE\\u2DD0-\\u2DD6\\u2DD8-\\u2DDE\\u2E2F\\u3005\\u3006\\u3031-\\u3035\\u303B\\u303C\\u3041-\\u3096\\u309D-\\u309F\\u30A1-\\u30FA\\u30FC-\\u30FF\\u3105-\\u312D\\u3131-\\u318E\\u31A0-\\u31B7\\u31F0-\\u31FF\\u3400\\u4DB5\\u4E00\\u9FC3\\uA000-\\uA48C\\uA500-\\uA60C\\uA610-\\uA61F\\uA62A\\uA62B\\uA640-\\uA65F\\uA662-\\uA66E\\uA67F-\\uA697\\uA717-\\uA71F\\uA722-\\uA788\\uA78B\\uA78C\\uA7FB-\\uA801\\uA803-\\uA805\\uA807-\\uA80A\\uA80C-\\uA822\\uA840-\\uA873\\uA882-\\uA8B3\\uA90A-\\uA925\\uA930-\\uA946\\uAA00-\\uAA28\\uAA40-\\uAA42\\uAA44-\\uAA4B\\uAC00\\uD7A3\\uF900-\\uFA2D\\uFA30-\\uFA6A\\uFA70-\\uFAD9\\uFB00-\\uFB06\\uFB13-\\uFB17\\uFB1D\\uFB1F-\\uFB28\\uFB2A-\\uFB36\\uFB38-\\uFB3C\\uFB3E\\uFB40\\uFB41\\uFB43\\uFB44\\uFB46-\\uFBB1\\uFBD3-\\uFD3D\\uFD50-\\uFD8F\\uFD92-\\uFDC7\\uFDF0-\\uFDFB\\uFE70-\\uFE74\\uFE76-\\uFEFC\\uFF21-\\uFF3A\\uFF41-\\uFF5A\\uFF66-\\uFFBE\\uFFC2-\\uFFC7\\uFFCA-\\uFFCF\\uFFD2-\\uFFD7\\uFFDA-\\uFFDC]", "i");
        return function(ch) {
                return rx.test(ch);
        };
})();

//# sourceMappingURL=helpspot.js.map
